@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-editor-product-filters__overlay-icon-size .components-range-control__number .components-input-control__input::-webkit-inner-spin-button,.wc-block-editor-product-filters__overlay-icon-size .components-range-control__number .components-input-control__input::-webkit-outer-spin-button{appearance:none;margin:0}.wc-block-editor-product-filters__overlay-icon-size .components-range-control__number .components-input-control__input{appearance:textfield;width:40px!important}.wc-block-editor-product-filters__overlay-icon-size .components-range-control__number .components-input-control__container:after{color:var(--wp-components-color-accent,var(--wp-admin-theme-color,#3858e9));content:"px";font-size:12px;position:absolute;right:7px;top:6px}.wc-block-product-filters__overlay{width:100%}
