:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.product-details-section__product-link{color:#757575;font-size:12px;display:block;margin-top:8px}.product-details-section__product-link>a{color:inherit;text-decoration:none;font-weight:600}.product-details-section__product-link .components-button.is-link{font-size:12px;text-decoration:none;margin-left:8px}.wp-block-woocommerce-product-name-field .has-error .components-base-control .components-input-control__backdrop{border-color:#d63638}.wp-block-woocommerce-product-name-field .has-error .components-base-control__help{color:#d63638}.wp-block-woocommerce-product-name-field .components-base-control .components-input-control__container .components-input-control__input{font-size:16px;min-height:48px}.wp-block-woocommerce-product-name-field .components-base-control .components-input-control__container .components-input-control__suffix{margin-right:0}
