@font-face { font-family: "Nioicon"; src: url("../../../public/dashboard/assets/fonts/Nioicon.eot"); src: url("../../../public/dashboard/assets/fonts/Nioicon.eot#iefix") format("embedded-opentype"), url("../../../public/dashboard/assets/fonts/Nioicon.ttf") format("truetype"), url("../../../public/dashboard/assets/fonts/Nioicon.woff") format("woff"), url("../../../public/dashboard/assets/fonts/Nioicon.svg#Nioicon") format("svg"); font-weight: normal; font-style: normal; font-display: block; }


.salesking-ni { /* use !important to prevent issues with browser extensions that change fonts */ font-family: "Nioicon" !important; speak: never; font-style: normal; font-weight: normal; font-variant: normal; text-transform: none; line-height: 1; /* Better Font Rendering =========== */ -webkit-font-smoothing: antialiased; -moz-osx-font-smoothing: grayscale; }

.salesking-ni-centos:before { content: ""; }

.salesking-ni-covid:before { content: ""; }

.salesking-ni-fedora:before { content: ""; }

.salesking-ni-hot-fill:before { content: ""; }

.salesking-ni-hot:before { content: ""; }

.salesking-ni-linux-server:before { content: ""; }

.salesking-ni-linux:before { content: ""; }

.salesking-ni-note-add-fill:before { content: ""; }

.salesking-ni-repeat-fill:before { content: ""; }

.salesking-ni-tranx-fill:before { content: ""; }

.salesking-ni-ubuntu:before { content: ""; }

.salesking-ni-virus:before { content: ""; }

.salesking-ni-b-chrome:before { content: ""; }

.salesking-ni-b-edge:before { content: ""; }

.salesking-ni-b-firefox:before { content: ""; }

.salesking-ni-b-ie:before { content: ""; }

.salesking-ni-b-opera:before { content: ""; }

.salesking-ni-b-safari:before { content: ""; }

.salesking-ni-b-si:before { content: ""; }

.salesking-ni-b-uc:before { content: ""; }

.salesking-ni-brick-fill:before { content: ""; }

.salesking-ni-brick:before { content: ""; }

.salesking-ni-col-3s:before { content: ""; }

.salesking-ni-col-4s:before { content: ""; }

.salesking-ni-col-2s:before { content: ""; }

.salesking-ni-comments:before { content: ""; }

.salesking-ni-dot-sq:before { content: ""; }

.salesking-ni-dot:before { content: ""; }

.salesking-ni-footer:before { content: ""; }

.salesking-ni-header:before { content: ""; }

.salesking-ni-heading:before { content: ""; }

.salesking-ni-layout-alt-fill:before { content: ""; }

.salesking-ni-layout-alt:before { content: ""; }

.salesking-ni-layout-fill1:before { content: ""; }

.salesking-ni-layout1:before { content: ""; }

.salesking-ni-list-index-fill:before { content: ""; }

.salesking-ni-list-index:before { content: ""; }

.salesking-ni-list-thumb-alt-fill:before { content: ""; }

.salesking-ni-list-thumb-alt:before { content: ""; }

.salesking-ni-list-thumb-fill:before { content: ""; }

.salesking-ni-list-thumb:before { content: ""; }

.salesking-ni-masonry-fill:before { content: ""; }

.salesking-ni-masonry:before { content: ""; }

.salesking-ni-menu-circled:before { content: ""; }

.salesking-ni-menu-squared:before { content: ""; }

.salesking-ni-notice:before { content: ""; }

.salesking-ni-pen2:before { content: ""; }

.salesking-ni-property-blank:before { content: ""; }

.salesking-ni-propert-blank:before { content: ""; }

.salesking-ni-property-add:before { content: ""; }

.salesking-ni-property-alt:before { content: ""; }

.salesking-ni-property-remove:before { content: ""; }

.salesking-ni-property:before { content: ""; }

.salesking-ni-puzzle-fill:before { content: ""; }

.salesking-ni-puzzle:before { content: ""; }

.salesking-ni-quote-left:before { content: ""; }

.salesking-ni-quote-right:before { content: ""; }

.salesking-ni-row-mix:before { content: ""; }

.salesking-ni-row-view1:before { content: ""; }

.salesking-ni-sidebar-r:before { content: ""; }

.salesking-ni-text2:before { content: ""; }

.salesking-ni-tile-thumb-fill:before { content: ""; }

.salesking-ni-tile-thumb:before { content: ""; }

.salesking-ni-view-col-fill:before { content: ""; }

.salesking-ni-view-col-sq:before { content: ""; }

.salesking-ni-view-col:before { content: ""; }

.salesking-ni-view-col2:before { content: ""; }

.salesking-ni-view-col3:before { content: ""; }

.salesking-ni-view-cols-fill:before { content: ""; }

.salesking-ni-view-cols-sq:before { content: ""; }

.salesking-ni-view-cols:before { content: ""; }

.salesking-ni-view-grid-fill:before { content: ""; }

.salesking-ni-view-grid-sq:before { content: ""; }

.salesking-ni-view-grid-wd:before { content: ""; }

.salesking-ni-view-grid:before { content: ""; }

.salesking-ni-view-grid2-wd:before { content: ""; }

.salesking-ni-view-grid3-wd:before { content: ""; }

.salesking-ni-view-group-fill:before { content: ""; }

.salesking-ni-view-group-wd:before { content: ""; }

.salesking-ni-view-list-fill:before { content: ""; }

.salesking-ni-view-list-sq:before { content: ""; }

.salesking-ni-view-list-wd:before { content: ""; }

.salesking-ni-view-list:before { content: ""; }

.salesking-ni-view-panel-fill:before { content: ""; }

.salesking-ni-view-panel-sq:before { content: ""; }

.salesking-ni-view-panel:before { content: ""; }

.salesking-ni-view-row-fill:before { content: ""; }

.salesking-ni-view-row-sq:before { content: ""; }

.salesking-ni-view-row-wd:before { content: ""; }

.salesking-ni-view-row:before { content: ""; }

.salesking-ni-view-x1:before { content: ""; }

.salesking-ni-view-x2:before { content: ""; }

.salesking-ni-view-x3:before { content: ""; }

.salesking-ni-view-x4:before { content: ""; }

.salesking-ni-view-x5:before { content: ""; }

.salesking-ni-view-x6:before { content: ""; }

.salesking-ni-view-x7:before { content: ""; }

.salesking-ni-dashlite:before { content: ""; }

.salesking-ni-dashlite-circle:before { content: ""; }

.salesking-ni-dashlite-alt:before { content: ""; }

.salesking-ni-master-card:before { content: ""; }

.salesking-ni-paypal:before { content: ""; }

.salesking-ni-visa-alt:before { content: ""; }

.salesking-ni-coin-eur:before { content: ""; }

.salesking-ni-coin-gbp:before { content: ""; }

.salesking-ni-sign-ada-alt:before { content: ""; }

.salesking-ni-sign-bch-alt:before { content: ""; }

.salesking-ni-sign-bgp-alt:before { content: ""; }

.salesking-ni-sign-bnb-alt:before { content: ""; }

.salesking-ni-sign-brl-alt:before { content: ""; }

.salesking-ni-sign-btc-alt:before { content: ""; }

.salesking-ni-sign-cc-alt:before { content: ""; }

.salesking-ni-sign-cc-alt2:before { content: ""; }

.salesking-ni-sign-chf-alt:before { content: ""; }

.salesking-ni-sign-cny-alt:before { content: ""; }

.salesking-ni-sign-czk-alt:before { content: ""; }

.salesking-ni-sign-dash-alt:before { content: ""; }

.salesking-ni-sign-dkk-alt:before { content: ""; }

.salesking-ni-sign-eos-alt:before { content: ""; }

.salesking-ni-sign-eth-alt:before { content: ""; }

.salesking-ni-sign-eur-alt2:before { content: ""; }

.salesking-ni-sign-euro-alt:before { content: ""; }

.salesking-ni-sign-gbp-alt2:before { content: ""; }

.salesking-ni-sign-hkd-alt:before { content: ""; }

.salesking-ni-sign-idr-alt:before { content: ""; }

.salesking-ni-sign-inr-alt:before { content: ""; }

.salesking-ni-sign-jpy-alt:before { content: ""; }

.salesking-ni-sign-kr-alt:before { content: ""; }

.salesking-ni-sign-ltc-alt:before { content: ""; }

.salesking-ni-sign-ltc:before { content: ""; }

.salesking-ni-sign-mxn-alt:before { content: ""; }

.salesking-ni-sign-mxr-alt:before { content: ""; }

.salesking-ni-sign-myr-alt:before { content: ""; }

.salesking-ni-sign-paypal-alt:before { content: ""; }

.salesking-ni-sign-paypal-full:before { content: ""; }

.salesking-ni-sign-php-alt:before { content: ""; }

.salesking-ni-sign-pln-alt:before { content: ""; }

.salesking-ni-sign-rub-alt:before { content: ""; }

.salesking-ni-sign-sek-alt:before { content: ""; }

.salesking-ni-sign-sgd-alt:before { content: ""; }

.salesking-ni-sign-kobo-alt:before { content: ""; }

.salesking-ni-sign-steem-alt:before { content: ""; }

.salesking-ni-sign-steller-alt:before { content: ""; }

.salesking-ni-sign-stripe-fulll:before { content: ""; }

.salesking-ni-sign-thb-alt:before { content: ""; }

.salesking-ni-sign-trx-alt:before { content: ""; }

.salesking-ni-sign-try-alt:before { content: ""; }

.salesking-ni-sign-usd-alt:before { content: ""; }

.salesking-ni-sign-usd-alt2:before { content: ""; }

.salesking-ni-sign-usdc-alt:before { content: ""; }

.salesking-ni-sign-usdt-alt:before { content: ""; }

.salesking-ni-sign-visa-alt:before { content: ""; }

.salesking-ni-sign-vnd-alt:before { content: ""; }

.salesking-ni-sign-waves-alt:before { content: ""; }

.salesking-ni-sign-xem-alt:before { content: ""; }

.salesking-ni-sign-xrp-new-alt:before { content: ""; }

.salesking-ni-sign-xrp-old-alt:before { content: ""; }

.salesking-ni-sign-zcash-alt:before { content: ""; }

.salesking-ni-chevron-left:before { content: ""; }

.salesking-ni-chevron-right:before { content: ""; }

.salesking-ni-chevron-up:before { content: ""; }

.salesking-ni-chevron-down:before { content: ""; }

.salesking-ni-chevron-left-round:before { content: ""; }

.salesking-ni-chevron-right-round:before { content: ""; }

.salesking-ni-chevron-up-round:before { content: ""; }

.salesking-ni-chevron-down-round:before { content: ""; }

.salesking-ni-chevron-left-round-fill:before { content: ""; }

.salesking-ni-chevron-right-round-fill:before { content: ""; }

.salesking-ni-chevron-up-round-fill:before { content: ""; }

.salesking-ni-chevron-down-round-fill:before { content: ""; }

.salesking-ni-chevron-left-c:before { content: ""; }

.salesking-ni-chevron-right-c:before { content: ""; }

.salesking-ni-chevron-up-c:before { content: ""; }

.salesking-ni-chevron-down-c:before { content: ""; }

.salesking-ni-chevron-left-fill-c:before { content: ""; }

.salesking-ni-chevron-right-fill-c:before { content: ""; }

.salesking-ni-chevron-up-fill-c:before { content: ""; }

.salesking-ni-chevron-down-fill-c:before { content: ""; }

.salesking-ni-chevron-left-circle:before { content: ""; }

.salesking-ni-chevron-right-circle:before { content: ""; }

.salesking-ni-chevron-up-circle:before { content: ""; }

.salesking-ni-chevron-down-circle:before { content: ""; }

.salesking-ni-chevron-left-circle-fill:before { content: ""; }

.salesking-ni-chevron-right-circle-fill:before { content: ""; }

.salesking-ni-chevron-up-circle-fill:before { content: ""; }

.salesking-ni-chevron-down-circle-fill:before { content: ""; }

.salesking-ni-caret-left:before { content: ""; }

.salesking-ni-caret-right:before { content: ""; }

.salesking-ni-caret-up:before { content: ""; }

.salesking-ni-caret-down:before { content: ""; }

.salesking-ni-caret-left-fill:before { content: ""; }

.salesking-ni-caret-right-fill:before { content: ""; }

.salesking-ni-caret-up-fill:before { content: ""; }

.salesking-ni-caret-down-fill:before { content: ""; }

.salesking-ni-sort:before { content: ""; }

.salesking-ni-sort-up:before { content: ""; }

.salesking-ni-sort-down:before { content: ""; }

.salesking-ni-sort-fill:before { content: ""; }

.salesking-ni-sort-up-fill:before { content: ""; }

.salesking-ni-sort-down-fill:before { content: ""; }

.salesking-ni-sort-v:before { content: ""; }

.salesking-ni-swap-v:before { content: ""; }

.salesking-ni-swap:before { content: ""; }

.salesking-ni-arrow-left-round:before { content: ""; }

.salesking-ni-arrow-right-round:before { content: ""; }

.salesking-ni-arrow-up-round:before { content: ""; }

.salesking-ni-arrow-down-round:before { content: ""; }

.salesking-ni-arrow-left-round-fill:before { content: ""; }

.salesking-ni-arrow-right-round-fill:before { content: ""; }

.salesking-ni-arrow-up-round-fill:before { content: ""; }

.salesking-ni-arrow-down-round-fill:before { content: ""; }

.salesking-ni-arrow-left-c:before { content: ""; }

.salesking-ni-arrow-right-c:before { content: ""; }

.salesking-ni-arrow-up-c:before { content: ""; }

.salesking-ni-arrow-down-c:before { content: ""; }

.salesking-ni-arrow-left-fill-c:before { content: ""; }

.salesking-ni-arrow-right-fill-c:before { content: ""; }

.salesking-ni-arrow-up-fill-c:before { content: ""; }

.salesking-ni-arrow-down-fill-c:before { content: ""; }

.salesking-ni-arrow-left-circle:before { content: ""; }

.salesking-ni-arrow-right-circle:before { content: ""; }

.salesking-ni-arrow-up-circle:before { content: ""; }

.salesking-ni-arrow-down-circle:before { content: ""; }

.salesking-ni-arrow-left-circle-fill:before { content: ""; }

.salesking-ni-arrow-up-circle-fill:before { content: ""; }

.salesking-ni-arrow-down-circle-fill:before { content: ""; }

.salesking-ni-arrow-right-circle-fill:before { content: ""; }

.salesking-ni-chevrons-left:before { content: ""; }

.salesking-ni-chevrons-right:before { content: ""; }

.salesking-ni-chevrons-up:before { content: ""; }

.salesking-ni-chevrons-down:before { content: ""; }

.salesking-ni-first:before { content: ""; }

.salesking-ni-last:before { content: ""; }

.salesking-ni-back-ios:before { content: ""; }

.salesking-ni-forward-ios:before { content: ""; }

.salesking-ni-upword-ios:before { content: ""; }

.salesking-ni-downward-ios:before { content: ""; }

.salesking-ni-back-alt:before { content: ""; }

.salesking-ni-forward-alt:before { content: ""; }

.salesking-ni-upword-alt:before { content: ""; }

.salesking-ni-downward-alt:before { content: ""; }

.salesking-ni-back-alt-fill:before { content: ""; }

.salesking-ni-forward-alt-fill:before { content: ""; }

.salesking-ni-upword-alt-fill:before { content: ""; }

.salesking-ni-downward-alt-fill:before { content: ""; }

.salesking-ni-arrow-long-left:before { content: ""; }

.salesking-ni-arrow-long-right:before { content: ""; }

.salesking-ni-arrow-long-up:before { content: ""; }

.salesking-ni-arrow-long-down:before { content: ""; }

.salesking-ni-arrow-left:before { content: ""; }

.salesking-ni-arrow-right:before { content: ""; }

.salesking-ni-arrow-up:before { content: ""; }

.salesking-ni-arrow-down:before { content: ""; }

.salesking-ni-arrow-up-left:before { content: ""; }

.salesking-ni-arrow-up-right:before { content: ""; }

.salesking-ni-arrow-down-left:before { content: ""; }

.salesking-ni-arrow-down-right:before { content: ""; }

.salesking-ni-arrow-to-left:before { content: ""; }

.salesking-ni-arrow-to-right:before { content: ""; }

.salesking-ni-arrow-to-up:before { content: ""; }

.salesking-ni-arrow-to-down:before { content: ""; }

.salesking-ni-arrow-from-left:before { content: ""; }

.salesking-ni-arrow-from-right:before { content: ""; }

.salesking-ni-arrow-from-up:before { content: ""; }

.salesking-ni-arrow-from-down:before { content: ""; }

.salesking-ni-curve-down-left:before { content: ""; }

.salesking-ni-curve-up-right:before { content: ""; }

.salesking-ni-curve-up-left:before { content: ""; }

.salesking-ni-curve-down-right:before { content: ""; }

.salesking-ni-curve-left-up:before { content: ""; }

.salesking-ni-curve-right-up:before { content: ""; }

.salesking-ni-curve-left-down:before { content: ""; }

.salesking-ni-curve-right-down:before { content: ""; }

.salesking-ni-back-arrow:before { content: ""; }

.salesking-ni-forward-arrow:before { content: ""; }

.salesking-ni-back-arrow-fill:before { content: ""; }

.salesking-ni-forward-arrow-fill:before { content: ""; }

.salesking-ni-navigate:before { content: ""; }

.salesking-ni-navigate-up:before { content: ""; }

.salesking-ni-navigate-fill:before { content: ""; }

.salesking-ni-navigate-up-fill:before { content: ""; }

.salesking-ni-send:before { content: ""; }

.salesking-ni-send-alt:before { content: ""; }

.salesking-ni-unfold-less:before { content: ""; }

.salesking-ni-unfold-more:before { content: ""; }

.salesking-ni-exchange-v:before { content: ""; }

.salesking-ni-exchange:before { content: ""; }

.salesking-ni-expand:before { content: ""; }

.salesking-ni-shrink:before { content: ""; }

.salesking-ni-focus:before { content: ""; }

.salesking-ni-maximize:before { content: ""; }

.salesking-ni-minimize:before { content: ""; }

.salesking-ni-maximize-alt:before { content: ""; }

.salesking-ni-minimize-alt:before { content: ""; }

.salesking-ni-shuffle:before { content: ""; }

.salesking-ni-cross-sm:before { content: ""; }

.salesking-ni-cross:before { content: ""; }

.salesking-ni-cross-round:before { content: ""; }

.salesking-ni-cross-circle:before { content: ""; }

.salesking-ni-cross-c:before { content: ""; }

.salesking-ni-cross-round-fill:before { content: ""; }

.salesking-ni-cross-circle-fill:before { content: ""; }

.salesking-ni-cross-fill-c:before { content: ""; }

.salesking-ni-na:before { content: ""; }

.salesking-ni-check:before { content: ""; }

.salesking-ni-check-thick:before { content: ""; }

.salesking-ni-done:before { content: ""; }

.salesking-ni-check-round:before { content: ""; }

.salesking-ni-check-circle:before { content: ""; }

.salesking-ni-check-c:before { content: ""; }

.salesking-ni-check-round-fill:before { content: ""; }

.salesking-ni-check-circle-fill:before { content: ""; }

.salesking-ni-check-fill-c:before { content: ""; }

.salesking-ni-check-circle-cut:before { content: ""; }

.salesking-ni-check-round-cut:before { content: ""; }

.salesking-ni-bullet:before { content: ""; }

.salesking-ni-circle:before { content: ""; }

.salesking-ni-square:before { content: ""; }

.salesking-ni-square-c:before { content: ""; }

.salesking-ni-bullet-fill:before { content: ""; }

.salesking-ni-circle-fill:before { content: ""; }

.salesking-ni-square-fill:before { content: ""; }

.salesking-ni-square-fill-c:before { content: ""; }

.salesking-ni-plus-sm:before { content: ""; }

.salesking-ni-minus-sm:before { content: ""; }

.salesking-ni-plus:before { content: ""; }

.salesking-ni-minus:before { content: ""; }

.salesking-ni-plus-round:before { content: ""; }

.salesking-ni-minus-round:before { content: ""; }

.salesking-ni-plus-circle:before { content: ""; }

.salesking-ni-minus-circle:before { content: ""; }

.salesking-ni-plus-c:before { content: ""; }

.salesking-ni-minus-c:before { content: ""; }

.salesking-ni-plus-round-fill:before { content: ""; }

.salesking-ni-plus-circle-fill:before { content: ""; }

.salesking-ni-minus-round-fill:before { content: ""; }

.salesking-ni-minus-circle-fill:before { content: ""; }

.salesking-ni-plus-fill-c:before { content: ""; }

.salesking-ni-minus-fill-c:before { content: ""; }

.salesking-ni-plus-medi:before { content: ""; }

.salesking-ni-plus-medi-fill:before { content: ""; }

.salesking-ni-equal-sm:before { content: ""; }

.salesking-ni-equal:before { content: ""; }

.salesking-ni-calc:before { content: ""; }

.salesking-ni-search:before { content: ""; }

.salesking-ni-zoom-out:before { content: ""; }

.salesking-ni-zoom-in:before { content: ""; }

.salesking-ni-play:before { content: ""; }

.salesking-ni-play-fill:before { content: ""; }

.salesking-ni-play-circle:before { content: ""; }

.salesking-ni-play-circle-fill:before { content: ""; }

.salesking-ni-pause:before { content: ""; }

.salesking-ni-pause-fill:before { content: ""; }

.salesking-ni-pause-circle:before { content: ""; }

.salesking-ni-pause-circle-fill:before { content: ""; }

.salesking-ni-stop:before { content: ""; }

.salesking-ni-stop-fill:before { content: ""; }

.salesking-ni-stop-circle:before { content: ""; }

.salesking-ni-stop-circle-fill:before { content: ""; }

.salesking-ni-rewind:before { content: ""; }

.salesking-ni-forward:before { content: ""; }

.salesking-ni-rewind-fill:before { content: ""; }

.salesking-ni-forward-fill:before { content: ""; }

.salesking-ni-step-back:before { content: ""; }

.salesking-ni-step-forward:before { content: ""; }

.salesking-ni-vol-off:before { content: ""; }

.salesking-ni-vol-no:before { content: ""; }

.salesking-ni-vol-half:before { content: ""; }

.salesking-ni-vol:before { content: ""; }

.salesking-ni-mic:before { content: ""; }

.salesking-ni-mic-off:before { content: ""; }

.salesking-ni-video:before { content: ""; }

.salesking-ni-video-off:before { content: ""; }

.salesking-ni-video-fill:before { content: ""; }

.salesking-ni-loader:before { content: ""; }

.salesking-ni-power:before { content: ""; }

.salesking-ni-signout:before { content: ""; }

.salesking-ni-signin:before { content: ""; }

.salesking-ni-upload:before { content: ""; }

.salesking-ni-download:before { content: ""; }

.salesking-ni-alert-circle:before { content: ""; }

.salesking-ni-alert:before { content: ""; }

.salesking-ni-caution:before { content: ""; }

.salesking-ni-report:before { content: ""; }

.salesking-ni-alert-c:before { content: ""; }

.salesking-ni-alert-circle-fill:before { content: ""; }

.salesking-ni-alert-fill:before { content: ""; }

.salesking-ni-caution-fill:before { content: ""; }

.salesking-ni-report-fill:before { content: ""; }

.salesking-ni-alert-fill-c:before { content: ""; }

.salesking-ni-info-i:before { content: ""; }

.salesking-ni-info:before { content: ""; }

.salesking-ni-info-fill:before { content: ""; }

.salesking-ni-help:before { content: ""; }

.salesking-ni-help-fill:before { content: ""; }

.salesking-ni-archived:before { content: ""; }

.salesking-ni-archive:before { content: ""; }

.salesking-ni-unarchive:before { content: ""; }

.salesking-ni-archived-fill:before { content: ""; }

.salesking-ni-archive-fill:before { content: ""; }

.salesking-ni-unarchive-fill:before { content: ""; }

.salesking-ni-bag:before { content: ""; }

.salesking-ni-bag-fill:before { content: ""; }

.salesking-ni-bell:before { content: ""; }

.salesking-ni-bell-off:before { content: ""; }

.salesking-ni-bell-fill:before { content: ""; }

.salesking-ni-bell-off-fill:before { content: ""; }

.salesking-ni-wifi:before { content: ""; }

.salesking-ni-wifi-off:before { content: ""; }

.salesking-ni-live:before { content: ""; }

.salesking-ni-signal:before { content: ""; }

.salesking-ni-bluetooth:before { content: ""; }

.salesking-ni-blank-alt:before { content: ""; }

.salesking-ni-blank:before { content: ""; }

.salesking-ni-blank-fill:before { content: ""; }

.salesking-ni-blankf-fill:before { content: ""; }

.salesking-ni-block-over:before { content: ""; }

.salesking-ni-book-read:before { content: ""; }

.salesking-ni-book:before { content: ""; }

.salesking-ni-book-fill:before { content: ""; }

.salesking-ni-bulb-fill:before { content: ""; }

.salesking-ni-bulb:before { content: ""; }

.salesking-ni-calendar-alt-fill:before { content: ""; }

.salesking-ni-calendar-alt:before { content: ""; }

.salesking-ni-calendar-booking-fill:before { content: ""; }

.salesking-ni-calendar-booking:before { content: ""; }

.salesking-ni-calendar-check-fill:before { content: ""; }

.salesking-ni-calendar-check:before { content: ""; }

.salesking-ni-calendar-fill:before { content: ""; }

.salesking-ni-calendar:before { content: ""; }

.salesking-ni-calender-date-fill:before { content: ""; }

.salesking-ni-calender-date:before { content: ""; }

.salesking-ni-call:before { content: ""; }

.salesking-ni-call-alt:before { content: ""; }

.salesking-ni-call-alt-fill:before { content: ""; }

.salesking-ni-call-fill:before { content: ""; }

.salesking-ni-camera-fill:before { content: ""; }

.salesking-ni-camera:before { content: ""; }

.salesking-ni-capsule:before { content: ""; }

.salesking-ni-capsule-fill:before { content: ""; }

.salesking-ni-cards:before { content: ""; }

.salesking-ni-cards-fill:before { content: ""; }

.salesking-ni-cart:before { content: ""; }

.salesking-ni-cart-fill:before { content: ""; }

.salesking-ni-cc:before { content: ""; }

.salesking-ni-cc-alt:before { content: ""; }

.salesking-ni-cc-alt2:before { content: ""; }

.salesking-ni-cc-secure:before { content: ""; }

.salesking-ni-cc-new:before { content: ""; }

.salesking-ni-cc-off:before { content: ""; }

.salesking-ni-cc-fill:before { content: ""; }

.salesking-ni-cc-alt-fill:before { content: ""; }

.salesking-ni-cc-alt2-fill:before { content: ""; }

.salesking-ni-cc-secure-fill:before { content: ""; }

.salesking-ni-msg-circle:before { content: ""; }

.salesking-ni-chat-circle:before { content: ""; }

.salesking-ni-msg:before { content: ""; }

.salesking-ni-chat:before { content: ""; }

.salesking-ni-question-alt:before { content: ""; }

.salesking-ni-question:before { content: ""; }

.salesking-ni-msg-circle-fill:before { content: ""; }

.salesking-ni-chat-circle-fill:before { content: ""; }

.salesking-ni-msg-fill:before { content: ""; }

.salesking-ni-chat-fill:before { content: ""; }

.salesking-ni-clip-h:before { content: ""; }

.salesking-ni-clip-v:before { content: ""; }

.salesking-ni-clip:before { content: ""; }

.salesking-ni-link-alt:before { content: ""; }

.salesking-ni-unlink:before { content: ""; }

.salesking-ni-unlink-alt:before { content: ""; }

.salesking-ni-link-h:before { content: ""; }

.salesking-ni-link-v:before { content: ""; }

.salesking-ni-link:before { content: ""; }

.salesking-ni-clipboard:before { content: ""; }

.salesking-ni-clipboad-check:before { content: ""; }

.salesking-ni-clipboard-fill:before { content: ""; }

.salesking-ni-clipboad-check-fill:before { content: ""; }

.salesking-ni-clock:before { content: ""; }

.salesking-ni-clock-fill:before { content: ""; }

.salesking-ni-cloud:before { content: ""; }

.salesking-ni-upload-cloud:before { content: ""; }

.salesking-ni-download-cloud:before { content: ""; }

.salesking-ni-cloud-fill:before { content: ""; }

.salesking-ni-contact:before { content: ""; }

.salesking-ni-contact-fill:before { content: ""; }

.salesking-ni-coffee:before { content: ""; }

.salesking-ni-coffee-fill:before { content: ""; }

.salesking-ni-box-view:before { content: ""; }

.salesking-ni-col-view:before { content: ""; }

.salesking-ni-sidebar:before { content: ""; }

.salesking-ni-layout:before { content: ""; }

.salesking-ni-table-view:before { content: ""; }

.salesking-ni-layout2:before { content: ""; }

.salesking-ni-row-view:before { content: ""; }

.salesking-ni-dot-box:before { content: ""; }

.salesking-ni-layout-fill:before { content: ""; }

.salesking-ni-box-view-fill:before { content: ""; }

.salesking-ni-sidebar-fill:before { content: ""; }

.salesking-ni-table-view-fill:before { content: ""; }

.salesking-ni-dot-box-fill:before { content: ""; }

.salesking-ni-template:before { content: ""; }

.salesking-ni-browser:before { content: ""; }

.salesking-ni-toolbar:before { content: ""; }

.salesking-ni-browser-fill:before { content: ""; }

.salesking-ni-toolbar-fill:before { content: ""; }

.salesking-ni-template-fill:before { content: ""; }

.salesking-ni-box:before { content: ""; }

.salesking-ni-package:before { content: ""; }

.salesking-ni-layer:before { content: ""; }

.salesking-ni-layers:before { content: ""; }

.salesking-ni-panel:before { content: ""; }

.salesking-ni-server:before { content: ""; }

.salesking-ni-layer-fill:before { content: ""; }

.salesking-ni-layers-fill:before { content: ""; }

.salesking-ni-package-fill:before { content: ""; }

.salesking-ni-panel-fill:before { content: ""; }

.salesking-ni-server-fill:before { content: ""; }

.salesking-ni-color-palette:before { content: ""; }

.salesking-ni-color-palette-fill:before { content: ""; }

.salesking-ni-copy:before { content: ""; }

.salesking-ni-copy-fill:before { content: ""; }

.salesking-ni-crop-alt:before { content: ""; }

.salesking-ni-crop:before { content: ""; }

.salesking-ni-target:before { content: ""; }

.salesking-ni-crosshair:before { content: ""; }

.salesking-ni-crosshair-fill:before { content: ""; }

.salesking-ni-db-fill:before { content: ""; }

.salesking-ni-db:before { content: ""; }

.salesking-ni-hard-drive:before { content: ""; }

.salesking-ni-cpu:before { content: ""; }

.salesking-ni-disk:before { content: ""; }

.salesking-ni-pen:before { content: ""; }

.salesking-ni-edit-alt:before { content: ""; }

.salesking-ni-pen-fill:before { content: ""; }

.salesking-ni-edit-alt-fill:before { content: ""; }

.salesking-ni-pen-alt-fill:before { content: ""; }

.salesking-ni-edit-fill:before { content: ""; }

.salesking-ni-edit:before { content: ""; }

.salesking-ni-external-alt:before { content: ""; }

.salesking-ni-external:before { content: ""; }

.salesking-ni-eye-alt:before { content: ""; }

.salesking-ni-eye-alt-fill:before { content: ""; }

.salesking-ni-eye:before { content: ""; }

.salesking-ni-eye-fill:before { content: ""; }

.salesking-ni-eye-off:before { content: ""; }

.salesking-ni-eye-off-fill:before { content: ""; }

.salesking-ni-file:before { content: ""; }

.salesking-ni-file-minus:before { content: ""; }

.salesking-ni-file-plus:before { content: ""; }

.salesking-ni-file-remove:before { content: ""; }

.salesking-ni-file-check:before { content: ""; }

.salesking-ni-file-code:before { content: ""; }

.salesking-ni-file-docs:before { content: ""; }

.salesking-ni-file-img:before { content: ""; }

.salesking-ni-file-doc:before { content: ""; }

.salesking-ni-file-pdf:before { content: ""; }

.salesking-ni-file-xls:before { content: ""; }

.salesking-ni-file-zip:before { content: ""; }

.salesking-ni-file-download:before { content: ""; }

.salesking-ni-file-text:before { content: ""; }

.salesking-ni-files:before { content: ""; }

.salesking-ni-file-fill:before { content: ""; }

.salesking-ni-file-minus-fill:before { content: ""; }

.salesking-ni-file-plus-fill:before { content: ""; }

.salesking-ni-file-remove-fill:before { content: ""; }

.salesking-ni-file-check-fill:before { content: ""; }

.salesking-ni-file-text-fill:before { content: ""; }

.salesking-ni-files-fill:before { content: ""; }

.salesking-ni-folder:before { content: ""; }

.salesking-ni-folder-minus:before { content: ""; }

.salesking-ni-folder-plus:before { content: ""; }

.salesking-ni-folder-remove:before { content: ""; }

.salesking-ni-folder-check:before { content: ""; }

.salesking-ni-folder-list:before { content: ""; }

.salesking-ni-folders:before { content: ""; }

.salesking-ni-folder-fill:before { content: ""; }

.salesking-ni-folders-fill:before { content: ""; }

.salesking-ni-filter-alt:before { content: ""; }

.salesking-ni-sort-line:before { content: ""; }

.salesking-ni-filter-fill:before { content: ""; }

.salesking-ni-filter:before { content: ""; }

.salesking-ni-flag:before { content: ""; }

.salesking-ni-flag-fill:before { content: ""; }

.salesking-ni-notify:before { content: ""; }

.salesking-ni-dashboard:before { content: ""; }

.salesking-ni-dashboard-fill:before { content: ""; }

.salesking-ni-grid-sq:before { content: ""; }

.salesking-ni-grid:before { content: ""; }

.salesking-ni-grid-c:before { content: ""; }

.salesking-ni-grid-alt:before { content: ""; }

.salesking-ni-grid-plus:before { content: ""; }

.salesking-ni-grid-add-c:before { content: ""; }

.salesking-ni-grid-fill:before { content: ""; }

.salesking-ni-grid-fill-c:before { content: ""; }

.salesking-ni-grid-alt-fill:before { content: ""; }

.salesking-ni-grid-plus-fill:before { content: ""; }

.salesking-ni-grid-add-fill-c:before { content: ""; }

.salesking-ni-grid-box-alt-fill:before { content: ""; }

.salesking-ni-grid-box-alt:before { content: ""; }

.salesking-ni-grid-box:before { content: ""; }

.salesking-ni-grid-box-fill:before { content: ""; }

.salesking-ni-grid-line:before { content: ""; }

.salesking-ni-menu-alt-left:before { content: ""; }

.salesking-ni-menu-alt-r:before { content: ""; }

.salesking-ni-menu-alt:before { content: ""; }

.salesking-ni-menu-center:before { content: ""; }

.salesking-ni-menu-left:before { content: ""; }

.salesking-ni-menu-right:before { content: ""; }

.salesking-ni-menu:before { content: ""; }

.salesking-ni-trend-up:before { content: ""; }

.salesking-ni-trend-down:before { content: ""; }

.salesking-ni-line-chart-down:before { content: ""; }

.salesking-ni-line-chart-up:before { content: ""; }

.salesking-ni-line-chart:before { content: ""; }

.salesking-ni-bar-chart:before { content: ""; }

.salesking-ni-bar-chart-alt:before { content: ""; }

.salesking-ni-chart-up:before { content: ""; }

.salesking-ni-chart-down:before { content: ""; }

.salesking-ni-growth:before { content: ""; }

.salesking-ni-growth-fill:before { content: ""; }

.salesking-ni-bar-chart-fill:before { content: ""; }

.salesking-ni-bar-c:before { content: ""; }

.salesking-ni-bar-fill-c:before { content: ""; }

.salesking-ni-pie:before { content: ""; }

.salesking-ni-pie-alt:before { content: ""; }

.salesking-ni-pie-fill:before { content: ""; }

.salesking-ni-activity:before { content: ""; }

.salesking-ni-activity-alt:before { content: ""; }

.salesking-ni-activity-round:before { content: ""; }

.salesking-ni-activity-round-fill:before { content: ""; }

.salesking-ni-meter:before { content: ""; }

.salesking-ni-speed:before { content: ""; }

.salesking-ni-happy:before { content: ""; }

.salesking-ni-sad:before { content: ""; }

.salesking-ni-meh:before { content: ""; }

.salesking-ni-happy-fill:before { content: ""; }

.salesking-ni-happyf-fill:before { content: ""; }

.salesking-ni-sad-fill:before { content: ""; }

.salesking-ni-meh-fill:before { content: ""; }

.salesking-ni-home:before { content: ""; }

.salesking-ni-home-alt:before { content: ""; }

.salesking-ni-home-fill:before { content: ""; }

.salesking-ni-img:before { content: ""; }

.salesking-ni-img-fill:before { content: ""; }

.salesking-ni-inbox:before { content: ""; }

.salesking-ni-inbox-in:before { content: ""; }

.salesking-ni-inbox-out:before { content: ""; }

.salesking-ni-inbox-fill:before { content: ""; }

.salesking-ni-inbox-in-fill:before { content: ""; }

.salesking-ni-inbox-out-fill:before { content: ""; }

.salesking-ni-link-group:before { content: ""; }

.salesking-ni-lock:before { content: ""; }

.salesking-ni-lock-alt:before { content: ""; }

.salesking-ni-lock-fill:before { content: ""; }

.salesking-ni-lock-alt-fill:before { content: ""; }

.salesking-ni-unlock:before { content: ""; }

.salesking-ni-unlock-fill:before { content: ""; }

.salesking-ni-mail:before { content: ""; }

.salesking-ni-emails:before { content: ""; }

.salesking-ni-mail-fill:before { content: ""; }

.salesking-ni-emails-fill:before { content: ""; }

.salesking-ni-map-pin:before { content: ""; }

.salesking-ni-location:before { content: ""; }

.salesking-ni-map:before { content: ""; }

.salesking-ni-map-pin-fill:before { content: ""; }

.salesking-ni-list:before { content: ""; }

.salesking-ni-list-ol:before { content: ""; }

.salesking-ni-align-center:before { content: ""; }

.salesking-ni-align-justify:before { content: ""; }

.salesking-ni-align-left:before { content: ""; }

.salesking-ni-align-right:before { content: ""; }

.salesking-ni-list-check:before { content: ""; }

.salesking-ni-list-round:before { content: ""; }

.salesking-ni-card-view:before { content: ""; }

.salesking-ni-list-fill:before { content: ""; }

.salesking-ni-save:before { content: ""; }

.salesking-ni-save-fill:before { content: ""; }

.salesking-ni-move:before { content: ""; }

.salesking-ni-scissor:before { content: ""; }

.salesking-ni-text:before { content: ""; }

.salesking-ni-text-a:before { content: ""; }

.salesking-ni-bold:before { content: ""; }

.salesking-ni-italic:before { content: ""; }

.salesking-ni-underline:before { content: ""; }

.salesking-ni-percent:before { content: ""; }

.salesking-ni-at:before { content: ""; }

.salesking-ni-hash:before { content: ""; }

.salesking-ni-code:before { content: ""; }

.salesking-ni-code-download:before { content: ""; }

.salesking-ni-terminal:before { content: ""; }

.salesking-ni-cmd:before { content: ""; }

.salesking-ni-sun:before { content: ""; }

.salesking-ni-sun-fill:before { content: ""; }

.salesking-ni-moon-fill:before { content: ""; }

.salesking-ni-moon:before { content: ""; }

.salesking-ni-light:before { content: ""; }

.salesking-ni-light-fill:before { content: ""; }

.salesking-ni-more-v:before { content: ""; }

.salesking-ni-more-h:before { content: ""; }

.salesking-ni-more-h-alt:before { content: ""; }

.salesking-ni-more-v-alt:before { content: ""; }

.salesking-ni-music:before { content: ""; }

.salesking-ni-movie:before { content: ""; }

.salesking-ni-offer:before { content: ""; }

.salesking-ni-offer-fill:before { content: ""; }

.salesking-ni-opt-alt:before { content: ""; }

.salesking-ni-opt:before { content: ""; }

.salesking-ni-opt-dot-alt:before { content: ""; }

.salesking-ni-opt-dot:before { content: ""; }

.salesking-ni-opt-dot-fill:before { content: ""; }

.salesking-ni-opt-alt-fill:before { content: ""; }

.salesking-ni-user-alt:before { content: ""; }

.salesking-ni-user-alt-fill:before { content: ""; }

.salesking-ni-user:before { content: ""; }

.salesking-ni-users:before { content: ""; }

.salesking-ni-user-add:before { content: ""; }

.salesking-ni-user-remove:before { content: ""; }

.salesking-ni-user-check:before { content: ""; }

.salesking-ni-user-cross:before { content: ""; }

.salesking-ni-account-setting:before { content: ""; }

.salesking-ni-account-setting-alt:before { content: ""; }

.salesking-ni-user-list:before { content: ""; }

.salesking-ni-user-fill:before { content: ""; }

.salesking-ni-users-fill:before { content: ""; }

.salesking-ni-user-add-fill:before { content: ""; }

.salesking-ni-user-remove-fill:before { content: ""; }

.salesking-ni-user-check-fill:before { content: ""; }

.salesking-ni-user-cross-fill:before { content: ""; }

.salesking-ni-account-setting-fill:before { content: ""; }

.salesking-ni-user-list-fill:before { content: ""; }

.salesking-ni-user-circle:before { content: ""; }

.salesking-ni-user-circle-fill:before { content: ""; }

.salesking-ni-user-c:before { content: ""; }

.salesking-ni-user-fill-c:before { content: ""; }

.salesking-ni-user-round:before { content: ""; }

.salesking-ni-printer:before { content: ""; }

.salesking-ni-printer-fill:before { content: ""; }

.salesking-ni-laptop:before { content: ""; }

.salesking-ni-monitor:before { content: ""; }

.salesking-ni-tablet:before { content: ""; }

.salesking-ni-mobile:before { content: ""; }

.salesking-ni-undo:before { content: ""; }

.salesking-ni-redo:before { content: ""; }

.salesking-ni-reload-alt:before { content: ""; }

.salesking-ni-reload:before { content: ""; }

.salesking-ni-regen-alt:before { content: ""; }

.salesking-ni-regen:before { content: ""; }

.salesking-ni-invest:before { content: ""; }

.salesking-ni-history:before { content: ""; }

.salesking-ni-histroy:before { content: ""; }

.salesking-ni-update:before { content: ""; }

.salesking-ni-repeat:before { content: ""; }

.salesking-ni-repeat-v:before { content: ""; }

.salesking-ni-tranx:before { content: ""; }

.salesking-ni-reply-all:before { content: ""; }

.salesking-ni-reply:before { content: ""; }

.salesking-ni-reply-fill:before { content: ""; }

.salesking-ni-reply-all-fill:before { content: ""; }

.salesking-ni-notes:before { content: ""; }

.salesking-ni-note-add:before { content: ""; }

.salesking-ni-notes-alt:before { content: ""; }

.salesking-ni-article:before { content: ""; }

.salesking-ni-text-rich:before { content: ""; }

.salesking-ni-todo:before { content: ""; }

.salesking-ni-report-profit:before { content: ""; }

.salesking-ni-reports-alt:before { content: ""; }

.salesking-ni-reports:before { content: ""; }

.salesking-ni-task:before { content: ""; }

.salesking-ni-note-add-c:before { content: ""; }

.salesking-ni-task-c:before { content: ""; }

.salesking-ni-todo-fill:before { content: ""; }

.salesking-ni-note-add-fill-c:before { content: ""; }

.salesking-ni-task-fill-c:before { content: ""; }

.salesking-ni-scan-fill:before { content: ""; }

.salesking-ni-scan:before { content: ""; }

.salesking-ni-qr:before { content: ""; }

.salesking-ni-money:before { content: ""; }

.salesking-ni-coins:before { content: ""; }

.salesking-ni-coin:before { content: ""; }

.salesking-ni-coin-alt:before { content: ""; }

.salesking-ni-coin-alt-fill:before { content: ""; }

.salesking-ni-setting-alt-fill:before { content: ""; }

.salesking-ni-setting-alt:before { content: ""; }

.salesking-ni-setting-fill:before { content: ""; }

.salesking-ni-setting:before { content: ""; }

.salesking-ni-share-alt:before { content: ""; }

.salesking-ni-share-fill:before { content: ""; }

.salesking-ni-share:before { content: ""; }

.salesking-ni-network:before { content: ""; }

.salesking-ni-rss:before { content: ""; }

.salesking-ni-shield:before { content: ""; }

.salesking-ni-shield-star:before { content: ""; }

.salesking-ni-shield-check:before { content: ""; }

.salesking-ni-shield-alert:before { content: ""; }

.salesking-ni-shield-off:before { content: ""; }

.salesking-ni-security:before { content: ""; }

.salesking-ni-policy:before { content: ""; }

.salesking-ni-shield-alert-fill:before { content: ""; }

.salesking-ni-shield-check-fill:before { content: ""; }

.salesking-ni-shield-fill:before { content: ""; }

.salesking-ni-shield-half:before { content: ""; }

.salesking-ni-shield-star-fill:before { content: ""; }

.salesking-ni-policy-fill:before { content: ""; }

.salesking-ni-spark:before { content: ""; }

.salesking-ni-spark-off:before { content: ""; }

.salesking-ni-spark-fill:before { content: ""; }

.salesking-ni-spark-off-fill:before { content: ""; }

.salesking-ni-wallet:before { content: ""; }

.salesking-ni-wallet-alt:before { content: ""; }

.salesking-ni-wallet-in:before { content: ""; }

.salesking-ni-wallet-out:before { content: ""; }

.salesking-ni-wallet-saving:before { content: ""; }

.salesking-ni-wallet-fill:before { content: ""; }

.salesking-ni-star:before { content: ""; }

.salesking-ni-star-half:before { content: ""; }

.salesking-ni-star-half-fill:before { content: ""; }

.salesking-ni-star-fill:before { content: ""; }

.salesking-ni-star-round:before { content: ""; }

.salesking-ni-heart:before { content: ""; }

.salesking-ni-heart-fill:before { content: ""; }

.salesking-ni-swap-alt-fill:before { content: ""; }

.salesking-ni-swap-alt:before { content: ""; }

.salesking-ni-thumbs-down:before { content: ""; }

.salesking-ni-thumbs-up:before { content: ""; }

.salesking-ni-tag:before { content: ""; }

.salesking-ni-tag-alt:before { content: ""; }

.salesking-ni-tags:before { content: ""; }

.salesking-ni-tag-fill:before { content: ""; }

.salesking-ni-tag-alt-fill:before { content: ""; }

.salesking-ni-tags-fill:before { content: ""; }

.salesking-ni-bookmark:before { content: ""; }

.salesking-ni-bookmark-fill:before { content: ""; }

.salesking-ni-label:before { content: ""; }

.salesking-ni-label-fill:before { content: ""; }

.salesking-ni-priority:before { content: ""; }

.salesking-ni-piority:before { content: ""; }

.salesking-ni-priority-fill:before { content: ""; }

.salesking-ni-piority-fill:before { content: ""; }

.salesking-ni-label-alt:before { content: ""; }

.salesking-ni-label-alt-fill:before { content: ""; }

.salesking-ni-ticket-alt:before { content: ""; }

.salesking-ni-ticket:before { content: ""; }

.salesking-ni-ticket-minus:before { content: ""; }

.salesking-ni-ticket-plus:before { content: ""; }

.salesking-ni-ticket-alt-fill:before { content: ""; }

.salesking-ni-ticket-fill:before { content: ""; }

.salesking-ni-ticket-minus-fill:before { content: ""; }

.salesking-ni-ticket-plus-fill:before { content: ""; }

.salesking-ni-toggle-off:before { content: ""; }

.salesking-ni-toggle-on:before { content: ""; }

.salesking-ni-trash-alt:before { content: ""; }

.salesking-ni-trash-empty:before { content: ""; }

.salesking-ni-trash:before { content: ""; }

.salesking-ni-trash-fill:before { content: ""; }

.salesking-ni-trash-empty-fill:before { content: ""; }

.salesking-ni-delete-fill:before { content: ""; }

.salesking-ni-delete:before { content: ""; }

.salesking-ni-alarm-alt:before { content: ""; }

.salesking-ni-alarm:before { content: ""; }

.salesking-ni-bugs:before { content: ""; }

.salesking-ni-building:before { content: ""; }

.salesking-ni-building-fill:before { content: ""; }

.salesking-ni-headphone:before { content: ""; }

.salesking-ni-headphone-fill:before { content: ""; }

.salesking-ni-aperture:before { content: ""; }

.salesking-ni-help-alt:before { content: ""; }

.salesking-ni-award:before { content: ""; }

.salesking-ni-briefcase:before { content: ""; }

.salesking-ni-gift:before { content: ""; }

.salesking-ni-globe:before { content: ""; }

.salesking-ni-umbrela:before { content: ""; }

.salesking-ni-truck:before { content: ""; }

.salesking-ni-sign-usd:before { content: ""; }

.salesking-ni-sign-dollar:before { content: ""; }

.salesking-ni-sign-mxn:before { content: ""; }

.salesking-ni-sign-sgd:before { content: ""; }

.salesking-ni-sign-euro:before { content: ""; }

.salesking-ni-sign-eur:before { content: ""; }

.salesking-ni-sign-gbp:before { content: ""; }

.salesking-ni-sign-pound:before { content: ""; }

.salesking-ni-sign-thb:before { content: ""; }

.salesking-ni-sign-inr:before { content: ""; }

.salesking-ni-sign-jpy:before { content: ""; }

.salesking-ni-sign-yen:before { content: ""; }

.salesking-ni-sign-cny:before { content: ""; }

.salesking-ni-sign-kobo:before { content: ""; }

.salesking-ni-sign-chf:before { content: ""; }

.salesking-ni-sign-vnd:before { content: ""; }

.salesking-ni-sign-php:before { content: ""; }

.salesking-ni-sign-brl:before { content: ""; }

.salesking-ni-sign-idr:before { content: ""; }

.salesking-ni-sign-czk:before { content: ""; }

.salesking-ni-sign-hkd:before { content: ""; }

.salesking-ni-sign-kr:before { content: ""; }

.salesking-ni-sign-dkk:before { content: ""; }

.salesking-ni-sign-nok:before { content: ""; }

.salesking-ni-sign-sek:before { content: ""; }

.salesking-ni-sign-rub:before { content: ""; }

.salesking-ni-sign-myr:before { content: ""; }

.salesking-ni-sign-pln:before { content: ""; }

.salesking-ni-sign-try:before { content: ""; }

.salesking-ni-sign-waves:before { content: ""; }

.salesking-ni-waves:before { content: ""; }

.salesking-ni-sign-trx:before { content: ""; }

.salesking-ni-tron:before { content: ""; }

.salesking-ni-sign-xem:before { content: ""; }

.salesking-ni-nem:before { content: ""; }

.salesking-ni-sign-mxr:before { content: ""; }

.salesking-ni-monero:before { content: ""; }

.salesking-ni-sign-usdc:before { content: ""; }

.salesking-ni-sign-steller:before { content: ""; }

.salesking-ni-sign-steem:before { content: ""; }

.salesking-ni-sign-usdt:before { content: ""; }

.salesking-ni-tether:before { content: ""; }

.salesking-ni-sign-btc:before { content: ""; }

.salesking-ni-bitcoin:before { content: ""; }

.salesking-ni-sign-bch:before { content: ""; }

.salesking-ni-bitcoin-cash:before { content: ""; }

.salesking-ni-sign-bnb:before { content: ""; }

.salesking-ni-binance:before { content: ""; }

.salesking-ni-sign-ada:before { content: ""; }

.salesking-ni-sign-zcash:before { content: ""; }

.salesking-ni-sign-eth:before { content: ""; }

.salesking-ni-ethereum:before { content: ""; }

.salesking-ni-sign-dash:before { content: ""; }

.salesking-ni-dash:before { content: ""; }

.salesking-ni-sign-xrp-old:before { content: ""; }

.salesking-ni-ripple-old:before { content: ""; }

.salesking-ni-sign-eos:before { content: ""; }

.salesking-ni-eos:before { content: ""; }

.salesking-ni-sign-xrp:before { content: ""; }

.salesking-ni-ripple:before { content: ""; }

.salesking-ni-american-express:before { content: ""; }

.salesking-ni-jcb:before { content: ""; }

.salesking-ni-cc-jcb:before { content: ""; }

.salesking-ni-mc:before { content: ""; }

.salesking-ni-cc-mc:before { content: ""; }

.salesking-ni-discover:before { content: ""; }

.salesking-ni-cc-discover:before { content: ""; }

.salesking-ni-visa:before { content: ""; }

.salesking-ni-cc-visa:before { content: ""; }

.salesking-ni-cc-paypal:before { content: ""; }

.salesking-ni-cc-stripe:before { content: ""; }

.salesking-ni-amazon-pay:before { content: ""; }

.salesking-ni-amazon-pay-fill:before { content: ""; }

.salesking-ni-google-pay:before { content: ""; }

.salesking-ni-google-pay-fill:before { content: ""; }

.salesking-ni-apple-pay:before { content: ""; }

.salesking-ni-apple-pay-fill:before { content: ""; }

.salesking-ni-angular:before { content: ""; }

.salesking-ni-react:before { content: ""; }

.salesking-ni-laravel:before { content: ""; }

.salesking-ni-html5:before { content: ""; }

.salesking-ni-css3-fill:before { content: ""; }

.salesking-ni-css3:before { content: ""; }

.salesking-ni-js:before { content: ""; }

.salesking-ni-php:before { content: ""; }

.salesking-ni-python:before { content: ""; }

.salesking-ni-bootstrap:before { content: ""; }

.salesking-ni-ebay:before { content: ""; }

.salesking-ni-google-wallet:before { content: ""; }

.salesking-ni-google-drive:before { content: ""; }

.salesking-ni-google-play-store:before { content: ""; }

.salesking-ni-android:before { content: ""; }

.salesking-ni-blogger-fill:before { content: ""; }

.salesking-ni-blogger:before { content: ""; }

.salesking-ni-hangout:before { content: ""; }

.salesking-ni-apple-store:before { content: ""; }

.salesking-ni-apple-store-ios:before { content: ""; }

.salesking-ni-stripe:before { content: ""; }

.salesking-ni-apple:before { content: ""; }

.salesking-ni-microsoft:before { content: ""; }

.salesking-ni-windows:before { content: ""; }

.salesking-ni-amazon:before { content: ""; }

.salesking-ni-paypal-alt:before { content: ""; }

.salesking-ni-airbnb:before { content: ""; }

.salesking-ni-adobe:before { content: ""; }

.salesking-ni-mailchimp:before { content: ""; }

.salesking-ni-dropbox:before { content: ""; }

.salesking-ni-digital-ocean:before { content: ""; }

.salesking-ni-slack:before { content: ""; }

.salesking-ni-slack-hash:before { content: ""; }

.salesking-ni-stack-overflow:before { content: ""; }

.salesking-ni-soundcloud:before { content: ""; }

.salesking-ni-blackberry:before { content: ""; }

.salesking-ni-spotify:before { content: ""; }

.salesking-ni-kickstarter:before { content: ""; }

.salesking-ni-houzz:before { content: ""; }

.salesking-ni-vine:before { content: ""; }

.salesking-ni-yelp:before { content: ""; }

.salesking-ni-yoast:before { content: ""; }

.salesking-ni-envato:before { content: ""; }

.salesking-ni-wordpress:before { content: ""; }

.salesking-ni-wp:before { content: ""; }

.salesking-ni-wordpress-fill:before { content: ""; }

.salesking-ni-elementor:before { content: ""; }

.salesking-ni-joomla:before { content: ""; }

.salesking-ni-megento:before { content: ""; }

.salesking-ni-git:before { content: ""; }

.salesking-ni-github:before { content: ""; }

.salesking-ni-github-round:before { content: ""; }

.salesking-ni-github-circle:before { content: ""; }

.salesking-ni-dribbble:before { content: ""; }

.salesking-ni-dribbble-round:before { content: ""; }

.salesking-ni-behance:before { content: ""; }

.salesking-ni-behance-fill:before { content: ""; }

.salesking-ni-flickr:before { content: ""; }

.salesking-ni-flickr-round:before { content: ""; }

.salesking-ni-medium:before { content: ""; }

.salesking-ni-medium-round:before { content: ""; }

.salesking-ni-reddit:before { content: ""; }

.salesking-ni-reddit-round:before { content: ""; }

.salesking-ni-reddit-circle:before { content: ""; }

.salesking-ni-google:before { content: ""; }

.salesking-ni-facebook-f:before { content: ""; }

.salesking-ni-facebook-fill:before { content: ""; }

.salesking-ni-facebook-circle:before { content: ""; }

.salesking-ni-instagram:before { content: ""; }

.salesking-ni-instagram-round:before { content: ""; }

.salesking-ni-linkedin:before { content: ""; }

.salesking-ni-linkedin-round:before { content: ""; }

.salesking-ni-twitter:before { content: ""; }

.salesking-ni-twitter-round:before { content: ""; }

.salesking-ni-pinterest:before { content: ""; }

.salesking-ni-pinterest-round:before { content: ""; }

.salesking-ni-pinterest-circle:before { content: ""; }

.salesking-ni-tumblr:before { content: ""; }

.salesking-ni-tumblr-round:before { content: ""; }

.salesking-ni-skype:before { content: ""; }

.salesking-ni-viber:before { content: ""; }

.salesking-ni-whatsapp:before { content: ""; }

.salesking-ni-whatsapp-round:before { content: ""; }

.salesking-ni-snapchat:before { content: ""; }

.salesking-ni-snapchat-fill:before { content: ""; }

.salesking-ni-telegram:before { content: ""; }

.salesking-ni-telegram-circle:before { content: ""; }

.salesking-ni-youtube-line:before { content: ""; }

.salesking-ni-youtube:before { content: ""; }

.salesking-ni-youtube-fill:before { content: ""; }

.salesking-ni-youtube-round:before { content: ""; }

.salesking-ni-vimeo:before { content: ""; }

.salesking-ni-vimeo-fill:before { content: ""; }


.salesking-btn, .dual-listbox .dual-listbox__button { text-decoration:none;display: inline-block; font-family: "DM Sans", sans-serif; font-weight: 700; color: #526484; text-align: center; vertical-align: middle; user-select: none; background-color: transparent; border: 1px solid transparent; padding: 0.4375rem 1.125rem; font-size: 0.8125rem; line-height: 1.25rem; border-radius: 4px; transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out; }

@media (prefers-reduced-motion: reduce) { .salesking-btn, .dual-listbox .dual-listbox__button { transition: none; } }

.salesking-btn:hover, .dual-listbox .dual-listbox__button:hover { color: #526484; text-decoration: none; }

.salesking-btn:focus, .dual-listbox .dual-listbox__button:focus, .salesking-btn.focus, .dual-listbox .focus.dual-listbox__button { outline: 0; box-shadow: 0 0 0 3px rgba(133, 79, 255, 0.1); }

.salesking-btn.disabled, .dual-listbox .disabled.dual-listbox__button, .salesking-btn:disabled, .dual-listbox .dual-listbox__button:disabled { opacity: 0.5; }

.salesking-btn:not(:disabled):not(.disabled), .dual-listbox .dual-listbox__button:not(:disabled):not(.disabled) { cursor: pointer; }

a.salesking-btn.disabled, .dual-listbox a.disabled.dual-listbox__button, fieldset:disabled a.salesking-btn, fieldset:disabled .dual-listbox a.dual-listbox__button, .dual-listbox fieldset:disabled a.dual-listbox__button { pointer-events: none; }

.salesking-btn-primary { color: #fff; background-color: #854fff; border-color: #854fff; }

.salesking-btn-primary:hover { color: #fff; background-color: #6a29ff; border-color: #621cff; }

.salesking-btn-primary:focus, .salesking-btn-primary.focus { color: #fff; background-color: #6a29ff; border-color: #621cff; box-shadow: 0 0 0 0.2rem rgba(151, 105, 255, 0.5); }

.salesking-btn-primary.disabled, .salesking-btn-primary:disabled { color: #fff; background-color: #854fff; border-color: #854fff; }

.salesking-btn-primary:not(:disabled):not(.disabled):active, .salesking-btn-primary:not(:disabled):not(.disabled).active, .show > .salesking-btn-primary.dropdown-toggle { color: #fff; background-color: #621cff; border-color: #590fff; }

.salesking-btn-primary:not(:disabled):not(.disabled):active:focus, .salesking-btn-primary:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-primary.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(151, 105, 255, 0.5); }

.salesking-btn-secondary { color: #fff; background-color: #364a63; border-color: #364a63; }

.salesking-btn-secondary:hover { color: #fff; background-color: #29384a; border-color: #243142; }

.salesking-btn-secondary:focus, .salesking-btn-secondary.focus { color: #fff; background-color: #29384a; border-color: #243142; box-shadow: 0 0 0 0.2rem rgba(84, 101, 122, 0.5); }

.salesking-btn-secondary.disabled, .salesking-btn-secondary:disabled { color: #fff; background-color: #364a63; border-color: #364a63; }

.salesking-btn-secondary:not(:disabled):not(.disabled):active, .salesking-btn-secondary:not(:disabled):not(.disabled).active, .show > .salesking-btn-secondary.dropdown-toggle { color: #fff; background-color: #243142; border-color: #202b3a; }

.salesking-btn-secondary:not(:disabled):not(.disabled):active:focus, .salesking-btn-secondary:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-secondary.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(84, 101, 122, 0.5); }

.salesking-btn-success { color: #fff; background-color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-success:hover { color: #fff; background-color: #19be92; border-color: #18b389; }

.salesking-btn-success:focus, .salesking-btn-success.focus { color: #fff; background-color: #19be92; border-color: #18b389; box-shadow: 0 0 0 0.2rem rgba(64, 229, 184, 0.5); }

.salesking-btn-success.disabled, .salesking-btn-success:disabled { color: #fff; background-color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-success:not(:disabled):not(.disabled):active, .salesking-btn-success:not(:disabled):not(.disabled).active, .show > .salesking-btn-success.dropdown-toggle { color: #fff; background-color: #18b389; border-color: #16a881; }

.salesking-btn-success:not(:disabled):not(.disabled):active:focus, .salesking-btn-success:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-success.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(64, 229, 184, 0.5); }

.salesking-btn-info { color: #fff; background-color: #09c2de; border-color: #09c2de; }

.salesking-btn-info:hover { color: #fff; background-color: #08a2b9; border-color: #0797ad; }

.salesking-btn-info:focus, .salesking-btn-info.focus { color: #fff; background-color: #08a2b9; border-color: #0797ad; box-shadow: 0 0 0 0.2rem rgba(46, 203, 227, 0.5); }

.salesking-btn-info.disabled, .salesking-btn-info:disabled { color: #fff; background-color: #09c2de; border-color: #09c2de; }

.salesking-btn-info:not(:disabled):not(.disabled):active, .salesking-btn-info:not(:disabled):not(.disabled).active, .show > .salesking-btn-info.dropdown-toggle { color: #fff; background-color: #0797ad; border-color: #078ca1; }

.salesking-btn-info:not(:disabled):not(.disabled):active:focus, .salesking-btn-info:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-info.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(46, 203, 227, 0.5); }

.salesking-btn-warning { color: #fff; background-color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-warning:hover { color: #fff; background-color: #d2a20a; border-color: #c69909; }

.salesking-btn-warning:focus, .salesking-btn-warning.focus { color: #fff; background-color: #d2a20a; border-color: #c69909; box-shadow: 0 0 0 0.2rem rgba(246, 199, 50, 0.5); }

.salesking-btn-warning.disabled, .salesking-btn-warning:disabled { color: #fff; background-color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-warning:not(:disabled):not(.disabled):active, .salesking-btn-warning:not(:disabled):not(.disabled).active, .show > .salesking-btn-warning.dropdown-toggle { color: #fff; background-color: #c69909; border-color: #ba8f08; }

.salesking-btn-warning:not(:disabled):not(.disabled):active:focus, .salesking-btn-warning:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-warning.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(246, 199, 50, 0.5); }

.salesking-btn-danger { color: #fff; background-color: #e85347; border-color: #e85347; }

.salesking-btn-danger:hover { color: #fff; background-color: #e43325; border-color: #e02b1c; }

.salesking-btn-danger:focus, .salesking-btn-danger.focus { color: #fff; background-color: #e43325; border-color: #e02b1c; box-shadow: 0 0 0 0.2rem rgba(235, 109, 99, 0.5); }

.salesking-btn-danger.disabled, .salesking-btn-danger:disabled { color: #fff; background-color: #e85347; border-color: #e85347; }

.salesking-btn-danger:not(:disabled):not(.disabled):active, .salesking-btn-danger:not(:disabled):not(.disabled).active, .show > .salesking-btn-danger.dropdown-toggle { color: #fff; background-color: #e02b1c; border-color: #d5281b; }

.salesking-btn-danger:not(:disabled):not(.disabled):active:focus, .salesking-btn-danger:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-danger.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(235, 109, 99, 0.5); }

.salesking-btn-dark { color: #fff; background-color: #1c2b46; border-color: #1c2b46; }

.salesking-btn-dark:hover { color: #fff; background-color: #111a2b; border-color: #0d1522; }

.salesking-btn-dark:focus, .salesking-btn-dark.focus { color: #fff; background-color: #111a2b; border-color: #0d1522; box-shadow: 0 0 0 0.2rem rgba(62, 75, 98, 0.5); }

.salesking-btn-dark.disabled, .salesking-btn-dark:disabled { color: #fff; background-color: #1c2b46; border-color: #1c2b46; }

.salesking-btn-dark:not(:disabled):not(.disabled):active, .salesking-btn-dark:not(:disabled):not(.disabled).active, .show > .salesking-btn-dark.dropdown-toggle { color: #fff; background-color: #0d1522; border-color: #0a0f18; }

.salesking-btn-dark:not(:disabled):not(.disabled):active:focus, .salesking-btn-dark:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-dark.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(62, 75, 98, 0.5); }

.salesking-btn-light-blue { color: #fff; background-color: #96b9d6; border-color: #96b9d6; }

.salesking-btn-light-blue:hover { color: #fff; background-color: #67a4d6; border-color: #67a4d6; }

.salesking-btn-gray { color: #fff; background-color: #8091a7; border-color: #8091a7; }

.salesking-btn-gray:hover { color: #fff; background-color: #697d97; border-color: #647790; }

.salesking-btn-gray:focus, .salesking-btn-gray.focus { color: #fff; background-color: #697d97; border-color: #647790; box-shadow: 0 0 0 0.2rem rgba(147, 162, 180, 0.5); }

.salesking-btn-gray.disabled, .salesking-btn-gray:disabled { color: #fff; background-color: #8091a7; border-color: #8091a7; }

.salesking-btn-gray:not(:disabled):not(.disabled):active, .salesking-btn-gray:not(:disabled):not(.disabled).active, .show > .salesking-btn-gray.dropdown-toggle { color: #fff; background-color: #647790; border-color: #5f7189; }

.salesking-btn-gray:not(:disabled):not(.disabled):active:focus, .salesking-btn-gray:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-gray.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(147, 162, 180, 0.5); }

.salesking-btn-light, .dual-listbox .dual-listbox__button { color: #101924; background-color: #e5e9f2; border-color: #e5e9f2; }

.salesking-btn-light:hover, .dual-listbox .dual-listbox__button:hover { color: #101924; background-color: #ccd3e5; border-color: #c3cce1; }

.salesking-btn-light:focus, .dual-listbox .dual-listbox__button:focus, .salesking-btn-light.focus, .dual-listbox .focus.dual-listbox__button { color: #101924; background-color: #ccd3e5; border-color: #c3cce1; box-shadow: 0 0 0 0.2rem rgba(197, 202, 211, 0.5); }

.salesking-btn-light.disabled, .dual-listbox .disabled.dual-listbox__button, .salesking-btn-light:disabled, .dual-listbox .dual-listbox__button:disabled { color: #101924; background-color: #e5e9f2; border-color: #e5e9f2; }

.salesking-btn-light:not(:disabled):not(.disabled):active, .dual-listbox .dual-listbox__button:not(:disabled):not(.disabled):active, .salesking-btn-light:not(:disabled):not(.disabled).active, .dual-listbox .dual-listbox__button:not(:disabled):not(.disabled).active, .show > .salesking-btn-light.dropdown-toggle, .dual-listbox .show > .dropdown-toggle.dual-listbox__button { color: #101924; background-color: #c3cce1; border-color: #bbc5dd; }

.salesking-btn-light:not(:disabled):not(.disabled):active:focus, .dual-listbox .dual-listbox__button:not(:disabled):not(.disabled):active:focus, .salesking-btn-light:not(:disabled):not(.disabled).active:focus, .dual-listbox .dual-listbox__button:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-light.dropdown-toggle:focus, .dual-listbox .show > .dropdown-toggle.dual-listbox__button:focus { box-shadow: 0 0 0 0.2rem rgba(197, 202, 211, 0.5); }

.salesking-btn-lighter { color: #101924; background-color: #f5f6fa; border-color: #f5f6fa; }

.salesking-btn-lighter:hover { color: #101924; background-color: #dcdfed; border-color: #d3d7e9; }

.salesking-btn-lighter:focus, .salesking-btn-lighter.focus { color: #101924; background-color: #dcdfed; border-color: #d3d7e9; box-shadow: 0 0 0 0.2rem rgba(211, 213, 218, 0.5); }

.salesking-btn-lighter.disabled, .salesking-btn-lighter:disabled { color: #101924; background-color: #f5f6fa; border-color: #f5f6fa; }

.salesking-btn-lighter:not(:disabled):not(.disabled):active, .salesking-btn-lighter:not(:disabled):not(.disabled).active, .show > .salesking-btn-lighter.dropdown-toggle { color: #101924; background-color: #d3d7e9; border-color: #cbd0e5; }

.salesking-btn-lighter:not(:disabled):not(.disabled):active:focus, .salesking-btn-lighter:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-lighter.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(211, 213, 218, 0.5); }

.salesking-btn-outline-primary { color: #854fff; border-color: #854fff; }

.salesking-btn-outline-primary:hover { color: #fff; background-color: #854fff; border-color: #854fff; }

.salesking-btn-outline-primary:focus, .salesking-btn-outline-primary.focus { box-shadow: 0 0 0 0.2rem rgba(133, 79, 255, 0.5); }

.salesking-btn-outline-primary.disabled, .salesking-btn-outline-primary:disabled { color: #854fff; background-color: transparent; }

.salesking-btn-outline-primary:not(:disabled):not(.disabled):active, .salesking-btn-outline-primary:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-primary.dropdown-toggle { color: #fff; background-color: #854fff; border-color: #854fff; }

.salesking-btn-outline-primary:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-primary:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-primary.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(133, 79, 255, 0.5); }

.salesking-btn-outline-secondary { color: #364a63; border-color: #364a63; }

.salesking-btn-outline-secondary:hover { color: #fff; background-color: #364a63; border-color: #364a63; }

.salesking-btn-outline-secondary:focus, .salesking-btn-outline-secondary.focus { box-shadow: 0 0 0 0.2rem rgba(54, 74, 99, 0.5); }

.salesking-btn-outline-secondary.disabled, .salesking-btn-outline-secondary:disabled { color: #364a63; background-color: transparent; }

.salesking-btn-outline-secondary:not(:disabled):not(.disabled):active, .salesking-btn-outline-secondary:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-secondary.dropdown-toggle { color: #fff; background-color: #364a63; border-color: #364a63; }

.salesking-btn-outline-secondary:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-secondary:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-secondary.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(54, 74, 99, 0.5); }

.salesking-btn-outline-success { color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-outline-success:hover { color: #fff; background-color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-outline-success:focus, .salesking-btn-outline-success.focus { box-shadow: 0 0 0 0.2rem rgba(30, 224, 172, 0.5); }

.salesking-btn-outline-success.disabled, .salesking-btn-outline-success:disabled { color: #1ee0ac; background-color: transparent; }

.salesking-btn-outline-success:not(:disabled):not(.disabled):active, .salesking-btn-outline-success:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-success.dropdown-toggle { color: #fff; background-color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-outline-success:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-success:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-success.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(30, 224, 172, 0.5); }

.salesking-btn-outline-info { color: #09c2de; border-color: #09c2de; }

.salesking-btn-outline-info:hover { color: #fff; background-color: #09c2de; border-color: #09c2de; }

.salesking-btn-outline-info:focus, .salesking-btn-outline-info.focus { box-shadow: 0 0 0 0.2rem rgba(9, 194, 222, 0.5); }

.salesking-btn-outline-info.disabled, .salesking-btn-outline-info:disabled { color: #09c2de; background-color: transparent; }

.salesking-btn-outline-info:not(:disabled):not(.disabled):active, .salesking-btn-outline-info:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-info.dropdown-toggle { color: #fff; background-color: #09c2de; border-color: #09c2de; }

.salesking-btn-outline-info:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-info:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-info.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(9, 194, 222, 0.5); }

.salesking-btn-outline-warning { color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-outline-warning:hover { color: #fff; background-color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-outline-warning:focus, .salesking-btn-outline-warning.focus { box-shadow: 0 0 0 0.2rem rgba(244, 189, 14, 0.5); }

.salesking-btn-outline-warning.disabled, .salesking-btn-outline-warning:disabled { color: #f4bd0e; background-color: transparent; }

.salesking-btn-outline-warning:not(:disabled):not(.disabled):active, .salesking-btn-outline-warning:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-warning.dropdown-toggle { color: #fff; background-color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-outline-warning:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-warning:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-warning.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(244, 189, 14, 0.5); }

.salesking-btn-outline-danger { color: #e85347; border-color: #e85347; }

.salesking-btn-outline-danger:hover { color: #fff; background-color: #e85347; border-color: #e85347; }

.salesking-btn-outline-danger:focus, .salesking-btn-outline-danger.focus { box-shadow: 0 0 0 0.2rem rgba(232, 83, 71, 0.5); }

.salesking-btn-outline-danger.disabled, .salesking-btn-outline-danger:disabled { color: #e85347; background-color: transparent; }

.salesking-btn-outline-danger:not(:disabled):not(.disabled):active, .salesking-btn-outline-danger:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-danger.dropdown-toggle { color: #fff; background-color: #e85347; border-color: #e85347; }

.salesking-btn-outline-danger:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-danger:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-danger.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(232, 83, 71, 0.5); }

.salesking-btn-outline-dark { color: #1c2b46; border-color: #1c2b46; }

.salesking-btn-outline-dark:hover { color: #fff; background-color: #1c2b46; border-color: #1c2b46; }

.salesking-btn-outline-dark:focus, .salesking-btn-outline-dark.focus { box-shadow: 0 0 0 0.2rem rgba(28, 43, 70, 0.5); }

.salesking-btn-outline-dark.disabled, .salesking-btn-outline-dark:disabled { color: #1c2b46; background-color: transparent; }

.salesking-btn-outline-dark:not(:disabled):not(.disabled):active, .salesking-btn-outline-dark:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-dark.dropdown-toggle { color: #fff; background-color: #1c2b46; border-color: #1c2b46; }

.salesking-btn-outline-dark:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-dark:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-dark.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(28, 43, 70, 0.5); }

.salesking-btn-outline-gray { color: #8091a7; border-color: #8091a7; }

.salesking-btn-outline-gray:hover { color: #fff; background-color: #8091a7; border-color: #8091a7; }

.salesking-btn-outline-gray:focus, .salesking-btn-outline-gray.focus { box-shadow: 0 0 0 0.2rem rgba(128, 145, 167, 0.5); }

.salesking-btn-outline-gray.disabled, .salesking-btn-outline-gray:disabled { color: #8091a7; background-color: transparent; }

.salesking-btn-outline-gray:not(:disabled):not(.disabled):active, .salesking-btn-outline-gray:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-gray.dropdown-toggle { color: #fff; background-color: #8091a7; border-color: #8091a7; }

.salesking-btn-outline-gray:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-gray:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-gray.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(128, 145, 167, 0.5); }

.salesking-btn-outline-light { color: #e5e9f2; border-color: #e5e9f2; }

.salesking-btn-outline-light:hover { color: #101924; background-color: #e5e9f2; border-color: #e5e9f2; }

.salesking-btn-outline-light:focus, .salesking-btn-outline-light.focus { box-shadow: 0 0 0 0.2rem rgba(229, 233, 242, 0.5); }

.salesking-btn-outline-light.disabled, .salesking-btn-outline-light:disabled { color: #e5e9f2; background-color: transparent; }

.salesking-btn-outline-light:not(:disabled):not(.disabled):active, .salesking-btn-outline-light:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-light.dropdown-toggle { color: #101924; background-color: #e5e9f2; border-color: #e5e9f2; }

.salesking-btn-outline-light:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-light:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-light.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(229, 233, 242, 0.5); }

.salesking-btn-outline-lighter { color: #f5f6fa; border-color: #f5f6fa; }

.salesking-btn-outline-lighter:hover { color: #101924; background-color: #f5f6fa; border-color: #f5f6fa; }

.salesking-btn-outline-lighter:focus, .salesking-btn-outline-lighter.focus { box-shadow: 0 0 0 0.2rem rgba(245, 246, 250, 0.5); }

.salesking-btn-outline-lighter.disabled, .salesking-btn-outline-lighter:disabled { color: #f5f6fa; background-color: transparent; }

.salesking-btn-outline-lighter:not(:disabled):not(.disabled):active, .salesking-btn-outline-lighter:not(:disabled):not(.disabled).active, .show > .salesking-btn-outline-lighter.dropdown-toggle { color: #101924; background-color: #f5f6fa; border-color: #f5f6fa; }

.salesking-btn-outline-lighter:not(:disabled):not(.disabled):active:focus, .salesking-btn-outline-lighter:not(:disabled):not(.disabled).active:focus, .show > .salesking-btn-outline-lighter.dropdown-toggle:focus { box-shadow: 0 0 0 0.2rem rgba(245, 246, 250, 0.5); }

.salesking-btn-link { font-weight: 400; color: #9d72ff; text-decoration: none; }

.salesking-btn-link:hover { color: #7a3fff; text-decoration: underline; }

.salesking-btn-link:focus, .salesking-btn-link.focus { text-decoration: underline; }

.salesking-btn-link:disabled, .salesking-btn-link.disabled { color: #f5f6fa; pointer-events: none; }

.salesking-btn-lg, .salesking-btn-group-lg > .salesking-btn, .dual-listbox .salesking-btn-group-lg > .dual-listbox__button { padding: 0.6875rem 1.5rem; font-size: 0.9375rem; line-height: 1.25rem; border-radius: 5px; }

.salesking-btn-sm, .salesking-btn-group-sm > .salesking-btn, .dual-listbox .salesking-btn-group-sm > .dual-listbox__button { padding: 0.25rem 0.75rem; font-size: 0.75rem; line-height: 1.25rem; border-radius: 3px; }

.salesking-btn-block { display: block; width: 100%; }

.salesking-btn-block + .salesking-btn-block { margin-top: 0.5rem; }

input[type="submit"].salesking-btn-block, input[type="reset"].salesking-btn-block, input[type="button"].salesking-btn-block { width: 100%; }


.salesking-btn-group, .salesking-btn-group-vertical { position: relative; display: inline-flex; vertical-align: middle; }

.salesking-btn-group > .salesking-btn, .dual-listbox .salesking-btn-group > .dual-listbox__button, .salesking-btn-group-vertical > .salesking-btn, .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button { position: relative; flex: 1 1 auto; }

.salesking-btn-group > .salesking-btn:hover, .dual-listbox .salesking-btn-group > .dual-listbox__button:hover, .salesking-btn-group-vertical > .salesking-btn:hover, .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button:hover { z-index: 1; }

.salesking-btn-group > .salesking-btn:focus, .dual-listbox .salesking-btn-group > .dual-listbox__button:focus, .salesking-btn-group > .salesking-btn:active, .dual-listbox .salesking-btn-group > .dual-listbox__button:active, .salesking-btn-group > .salesking-btn.active, .dual-listbox .salesking-btn-group > .active.dual-listbox__button, .salesking-btn-group-vertical > .salesking-btn:focus, .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button:focus, .salesking-btn-group-vertical > .salesking-btn:active, .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button:active, .salesking-btn-group-vertical > .salesking-btn.active, .dual-listbox .salesking-btn-group-vertical > .active.dual-listbox__button { z-index: 1; }

.salesking-btn-toolbar { display: flex; flex-wrap: wrap; justify-content: flex-start; }

.salesking-btn-toolbar .input-group { width: auto; }

.salesking-btn-group > .salesking-btn:not(:first-child), .dual-listbox .salesking-btn-group > .dual-listbox__button:not(:first-child), .salesking-btn-group > .salesking-btn-group:not(:first-child) { margin-left: -1px; }

.salesking-btn-group > .salesking-btn:not(:last-child):not(.dropdown-toggle), .dual-listbox .salesking-btn-group > .dual-listbox__button:not(:last-child):not(.dropdown-toggle), .salesking-btn-group > .salesking-btn-group:not(:last-child) > .salesking-btn, .dual-listbox .salesking-btn-group > .salesking-btn-group:not(:last-child) > .dual-listbox__button { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.salesking-btn-group > .salesking-btn:not(:first-child), .dual-listbox .salesking-btn-group > .dual-listbox__button:not(:first-child), .salesking-btn-group > .salesking-btn-group:not(:first-child) > .salesking-btn, .dual-listbox .salesking-btn-group > .salesking-btn-group:not(:first-child) > .dual-listbox__button { border-top-left-radius: 0; border-bottom-left-radius: 0; }


.salesking-btn-sm + .dropdown-toggle-split, .salesking-btn-group-sm > .salesking-btn + .dropdown-toggle-split, .dual-listbox .salesking-btn-group-sm > .dual-listbox__button + .dropdown-toggle-split { padding-right: 0.5625rem; padding-left: 0.5625rem; }

.salesking-btn-lg + .dropdown-toggle-split, .salesking-btn-group-lg > .salesking-btn + .dropdown-toggle-split, .dual-listbox .salesking-btn-group-lg > .dual-listbox__button + .dropdown-toggle-split { padding-right: 1.125rem; padding-left: 1.125rem; }

.salesking-btn-group-vertical { flex-direction: column; align-items: flex-start; justify-content: center; }

.salesking-btn-group-vertical > .salesking-btn, .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button, .salesking-btn-group-vertical > .salesking-btn-group { width: 100%; }

.salesking-btn-group-vertical > .salesking-btn:not(:first-child), .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button:not(:first-child), .salesking-btn-group-vertical > .salesking-btn-group:not(:first-child) { margin-top: -1px; }

.salesking-btn-group-vertical > .salesking-btn:not(:last-child):not(.dropdown-toggle), .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button:not(:last-child):not(.dropdown-toggle), .salesking-btn-group-vertical > .salesking-btn-group:not(:last-child) > .salesking-btn, .dual-listbox .salesking-btn-group-vertical > .salesking-btn-group:not(:last-child) > .dual-listbox__button { border-bottom-right-radius: 0; border-bottom-left-radius: 0; }

.salesking-btn-group-vertical > .salesking-btn:not(:first-child), .dual-listbox .salesking-btn-group-vertical > .dual-listbox__button:not(:first-child), .salesking-btn-group-vertical > .salesking-btn-group:not(:first-child) > .salesking-btn, .dual-listbox .salesking-btn-group-vertical > .salesking-btn-group:not(:first-child) > .dual-listbox__button { border-top-left-radius: 0; border-top-right-radius: 0; }

.salesking-btn-group-toggle > .salesking-btn, .dual-listbox .salesking-btn-group-toggle > .dual-listbox__button, .salesking-btn-group-toggle > .salesking-btn-group > .salesking-btn, .dual-listbox .salesking-btn-group-toggle > .salesking-btn-group > .dual-listbox__button { margin-bottom: 0; }

.salesking-btn-group-toggle > .salesking-btn input[type="radio"], .dual-listbox .salesking-btn-group-toggle > .dual-listbox__button input[type="radio"], .salesking-btn-group-toggle > .salesking-btn input[type="checkbox"], .dual-listbox .salesking-btn-group-toggle > .dual-listbox__button input[type="checkbox"], .salesking-btn-group-toggle > .salesking-btn-group > .salesking-btn input[type="radio"], .dual-listbox .salesking-btn-group-toggle > .salesking-btn-group > .dual-listbox__button input[type="radio"], .salesking-btn-group-toggle > .salesking-btn-group > .salesking-btn input[type="checkbox"], .dual-listbox .salesking-btn-group-toggle > .salesking-btn-group > .dual-listbox__button input[type="checkbox"] { position: absolute; clip: rect(0, 0, 0, 0); pointer-events: none; }


.salesking-btn, .dual-listbox .dual-listbox__button { position: relative; letter-spacing: 0.02em; display: inline-flex; align-items: center; }

.salesking-btn-xl { padding: 0.6875rem 1.5rem; font-size: 0.9375rem; line-height: 1.25rem; border-radius: 5px; }

.salesking-btn-xs { padding: 0.125rem 0.5rem; font-size: 0.6875rem; line-height: 1rem; border-radius: 3px; }

.salesking-btn .icon, .dual-listbox .dual-listbox__button .icon { font-size: 1.4em; line-height: inherit; }

.salesking-btn > span, .dual-listbox .dual-listbox__button > span { display: inline-block; white-space: nowrap; }

.salesking-btn > span:only-child, .dual-listbox .dual-listbox__button > span:only-child { width: 100%; }

.salesking-btn .icon + span, .dual-listbox .dual-listbox__button .icon + span, .salesking-btn span + .icon, .dual-listbox .dual-listbox__button span + .icon { padding-left: 8px; }

.salesking-btn .dd-indc, .dual-listbox .dual-listbox__button .dd-indc { transform: translateX(-8px); }

.salesking-btn span + .dd-indc, .dual-listbox .dual-listbox__button span + .dd-indc { transform: translateX(8px); }

.salesking-btn-lg .icon + span, .salesking-btn-group-lg > .salesking-btn .icon + span, .dual-listbox .salesking-btn-group-lg > .dual-listbox__button .icon + span, .salesking-btn-lg span + .icon, .salesking-btn-group-lg > .salesking-btn span + .icon, .dual-listbox .salesking-btn-group-lg > .dual-listbox__button span + .icon { padding-left: 12px; }

.salesking-btn-round { border-radius: 2.125rem; }

.salesking-btn-block { justify-content: center; }

.salesking-btn-ucap, .salesking-btn.ucap, .dual-listbox .ucap.dual-listbox__button { text-transform: uppercase; font-size: 12px; letter-spacing: 0.05em; }

.salesking-btn-icon:not([class*="btn-icon-break"]) { padding-left: 0; padding-right: 0; }

.salesking-btn-icon .icon { width: 2.125rem; }

.salesking-btn-icon.salesking-btn-xl .icon { width: 2.625rem; }

.salesking-btn-icon.salesking-btn-lg .icon, .salesking-btn-group-lg > .salesking-btn-icon.salesking-btn .icon, .dual-listbox .salesking-btn-group-lg > .salesking-btn-icon.dual-listbox__button .icon { width: 2.625rem; }

.salesking-btn-icon.salesking-btn-sm .icon, .salesking-btn-group-sm > .salesking-btn-icon.salesking-btn .icon, .dual-listbox .salesking-btn-group-sm > .salesking-btn-icon.dual-listbox__button .icon { width: 1.75rem; }

.salesking-btn-icon.salesking-btn-xs .icon { width: 1.25rem; font-size: 1.1em; }

.salesking-btn-icon .dot { top: .35rem; position: absolute; right: .35rem; transform: translate(50%, -50%); }

.salesking-btn-icon .badge { top: .25rem; position: absolute; right: .25rem; transform: translate(50%, -50%); }

.salesking-btn-icon .badge-circle { border-radius: 50%; height: 1.125rem; width: 1.125rem; padding: 0; font-weight: 700; font-size: 11px; text-align: center; justify-content: center; }

.salesking-btn-mw { min-width: 120px; justify-content: center; }

.salesking-btn-wrap { flex-direction: column; align-items: center; flex-grow: 0; }

.salesking-btn-extext { font-size: 12px; font-weight: 500; text-align: center; margin-top: 0.25rem; color: #8094ae; }

.salesking-btn-wider { display: flex; }

.salesking-btn-wider .icon + span, .salesking-btn-wider span + .icon { margin-left: auto; }

.salesking-btn-auto { min-width: auto; }

.salesking-btn-pd-auto { padding-left: 0.25rem; padding-right: 0.25rem; }

.salesking-btn .spinner-border, .dual-listbox .dual-listbox__button .spinner-border, .salesking-btn .spinner-grow, .dual-listbox .dual-listbox__button .spinner-grow { margin: .125rem; }

.salesking-btn .spinner-border + span, .dual-listbox .dual-listbox__button .spinner-border + span, .salesking-btn .spinner-grow + span, .dual-listbox .dual-listbox__button .spinner-grow + span { margin-left: 0.25rem; }

.salesking-btn-indc { width: 100%; }

.salesking-btn-indc .icon { font-size: 1.43em; }

.salesking-btn-indc .indc { opacity: .6; margin-left: -8px; margin-right: auto; }

.salesking-btn-indc span + .indc { margin-left: auto; margin-right: -8px; }

@media (min-width: 768px) { .salesking-btn-xl { padding: 0.625rem 2rem; font-size: 1.125rem; line-height: 2rem; border-radius: 5px; }
  .salesking-btn-xl.salesking-btn-round { border-radius: 3.25rem; }
  .salesking-btn-icon.salesking-btn-xl .icon { width: 3.25rem; } }

.salesking-btn-trigger { position: relative; z-index: 1; color: #526484; }

.salesking-btn-trigger:focus { box-shadow: none; }

.salesking-btn-trigger:before { position: absolute; z-index: -1; height: 20px; width: 20px; top: 50%; left: 50%; transform: translate(-50%, -50%); transform-origin: 50% 50%; content: ''; background-color: #e5e9f2; border-radius: 50%; opacity: 0; transition: all .3s; }

.is-dark .salesking-btn-trigger:before { background-color: #26164b; }

.show > .salesking-btn-trigger:before { opacity: 1; height: 120%; width: 120%; }

.salesking-btn-trigger:hover:before, .salesking-btn-trigger:focus:before, .salesking-btn-trigger.active:not(.revarse):before { opacity: 1; height: 120%; width: 120%; }

.salesking-btn-trigger.active:hover:before { background-color: #dbdfea; }

a:hover .salesking-btn-trigger:before { opacity: 1; height: 120%; width: 120%; }

.salesking-btn-dim.salesking-btn-outline-primary { color: #854fff; background-color: #f2ecff; border-color: #ceb9ff; }

.salesking-btn-dim.salesking-btn-outline-primary:not(:disabled):not(.disabled):hover { color: #fff; background-color: #854fff; border-color: #854fff; }

.salesking-btn-white.salesking-btn-outline-primary:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-primary:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #854fff; background: #f2ecff; }

.salesking-btn-dim.salesking-btn-outline-success { color: #1ee0ac; background-color: #e6fcf6; border-color: #a5f3de; }

.salesking-btn-dim.salesking-btn-outline-success:not(:disabled):not(.disabled):hover { color: #fff; background-color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-white.salesking-btn-outline-success:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-success:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #1ee0ac; background: #e6fcf6; }

.salesking-btn-dim.salesking-btn-outline-warning { color: #f4bd0e; background-color: #fef8e4; border-color: #fbe59f; }

.salesking-btn-dim.salesking-btn-outline-warning:not(:disabled):not(.disabled):hover { color: #fff; background-color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-white.salesking-btn-outline-warning:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-warning:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #f4bd0e; background: #fef8e4; }

.salesking-btn-dim.salesking-btn-outline-info { color: #09c2de; background-color: #e4f8fb; border-color: #9de7f2; }

.salesking-btn-dim.salesking-btn-outline-info:not(:disabled):not(.disabled):hover { color: #fff; background-color: #09c2de; border-color: #09c2de; }

.salesking-btn-white.salesking-btn-outline-info:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-info:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #09c2de; background: #e4f8fb; }

.salesking-btn-dim.salesking-btn-outline-danger { color: #e85347; background-color: #fceceb; border-color: #f6bab5; }

.salesking-btn-dim.salesking-btn-outline-danger:not(:disabled):not(.disabled):hover { color: #fff; background-color: #e85347; border-color: #e85347; }

.salesking-btn-white.salesking-btn-outline-danger:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-danger:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #e85347; background: #fceceb; }

.salesking-btn-dim.salesking-btn-outline-secondary { color: #364a63; background-color: #e9ebee; border-color: #b9c0c8; }

.salesking-btn-dim.salesking-btn-outline-secondary:not(:disabled):not(.disabled):hover { color: #fff; background-color: #364a63; border-color: #364a63; }

.salesking-btn-white.salesking-btn-outline-secondary:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-secondary:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #364a63; background: #e9ebee; }

.salesking-btn-dim.salesking-btn-outline-gray { color: #3c4d62; background-color: #f1f3f5; border-color: #d3d9e0; }

.salesking-btn-dim.salesking-btn-outline-gray:not(:disabled):not(.disabled):hover { color: #fff; background-color: #3c4d62; border-color: #3c4d62; }

.salesking-btn-white.salesking-btn-outline-gray:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-gray:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #3c4d62; background: #f1f3f5; }

.salesking-btn-dim.salesking-btn-outline-dark { color: #1f2b3a; background-color: #e6e8e9; border-color: #b1b5ba; }

.salesking-btn-dim.salesking-btn-outline-dark:not(:disabled):not(.disabled):hover { color: #fff; background-color: #1f2b3a; border-color: #1f2b3a; }

.salesking-btn-white.salesking-btn-outline-dark:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-dark:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #1f2b3a; background: #e6e8e9; }

.salesking-btn-dim.salesking-btn-outline-light { color: #526484; background-color: #f5f6fa; border-color: #dbdfea; }

.salesking-btn-dim.salesking-btn-outline-light:not(:disabled):not(.disabled):hover { color: #fff; background-color: #526484; border-color: #526484; }

.salesking-btn-white.salesking-btn-outline-light:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover, .salesking-btn-trans.salesking-btn-outline-light:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #526484; background: #f5f6fa; }

.salesking-btn-dim.salesking-btn-primary { color: #854fff; background-color: #f2ecff; border-color: transparent; }

.salesking-btn-dim.salesking-btn-primary:not(:disabled):not(.disabled):hover { color: #fff; background-color: #854fff; border-color: #854fff; }

.salesking-btn-dim.salesking-btn-secondary { color: #364a63; background-color: #e9ebee; border-color: transparent; }

.salesking-btn-dim.salesking-btn-secondary:not(:disabled):not(.disabled):hover { color: #fff; background-color: #364a63; border-color: #364a63; }

.salesking-btn-dim.salesking-btn-success { color: #1ee0ac; background-color: #e6fcf6; border-color: transparent; }

.salesking-btn-dim.salesking-btn-success:not(:disabled):not(.disabled):hover { color: #fff; background-color: #1ee0ac; border-color: #1ee0ac; }

.salesking-btn-dim.salesking-btn-warning { color: #f4bd0e; background-color: #fef8e4; border-color: transparent; }

.salesking-btn-dim.salesking-btn-warning:not(:disabled):not(.disabled):hover { color: #fff; background-color: #f4bd0e; border-color: #f4bd0e; }

.salesking-btn-dim.salesking-btn-info { color: #09c2de; background-color: #e4f8fb; border-color: transparent; }

.salesking-btn-dim.salesking-btn-info:not(:disabled):not(.disabled):hover { color: #fff; background-color: #09c2de; border-color: #09c2de; }

.salesking-btn-dim.salesking-btn-danger { color: #e85347; background-color: #fceceb; border-color: transparent; }

.salesking-btn-dim.salesking-btn-danger:not(:disabled):not(.disabled):hover { color: #fff; background-color: #e85347; border-color: #e85347; }

.salesking-btn-dim.salesking-btn-gray { color: #3c4d62; background-color: #eaebee; border-color: transparent; }

.salesking-btn-dim.salesking-btn-gray:not(:disabled):not(.disabled):hover { color: #fff; background-color: #3c4d62; border-color: #3c4d62; }

.salesking-btn-dim.salesking-btn-dark { color: #1f2b3a; background-color: #e6e8e9; border-color: transparent; }

.salesking-btn-dim.salesking-btn-dark:not(:disabled):not(.disabled):hover { color: #fff; background-color: #1f2b3a; border-color: #1f2b3a; }

.salesking-btn-dim.salesking-btn-light, .dual-listbox .salesking-btn-dim.dual-listbox__button { color: #8091a7; background-color: #f1f3f5; border-color: transparent; }

.salesking-btn-dim.salesking-btn-light:not(:disabled):not(.disabled):hover, .dual-listbox .salesking-btn-dim.dual-listbox__button:not(:disabled):not(.disabled):hover { color: #fff; background-color: #8091a7; border-color: #8091a7; }

.salesking-btn-dim.salesking-btn-lighter { color: #b7c2d0; background-color: #f7f8fa; border-color: transparent; }

.salesking-btn-dim.salesking-btn-lighter:not(:disabled):not(.disabled):hover { color: #101924; background-color: #b7c2d0; border-color: #b7c2d0; }

.salesking-btn-trans.salesking-btn, .dual-listbox .salesking-btn-trans.dual-listbox__button { background-color: transparent; border-color: transparent; }

.salesking-btn-outline-light { border-color: #dbdfea; }

.salesking-btn-outline-lighter { border-color: #e5e9f2; }

.salesking-btn-outline-light, .salesking-btn-outline-lighter { color: #526484; }

.salesking-btn-white, .salesking-btn-white.salesking-btn-dim { background: #fff; }

.salesking-btn-white.salesking-btn-outline-light:not(.salesking-btn-dim):not(:disabled):not(.disabled):hover { color: #fff; background: #526484; border-color: #526484; }

.salesking-btn-toolbar-sep { border-right: 1px solid #e5e9f2; margin-left: .75rem; margin-right: .75rem; }

.card-tools .salesking-btn-toolbar-sep { padding: 0 !important; margin-left: .5rem; margin-right: .5rem; }

.salesking-btn-group.is-tags .salesking-btn-xs:first-child { padding-left: 0.25rem; padding-right: 0.25rem; }

.salesking-btn-group.is-tags .salesking-btn-xs:last-child { margin-left: 0; }

.salesking-btn-group.is-tags .salesking-btn-xs .icon { width: 1rem; }

.salesking-btn-group.is-tags .salesking-btn-dim:not(:disabled):not(.disabled):hover { border-color: transparent; }


.salesking-bg-blue { background-color: #559bfb !important; }

.salesking-text-blue { color: #559bfb !important; }

.salesking-bg-azure { background-color: #1676fb !important; }

.salesking-text-azure { color: #1676fb !important; }

.salesking-bg-indigo { background-color: #2c3782 !important; }

.salesking-text-indigo { color: #2c3782 !important; }

.salesking-bg-purple { background-color: #816bff !important; }

.salesking-text-purple { color: #816bff !important; }

.salesking-bg-pink { background-color: #ff63a5 !important; }

.salesking-text-pink { color: #ff63a5 !important; }

.salesking-bg-orange { background-color: #ffa353 !important; }

.salesking-text-orange { color: #ffa353 !important; }

.salesking-bg-teal { background-color: #20c997 !important; }

.salesking-text-teal { color: #20c997 !important; }

.salesking-bg-blue-dim { background-color: #e9f2fe !important; }

.salesking-text-blue-dim { color: #e9f2fe !important; }

.salesking-bg-azure-dim { background-color: #e1edfe !important; }

.salesking-text-azure-dim { color: #e1edfe !important; }

.salesking-bg-indigo-dim { background-color: #e4e5ef !important; }

.salesking-text-indigo-dim { color: #e4e5ef !important; }

.salesking-bg-purple-dim { background-color: #efecff !important; }

.salesking-text-purple-dim { color: #efecff !important; }

.salesking-bg-pink-dim { background-color: #ffebf3 !important; }

.salesking-text-pink-dim { color: #ffebf3 !important; }

.salesking-bg-orange-dim { background-color: #fff3e9 !important; }

.salesking-text-orange-dim { color: #fff3e9 !important; }

.salesking-bg-teal-dim { background-color: #e2f8f1 !important; }

.salesking-text-teal-dim { color: #e2f8f1 !important; }

.salesking-bg-primary-dim, .dual-listbox .dual-listbox__item:active, .dual-listbox .dual-listbox__item.dual-listbox__item--selected { background-color: #efe8ff !important; }

.salesking-text-primary-dim { color: #efe8ff !important; }

.salesking-bg-success-dim { background-color: #e2fbf4 !important; }

.salesking-text-success-dim { color: #e2fbf4 !important; }

.salesking-bg-info-dim { background-color: #dff7fb !important; }

.salesking-text-info-dim { color: #dff7fb !important; }

.salesking-bg-warning-dim { background-color: #fef6e0 !important; }

.salesking-text-warning-dim { color: #fef6e0 !important; }

.salesking-bg-danger-dim { background-color: #fce9e7 !important; }

.salesking-text-danger-dim { color: #fce9e7 !important; }

.salesking-bg-secondary-dim { background-color: #e5ecf5 !important; }

.salesking-text-secondary-dim { color: #e5ecf5 !important; }

.salesking-bg-dark-dim { background-color: #d9e1ef !important; }

.salesking-text-dark-dim { color: #d9e1ef !important; }

.salesking-bg-gray-dim { background-color: #edf2f9 !important; }

.salesking-text-gray-dim { color: #edf2f9 !important; }

.salesking-bg-gray-100 { background-color: #ebeef2 !important; }

.salesking-bg-gray-200 { background-color: #e5e9f2 !important; }

.salesking-bg-gray-300 { background-color: #dbdfea !important; }

.salesking-bg-gray-400 { background-color: #b7c2d0 !important; }

.salesking-bg-gray-500 { background-color: #8091a7 !important; }

.salesking-bg-gray-600 { background-color: #3c4d62 !important; }

.salesking-bg-gray-700 { background-color: #344357 !important; }

.salesking-bg-gray-800 { background-color: #2b3748 !important; }

.salesking-bg-gray-900 { background-color: #1f2b3a !important; }

.salesking-bg-abstract { background-image: linear-gradient(to right, #2c3782 calc(60% - 150px), #39469f calc(60% - 150px), #39469f 60%, #4856b5 60%, #4856b5 calc(60% + 150px), #5b6ac6 calc(60% + 150px), #5b6ac6 100%); }

.salesking-bg-white-1 { background: rgba(255, 255, 255, 0.1) !important; }

.salesking-bg-white-2 { background: rgba(255, 255, 255, 0.2) !important; }

.salesking-bg-white-3 { background: rgba(255, 255, 255, 0.3) !important; }

.salesking-bg-white-4 { background: rgba(255, 255, 255, 0.4) !important; }

.salesking-bg-white-5 { background: rgba(255, 255, 255, 0.5) !important; }

.salesking-bg-white-6 { background: rgba(255, 255, 255, 0.6) !important; }

.salesking-bg-white-7 { background: rgba(255, 255, 255, 0.7) !important; }

.salesking-bg-white-8 { background: rgba(255, 255, 255, 0.8) !important; }

.salesking-bg-white-9 { background: rgba(255, 255, 255, 0.9) !important; }
