@use "../common/variables" as *;
@use "../common/mixins/utilities" as *;

//
// jQuery BlockUI
//----------------

.blockUI.blockOverlay {
	
	&:before {
		display: none;
	}
	
	&:after {
		content: '';
		top: 45%;
		left: 0;
		right: 0;
		margin: auto;
		@include loader(30px, $info, 3px);
		
		.note & {
			top: 38%;
			@include loader(25px, $info);
		}
	}
	
}

@include loader-rotate-animation;