@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}:where(.wp-block-woocommerce-add-to-cart-with-options-variation-selector-attribute-name.wp-block-woocommerce-add-to-cart-with-options-variation-selector-attribute-name){margin-bottom:0}
