@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.editor-styles-wrapper .wc-block-grid .wc-block-grid__products{list-style:none;margin:0 -8px 16px;padding:0}.editor-styles-wrapper .wc-block-grid .wc-block-grid__products .wc-block-grid__product{margin:0 0 24px}.editor-styles-wrapper .wc-block-grid .wc-block-grid__products .wc-block-grid__product .wc-block-grid__product-onsale{position:absolute}.editor-styles-wrapper .wc-block-grid.components-placeholder{padding:2em 1em}.editor-styles-wrapper .wc-block-grid.is-loading,.editor-styles-wrapper .wc-block-grid.is-not-found{display:block}.components-base-control+.wc-block-base-control-notice{margin:-16px 0 16px}.components-base-control+.wc-block-base-control-notice:last-child{margin:-16px 0 12px}svg.wc-block-editor-components-block-icon--sparkles path{fill:currentColor}.block-editor-list-view-leaf.is-selected .block-editor-list-view-block-contents svg.wc-block-editor-components-block-icon{color:currentColor}.theme-twentytwenty .wp-block .wc-block-active-filters__title,.theme-twentytwenty .wp-block .wc-block-attribute-filter__title,.theme-twentytwenty .wp-block .wc-block-grid__product-title,.theme-twentytwenty .wp-block .wc-block-price-filter__title,.theme-twentytwenty .wp-block .wc-block-stock-filter__title{font-size:1em}.woocommerce-customer-effort-score__errors>p{color:#cc1818;margin-bottom:16px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-components-title{background-color:transparent}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-active-filters .wc-block-active-filters__list-item-name{margin-top:9px}.wc-block-active-filter__style-toggle{width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.editor-styles-wrapper .wc-block-components-product-title a.wc-block-components-product-name{color:inherit}.editor-styles-wrapper .wc-block-components-product-title{display:block;font-size:inherit;font-weight:700;line-height:1.5;margin-bottom:12px;margin-top:0;padding:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-product-rating__link{pointer-events:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-product-summary p{font-size:inherit}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.editor-styles-wrapper .wp-block-woocommerce-attribute-filter{border-style:none!important}.wc-block-attribute-filter .components-placeholder__instructions{border-bottom:1px solid #e0e2e6;margin-bottom:2em;padding-bottom:1em;width:100%}.wc-block-attribute-filter .components-placeholder__label svg{fill:currentColor;margin-left:1ch}.wc-block-attribute-filter .components-placeholder__fieldset{display:block}.wc-block-attribute-filter .woocommerce-search-list__search{border-top:0;margin-top:0;padding-top:0}.wc-block-attribute-filter .wc-block-attribute-filter__add-attribute-button{height:auto;margin:0 0 1em;padding:.5em 1em;vertical-align:middle}.wc-block-attribute-filter .wc-block-attribute-filter__add-attribute-button svg{fill:currentColor;margin-right:.5ch;vertical-align:middle}.wc-block-attribute-filter .wc-block-attribute-filter__read_more_button{display:block;margin-bottom:1em}.wc-block-attribute-filter .components-disabled{border-color:inherit;border-radius:inherit}.wc-block-attribute-filter .components-notice__content{color:#000}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-featured-category .is-applying .components-spinner{right:50%;margin-right:-9px;margin-top:-9px;position:absolute;top:50%}.wp-block-woocommerce-featured-category .is-applying img{opacity:.3}.wp-block-woocommerce-featured-category>.components-resizable-box__container{bottom:0;right:0;min-height:50px;position:absolute!important;left:0;top:0}.wp-block-woocommerce-featured-category>.components-resizable-box__container:not(.is-resizing){height:auto!important}.wp-block-woocommerce-featured-category .components-resizable-box__handle{z-index:10}.color-block-support-panel .image-bg-color-warning{grid-column:span 2}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-featured-product .is-applying .components-spinner{right:50%;margin-right:-9px;margin-top:-9px;position:absolute;top:50%}.wp-block-woocommerce-featured-product .is-applying img{opacity:.3}.wp-block-woocommerce-featured-product>.components-resizable-box__container{bottom:0;right:0;min-height:50px;position:absolute!important;left:0;top:0}.wp-block-woocommerce-featured-product>.components-resizable-box__container:not(.is-resizing){height:auto!important}.wp-block-woocommerce-featured-product .components-resizable-box__handle{z-index:10}.color-block-support-panel .image-bg-color-warning{grid-column:span 2}.wp-block-woocommerce-featured-product__message{margin-bottom:16px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-handpicked-products__selection{width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}:where(.wp-block-woocommerce-legacy-template){margin-right:auto;margin-left:auto}.wp-block-woocommerce-classic-template__placeholder-warning{border-right:5px solid #2181d2;padding-right:2.5em}.wp-block-woocommerce-classic-template__placeholder .components-placeholder__fieldset{display:grid;grid-template-columns:1fr}.wp-block-woocommerce-classic-template__placeholder-copy,.wp-block-woocommerce-classic-template__placeholder-wireframe{grid-column-start:1;grid-row-start:1;transition:all .3s ease}.wp-block-woocommerce-classic-template__placeholder-copy{background-color:#fff;border:1px solid #1e1e1e;border-radius:4px;display:flex;flex-direction:column;margin:auto;max-width:900px;opacity:0;padding:24px 36px;width:400px;z-index:10}.wp-block-woocommerce-classic-template__placeholder-copy .wp-block-woocommerce-classic-template__placeholder-copy__icon-container{margin:0 0 16px}.wp-block-woocommerce-classic-template__placeholder-copy .wp-block-woocommerce-classic-template__placeholder-copy__icon-container h1{color:#720eec;font-size:1.25em;margin:0}.wp-block-woocommerce-classic-template__placeholder-copy .wp-block-woocommerce-classic-template__placeholder-copy__icon-container span{display:block;font-size:2em}.wp-block-woocommerce-classic-template__placeholder-copy p{margin:0 0 16px}.wp-block-woocommerce-classic-template__placeholder-copy .wp-block-woocommerce-classic-template__placeholder-migration-button-container{justify-content:center;margin:16px 0}.wp-block-woocommerce-classic-template__placeholder-wireframe{pointer-events:none}.wp-block-woocommerce-classic-template__placeholder-wireframe>img{width:100%}.wp-block-woocommerce-legacy-template .components-placeholder{box-shadow:none;padding:0}.wp-block-woocommerce-legacy-template.is-selected .wp-block-woocommerce-classic-template__placeholder-wireframe{filter:blur(3px);opacity:.5}.wp-block-woocommerce-legacy-template.is-selected .wp-block-woocommerce-classic-template__placeholder-wireframe *{border-color:#e0e0e0!important;color:#e0e0e0!important}.wp-block-woocommerce-legacy-template.is-selected .wp-block-woocommerce-classic-template__placeholder-copy{opacity:1}.wp-block-woocommerce-legacy-template.is-selected .components-placeholder{box-shadow:inherit}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}:where(.wp-block-woocommerce-classic-shortcode){margin-right:auto;margin-left:auto}.wp-block-woocommerce-classic-shortcode__placeholder-warning{border-right:5px solid #2181d2;padding-right:2.5em}.wp-block-woocommerce-classic-shortcode__placeholder .components-placeholder__fieldset{display:grid;grid-template-columns:1fr}.wp-block-woocommerce-classic-shortcode__placeholder-copy,.wp-block-woocommerce-classic-shortcode__placeholder-wireframe{grid-column-start:1;grid-row-start:1;transition:all .3s ease}.wp-block-woocommerce-classic-shortcode__placeholder-copy{background-color:#fff;border:1px solid #1e1e1e;border-radius:4px;display:flex;flex-direction:column;margin:auto;max-width:900px;opacity:0;padding:24px 36px;width:400px;z-index:10}.wp-block-woocommerce-classic-shortcode__placeholder-copy .wp-block-woocommerce-classic-shortcode__placeholder-copy__icon-container{margin:0 0 16px}.wp-block-woocommerce-classic-shortcode__placeholder-copy .wp-block-woocommerce-classic-shortcode__placeholder-copy__icon-container h1{color:#720eec;font-size:1.25em;margin:0}.wp-block-woocommerce-classic-shortcode__placeholder-copy .wp-block-woocommerce-classic-shortcode__placeholder-copy__icon-container span{display:block;font-size:2em}.wp-block-woocommerce-classic-shortcode__placeholder-copy p{margin:0 0 16px}.wp-block-woocommerce-classic-shortcode__placeholder-copy .wp-block-woocommerce-classic-shortcode__placeholder-migration-button-container{display:inline-flex;flex-wrap:nowrap;gap:16px;justify-content:flex-start;margin:16px 0}.wp-block-woocommerce-classic-shortcode__placeholder-wireframe{pointer-events:none}.wp-block-woocommerce-classic-shortcode__placeholder-wireframe>img,.wp-block-woocommerce-classic-shortcode__placeholder-wireframe>svg{color:color-mix(in srgb,currentColor 20%,transparent);height:auto;width:100%}.wp-block-woocommerce-classic-shortcode .components-placeholder{background-color:transparent;box-shadow:none;padding:0}.is-hovered .wp-block-woocommerce-classic-shortcode .wp-block-woocommerce-classic-shortcode__placeholder-wireframe,.is-selected .wp-block-woocommerce-classic-shortcode .wp-block-woocommerce-classic-shortcode__placeholder-wireframe,.wp-block-woocommerce-classic-shortcode.is-hovered .wp-block-woocommerce-classic-shortcode__placeholder-wireframe,.wp-block-woocommerce-classic-shortcode.is-selected .wp-block-woocommerce-classic-shortcode__placeholder-wireframe{filter:blur(3px);opacity:.5}.is-hovered .wp-block-woocommerce-classic-shortcode .wp-block-woocommerce-classic-shortcode__placeholder-wireframe *,.is-selected .wp-block-woocommerce-classic-shortcode .wp-block-woocommerce-classic-shortcode__placeholder-wireframe *,.wp-block-woocommerce-classic-shortcode.is-hovered .wp-block-woocommerce-classic-shortcode__placeholder-wireframe *,.wp-block-woocommerce-classic-shortcode.is-selected .wp-block-woocommerce-classic-shortcode__placeholder-wireframe *{border-color:color-mix(in srgb,currentColor 20%,transparent)!important;color:color-mix(in srgb,currentColor 20%,transparent)!important}.is-hovered .wp-block-woocommerce-classic-shortcode .wp-block-woocommerce-classic-shortcode__placeholder-copy,.is-selected .wp-block-woocommerce-classic-shortcode .wp-block-woocommerce-classic-shortcode__placeholder-copy,.wp-block-woocommerce-classic-shortcode.is-hovered .wp-block-woocommerce-classic-shortcode__placeholder-copy,.wp-block-woocommerce-classic-shortcode.is-selected .wp-block-woocommerce-classic-shortcode__placeholder-copy{opacity:1}.is-hovered .wp-block-woocommerce-classic-shortcode .components-placeholder,.is-selected .wp-block-woocommerce-classic-shortcode .components-placeholder,.wp-block-woocommerce-classic-shortcode.is-hovered .components-placeholder,.wp-block-woocommerce-classic-shortcode.is-selected .components-placeholder{box-shadow:inherit}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-page-content-wrapper{max-width:100%!important}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-price-filter .components-disabled{border-color:inherit;border-radius:inherit}.wp-block-woocommerce-price-filter .components-disabled .wc-block-price-filter__range-input-wrapper .wc-block-price-filter__range-input::-webkit-slider-thumb{pointer-events:none}.wp-block-woocommerce-price-filter .components-disabled .wc-block-price-filter__range-input-wrapper .wc-block-price-filter__range-input::-moz-range-thumb{pointer-events:none}.wp-block-woocommerce-price-filter .components-disabled .wc-block-price-filter__range-input-wrapper .wc-block-price-filter__range-input::-ms-thumb{pointer-events:none}.wc-block-price-filter__price-range-toggle{width:100%}.wc-block-price-filter__price-range-toggle>div{flex-grow:1}.wc-block-price-slider .components-placeholder__instructions{border-bottom:1px solid #e0e2e6;margin-bottom:2em;padding-bottom:1em;width:100%}.wc-block-price-slider .components-placeholder__label svg{fill:currentColor;margin-left:1ch}.wc-block-price-slider .components-placeholder__fieldset{display:block}.wc-block-price-slider .wc-block-price-slider__add-product-button{height:auto;margin:0 0 1em;padding:.5em 1em;vertical-align:middle}.wc-block-price-slider .wc-block-price-slider__add-product-button svg{fill:currentColor;margin-right:.5ch;vertical-align:middle}.wc-block-price-slider .wc-block-price-slider__read_more_button{display:block;margin-bottom:1em}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-products-category__selection{width:100%}.wc-block-products-category__cancel-button.is-tertiary{margin:1em auto 0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-categories.wc-block-product-categories ul{margin-right:20px}.wc-block-product-categories .components-placeholder__label svg{fill:currentColor;margin-left:1ch}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce-product-tags__operator .components-base-control__help{clip:rect(1px,1px,1px,1px);word-wrap:normal!important;border:0;clip-path:inset(50%);height:1px;margin:-1px;overflow:hidden;overflow-wrap:normal!important;padding:0;position:absolute!important;width:1px}.woocommerce-product-tags__operator .components-base-control__label{margin-bottom:0;margin-left:.5em}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-products-by-attribute__selection{width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce-product-attributes__operator .components-base-control__help{clip:rect(1px,1px,1px,1px);word-wrap:normal!important;border:0;clip-path:inset(50%);height:1px;margin:-1px;overflow:hidden;overflow-wrap:normal!important;padding:0;position:absolute!important;width:1px}.woocommerce-product-attributes__operator .components-base-control__label{margin-bottom:0;margin-left:.5em}.woocommerce-search-list__item.woocommerce-product-attributes__item.is-searching .woocommerce-search-list__item-prefix:after,.woocommerce-search-list__item.woocommerce-product-attributes__item.is-skip-level .woocommerce-search-list__item-prefix:after{content:":"}.woocommerce-search-list__item.woocommerce-product-attributes__item.is-not-active:active,.woocommerce-search-list__item.woocommerce-product-attributes__item.is-not-active:focus,.woocommerce-search-list__item.woocommerce-product-attributes__item.is-not-active:hover{background:#fff}.woocommerce-search-list__item.woocommerce-product-attributes__item.is-loading{justify-content:center}.woocommerce-search-list__item.woocommerce-product-attributes__item.is-loading .components-spinner{margin-bottom:12px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-rating-filter .components-notice__content{color:#000}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-stock-filter .components-placeholder__instructions{border-bottom:1px solid #e0e2e6;margin-bottom:2em;padding-bottom:1em;width:100%}.wc-block-stock-filter .components-placeholder__label svg{fill:currentColor;margin-left:1ch}.wc-block-stock-filter .components-placeholder__fieldset{display:block}.wc-block-stock-filter .woocommerce-search-list__search{border-top:0;margin-top:0;padding-top:0}.wc-block-stock-filter .wc-block-stock-filter__add-stock-button{height:auto;margin:0 0 1em;padding:.5em 1em;vertical-align:middle}.wc-block-stock-filter .wc-block-stock-filter__add-stock-button svg{fill:currentColor;margin-right:.5ch;vertical-align:middle}.wc-block-stock-filter .wc-block-stock-filter__read_more_button{display:block;margin-bottom:1em}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-store-notices .components-notice__content{color:#000}.wc-block-store-notices .components-notice{margin-right:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-order-confirmation-downloads-wrapper:not(.store-has-downloads):not(.is-selected):not(.has-child-selected){display:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-product-details ul.wc-tabs{border-bottom:1px solid #e0e0e0;list-style:none;margin:0 0 1.618em;overflow:hidden;padding:0 1em 0 0;position:relative}.wp-block-woocommerce-product-details ul.wc-tabs li{border:1px solid #e0e0e0;border-radius:4px 4px 0 0;display:inline-block;margin:0;padding:0 1em;position:relative;z-index:0}.wp-block-woocommerce-product-details ul.wc-tabs li a{display:inline-block;font-weight:700;padding:.5em 0;text-decoration:none}.wp-block-woocommerce-product-details ul.wc-tabs li a:hover{text-decoration:none}.wp-block-woocommerce-product-details ul.wc-tabs li.active{z-index:2}.wp-block-woocommerce-product-details ul.wc-tabs li.active a{text-shadow:inherit}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block[data-align=center]>.wp-block-woocommerce-product-reviews-pagination{justify-content:center}:where(.editor-styles-wrapper) .wp-block-woocommerce-product-reviews-pagination{max-width:100%}:where(.editor-styles-wrapper) .wp-block-woocommerce-product-reviews-pagination.block-editor-block-list__layout{margin:0}.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-next,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-numbers,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-previous{font-size:inherit;margin:.5em 0 .5em .5em}.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-next:last-child,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-numbers:last-child,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-previous:last-child{margin-left:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-product-reviews-pagination-numbers a{text-decoration:underline}.wp-block-woocommerce-product-reviews-pagination-numbers .page-numbers{margin-left:2px}.wp-block-woocommerce-product-reviews-pagination-numbers .page-numbers:last-child{margin-left:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-filled-cart-block .wc-block-components-sidebar-layout{display:block}.wp-block-woocommerce-filled-cart-block .block-editor-block-list__layout{align-items:flex-start;display:flex;flex-flow:row wrap}.wp-block-woocommerce-filled-cart-block .block-editor-block-list__layout>:first-child,.wp-block-woocommerce-filled-cart-block .wc-block-components-main>:first-child,.wp-block-woocommerce-filled-cart-block .wc-block-components-sidebar>:first-child{margin-top:0}.wp-block-woocommerce-filled-cart-block .wp-block-woocommerce-cart-items-block .block-editor-block-list__layout,.wp-block-woocommerce-filled-cart-block .wp-block-woocommerce-cart-totals-block .block-editor-block-list__layout{display:block}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-cart-cross-sells-products-block .cross-sells-product{display:inline-block;margin-bottom:2em;padding-left:5%;text-align:center;vertical-align:top;width:30%}.wp-block-woocommerce-cart-cross-sells-products-block .cross-sells-product:nth-child(3n+3){padding-left:0}.wp-block-woocommerce-cart-cross-sells-products-block .cross-sells-product div .wc-block-components-product-name{font-weight:400}.wp-block-woocommerce-cart-cross-sells-products-block .cross-sells-product div .wc-block-components-product-price{display:block}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-cart-express-payment-block .components-placeholder__label svg{font-size:1em}.wp-block-woocommerce-cart-express-payment-block .wc-block-cart__payment-options{padding:0}.wp-block-woocommerce-cart-express-payment-block .wc-block-cart__payment-options .wc-block-components-express-payment-continue-rule{margin-bottom:-12px}.wp-block-woocommerce-proceed-to-checkout-block{margin-bottom:28px;margin-top:28px}.wp-block-woocommerce-checkout-express-payment-block-placeholder *{pointer-events:all}.wp-block-woocommerce-cart-express-payment-block .wp-block-woocommerce-checkout-express-payment-block-placeholder,.wp-block-woocommerce-checkout-express-payment-block-placeholder .wp-block-woocommerce-checkout-express-payment-block-placeholder__description{margin:0 0 1em}.wp-block-woocommerce-checkout-express-payment-block-placeholder .wp-block-woocommerce-checkout-express-payment-block-placeholder__description{display:block}.express-payment-styles-notice{margin-bottom:16px}.express-payment-styles-beta-badge{align-items:center;background-color:#1e1e1e;border-radius:2px;color:#fff;font-size:12px;height:24px;line-height:1;margin-right:8px;padding:3px 8px}.border-radius-control-container select{pointer-events:none}.button-height-control+.border-radius-control-container{margin-top:24px}.wc-block-components-express-payment .wc-block-components-express-payment__event-buttons>div,.wc-block-components-express-payment .wc-block-components-express-payment__event-buttons>li{pointer-events:none;user-select:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-cart-link{cursor:default;user-select:none}.wc-block-cart-link .wc-block-cart-link__text{cursor:text;user-select:text}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-checkout__additional_fields{margin:1.5em 0 0}.wc-block-components-checkout-step__description-placeholder{display:none;opacity:.5}.is-selected .wc-block-components-checkout-step__description-placeholder{display:block}.wc-block-components-checkout-step__description,.wc-block-components-checkout-step__title{display:flex;width:100%}.wc-block-components-checkout-step__description .block-editor-plain-text,.wc-block-components-checkout-step__title .block-editor-plain-text{height:auto!important;resize:none!important}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}@container (min-width: 400px) and (max-width: 519px){.edit-post-visual-editor .wc-block-checkout__terms{padding:4px}}@container (min-width: 520px) and (max-width: 699px){.edit-post-visual-editor .wc-block-checkout__terms{padding:4px}}.wc-block-checkout__terms{align-items:flex-start;display:flex;margin:0 0 36px;padding-bottom:4px;padding-top:4px}.wc-block-checkout__terms-checkbox-wrapper{margin-left:12px}.wc-block-checkout__terms_notice{margin:0}.wc-block-checkout__terms_notice .components-notice__content{margin:4px 0}.wc-block-checkout__terms_notice .components-notice__actions button{margin-right:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-checkout-order-note-block{padding:4px 0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-components-external-link-card{align-items:flex-start;color:inherit;display:flex;flex-direction:row;margin:24px 0;text-decoration:none}.wc-block-editor-components-external-link-card+.wc-block-editor-components-external-link-card{margin-top:-8px}.wc-block-editor-components-external-link-card:last-child{margin-bottom:0}.wc-block-editor-components-external-link-card .wc-block-editor-components-external-link-card__content{flex:1 1 0;padding-left:16px}.wc-block-editor-components-external-link-card .wc-block-editor-components-external-link-card__title{display:block;font-weight:500}.wc-block-editor-components-external-link-card .wc-block-editor-components-external-link-card__description{color:#757575;display:block;font-size:.875em;margin-top:.5em}.wc-block-editor-components-external-link-card .wc-block-editor-components-external-link-card__icon{color:inherit;flex:0 0 24px;margin:0;text-align:left;vertical-align:top}.wc-block-editor-components-external-link-card .wc-block-editor-components-external-link-card__warning{align-items:flex-start;color:#cc1818;column-gap:4px;display:flex;font-size:.875em;margin-top:.5em}.wc-block-editor-components-external-link-card .wc-block-editor-components-external-link-card__warning svg{height:18px;min-width:18px;width:18px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-cart-order-summary-heading-block textarea{height:auto;line-height:1;padding-right:16px;text-align:right;text-transform:uppercase}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}body.wc-lock-selected-block--move .block-editor-block-mover,body.wc-lock-selected-block--move .block-editor-block-mover__move-button-container{display:none}body.wc-lock-selected-block--remove .block-editor-block-settings-menu__popover .components-menu-group:last-child{display:none}body.wc-lock-selected-block--remove .block-editor-block-settings-menu__popover .components-menu-group:nth-last-child(2){margin-bottom:-12px}.wp-block-woocommerce-cart-items-block .block-list-appender,.wp-block-woocommerce-cart-totals-block .block-list-appender,.wp-block-woocommerce-empty-cart-block .block-list-appender{position:relative}.wp-block-woocommerce-cart-order-summary-block .block-editor-block-list__layout>div{margin:0!important}.wp-block-woocommerce-cart-order-summary-block .wc-block-components-totals-wrapper{box-sizing:border-box}.wc-block-cart .wc-block-cart__totals-title textarea{font-weight:500;height:auto!important;resize:none!important;vertical-align:middle}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-checkout-express-payment-block{margin:14px 0 28px}.wp-block-woocommerce-checkout-express-payment-block .components-placeholder__label svg{font-size:1em}.wp-block-woocommerce-checkout-express-payment-block .wc-block-components-express-payment-continue-rule--checkout{margin-bottom:0}.wp-block-woocommerce-checkout-express-payment-block.wp-block-woocommerce-checkout-express-payment-block--has-express-payment-methods{margin:-14px 0 14px!important;padding:14px 0;position:relative}.wp-block-woocommerce-checkout-express-payment-block-placeholder *{pointer-events:all}.wp-block-woocommerce-checkout-express-payment-block-placeholder .wp-block-woocommerce-checkout-express-payment-block-placeholder__description{display:block;margin:0 0 1em}.express-payment-styles-notice{margin-bottom:16px}.express-payment-styles-beta-badge{align-items:center;background-color:#1e1e1e;border-radius:2px;color:#fff;font-size:12px;height:24px;line-height:1;margin-right:8px;padding:3px 8px}.border-radius-control-container select{pointer-events:none}.button-height-control+.border-radius-control-container{margin-top:24px}.wc-block-components-express-payment .wc-block-components-express-payment__event-buttons>div,.wc-block-components-express-payment .wc-block-components-express-payment__event-buttons>li{pointer-events:none;user-select:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-shipping-rates-control__no-results-notice .components-notice__content{color:#000}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-checkout .wc-block-components-sidebar-layout{display:block}.wp-block-woocommerce-checkout .block-editor-block-list__layout{align-items:flex-start;display:flex;flex-flow:row wrap;padding-right:5px}.wp-block-woocommerce-checkout .block-editor-block-list__layout:has(>:first-child.wp-block-woocommerce-checkout-totals-block){flex-direction:row-reverse}.wp-block-woocommerce-checkout .block-editor-block-list__layout .wc-block-checkout__additional_fields{padding:0}.wp-block-woocommerce-checkout .block-editor-block-list__layout>:first-child,.wp-block-woocommerce-checkout .wc-block-components-main>:first-child,.wp-block-woocommerce-checkout .wc-block-components-sidebar>:first-child{margin-top:0}.wp-block-woocommerce-checkout .wp-block-woocommerce-checkout-fields-block .block-editor-block-list__layout,.wp-block-woocommerce-checkout .wp-block-woocommerce-checkout-totals-block .block-editor-block-list__layout{display:block}.wp-block-woocommerce-checkout .wp-block-woocommerce-checkout-fields-block .block-list-appender,.wp-block-woocommerce-checkout .wp-block-woocommerce-checkout-totals-block .block-list-appender{position:relative}@container (min-width: 700px){.wp-block-woocommerce-checkout .wc-block-checkout__sidebar{top:0}}body.wc-lock-selected-block--move .block-editor-block-mover,body.wc-lock-selected-block--move .block-editor-block-mover__move-button-container{display:none}body.wc-lock-selected-block--remove .block-editor-block-settings-menu__popover .components-menu-group:last-child{display:none}body.wc-lock-selected-block--remove .block-editor-block-settings-menu__popover .components-menu-group:nth-last-child(2){margin-bottom:-12px}.components-base-control--nested{margin-top:-12px;padding-right:52px}.components-panel__body-title .components-button{opacity:1}.wp-block-woocommerce-checkout.is-editor-preview{max-height:1000px;overflow:hidden}.wp-block-woocommerce-checkout-order-summary-block .block-editor-block-list__layout{padding-right:0}.wp-block-woocommerce-checkout-order-summary-block .block-editor-block-list__layout>div{margin:0!important}.wp-block-woocommerce-checkout-order-summary-block .wc-block-components-totals-wrapper{box-sizing:border-box}.wp-block-woocommerce-checkout-order-summary-block .wp-block-woocommerce-checkout-order-summary-cart-items-block .wc-block-components-totals-wrapper{border-top:0}.wc-block-components-sidebar-layout>.block-editor-inner-blocks>.block-editor-block-list__layout{display:flex;flex-wrap:wrap;margin:0 auto 16px;position:relative}.wc-block-components-sidebar-layout>.block-editor-inner-blocks>.block-editor-block-list__layout:has(>:last-child.wp-block-woocommerce-checkout-fields-block){flex-direction:row-reverse}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-default-page-notice.is-dismissible{margin:0;padding-left:16px}.wc-default-page-notice.is-dismissible .components-notice__dismiss{min-width:24px}.wc-default-page-notice.is-dismissible .components-notice__content{margin:4px 0}.wc-default-page-notice.is-dismissible svg{height:16px;width:16px}.wc-blocks-legacy-page-notice{margin:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-blocks-switch-to-classic-shortcode-modal-content{max-width:480px}.wc-blocks-switch-to-classic-shortcode-modal-content p{margin-top:0}.wc-blocks-switch-to-classic-shortcode-modal-actions{text-align:left}.wc-blocks-switch-to-classic-shortcode-modal-actions button{display:inline-block;margin-right:4px}ul.cross-list{margin:0 1em 24px 0}ul.cross-list,ul.cross-list li{list-style:none outside;padding:0}ul.cross-list li{margin:1em 0}ul.cross-list li:before{content:"❌";margin-left:.5em}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-blocks-incompatible-extensions-notice.is-dismissible{margin:0;padding-left:16px}.wc-blocks-incompatible-extensions-notice.is-dismissible .components-notice__dismiss{min-width:24px}.wc-blocks-incompatible-extensions-notice.is-dismissible .components-notice__content{margin:4px 0}.wc-blocks-incompatible-extensions-notice.is-dismissible svg{height:16px;width:16px}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content{display:flex}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details{margin:0}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details[open]{margin:0 0 16px}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details[open] summary svg{transform:rotate(-180deg)}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details summary{cursor:pointer;display:block;margin:0 0 16px;text-decoration:underline}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details summary span{color:#757575;text-decoration:underline}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details summary::-webkit-details-marker{display:none}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content details summary svg{fill:#757575;height:24px;position:relative;top:6px;width:24px}.wc-blocks-incompatible-extensions-notice.is-dismissible .wc-blocks-incompatible-extensions-notice__content .wc-blocks-incompatible-extensions-notice__warning-icon{height:24px;margin-left:6px;min-width:24px;width:24px}.wc-blocks-incompatible-extensions-notice.is-dismissible ul{list-style:disc outside;margin:0 1.2em 0 0;padding:0}.wc-blocks-legacy-page-notice{margin:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-feedback-prompt{background-color:#f7f7f7;border-top:1px solid #e0e0e0;margin:0;padding:24px;text-align:center}.wc-block-feedback-prompt .wc-block-feedback-prompt__title{margin:0 0 12px}.wc-block-feedback-prompt .wc-block-feedback-prompt__link{color:inherit}.wc-block-feedback-prompt .wc-block-feedback-prompt__link>.gridicon{vertical-align:text-bottom}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-mini-cart__render-in-cart-and-checkout-toggle{width:100%}.wc-block-editor-mini-cart__drawer-image{margin-bottom:6px}.wc-block-editor-mini-cart__drawer-link{margin-bottom:24px}html[dir=rtl] .wc-block-editor-mini-cart__icon{transform:scaleX(-1)}.wc-block-mini-cart__product-count-radiocontrol .components-base-control__field>.components-v-stack{gap:6px}.wc-block-mini-cart__product-count-radiocontrol .components-base-control__field>.components-v-stack .components-radio-control__option{align-items:flex-start}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.editor-styles-wrapper .wc-block-editor-mini-cart-contents__wrapper.wc-block-editor-mini-cart-contents__wrapper{display:flex;justify-content:center;margin:0;position:relative;z-index:9999}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-empty-mini-cart-contents-block[hidden],.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-filled-mini-cart-contents-block[hidden]{display:none}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-filled-mini-cart-contents-block>.block-editor-inner-blocks>.block-editor-block-list__layout{display:flex;flex-direction:column;height:100vh}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-mini-cart-items-block{display:grid;flex-grow:1;margin-bottom:16px;padding:0 16px}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-mini-cart-items-block>.block-editor-inner-blocks>.block-editor-block-list__layout{display:flex;flex-direction:column;height:100%}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-mini-cart-items-block .block-list-appender{position:relative}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-mini-cart-products-table-block{margin-bottom:auto;margin-top:16px}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents h2.wc-block-mini-cart__title{font-size:2em}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents h2.wc-block-mini-cart__title .block-editor-block-list__layout{align-items:baseline;display:flex}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents table.wc-block-cart-items{color:inherit}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .block-editor-button-block-appender{box-shadow:inset 0 0 0 1px;color:inherit}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-empty-mini-cart-contents-block{min-height:100vh;overflow-y:unset;padding:0}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-empty-mini-cart-contents-block>.block-editor-inner-blocks{box-sizing:border-box;max-height:100vh;overflow-y:auto;padding:48px 16px 16px}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wp-block-woocommerce-empty-mini-cart-contents-block .block-list-appender{margin-top:16px;position:relative}.editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents .wc-block-mini-cart__shopping-button a{color:currentColor}.block-editor-block-preview__content-iframe .editor-styles-wrapper .wp-block-woocommerce-empty-mini-cart-contents-block,.block-editor-block-preview__content-iframe .editor-styles-wrapper .wp-block-woocommerce-filled-mini-cart-contents-block,.block-editor-block-preview__content-iframe .editor-styles-wrapper .wp-block-woocommerce-mini-cart-contents{height:800px;min-height:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.editor-styles-wrapper .wc-block-mini-cart__footer .block-editor-inner-blocks{width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce-product-categories__operator .components-base-control__help{clip:rect(1px,1px,1px,1px);word-wrap:normal!important;border:0;clip-path:inset(50%);height:1px;margin:-1px;overflow:hidden;overflow-wrap:normal!important;padding:0;position:absolute!important;width:1px}.woocommerce-product-categories__operator .components-base-control__label{margin-bottom:0;margin-left:.5em}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-components-upgrade-downgrade-notice .components-notice__content{display:flex;flex-direction:column;gap:16px}.wc-block-editor-components-upgrade-downgrade-notice .components-notice__actions .components-notice__action.components-button{margin-right:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-product-sku strong{margin-right:4px;margin-left:4px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-product-gallery img{height:auto;max-width:500px;width:100%}.wc-block-editor-product-gallery .wc-block-editor-product-gallery__other-images img{height:100px;margin:5px;width:100px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-related-products__notice{margin:auto 16px 16px;max-width:max-content}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-related-products__notice{margin:10px auto;max-width:max-content}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-products .components-placeholder__instructions{border-bottom:1px solid #e0e2e6;margin-bottom:2em;padding-bottom:1em;width:100%}.wc-block-products .components-placeholder__label svg{fill:currentColor;margin-left:1ch}.wc-block-products .components-placeholder__fieldset{display:block}.wc-block-products .wc-block-products__add-product-button{height:auto;margin:0 0 1em;padding:.5em 1em;vertical-align:middle}.wc-block-products .wc-block-products__add-product-button svg{fill:currentColor;margin-right:.5ch;vertical-align:middle}.wc-block-products .wc-block-products__read_more_button{display:block;margin-bottom:1em}.wc-block-all-products .components-placeholder__fieldset{max-width:none;overflow:hidden}.wc-block-all-products .wc-block-all-products-grid-item-template{border-top:1px solid #e0e0e0;margin-top:20px;overflow:hidden;text-align:center;width:100%}.wc-block-all-products .wc-block-all-products-grid-item-template .components-tip{margin:20px auto;max-width:450px;text-align:right}.wc-block-all-products .wc-block-all-products-grid-item-template .components-tip p{margin:1em 0}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-all-products__actions{align-items:center;display:flex;margin:20px auto;max-width:450px;padding:1em 0 0;vertical-align:middle}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-all-products__actions .wc-block-all-products__done-button{height:auto;line-height:32px;margin:0;order:3}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-all-products__actions .wc-block-all-products__cancel-button{margin:0 auto 0 1em;order:2}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-all-products__actions .wc-block-all-products__reset-button{margin:0;order:1}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__products{margin:0 auto!important;max-width:450px;position:relative;text-align:center}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__product{background:#fff;box-shadow:0 5px 7px -2px rgba(0,0,0,.2);margin:0 auto;padding:1px 20px;position:static}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__product .wp-block-button__link{margin-top:0}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__product:after,.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__product:before{background:#e0e0e0;bottom:20px;content:"";display:block;position:absolute;top:20px;width:100%}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__product:before{margin-left:30px;left:100%}.wc-block-all-products .wc-block-all-products-grid-item-template .wc-block-grid__product:after{right:100%;margin-right:30px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-reviews__selection{width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-error-message{margin-bottom:16px;margin-top:8px}.wc-block-api-error .components-placeholder__fieldset{display:block}.wc-block-api-error .wc-block-error-message{margin-top:0}.wc-block-api-error .components-spinner{float:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-editor-single-product__selection{width:100%}.wc-block-editor-single-product__reset-layout{padding:0}.wc-block-editor-single-product__info-icon{fill:var(--wp--preset--color--luminous-vivid-orange,#e26f56)}.wc-block-single-product__edit-card{border-top:1px solid #e0e0e0;padding:16px}.wc-block-single-product__edit-card .wc-block-single-product__edit-card-title{margin:0 0 16px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce-tag{display:inline-flex;margin:1px 0 1px 4px;overflow:hidden;vertical-align:middle}.woocommerce-tag .woocommerce-tag__remove,.woocommerce-tag .woocommerce-tag__text{background:#f0f0f0;display:inline-block;line-height:24px;transition:all .2s cubic-bezier(.4,1,.4,1)}.woocommerce-tag .woocommerce-tag__text{align-self:center;border-radius:12px;color:#757575;overflow:hidden;padding:0 8px;text-overflow:ellipsis;white-space:nowrap}.woocommerce-tag.has-remove .woocommerce-tag__text{border-radius:0 12px 12px 0;padding:0 8px 0 4px}.woocommerce-tag .woocommerce-tag__remove{border-radius:12px 0 0 12px;color:#757575;cursor:pointer;height:24px;line-height:10px;padding:0 2px;text-indent:0}.woocommerce-tag .woocommerce-tag__remove:hover{color:#1e1e1e}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce-search-list{padding:0 0 16px;text-align:right;width:100%}.woocommerce-search-list.is-compact .woocommerce-search-list__selected{border-top:none;margin:0 0 16px;min-height:54px;padding:0}.woocommerce-search-list.is-compact .woocommerce-search-list__search{border-top:none;margin:0 0 16px;padding:0}.woocommerce-search-list.is-compact .woocommerce-search-list__search.is-token{margin-bottom:0}.woocommerce-search-list.is-loading .woocommerce-search-list__list{border:none;padding:12px 0;text-align:center}.woocommerce-search-list.is-loading .components-form-token-field__remove-token{display:none}.woocommerce-search-list.is-token .woocommerce-search-list__list{border-top:0}.woocommerce-search-list.is-token .woocommerce-search-list__search{margin-bottom:0}.woocommerce-search-list.is-token .woocommerce-search-list__search .components-form-token-field__input-container{border-bottom-right-radius:0;border-bottom-left-radius:0;margin-bottom:0}.woocommerce-search-list .woocommerce-search-list__list{padding-right:0}.woocommerce-search-list__selected{border-top:1px solid #f0f0f0;margin:16px 0;min-height:76px;padding:16px 0 0}.woocommerce-search-list__selected .woocommerce-search-list__selected-header{margin-bottom:8px}.woocommerce-search-list__selected .woocommerce-search-list__selected-header button{margin-right:12px}.woocommerce-search-list__selected .woocommerce-tag__text{max-width:13em}.woocommerce-search-list__selected ul{display:flex;flex-wrap:wrap;gap:4px;list-style:none;margin:0;padding:0}.woocommerce-search-list__search{border-top:1px solid #f0f0f0;clear:both;margin:16px 0;padding:16px 0 0}.woocommerce-search-list__search .components-base-control__field{margin-bottom:16px}.woocommerce-search-list__list{border:1px solid #e0e0e0;list-style:none;margin:0;max-height:17em;overflow-x:hidden;overflow-y:auto;padding:0}.woocommerce-search-list__list li{margin-bottom:0}.woocommerce-search-list__list.is-not-found{border:none;display:flex;justify-content:center;padding:12px 0;text-align:center}.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-icon,.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-text{align-content:center;display:flex;flex-wrap:wrap}.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-icon{margin-left:16px}.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-icon .gridicon{margin-top:-1px;vertical-align:top}.woocommerce-search-list__list .components-spinner{float:none;margin:0 auto}.woocommerce-search-list__list .components-menu-group__label{clip:rect(1px,1px,1px,1px);word-wrap:normal!important;border:0;clip-path:inset(50%);height:1px;margin:-1px;overflow:hidden;overflow-wrap:normal!important;padding:0;position:absolute!important;width:1px}.woocommerce-search-list__list>[role=menu]{border:1px solid #f0f0f0;border-bottom:none}.woocommerce-search-list__list .woocommerce-search-list__item{align-items:center;background:#fff;border-bottom:1px solid #f0f0f0;color:#757575;display:flex;margin-bottom:0;padding:12px 16px}.woocommerce-search-list__list .woocommerce-search-list__item:active,.woocommerce-search-list__list .woocommerce-search-list__item:focus,.woocommerce-search-list__list .woocommerce-search-list__item:hover{background:#f0f0f0}.woocommerce-search-list__list .woocommerce-search-list__item:active,.woocommerce-search-list__list .woocommerce-search-list__item:focus{box-shadow:none}.woocommerce-search-list__list .woocommerce-search-list__item.has-children{cursor:pointer}.woocommerce-search-list__list .woocommerce-search-list__item.has-children:after{background-position:0%;background-repeat:no-repeat;background-size:contain;content:"";height:24px;margin-right:8px;width:24px}.woocommerce-search-list__list .woocommerce-search-list__item.has-children:not(.is-expanded):after{background-image:url("data:image/svg+xml;utf8,<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"><path d=\"M7.41 8.59L12 13.17l4.59-4.58L18 10l-6 6-6-6 1.41-1.41z\" fill=\"%23757575\" /></svg>")}.woocommerce-search-list__list .woocommerce-search-list__item.has-children[disabled]:after{background:none;margin-right:0;width:auto}.woocommerce-search-list__list .woocommerce-search-list__item.has-children.is-expanded:after{background-image:url("data:image/svg+xml;utf8,<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"><path d=\"M7.41 15.41L12 10.83l4.59 4.58L18 14l-6-6-6 6z\" fill=\"%23757575\" /></svg>")}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-input{margin:0}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-input[type=radio]{margin-left:8px}.woocommerce-search-list__list .woocommerce-search-list__item .components-base-control__field{margin:0}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-label{display:flex;flex:1}.woocommerce-search-list__list .woocommerce-search-list__item.depth-0+.depth-1{margin-top:-1px}.woocommerce-search-list__list .woocommerce-search-list__item:not(.depth-0){border-bottom:0!important}.woocommerce-search-list__list .woocommerce-search-list__item:not(.depth-0)+.depth-0{border-top:1px solid #f0f0f0}.woocommerce-search-list__list .woocommerce-search-list__item[class*=depth-] .woocommerce-search-list__item-label:before{content:str-repeat("— ",5);margin-left:4px}.woocommerce-search-list__list .woocommerce-search-list__item.depth-0 .woocommerce-search-list__item-label:before{content:"";margin-left:0}.woocommerce-search-list__list .woocommerce-search-list__item.depth-1{padding-right:32px}.woocommerce-search-list__list .woocommerce-search-list__item.depth-1 .woocommerce-search-list__item-label:before{content:str-repeat("— ",1)}.woocommerce-search-list__list .woocommerce-search-list__item.depth-2{padding-right:48px}.woocommerce-search-list__list .woocommerce-search-list__item.depth-2 .woocommerce-search-list__item-label:before{content:str-repeat("— ",2)}.woocommerce-search-list__list .woocommerce-search-list__item.depth-3{padding-right:64px}.woocommerce-search-list__list .woocommerce-search-list__item.depth-3 .woocommerce-search-list__item-label:before{content:str-repeat("— ",3)}.woocommerce-search-list__list .woocommerce-search-list__item.depth-4{padding-right:80px}.woocommerce-search-list__list .woocommerce-search-list__item.depth-4 .woocommerce-search-list__item-label:before{content:str-repeat("— ",4)}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-name{display:inline-block}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-prefix{color:#757575;display:none}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-label,.woocommerce-search-list__list .woocommerce-search-list__item.is-skip-level .woocommerce-search-list__item-label{display:inline-block}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-prefix,.woocommerce-search-list__list .woocommerce-search-list__item.is-skip-level .woocommerce-search-list__item-prefix{display:inline}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-prefix:after,.woocommerce-search-list__list .woocommerce-search-list__item.is-skip-level .woocommerce-search-list__item-prefix:after{content:" ›";margin-left:4px}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-name{color:#1e1e1e}.woocommerce-search-list__list .woocommerce-search-list__item.has-count>.components-menu-item__item{width:100%}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-count{background:#fff;border:1px solid #f0f0f0;border-radius:12px;color:#757575;flex:0 1 auto;font-size:.8em;line-height:1.4;margin-right:auto;padding:2px 8px;white-space:nowrap}.woocommerce-search-list__list li:last-child .woocommerce-search-list__item{border-bottom:none}.woocommerce-search-list__list .woocommerce-search-list__item-load-more{border:none;color:var(--wp-components-color-accent,var(--wp-admin-theme-color,#3858e9));cursor:pointer;padding-right:56px;width:100%}@media screen and (max-width:782px){.woocommerce-search-list__list .woocommerce-search-list__item-load-more{box-sizing:content-box;height:25px;padding-right:65px}}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce-search-product__item .woocommerce-search-list__item-name .description{display:block}.woocommerce-search-product__item.is-searching .woocommerce-search-list__item-prefix:after,.woocommerce-search-product__item.is-skip-level .woocommerce-search-list__item-prefix:after{content:":"}.woocommerce-search-product__item.is-not-active:active,.woocommerce-search-product__item.is-not-active:focus,.woocommerce-search-product__item.is-not-active:hover{background:#fff}.woocommerce-search-product__item.is-loading{justify-content:center}.woocommerce-search-product__item.is-loading .components-spinner{margin-bottom:12px}.woocommerce-search-product__item.depth-0.is-variable:after{background-image:url("data:image/svg+xml;utf8,<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"><path d=\"M7.41 8.59L12 13.17l4.59-4.58L18 10l-6 6-6-6 1.41-1.41z\" fill=\"%23757575\" /></svg>");background-position:0%;background-repeat:no-repeat;background-size:contain;content:"";height:24px;margin-right:8px;width:24px}.woocommerce-search-product__item.depth-0.is-variable.is-selected:after{background-image:url("data:image/svg+xml;utf8,<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\"><path d=\"M7.41 15.41L12 10.83l4.59 4.58L18 14l-6-6-6 6z\" fill=\"%23757575\" /></svg>")}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-on-sale .components-placeholder__label svg{fill:currentColor;margin-left:1ch}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woo-inherit-query-toggle{grid-column-end:3;grid-column-start:1}.products-block-post-template.has-background{padding:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-tag__selection{width:100%}.wc-block-product-tag__cancel-button.is-tertiary{margin:1em auto 0}
