@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-block-woocommerce-product-review-template{box-sizing:border-box;list-style:none;margin-bottom:0;max-width:100%;padding:0}.wp-block-woocommerce-product-review-template li{clear:both}.wp-block-woocommerce-product-review-template ol{list-style:none;margin-bottom:0;max-width:100%;padding-left:2rem}.wp-block-woocommerce-product-review-template.alignleft{float:left}.wp-block-woocommerce-product-review-template.aligncenter{margin-left:auto;margin-right:auto;width:fit-content}.wp-block-woocommerce-product-review-template.alignright{float:right}
