//
// ATUM Dashboard RTL
//---------------

@use "atoms/nice-select-rtl";
@use "atoms/form-check-rtl";

@use "organisms/pages/dashboard-rtl";

@use "organisms/widgets/statistics-rtl";
@use "organisms/widgets/stock-control-rtl";
@use "organisms/widgets/current-stock-value-rtl";
@use "organisms/widgets/videos-rtl";