@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-template{list-style:none;margin-bottom:0;margin-top:0;max-width:100%;padding:0}.wc-block-product-template.wc-block-product-template{background:none}.wc-block-product-template.is-flex-container{display:flex;flex-direction:row;flex-wrap:wrap;gap:1.25em}.wc-block-product-template.is-flex-container>li{list-style:none;margin:0;width:100%}@media(min-width:600px){.wc-block-product-template.is-flex-container.is-flex-container.columns-2>li{width:calc(50% - .625em)}.wc-block-product-template.is-flex-container.is-flex-container.columns-3>li{width:calc(33.33333% - .83333em)}.wc-block-product-template.is-flex-container.is-flex-container.columns-4>li{width:calc(25% - .9375em)}.wc-block-product-template.is-flex-container.is-flex-container.columns-5>li{width:calc(20% - 1em)}.wc-block-product-template.is-flex-container.is-flex-container.columns-6>li{width:calc(16.66667% - 1.04167em)}}.wc-block-product-template__responsive{grid-gap:1.25em;display:grid}.wc-block-product-template__responsive.columns-2{grid-template-columns:repeat(auto-fill,minmax(max(150px,calc(50% - .625em)),1fr))}.wc-block-product-template__responsive.columns-3{grid-template-columns:repeat(auto-fill,minmax(max(150px,calc(33.33333% - .83333em)),1fr))}.wc-block-product-template__responsive.columns-4{grid-template-columns:repeat(auto-fill,minmax(max(150px,calc(25% - .9375em)),1fr))}.wc-block-product-template__responsive.columns-5{grid-template-columns:repeat(auto-fill,minmax(max(150px,calc(20% - 1em)),1fr))}.wc-block-product-template__responsive.columns-6{grid-template-columns:repeat(auto-fill,minmax(max(150px,calc(16.66667% - 1.04167em)),1fr))}.wc-block-product-template__responsive>li{margin-block-start:0}:where(.wc-block-product-template .wc-block-product)>:not(:last-child){margin-bottom:.75rem;margin-top:0}.is-product-collection-layout-list .wc-block-product:not(:last-child){margin-bottom:1.2rem}.is-product-collection-layout-carousel{container-name:carousel;container-type:inline-size;overflow-x:auto;padding:4px;position:relative;scroll-padding:0 30%;scroll-snap-type:x mandatory;scrollbar-width:none}.is-product-collection-layout-carousel .wc-block-product{flex-basis:0;max-width:400px;min-width:42.5%;scroll-snap-align:center}@container carousel (min-width: 600px){.is-product-collection-layout-carousel .wc-block-product{min-width:28.5%}}@container carousel (min-width: 782px){.is-product-collection-layout-carousel .wc-block-product{min-width:29%}}@container carousel (min-width: 960px){.is-product-collection-layout-carousel .wc-block-product{min-width:22%}}@container carousel (min-width: 1280px){.is-product-collection-layout-carousel .wc-block-product{min-width:18%}}@container carousel (min-width: 1440px){.is-product-collection-layout-carousel .wc-block-product{min-width:15%}}
