:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.customer-feedback-simple__container{display:flex;justify-content:center;align-items:center}.customer-feedback-simple__container .components-button{line-height:32px;font-size:20px;border-radius:3px;padding:6px}.customer-feedback-simple__container .components-button:hover{background-color:#f0f0f0}.customer-feedback-simple__selection{margin-right:12px}.woocommerce-feedback-modal__buttons{text-align:left}.woocommerce-feedback-modal__buttons .components-button{margin-right:1em}.woocommerce-feedback-modal .woocommerce-feedback-modal__description{max-width:550px;margin:0 0 1.5em 0}.woocommerce-customer-effort-score__selection{margin:1em 0 1.5em 0;max-width:100%;width:500px}.woocommerce-customer-effort-score__selection .woocommerce-customer-effort-score__radio-control .components-radio-control__group-wrapper,.woocommerce-customer-effort-score__selection .woocommerce-customer-effort-score__radio-control .components-v-stack{display:grid;grid-template-columns:repeat(auto-fit, minmax(90px, 1fr));margin:0 auto;color:var(--wp-admin-theme-color);gap:4px;justify-items:center}.woocommerce-customer-effort-score__selection .components-radio-control__option{-moz-column-gap:0;column-gap:0}.woocommerce-customer-effort-score__selection .components-radio-control__option:not(:last-child){margin-bottom:0}.woocommerce-customer-effort-score__selection .components-radio-control__option input{position:absolute;opacity:0}.woocommerce-customer-effort-score__selection .components-radio-control__option label{display:block;text-align:center;box-sizing:border-box;width:9em;height:100%;padding:1em .5em;font-size:.9em}.woocommerce-customer-effort-score__selection .components-radio-control__option label:hover{background-color:#fbfcfe}.woocommerce-customer-effort-score__selection .components-radio-control__option input:focus+label{outline:2px solid #3858e9;background-color:peach;color:#055d9c}.woocommerce-customer-effort-score__selection .components-radio-control__option input:checked+label{outline:2px solid #3858e9;background-color:#fbfcfe}.woocommerce-customer-effort-score__selection .components-radio-control__option label::before{display:block;font-size:24px;text-align:center;margin:1em 0;color:#3858e9}.woocommerce-customer-effort-score__selection .components-radio-control__option input[value="1"]+label::before{content:"😞"}.woocommerce-customer-effort-score__selection .components-radio-control__option input[value="2"]+label::before{content:"🙁"}.woocommerce-customer-effort-score__selection .components-radio-control__option input[value="3"]+label::before{content:"😑"}.woocommerce-customer-effort-score__selection .components-radio-control__option input[value="4"]+label::before{content:"🙂"}.woocommerce-customer-effort-score__selection .components-radio-control__option input[value="5"]+label::before{content:"😍"}.woocommerce-customer-effort-score__comments{margin-bottom:1.5em}.woocommerce-customer-effort-score__comments label{display:block;color:inherit;font-weight:bold;text-transform:none;font-size:14px}.woocommerce-customer-effort-score__comments textarea{width:100%}.woocommerce-customer-effort-score__comments .components-base-control__field{margin-bottom:8px}.woocommerce-customer-effort-score .components-modal__content{padding-bottom:100px}.woocommerce-customer-effort-score__buttons{text-align:left;position:fixed;bottom:0;right:0;left:0;background-color:#fff;padding:32px}.woocommerce-customer-effort-score__buttons .components-button{margin-right:1em}.woocommerce-customer-effort-score .woocommerce-customer-effort-score__intro{max-width:550px;margin:0 0 1.5em 0}
