@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.color-block-support-panel .wc-block-feedback-prompt{grid-column:1/-1}.woocommerce-product-query-panel__external-link{display:block;margin-top:12px}.woocommerce-product-query-panel__external-link .components-external-link__icon{margin-right:8px}:where(.products-block-post-template .wp-block-post)>*{margin-bottom:.75rem;margin-top:0}:where(.editor-styles-wrapper .products-block-post-template .wp-block-post)>*>*{margin-bottom:0;margin-top:0}
