<?php return array('dependencies' => array('wc-cart-checkout-base', 'wc-cart-checkout-vendors', 'react', 'react-jsx-runtime', 'wc-blocks-checkout', 'wc-blocks-checkout-events', 'wc-blocks-components', 'wc-blocks-data-store', 'wc-blocks-registry', 'wc-blocks-shared-hocs', 'wc-price-format', 'wc-sanitize', 'wc-settings', 'wc-types', 'wp-a11y', 'wp-api-fetch', 'wp-autop', 'wp-components', 'wp-compose', 'wp-data', 'wp-deprecated', 'wp-dom', 'wp-dom-ready', 'wp-element', 'wp-hooks', 'wp-html-entities', 'wp-i18n', 'wp-is-shallow-equal', 'wp-notices', 'wp-plugins', 'wp-polyfill', 'wp-primitives', 'wp-url', 'wp-wordcount'), 'version' => 'cf98e74b2744b0afb651');
