<?php
declare(strict_types=1);

// THIS FILE IS AUTO-GENERATED. DO NOT EDIT MANUALLY.

namespace Automattic\WooCommerce\Internal\Api\Autogenerated;

use Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Output\ProductVariation;
use Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Output\ExternalProduct;
use Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Output\VariableProduct;
use Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Output\SimpleProduct;
use Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Output\Coupon;

class TypeRegistry {
	/**
	 * Return all concrete types that implement interfaces.
	 *
	 * Pass this to the Schema 'types' config so that inline fragments
	 * (e.g. `... on VariableProduct`) are resolvable.
	 *
	 * @return array
	 */
	public static function get_interface_implementors(): array {
		return array(
			ProductVariation::get(),
			ExternalProduct::get(),
			VariableProduct::get(),
			SimpleProduct::get(),
			Coupon::get(),
		);
	}
}
