<?php

declare( strict_types = 1 );

namespace Automattic\WooCommerce\Admin\API\AI;

defined( 'ABSPATH' ) || exit;

/**
 * Store Title controller
 *
 * @internal
 * @deprecated This class can't be removed due https://github.com/woocommerce/woocommerce/issues/52311.
 */
class BusinessDescription {}
