<?php
namespace ETC\App\Models;

use ETC\Core\Model;

/**
 * Blueprint for frontside related Models.
 *
 * @since      1.4.4
 * @package    ETC
 * @subpackage ETC/Models
 */
abstract class Base_Model extends Model {

	/**
	 *
	 * @since      1.4.4
	 * @package    ETC
	 */
	protected function hooks(){}

}
