<?php
/**
 * Override field methods
 *
 * @package     Kirki
 * @subpackage  Controls
 * @copyright   Copyright (c) 2020, David Vongries
 * @license     https://opensource.org/licenses/MIT
 * @since       2.3.2
 */

/**
 * This is simply an alias for the Kirki_Field_Kirki_Generic class.
 */
class Kirki_Field_Generic extends Kirki_Field_Kirki_Generic {}
