@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.editor-styles-wrapper .wc-block-order-confirmation-additional-information-placeholder{border:1px solid color-mix(in srgb,currentColor 20%,transparent);border-radius:4px;font-style:italic;padding:16px}
