@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.editor-styles-wrapper .is-product-collection-layout-carousel{overflow-x:hidden}.editor-styles-wrapper ul.wc-block-product-template{list-style:none;margin-right:0;padding-right:0}
