<?php return array('dependencies' => array('react', 'react-dom', 'react-jsx-runtime', 'wc-blocks-checkout-events', 'wc-blocks-components', 'wc-blocks-data-store', 'wc-blocks-registry', 'wc-sanitize', 'wc-settings', 'wc-types', 'wp-compose', 'wp-data', 'wp-deprecated', 'wp-element', 'wp-html-entities', 'wp-i18n', 'wp-is-shallow-equal', 'wp-notices', 'wp-polyfill', 'wp-primitives', 'wp-warning'), 'version' => 'c01f0cb08305b3b35f3d');
