@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-block-woocommerce-product-sale-badge{display:flex;flex-direction:column}.wc-block-components-product-sale-badge{background:#fff;border:1px solid #43454b;border-radius:4px;box-sizing:border-box;color:#43454b;display:inline-block;font-size:.875em;font-weight:600;padding:.25em .75em;position:static;text-align:center;text-transform:uppercase;width:fit-content;z-index:9}.wc-block-components-product-sale-badge--align-left{align-self:auto}.wc-block-components-product-sale-badge--align-center{align-self:center}.wc-block-components-product-sale-badge--align-right{align-self:flex-end}.wc-block-components-product-sale-badge span{background-color:inherit;color:inherit}
