@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-product-gallery-thumbnails__scrollable{overflow:hidden}.wc-block-product-gallery-thumbnails__thumbnail{pointer-events:none}@media(max-width:600px){.wp-block-woocommerce-product-gallery-is-layout-flex.is-nowrap{flex-wrap:wrap}}
