.woocommerce-wishlist .page-heading,
.woocommerce-waitlist .page-heading,
.woocommerce-compare .page-heading,
.woocommerce-account .page-heading {
  padding: 2.3vw 0;
  margin-bottom: 2.3vw;
  line-height: 1.4;
  background-color: #fafafa;
}
@media only screen and (max-width: 768px) {
  .woocommerce-wishlist .page-heading,
  .woocommerce-waitlist .page-heading,
  .woocommerce-compare .page-heading,
  .woocommerce-account .page-heading {
    margin-bottom: 50px;
  }
}
@media only screen and (max-width: 480px) {
  .woocommerce-wishlist .page-heading,
  .woocommerce-waitlist .page-heading,
  .woocommerce-compare .page-heading,
  .woocommerce-account .page-heading {
    padding: 15px 0;
  }
}
.woocommerce-wishlist .page-heading .breadcrumbs,
.woocommerce-waitlist .page-heading .breadcrumbs,
.woocommerce-compare .page-heading .breadcrumbs,
.woocommerce-account .page-heading .breadcrumbs,
.woocommerce-wishlist .page-heading .back-history,
.woocommerce-waitlist .page-heading .back-history,
.woocommerce-compare .page-heading .back-history,
.woocommerce-account .page-heading .back-history {
  display: none;
}
.woocommerce-wishlist .page-heading .title,
.woocommerce-waitlist .page-heading .title,
.woocommerce-compare .page-heading .title,
.woocommerce-account .page-heading .title {
  display: block;
  font-size: 1.7rem;
  text-transform: uppercase;
  text-align: center;
}
.woocommerce-wishlist .page-heading .title:before,
.woocommerce-waitlist .page-heading .title:before,
.woocommerce-compare .page-heading .title:before,
.woocommerce-account .page-heading .title:before {
  font-family: 'xstore-icons';
  font-size: 0.75em;
  -webkit-margin-end: 7px;
          margin-inline-end: 7px;
  content: '\e1000';
}
.woocommerce-wishlist.et-header-overlap .page-heading,
.woocommerce-waitlist.et-header-overlap .page-heading,
.woocommerce-compare.et-header-overlap .page-heading,
.woocommerce-account.et-header-overlap .page-heading {
  padding: 7em 0 3em;
}
.woocommerce-wishlist .page-heading .title:before {
  content: '\e908';
}
.woocommerce-waitlist .page-heading .title:before {
  content: '\e959';
}
/* compare page */
.woocommerce-compare .page-heading .title:before {
  content: '\e915';
}
.xstore-compare-table {
  margin-bottom: 0;
  --table-td-padding-v: 16px;
  --table-td-padding-h: 30px;
}
@media only screen and (max-width: 768px) {
  .xstore-compare-table {
    --table-td-padding-v: 10px;
    --table-td-padding-h: 15px;
  }
}
.xstore-compare-table-wrapper {
  overflow: auto;
  overflow-y: hidden;
  margin-bottom: 1.43em;
  border: 1px solid var(--et_border-color);
}
.xstore-compare-table-wrapper::-webkit-scrollbar {
  display: none;
}
.xstore-compare-items td:first-child,
.xstore-compare-items th:first-child {
  padding-left: var(--table-td-padding-h);
  padding-right: var(--table-td-padding-h);
}
.xstore-compare-items td:last-child,
.xstore-compare-items th:last-child {
  padding-right: var(--table-td-padding-h);
  padding-left: var(--table-td-padding-h);
  text-align: center;
}
.xstore-compare-items tr:first-child td {
  padding-top: var(--table-td-padding-v);
  border-top: none;
}
.xstore-compare-items tr:last-child td {
  border-bottom: none;
}
.xstore-compare-items td {
  vertical-align: middle;
  border: 1px solid var(--et_border-color);
  text-align: center;
  padding: var(--table-td-padding-v) var(--table-td-padding-h);
}
.xstore-compare-items td:first-child {
  position: sticky;
  left: 0;
  z-index: 1;
  background-color: var(--et_light-color);
  color: var(--et_dark-2-white);
  text-align: start;
  text-transform: uppercase;
  width: 20%;
  border-left: none;
  min-width: 160px;
}
@media only screen and (max-width: 768px) {
  .xstore-compare-items td:first-child {
    min-width: 100px;
  }
}
.xstore-compare-items td:first-child:hover ~ td {
  background-color: var(--et_light-color);
}
.xstore-compare-items td:last-child {
  border-right: none;
}
.xstore-compare-items td p:last-child {
  margin-bottom: 0;
}
.xstore-compare-items td[class*=xstore-compare-attribute] {
  color: var(--et_dark-2-white);
}
.xstore-compare-items td ~ td {
  min-width: 240px;
}
.xstore-compare-items .xstore-compare {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}
.xstore-compare-items .xstore-compare[data-action=remove]:not(.processing) .et-icon {
  color: currentColor;
}
.xstore-compare-items .product-title {
  display: block;
  font-size: 1.14em;
}
.xstore-compare-items .product_meta {
  font-size: 1rem;
  margin-bottom: 0;
}
.xstore-compare-items .quantity {
  float: none;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  margin: 0;
}
.xstore-compare-product {
  max-width: 300px;
}
.xstore-compare-product[data-product_id*=ghost] img {
  opacity: 0;
  visibility: hidden;
}
.xstore-compare-image {
  display: inline-block;
  padding: 0;
}
.xstore-compare-image img {
  max-width: 200px;
  max-height: 150px;
  width: auto;
}
.xstore-compare-button .button {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  background-color: var(--et_btn-dark-bg-color);
  border: 1px solid var(--et_btn-dark-br-color);
  color: var(--et_btn-dark-color);
  --loader-side-color: var(--et_btn-dark-color);
  white-space: nowrap;
  height: auto;
  margin: 0 7px;
}
.xstore-compare-button .button:hover {
  background-color: var(--et_btn-dark-bg-color-hover);
  border-color: var(--et_btn-dark-br-color-hover);
  color: var(--et_btn-dark-color-hover);
  --loader-side-color: var(--et_btn-dark-color-hover);
}
.xstore-compare-button .button:focus {
  color: var(--et_btn-dark-color);
}
.xstore-compare-checkbox label {
  white-space: nowrap;
  margin-bottom: 0;
}
.xstore-compare-apply-actions select {
  min-width: 170px;
  -webkit-margin-end: 10px;
          margin-inline-end: 10px;
}
.xstore-compare-table .xstore-compare-stock_status p {
  line-height: var(--p-line-height, 1.6);
  font-size: var(--p-font-size, 1.14rem);
}
.xstore-compare-table .xstore-compare-stock_status p:last-child {
  margin-bottom: 0;
}
.xstore-compare-table .star-rating {
  margin-bottom: 0;
}
.xstore-compare-table-wrapper:not(:hover) .xstore-compare-table-arrow[data-side=left] {
  -webkit-transform: translateX(-7px);
          transform: translateX(-7px);
}
.xstore-compare-table-wrapper:not(:hover) .xstore-compare-table-arrow[data-side=right] {
  -webkit-transform: translateX(7px);
          transform: translateX(7px);
}
.xstore-compare-table-arrow {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center;
  width: var(--arrow-size, 50px) !important;
  height: var(--arrow-size, 50px) !important;
  position: absolute;
  top: calc(50% - var(--arrow-size,50px)/ 2);
  background-color: var(--et_white-2-dark);
  border: 1px solid var(--et_border-color);
  cursor: pointer;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
  outline: 0;
  border-radius: 50%;
  z-index: 3;
}
.xstore-compare-table-arrow:hover {
  color: var(--et_white-2-dark);
  background-color: var(--et_dark-2-white);
}
.xstore-compare-table-arrow:before {
  font-family: "xstore-icons";
  font-size: calc(var(--arrow-size, 50px)/2.5);
}
.xstore-compare-table-arrow[data-side=left] {
  left: calc(var(--arrow-size, 50px)*-1 - 5px);
}
.xstore-compare-table-arrow[data-side=left]:before {
  content: '\e902';
}
.xstore-compare-table-arrow[data-side=right] {
  right: calc(var(--arrow-size, 50px)*-1 - 5px);
}
.xstore-compare-table-arrow[data-side=right]:before {
  content: '\e904';
}
.xstore-compare-table.processing ~ .xstore-compare-table-arrow {
  display: none;
}
.form-actions {
  padding-top: 15px;
  padding-bottom: 15px;
  margin-bottom: -10px;
}
@media only screen and (min-width: 993px) {
  .form-actions {
    padding-top: 0;
    padding-bottom: 3em;
  }
}
.form-actions > div > div {
  margin-bottom: 10px;
}
.form-actions .btn {
  height: auto;
  padding-top: 0.89rem;
  padding-bottom: 0.89rem;
}
@media only screen and (max-width: 480px) {
  .form-actions .compare-more-products {
    text-align: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    width: 100%;
  }
}
.empty-compare-block {
  text-align: center;
  color: var(--et_dark-2-white);
  padding: 5em 0;
}
.empty-compare-block:before {
  content: "\e915";
  font-family: 'xstore-icons';
  display: block;
  border: none !important;
  font-size: 2.6rem;
  line-height: 1.5;
}
.empty-compare-block h1,
.empty-compare-block h2 {
  font-size: 1.7rem;
  text-transform: uppercase;
}
.empty-compare-block .btn {
  background-color: var(--et_btn-dark-bg-color);
  border: 1px solid var(--et_btn-dark-br-color);
  color: var(--et_btn-dark-color);
  -webkit-text-fill-color: currentColor;
  height: auto;
}
.empty-compare-block .btn:hover {
  background-color: var(--et_btn-dark-bg-color-hover);
  border-color: var(--et_btn-dark-br-color-hover);
  color: var(--et_btn-dark-color-hover);
}
.empty-compare-block p {
  color: var(--et_font-color);
}
@media only screen and (max-width: 992px) {
  .form-actions > div > div {
    -webkit-box-flex: 1;
        -ms-flex: 1;
            flex: 1;
    -ms-flex-preferred-size: 100%;
        flex-basis: 100%;
    width: 100%;
  }
  .xstore-compare-apply-actions select {
    -webkit-box-flex: 1;
        -ms-flex: 1;
            flex: 1;
    min-width: unset;
  }
}
.rtl .xstore-compare-items td:first-child {
  left: auto;
  right: 0;
  border-right: none;
  border-left: 1px solid var(--et_border-color);
}
.rtl .xstore-compare-items td:last-child {
  border-right: 1px solid var(--et_border-color);
  border-left: none;
}
