@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-error{align-items:center;color:#757575;display:flex;flex-direction:column;justify-content:center;margin:48px 0;padding:48px 0;text-align:center}.wc-block-components-error__header{color:#646970;font-size:2em;margin:0}.wc-block-components-error__image{margin:0 0 24px;width:25%}.wc-block-components-error__text{color:#8c8f94;font-size:1.25em;margin:1em 0 0;max-width:60ch}.wc-block-components-error__message{color:#8c8f94;font-style:italic;margin:1em auto 0;max-width:60ch}.wc-block-error__button{margin:48px 0 0}
