@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}:where(.wp-block-woocommerce-product-review-form) input:not([type=submit]),:where(.wp-block-woocommerce-product-review-form) textarea{border:1px solid #949494;font-family:inherit;font-size:1em}:where(.wp-block-woocommerce-product-review-form) input:where(:not([type=submit]):not([type=checkbox])),:where(.wp-block-woocommerce-product-review-form) textarea{padding:calc(.667em + 2px)}:where(.wp-block-woocommerce-product-review-form) :where(.comment-form-rating button.is-hovered path),:where(.wp-block-woocommerce-product-review-form) :where(.comment-form-rating button.is-selected path){fill:currentColor}.wp-block-woocommerce-product-review-form{box-sizing:border-box}.wp-block-woocommerce-product-review-form[style*=font-weight].comment-respond :where(.comment-reply-title){font-weight:inherit}.wp-block-woocommerce-product-review-form[style*=font-family].comment-respond :where(.comment-reply-title){font-family:inherit}.wp-block-woocommerce-product-review-form[class*=-font-size].comment-respond :where(.comment-reply-title),.wp-block-woocommerce-product-review-form[style*=font-size].comment-respond :where(.comment-reply-title){font-size:inherit}.wp-block-woocommerce-product-review-form[style*=line-height].comment-respond :where(.comment-reply-title){line-height:inherit}.wp-block-woocommerce-product-review-form[style*=font-style].comment-respond :where(.comment-reply-title){font-style:inherit}.wp-block-woocommerce-product-review-form[style*=letter-spacing].comment-respond :where(.comment-reply-title){letter-spacing:inherit}.wp-block-woocommerce-product-review-form :where(input[type=submit]){box-shadow:none;cursor:pointer;display:inline-block;overflow-wrap:break-word;text-align:center}.wp-block-woocommerce-product-review-form .review-form input:not([type=submit]):not([type=checkbox]):not([type=hidden]),.wp-block-woocommerce-product-review-form .review-form textarea{box-sizing:border-box;display:block;width:100%}.wp-block-woocommerce-product-review-form textarea[name=comment]:focus{outline-offset:-2px}.wp-block-woocommerce-product-review-form .comment-form-author label,.wp-block-woocommerce-product-review-form .comment-form-email label,.wp-block-woocommerce-product-review-form .comment-form-url label{display:block;margin-bottom:.25em}.wp-block-woocommerce-product-review-form .comment-form-cookies-consent{display:flex;gap:.25em}.wp-block-woocommerce-product-review-form .comment-form-cookies-consent #wp-comment-cookies-consent{margin-top:.35em}.wp-block-woocommerce-product-review-form .comment-reply-title{font-size:var(--wp--preset--font-size--medium);font-weight:700;margin-bottom:0}.wp-block-woocommerce-product-review-form .comment-form-rating select{margin-right:.5em}.wp-block-woocommerce-product-review-form .comment-form-rating button{appearance:none;background:transparent;border:none;cursor:pointer;padding:0 1px}.wp-block-woocommerce-product-review-form .comment-form-rating .stars-wrapper:not([hidden]){align-items:center;display:flex;gap:16px}.wp-block-woocommerce-product-review-form .comment-form-rating .stars{align-items:center;display:flex}.wp-block-woocommerce-product-review-form .comment-form-rating .stars svg{display:block}
