<?php

declare(strict_types=1);

// THIS FILE IS AUTO-GENERATED. DO NOT EDIT MANUALLY.

namespace Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Pagination;

use Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Output\Coupon as CouponType;
use Automattic\WooCommerce\Internal\Api\Schema\ObjectType;
use Automattic\WooCommerce\Internal\Api\Schema\Type;

class CouponEdge {
	private static ?ObjectType $instance = null;

	public static function get(): ObjectType {
		if ( null === self::$instance ) {
			self::$instance = new ObjectType(
				array(
					'name'   => 'CouponEdge',
					'fields' => fn() => array(
						'cursor' => array(
							'type' => Type::nonNull( Type::string() ),
						),
						'node'   => array(
							'type' => Type::nonNull( CouponType::get() ),
						),
					),
				)
			);
		}
		return self::$instance;
	}
}
