@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.coming-soon-newsletter-mailpoet-setting-panel-body{background-color:#f1f6fc;padding:15px}.coming-soon-newsletter-mailpoet-setting-panel-body h3{font-size:13px;text-transform:none}.coming-soon-newsletter-mailpoet-setting-panel-body a.components-button.is-link{text-decoration:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}body:has(.woocommerce-coming-soon-store-only) .woocommerce-breadcrumb{display:none}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-site-blocks:has(>.wp-block-woocommerce-coming-soon){--wp--style--root--padding-top:0;--wp--style--root--padding-bottom:0}.woocommerce-coming-soon-default{--cover--color-background:var(--woocommerce-coming-soon-color);--wp--preset--color--background:var(--woocommerce-coming-soon-color);--responsive--aligndefault-width:1280px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;min-width:320px}.woocommerce-coming-soon-default h1.wp-block-heading.woocommerce-coming-soon-banner{text-wrap:balance}.woocommerce-coming-soon-default .wp-block-loginout a,.woocommerce-coming-soon-image-gallery .wp-block-loginout a,.woocommerce-coming-soon-minimal-left-image .wp-block-loginout a{text-decoration:none}.woocommerce-coming-soon-minimal-left-image{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif}.woocommerce-coming-soon-minimal-left-image__content .wp-block-columns-is-layout-flex{justify-content:center}.woocommerce-coming-soon-modern-black{--wp--preset--color--contrast:#fff}.woocommerce-coming-soon-split-right-image{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif}.woocommerce-coming-soon-split-right-image .woocommerce-split-right-image-content{width:100%}.woocommerce-coming-soon-split-right-image .woocommerce-split-right-image-cover{align-items:start}.woocommerce-coming-soon-split-right-image .is-size-fit-content{width:fit-content}.block-editor-block-preview__content-iframe .wp-block-woocommerce-coming-soon{aspect-ratio:1/1}
