.cm-s-yonce.CodeMirror{background:#1c1c1c;color:#d4d4d4}.cm-s-yonce div.CodeMirror-selected{background:rgba(252,69,133,.478)}.cm-s-yonce .CodeMirror-line::-moz-selection,.cm-s-yonce .CodeMirror-line::selection,.cm-s-yonce .CodeMirror-line>span::-moz-selection,.cm-s-yonce .CodeMirror-line>span::selection,.cm-s-yonce .CodeMirror-line>span>span::-moz-selection,.cm-s-yonce .CodeMirror-line>span>span::selection,.cm-s-yonce .CodeMirror-selected,.cm-s-yonce .CodeMirror-selectedtext{background:rgba(252,67,132,.47)}.cm-s-yonce.CodeMirror pre{padding-left:0}.cm-s-yonce .CodeMirror-gutters{background:#1c1c1c;border-right:0}.cm-s-yonce .CodeMirror-linenumber{padding-right:10px}.cm-s-yonce .CodeMirror-activeline .CodeMirror-linenumber.CodeMirror-gutter-elt{background:#1c1c1c;color:#fc4384}.cm-s-yonce .CodeMirror-linenumber{color:#777}.cm-s-yonce .CodeMirror-cursor{border-left:2px solid #fc4384}.cm-s-yonce .cm-searching{background:rgba(243,155,53,.3)!important;outline:1px solid #f39b35}.cm-s-yonce .cm-searching.CodeMirror-selectedtext{background:rgba(243,155,53,.7)!important;color:#fff}.cm-s-yonce .cm-keyword{color:#00a7aa}.cm-s-yonce .cm-atom{color:#f39b35}.cm-s-yonce .cm-number,.cm-s-yonce span.cm-type{color:#a06fca}.cm-s-yonce .cm-def{color:#98e342}.cm-s-yonce .cm-property,.cm-s-yonce span.cm-variable{color:#d4d4d4;font-style:italic}.cm-s-yonce span.cm-variable-2{color:#da7dae;font-style:italic}.cm-s-yonce span.cm-variable-3{color:#a06fca}.cm-s-yonce .cm-type.cm-def{text-decoration:underline}.cm-s-yonce .cm-callee,.cm-s-yonce .cm-property.cm-def,.cm-s-yonce .cm-type.cm-def{color:#fc4384;font-style:normal}.cm-s-yonce .cm-operator,.cm-s-yonce .cm-qualifier,.cm-s-yonce .cm-tag{color:#fc4384}.cm-s-yonce .cm-tag.cm-bracket{color:#d4d4d4}.cm-s-yonce .cm-attribute{color:#a06fca}.cm-s-yonce .cm-comment{color:#696d70;font-style:italic;font-weight:400}.cm-s-yonce .cm-comment.cm-tag{color:#fc4384}.cm-s-yonce .cm-comment.cm-attribute{color:#d4d4d4}.cm-s-yonce .cm-string{color:#e6db74}.cm-s-yonce .cm-string-2{color:#f39b35}.cm-s-yonce .cm-meta{background:inherit;color:#d4d4d4}.cm-s-yonce .cm-builtin{color:#fc4384}.cm-s-yonce .cm-header{color:#da7dae}.cm-s-yonce .cm-hr{color:#98e342}.cm-s-yonce .cm-link{color:#696d70;font-style:italic;text-decoration:none}.cm-s-yonce .cm-error{border-bottom:1px solid #c42412}.cm-s-yonce .CodeMirror-activeline-background{background:#272727}.cm-s-yonce .CodeMirror-matchingbracket{color:#d4d4d4!important;outline:1px solid grey}
