@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-filter-chips.is-loading .wc-block-product-filter-chips__item{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;display:block;line-height:1;margin:5px 0;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;z-index:1}.wc-block-product-filter-chips.is-loading .wc-block-product-filter-chips__item>*{visibility:hidden}.wc-block-product-filter-chips.is-loading .wc-block-product-filter-chips__item:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(-90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;right:0;position:absolute;left:0;top:0;transform:translateX(100%)}@keyframes loading__animation{to{transform:translateX(-100%)}}@media screen and (prefers-reduced-motion:reduce){.wc-block-product-filter-chips.is-loading .wc-block-product-filter-chips__item{animation:none}}
