@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pills){display:inline-flex;flex-wrap:wrap;gap:8px;list-style:none;margin:0;padding:0}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill){--pill-color:currentColor;--pill-background-color:transparent;background-color:var(--pill-background-color);border:1px solid color-mix(in srgb,var(--pill-color) 40%,transparent);border-radius:2px;color:var(--pill-color);cursor:pointer;font-size:.8em;padding:.25em .75em;user-select:none}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill):where(:has(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill-input:disabled)){color:color-mix(in srgb,var(--pill-color) 40%,transparent);cursor:not-allowed;text-decoration:line-through}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill):where(:hover:not(:has(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill-input:disabled))){background-color:color-mix(in srgb,var(--pill-color) 10%,transparent)}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill):where(:hover:has(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill-input:checked)){background-color:color-mix(in srgb,var(--pill-background-color) 85%,transparent)}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill):has(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill-input[hidden]){display:none}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill):where(:focus-within){outline:1px solid var(--pill-color);outline-offset:1px}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill):where(:focus-within:has(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill-input:checked)){outline-color:var(--pill-background-color)}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill) :where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__pill-input){height:0;opacity:0;position:absolute;width:0}:where(.wc-block-add-to-cart-with-options-variation-selector-attribute-options__dropdown){height:3em;padding:.25em 1em}
