(()=>{"use strict";var o,e,t,r={4190:(o,e,t)=>{const r=window.wp.blocks;var c=t(7871),i=t(6645);const n=JSON.parse('{"name":"woocommerce/add-to-cart-with-options-variation-selector","title":"Variation Selector (Beta)","description":"Display any product variations available to select from and add to cart.","category":"woocommerce-product-elements","keywords":["WooCommerce"],"usesContext":["postId"],"ancestor":["woocommerce/add-to-cart-with-options"],"textdomain":"woocommerce","apiVersion":3,"supports":{"interactivity":true},"$schema":"https://schemas.wp.org/trunk/block.json","viewScriptModule":"woocommerce/add-to-cart-with-options-variation-selector"}'),a=window.wp.blockEditor;var s=t(7723);const l=[["woocommerce/add-to-cart-with-options-variation-selector-attribute",{},[["core/group",{layout:{type:"flex",orientation:"vertical",flexWrap:"nowrap"},style:{spacing:{blockGap:"0.5rem",margin:{top:"1rem",bottom:"1rem"}}}},[["woocommerce/add-to-cart-with-options-variation-selector-attribute-name",{fontSize:"medium"}],["woocommerce/add-to-cart-with-options-variation-selector-attribute-options"]]]]]];(0,s.__)("Color","woocommerce"),(0,s.__)("Blue","woocommerce"),(0,s.__)("Red","woocommerce"),(0,s.__)("Green","woocommerce"),(0,s.__)("Size","woocommerce"),(0,s.__)("Small","woocommerce"),(0,s.__)("Medium","woocommerce"),(0,s.__)("Large","woocommerce");var p=t(790);(0,r.registerBlockType)(n,{edit:function(o){const{className:e}=o.attributes,t=(0,a.useBlockProps)({className:e}),r=(0,a.useInnerBlocksProps)(t,{template:l,templateLock:"all"});return(0,p.jsx)("div",{...r})},icon:{src:(0,p.jsx)(c.A,{icon:i.A,className:"wc-block-editor-components-block-icon"})},save:function(){const o=a.useBlockProps.save(),e=a.useInnerBlocksProps.save({...o,role:"list"});return(0,p.jsx)("div",{...e})}})},790:o=>{o.exports=window.ReactJSXRuntime},6087:o=>{o.exports=window.wp.element},7723:o=>{o.exports=window.wp.i18n},5573:o=>{o.exports=window.wp.primitives}},c={};function i(o){var e=c[o];if(void 0!==e)return e.exports;var t=c[o]={exports:{}};return r[o](t,t.exports,i),t.exports}i.m=r,o=[],i.O=(e,t,r,c)=>{if(!t){var n=1/0;for(p=0;p<o.length;p++){for(var[t,r,c]=o[p],a=!0,s=0;s<t.length;s++)(!1&c||n>=c)&&Object.keys(i.O).every(o=>i.O[o](t[s]))?t.splice(s--,1):(a=!1,c<n&&(n=c));if(a){o.splice(p--,1);var l=r();void 0!==l&&(e=l)}}return e}c=c||0;for(var p=o.length;p>0&&o[p-1][2]>c;p--)o[p]=o[p-1];o[p]=[t,r,c]},i.n=o=>{var e=o&&o.__esModule?()=>o.default:()=>o;return i.d(e,{a:e}),e},t=Object.getPrototypeOf?o=>Object.getPrototypeOf(o):o=>o.__proto__,i.t=function(o,r){if(1&r&&(o=this(o)),8&r)return o;if("object"==typeof o&&o){if(4&r&&o.__esModule)return o;if(16&r&&"function"==typeof o.then)return o}var c=Object.create(null);i.r(c);var n={};e=e||[null,t({}),t([]),t(t)];for(var a=2&r&&o;"object"==typeof a&&!~e.indexOf(a);a=t(a))Object.getOwnPropertyNames(a).forEach(e=>n[e]=()=>o[e]);return n.default=()=>o,i.d(c,n),c},i.d=(o,e)=>{for(var t in e)i.o(e,t)&&!i.o(o,t)&&Object.defineProperty(o,t,{enumerable:!0,get:e[t]})},i.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(o){if("object"==typeof window)return window}}(),i.o=(o,e)=>Object.prototype.hasOwnProperty.call(o,e),i.r=o=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(o,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(o,"__esModule",{value:!0})},i.j=2475,(()=>{var o={2475:0};i.O.j=e=>0===o[e];var e=(e,t)=>{var r,c,[n,a,s]=t,l=0;if(n.some(e=>0!==o[e])){for(r in a)i.o(a,r)&&(i.m[r]=a[r]);if(s)var p=s(i)}for(e&&e(t);l<n.length;l++)c=n[l],i.o(o,c)&&o[c]&&o[c][0](),o[c]=0;return i.O(p)},t=globalThis.webpackChunkwebpackWcBlocksMainJsonp=globalThis.webpackChunkwebpackWcBlocksMainJsonp||[];t.forEach(e.bind(null,0)),t.push=e.bind(null,t.push.bind(t))})();var n=i.O(void 0,[94],()=>i(4190));n=i.O(n),((this.wc=this.wc||{}).blocks=this.wc.blocks||{})["add-to-cart-with-options-variation-selector"]=n})();