<?php return array('dependencies' => array('react', 'wc-experimental', 'wc-settings', 'wc-tracks', 'wp-api-fetch', 'wp-components', 'wp-element', 'wp-i18n', 'wp-primitives', 'wp-url'), 'version' => '44dec6e33204dfe949d3');
