:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-dismissable-list{margin:0 20px 10px 20px;animation:isLoaded;animation-duration:250ms}@media(min-width: 782px){.woocommerce-dismissable-list{margin-right:0;margin-left:0}}.woocommerce-dismissable-list .woocommerce-dismissable-list__controls{text-align:center}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-shipping-plugin-item__logo{width:36px;height:auto}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-recommended-shipping-extensions .woocommerce-list__item>.woocommerce-list__item-inner{align-items:flex-start}.woocommerce-recommended-shipping-extensions .woocommerce-list__item:hover{background-color:#fff}.woocommerce-recommended-shipping-extensions .woocommerce-list__item:hover .woocommerce-list__item-title{color:#1e1e1e}.woocommerce-recommended-shipping-extensions .woocommerce-list__item-title{font-size:14px;color:#1e1e1e;font-weight:600}.woocommerce-recommended-shipping-extensions .woocommerce-pill{margin-right:4px;margin-top:4px;margin-bottom:4px;padding:2px 8px}@media(min-width: 480px){.woocommerce-recommended-shipping-extensions .woocommerce-pill{margin-top:0;margin-bottom:0}}.woocommerce-recommended-shipping-extensions .woocommerce-list__item-after .components-button{margin-right:12px}.woocommerce-recommended-shipping-extensions .woocommerce-list__item-text,.woocommerce-recommended-shipping-extensions .woocommerce-recommended-shipping__header-heading{max-width:749px}
