#paymob-logo {
		width: auto !important;
	height:24px !important;
	margin-inline-start: auto  !important ;
	/* max-width: 70px !important; */
	float: right !important;
	padding-top: 6px !important;
}

/* Align logo to the left for RTL languages */
html[lang="ar"] #paymob-logo {
	float: left !important;
}

.payment_method_paymob label {
	/* 	display: flex !important ; */
	/* 	justify-content: space-between; */
	/* 	width:100% !important ; */
	flex-grow: 1 !important;
	align-items: end !important;
	/* margin-inline-start: 0.25rem  !important; */
	/* 	margin-bottom:0  !important; */
}

li.payment_method_paymob div.payment_method_paymob {
	/* display: flex !important ; */
	flex-wrap: wrap !important;
}

/* firefox */
@-moz-document url-prefix() {
	#paymob-logo {
		margin-left: auto !important;
	}
}
.woocommerce-checkout.processing {
    position: relative;
}
.woocommerce-checkout.processing:after {
    content: '';
    position: absolute;
    top: 50%;
    left: 50%;
    margin-left: -16px;
    margin-top: -16px;
    width: 32px;
    height: 32px;
    border: 3px solid rgba(0,0,0,0.1);
    border-left-color: #000;
    border-radius: 50%;
    animation: spin 0.6s linear infinite;
    z-index: 9999;
}
@keyframes spin {
    from {
        transform: rotate(0deg);
    }
    to {
        transform: rotate(360deg);
    }
}
/* flash-message.css */
.flash-message {
    position: fixed;
    top: 50px; /* Increased padding from top */
    right: 20px;
    z-index: 9999;
    background: linear-gradient(135deg, #f44336, #d32f2f);
    color: white;
    padding: 15px 20px;
    border-radius: 8px;
    box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
    opacity: 1;
    display: flex;
    align-items: center;
    gap: 10px;
    font-family: Arial, sans-serif;
    font-size: 14px;
    animation: slideIn 0.5s ease;
    transition: opacity 0.3s ease, transform 0.3s ease;
}

.flash-message p {
    margin: 0;
    flex-grow: 1;
}

.flash-message .close-flash {
    color: white;
    background-color: rgba(255, 255, 255, 0.2);
    border: none;
    border-radius: 50%;
    width: 25px;
    height: 25px;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 18px;
    cursor: pointer;
    transition: background-color 0.3s;
}

.flash-message .close-flash:hover {
    background-color: rgba(255, 255, 255, 0.4);
}

@keyframes slideIn {
    from {
        opacity: 0;
        transform: translateX(100%);
    }
    to {
        opacity: 1;
        transform: translateX(0);
    }
}
