<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
esc_html__( 'VAT', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Tax rate', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Payment date', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Payment Date:', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Payment method', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Shipping method', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Send email', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Description', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'SKU', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Product', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Quantity', 'woocommerce-pdf-invoices-packing-slips' );
esc_html__( 'Price', 'woocommerce-pdf-invoices-packing-slips' );