<!-- wp:woocommerce/add-to-cart-with-options-grouped-product-selector -->
<div
	class="wp-block-woocommerce-add-to-cart-with-options-grouped-product-selector"
	role="list"
>
	<!-- wp:woocommerce/add-to-cart-with-options-grouped-product-item -->
	<div
		class="wp-block-woocommerce-add-to-cart-with-options-grouped-product-item"
		role="listitem"
	>
		<!-- wp:group {"style":{"spacing":{"margin":{"top":"1rem","bottom":"1rem"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"left"}} -->
		<div
			class="wp-block-group"
			style="margin-top: 1rem; margin-bottom: 1rem"
		>
			<!-- wp:woocommerce/add-to-cart-with-options-grouped-product-item-selector /-->

			<!-- wp:woocommerce/add-to-cart-with-options-grouped-product-item-label {"style":{"layout":{"selfStretch":"fill"},"spacing":{"margin":{"top":"0","bottom":"0"}},"typography":{"fontWeight":400}}} /-->

			<!-- wp:group {"style":{"spacing":{"blockGap":"0"}},"layout":{"type":"flex","orientation":"vertical","justifyContent":"right"}} -->
			<div class="wp-block-group">
				<!-- wp:woocommerce/product-price {"textAlign":"right","isDescendentOfSingleProductTemplate":true,"isDescendentOfSingleProductBlock":true,"style":{"typography":{"fontWeight":400,"fontStyle":"normal"}}} /-->
				<!-- wp:woocommerce/product-stock-indicator {"fontSize":"small"} /--></div>
			<!-- /wp:group -->
		</div>
		<!-- /wp:group -->
	</div>
	<!-- /wp:woocommerce/add-to-cart-with-options-grouped-product-item -->
</div>
<!-- /wp:woocommerce/add-to-cart-with-options-grouped-product-selector -->
<!-- wp:group {"layout":{"type":"flex","flexWrap":"nowrap"}} -->
<div class="wp-block-group"><!-- wp:woocommerce/product-button {"textAlign":"left"} /--></div>
<!-- /wp:group -->
