@use "../../common/variables" as *;
@use "../../common/mixins/utilities" as *;

//
// ATUM Orders list pages
//------------------------

table.wp-list-table {
	
	.column-notes {
		width: 48px;
		text-align: center;
		
		img {
			margin: 0 auto;
			padding-top: 0 !important;
		}
	}
	
	.column-actions {
		width: 110px;
		
		a {
			float: left;
			margin: 0 4px 2px 0;
			cursor: pointer;
			height: inherit;
			padding: 3px 4px;
			
			img {
				display: block;
				width: 12px;
				height: auto;
			}
		}
	}
	
	.column-status {
		text-align: left;
		
		@include atum-order-status;
	}
	
	tbody > :nth-child(odd), ul.striped > :nth-child(odd), .alternate {
		background-color: var(--atum-table-row-odd);
		&.active-row {
			background-color: var(--primary-dark);
		}
	}
	
	td.column-status {
		padding-top: 9px;
	}
	
	.column-notes {
		.note-on {
			@include ir();
			margin: 0 auto;
			color: var(--wp-gray-1);
			
			&:after {
				@include atum-icon-font-family;
				content: $atmi-bubble;
				line-height: 16px;
			}
		}
	}
	
	.column-actions {
		
		.complete, .view, .pdf{
			i {
				font-size: 18px;
			}
		}
		
		.pdf {
			i {
				color: var(--danger);
			}
		}
		
	}
	
	img {
		margin: 1px 2px;
	}
	
	.row-actions, span.na {
		color: var(--wp-gray-1);
	}
	
	.notes_head, .notes_head, .status_head {
		@include ir();
		margin: 0 auto;
		
		&:after {
			@include atum-icon-font-family;
		}
	}
	
	.notes_head::after {
		content: $atmi-bubble;
	}
	
	.status_head::after {
		content: $atmi-cloud-sync;
	}
	
}