#menu-posts-testimonial .wp-menu-image {
  background: none;
  background-image: url(../images/testimonials-icon.png);
  background-position: 7px -132px !important;
  background-repeat: no-repeat;
}
#menu-posts-testimonial.wp-menu-open .wp-menu-image,
#menu-posts-testimonial:hover .wp-menu-image {
  background-position: 7px -164px !important;
}
#icon-edit.icon32-posts-testimonial {
  background: transparent url(../images/testimonials-icon.png) no-repeat 0 0;
}
@media only screen and (-webkit-min-device-pixel-ratio: 2), only screen and (min--moz-device-pixel-ratio: 2), only screen and (-o-min-device-pixel-ratio: 2/1), only screen and (min-device-pixel-ratio: 2) {
  #menu-posts-testimonial .wp-menu-image {
    background-image: url(../images/testimonials-icon@x2.png);
    background-size: 32px 187px;
  }
  #icon-edit.icon32-posts-testimonial {
    background-image: url(../images/testimonials-icon@x2.png);
    background-size: 32px 187px;
  }
}
