<?php return array('dependencies' => array('react', 'wc-tracks', 'wp-commands', 'wp-core-data', 'wp-data', 'wp-dom-ready', 'wp-element', 'wp-html-entities', 'wp-i18n', 'wp-primitives', 'wp-url'), 'version' => 'b3da20477a4b2fb1534f');
