__( 'Display Conditions', 'elementor-pro' );
__( "Empty attribute names aren't valid and won't render on the page.", 'elementor-pro' );
__( 'Name', 'elementor-pro' );
__( 'Value', 'elementor-pro' );
__(
				'Names can only use letters, numbers, dashes (-) and underscores (_).',
				'elementor-pro'
			);
__(
			'The use of pseudo-states is not permitted. Instead, switch to the desired pseudo state and add your custom code there.',
			'elementor-pro'
		);
__(
			'The use of @media width queries is not permitted. Instead, switch to the desired breakpoint and add your custom code there.',
			'elementor-pro'
		);
__( 'Clear', 'elementor-pro' );
