@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.is-layout-constrained>.wp-block-woocommerce-customer-account.alignright{float:none;justify-content:flex-end}.is-layout-constrained>.wp-block-woocommerce-customer-account.alignleft{float:none;justify-content:flex-start}.is-layout-constrained>.wp-block-woocommerce-customer-account.aligncenter{float:none;justify-content:center}:where(.wp-block-woocommerce-customer-account){--wc-customer-account-viewport-gutter:var(--wp--preset--spacing--20,16px);--wc-customer-account-dropdown-padding-inline:var( --wp--preset--spacing--30,16px );--wc-customer-account-dropdown-padding-block:var( --wp--preset--spacing--20,8px );--wc-customer-account-dropdown-surface:var( --wp--preset--color--base,#fff );--wc-customer-account-dropdown-border-color:color-mix(in srgb,currentColor 20%,transparent);--wc-customer-account-dropdown-item-hover-bg:color-mix(in srgb,currentColor 10%,transparent)}:where(.wp-block-woocommerce-customer-account .wc-block-customer-account__link),:where(.wp-block-woocommerce-customer-account.wc-block-customer-account--has-dropdown .wc-block-customer-account__toggle){align-items:center;color:inherit;display:flex;font-family:inherit;font-size:inherit;font-weight:inherit;line-height:1;padding:.5em;text-decoration:none;white-space:nowrap}:where(.wp-block-woocommerce-customer-account .wc-block-customer-account__link):hover,:where(.wp-block-woocommerce-customer-account.wc-block-customer-account--has-dropdown .wc-block-customer-account__toggle):hover{text-decoration:underline}:where(.wp-block-woocommerce-customer-account .wc-block-customer-account__link) .wc-block-customer-account__account-icon,:where(.wp-block-woocommerce-customer-account.wc-block-customer-account--has-dropdown .wc-block-customer-account__toggle) .wc-block-customer-account__account-icon{height:1.5em;width:1.5em}:where(.wp-block-woocommerce-customer-account) .wc-block-customer-account__caret{height:.375em;margin-right:.25em;transition:transform .2s ease;width:.625em}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown{position:relative}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__toggle{background:none;border:none;cursor:pointer;font:inherit}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown.wc-block-customer-account--is-dropdown-open .wc-block-customer-account__caret{transform:rotate(-180deg)}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown{background:var(--wc-customer-account-dropdown-surface);border:1px solid var(--wc-customer-account-dropdown-border-color);border-radius:4px;box-shadow:0 2px 8px rgba(0,0,0,.12);right:0;max-width:calc(100vw - var(--wc-customer-account-viewport-gutter)*2);min-width:200px;position:absolute;top:100%;z-index:100}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown[hidden]{display:none}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown.wc-block-customer-account--show-above .wc-block-customer-account__dropdown{bottom:100%;top:auto}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown.wc-block-customer-account--align-right .wc-block-customer-account__dropdown{right:auto;left:0}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown-divider{background:var(--wc-customer-account-dropdown-border-color);height:1px}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown-item{color:inherit;display:block;font-size:var(--wp--preset--font-size--small);line-height:1.5;padding:calc(var(--wc-customer-account-dropdown-padding-block)/2) var(--wc-customer-account-dropdown-padding-block);text-decoration:none;white-space:nowrap}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown-item:focus,:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown-item:hover{background:var(--wc-customer-account-dropdown-item-hover-bg);text-decoration:none}:where(.wp-block-woocommerce-customer-account).wc-block-customer-account--has-dropdown .wc-block-customer-account__dropdown-item:focus-visible{outline:2px solid currentColor;outline-offset:-2px}
