<?php
declare(strict_types=1);
namespace Automattic\WooCommerce\Internal\Agentic\Enums\Specs;

/**
 * Payment provider identifiers as defined in the Agentic Commerce Protocol.
 */
class PaymentProvider {
	/**
	 * Stripe payment provider.
	 */
	const STRIPE = 'stripe';
}
