<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Atum\\Addons\\AddonBootstrap' => $baseDir . '/classes/Addons/AddonBootstrap.php',
    'Atum\\Addons\\Addons' => $baseDir . '/classes/Addons/Addons.php',
    'Atum\\Addons\\AddonsLoader' => $baseDir . '/classes/Addons/AddonsLoader.php',
    'Atum\\Addons\\AddonsLoaderDev' => $baseDir . '/classes/Addons/AddonsLoaderDev.php',
    'Atum\\Addons\\Updater' => $baseDir . '/classes/Addons/Updater.php',
    'Atum\\Api\\AtumApi' => $baseDir . '/classes/Api/AtumApi.php',
    'Atum\\Api\\Controllers\\V3\\AddonsController' => $baseDir . '/classes/Api/Controllers/V3/AddonsController.php',
    'Atum\\Api\\Controllers\\V3\\AllOrderRefundsController' => $baseDir . '/classes/Api/Controllers/V3/AllOrderRefundsController.php',
    'Atum\\Api\\Controllers\\V3\\AtumOrderNotesController' => $baseDir . '/classes/Api/Controllers/V3/AtumOrderNotesController.php',
    'Atum\\Api\\Controllers\\V3\\AtumOrdersController' => $baseDir . '/classes/Api/Controllers/V3/AtumOrdersController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardController' => $baseDir . '/classes/Api/Controllers/V3/DashboardController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardCurrentStockValueController' => $baseDir . '/classes/Api/Controllers/V3/DashboardCurrentStockValueController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardLostSalesController' => $baseDir . '/classes/Api/Controllers/V3/DashboardLostSalesController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardOrdersController' => $baseDir . '/classes/Api/Controllers/V3/DashboardOrdersController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardPromoSalesController' => $baseDir . '/classes/Api/Controllers/V3/DashboardPromoSalesController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardSalesController' => $baseDir . '/classes/Api/Controllers/V3/DashboardSalesController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardStatisticsController' => $baseDir . '/classes/Api/Controllers/V3/DashboardStatisticsController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardStockControlController' => $baseDir . '/classes/Api/Controllers/V3/DashboardStockControlController.php',
    'Atum\\Api\\Controllers\\V3\\DashboardWidgetController' => $baseDir . '/classes/Api/Controllers/V3/DashboardWidgetController.php',
    'Atum\\Api\\Controllers\\V3\\FullExportController' => $baseDir . '/classes/Api/Controllers/V3/FullExportController.php',
    'Atum\\Api\\Controllers\\V3\\InboundStockController' => $baseDir . '/classes/Api/Controllers/V3/InboundStockController.php',
    'Atum\\Api\\Controllers\\V3\\InventoryLogNotesController' => $baseDir . '/classes/Api/Controllers/V3/InventoryLogNotesController.php',
    'Atum\\Api\\Controllers\\V3\\InventoryLogsController' => $baseDir . '/classes/Api/Controllers/V3/InventoryLogsController.php',
    'Atum\\Api\\Controllers\\V3\\ProductLocationsController' => $baseDir . '/classes/Api/Controllers/V3/ProductLocationsController.php',
    'Atum\\Api\\Controllers\\V3\\ProductVariationsController' => $baseDir . '/classes/Api/Controllers/V3/ProductVariationsController.php',
    'Atum\\Api\\Controllers\\V3\\PurchaseOrderNotesController' => $baseDir . '/classes/Api/Controllers/V3/PurchaseOrderNotesController.php',
    'Atum\\Api\\Controllers\\V3\\PurchaseOrdersController' => $baseDir . '/classes/Api/Controllers/V3/PurchaseOrdersController.php',
    'Atum\\Api\\Controllers\\V3\\SettingOptionsController' => $baseDir . '/classes/Api/Controllers/V3/SettingOptionsController.php',
    'Atum\\Api\\Controllers\\V3\\SettingsController' => $baseDir . '/classes/Api/Controllers/V3/SettingsController.php',
    'Atum\\Api\\Controllers\\V3\\SuppliersController' => $baseDir . '/classes/Api/Controllers/V3/SuppliersController.php',
    'Atum\\Api\\Controllers\\V3\\ToolsController' => $baseDir . '/classes/Api/Controllers/V3/ToolsController.php',
    'Atum\\Api\\Extenders\\AtumProductData' => $baseDir . '/classes/Api/Extenders/AtumProductData.php',
    'Atum\\Api\\Extenders\\Media' => $baseDir . '/classes/Api/Extenders/Media.php',
    'Atum\\Api\\Extenders\\OrderNotes' => $baseDir . '/classes/Api/Extenders/OrderNotes.php',
    'Atum\\Api\\Extenders\\Orders' => $baseDir . '/classes/Api/Extenders/Orders.php',
    'Atum\\Api\\Extenders\\ProductAttributes' => $baseDir . '/classes/Api/Extenders/ProductAttributes.php',
    'Atum\\Api\\Extenders\\ProductCategories' => $baseDir . '/classes/Api/Extenders/ProductCategories.php',
    'Atum\\Api\\Generators\\AddonGenerator' => $baseDir . '/classes/Api/Generators/AddonGenerator.php',
    'Atum\\Api\\Generators\\AttributeGenerator' => $baseDir . '/classes/Api/Generators/AttributeGenerator.php',
    'Atum\\Api\\Generators\\CategoryGenerator' => $baseDir . '/classes/Api/Generators/CategoryGenerator.php',
    'Atum\\Api\\Generators\\CommentGenerator' => $baseDir . '/classes/Api/Generators/CommentGenerator.php',
    'Atum\\Api\\Generators\\CouponGenerator' => $baseDir . '/classes/Api/Generators/CouponGenerator.php',
    'Atum\\Api\\Generators\\CustomerGenerator' => $baseDir . '/classes/Api/Generators/CustomerGenerator.php',
    'Atum\\Api\\Generators\\Generator' => $baseDir . '/classes/Api/Generators/Generator.php',
    'Atum\\Api\\Generators\\GeneratorBase' => $baseDir . '/classes/Api/Generators/GeneratorBase.php',
    'Atum\\Api\\Generators\\InboundStockGenerator' => $baseDir . '/classes/Api/Generators/InboundStockGenerator.php',
    'Atum\\Api\\Generators\\InventoryGenerator' => $baseDir . '/classes/Api/Generators/InventoryGenerator.php',
    'Atum\\Api\\Generators\\InventoryLogGenerator' => $baseDir . '/classes/Api/Generators/InventoryLogGenerator.php',
    'Atum\\Api\\Generators\\LocationGenerator' => $baseDir . '/classes/Api/Generators/LocationGenerator.php',
    'Atum\\Api\\Generators\\MediaGenerator' => $baseDir . '/classes/Api/Generators/MediaGenerator.php',
    'Atum\\Api\\Generators\\OrderGenerator' => $baseDir . '/classes/Api/Generators/OrderGenerator.php',
    'Atum\\Api\\Generators\\PaymentMethodGenerator' => $baseDir . '/classes/Api/Generators/PaymentMethodGenerator.php',
    'Atum\\Api\\Generators\\ProductGenerator' => $baseDir . '/classes/Api/Generators/ProductGenerator.php',
    'Atum\\Api\\Generators\\PurchaseOrderGenerator' => $baseDir . '/classes/Api/Generators/PurchaseOrderGenerator.php',
    'Atum\\Api\\Generators\\RefundGenerator' => $baseDir . '/classes/Api/Generators/RefundGenerator.php',
    'Atum\\Api\\Generators\\ShippingMethodGenerator' => $baseDir . '/classes/Api/Generators/ShippingMethodGenerator.php',
    'Atum\\Api\\Generators\\StoreSettingsGenerator' => $baseDir . '/classes/Api/Generators/StoreSettingsGenerator.php',
    'Atum\\Api\\Generators\\SupplierGenerator' => $baseDir . '/classes/Api/Generators/SupplierGenerator.php',
    'Atum\\Api\\Generators\\TagGenerator' => $baseDir . '/classes/Api/Generators/TagGenerator.php',
    'Atum\\Api\\Generators\\TaxClassGenerator' => $baseDir . '/classes/Api/Generators/TaxClassGenerator.php',
    'Atum\\Api\\Generators\\TaxRateGenerator' => $baseDir . '/classes/Api/Generators/TaxRateGenerator.php',
    'Atum\\Api\\Generators\\VariationGenerator' => $baseDir . '/classes/Api/Generators/VariationGenerator.php',
    'Atum\\Bootstrap' => $baseDir . '/classes/Bootstrap.php',
    'Atum\\Cli\\AtumCli' => $baseDir . '/classes/Cli/AtumCli.php',
    'Atum\\Cli\\CliCommands' => $baseDir . '/classes/Cli/CliCommands.php',
    'Atum\\Components\\AtumAdminModal' => $baseDir . '/classes/Components/AtumAdminModal.php',
    'Atum\\Components\\AtumAdminNotices' => $baseDir . '/classes/Components/AtumAdminNotices.php',
    'Atum\\Components\\AtumBarcodes' => $baseDir . '/classes/Components/AtumBarcodes.php',
    'Atum\\Components\\AtumCache' => $baseDir . '/classes/Components/AtumCache.php',
    'Atum\\Components\\AtumCalculatedProps' => $baseDir . '/classes/Components/AtumCalculatedProps.php',
    'Atum\\Components\\AtumCapabilities' => $baseDir . '/classes/Components/AtumCapabilities.php',
    'Atum\\Components\\AtumColors' => $baseDir . '/classes/Components/AtumColors.php',
    'Atum\\Components\\AtumEmailNotifications' => $baseDir . '/classes/Components/AtumEmailNotifications.php',
    'Atum\\Components\\AtumException' => $baseDir . '/classes/Components/AtumException.php',
    'Atum\\Components\\AtumHelpGuide' => $baseDir . '/classes/Components/AtumHelpGuide.php',
    'Atum\\Components\\AtumListTables\\AtumListPage' => $baseDir . '/classes/Components/AtumListTables/AtumListPage.php',
    'Atum\\Components\\AtumListTables\\AtumListTable' => $baseDir . '/classes/Components/AtumListTables/AtumListTable.php',
    'Atum\\Components\\AtumListTables\\AtumUncontrolledListTable' => $baseDir . '/classes/Components/AtumListTables/AtumUncontrolledListTable.php',
    'Atum\\Components\\AtumMarketingPopup' => $baseDir . '/classes/Components/AtumMarketingPopup.php',
    'Atum\\Components\\AtumOrders\\AtumComments' => $baseDir . '/classes/Components/AtumOrders/AtumComments.php',
    'Atum\\Components\\AtumOrders\\AtumOrderPostType' => $baseDir . '/classes/Components/AtumOrders/AtumOrderPostType.php',
    'Atum\\Components\\AtumOrders\\Items\\AtumOrderItemFee' => $baseDir . '/classes/Components/AtumOrders/Items/AtumOrderItemFee.php',
    'Atum\\Components\\AtumOrders\\Items\\AtumOrderItemProduct' => $baseDir . '/classes/Components/AtumOrders/Items/AtumOrderItemProduct.php',
    'Atum\\Components\\AtumOrders\\Items\\AtumOrderItemShipping' => $baseDir . '/classes/Components/AtumOrders/Items/AtumOrderItemShipping.php',
    'Atum\\Components\\AtumOrders\\Items\\AtumOrderItemTax' => $baseDir . '/classes/Components/AtumOrders/Items/AtumOrderItemTax.php',
    'Atum\\Components\\AtumOrders\\Items\\AtumOrderItemTrait' => $baseDir . '/classes/Components/AtumOrders/Items/AtumOrderItemTrait.php',
    'Atum\\Components\\AtumOrders\\Models\\AtumOrderItemModel' => $baseDir . '/classes/Components/AtumOrders/Models/AtumOrderItemModel.php',
    'Atum\\Components\\AtumOrders\\Models\\AtumOrderModel' => $baseDir . '/classes/Components/AtumOrders/Models/AtumOrderModel.php',
    'Atum\\Components\\AtumQueues' => $baseDir . '/classes/Components/AtumQueues.php',
    'Atum\\Components\\AtumReserveStock' => $baseDir . '/classes/Components/AtumReserveStock.php',
    'Atum\\Components\\AtumStockDecimals' => $baseDir . '/classes/Components/AtumStockDecimals.php',
    'Atum\\Components\\AtumWidget' => $baseDir . '/classes/Components/AtumWidget.php',
    'Atum\\Dashboard\\Dashboard' => $baseDir . '/classes/Dashboard/Dashboard.php',
    'Atum\\Dashboard\\WidgetHelpers' => $baseDir . '/classes/Dashboard/WidgetHelpers.php',
    'Atum\\Dashboard\\Widgets\\CurrentStockValue' => $baseDir . '/classes/Dashboard/Widgets/CurrentStockValue.php',
    'Atum\\Dashboard\\Widgets\\LostSales' => $baseDir . '/classes/Dashboard/Widgets/LostSales.php',
    'Atum\\Dashboard\\Widgets\\Orders' => $baseDir . '/classes/Dashboard/Widgets/Orders.php',
    'Atum\\Dashboard\\Widgets\\PromoSales' => $baseDir . '/classes/Dashboard/Widgets/PromoSales.php',
    'Atum\\Dashboard\\Widgets\\Sales' => $baseDir . '/classes/Dashboard/Widgets/Sales.php',
    'Atum\\Dashboard\\Widgets\\Statistics' => $baseDir . '/classes/Dashboard/Widgets/Statistics.php',
    'Atum\\Dashboard\\Widgets\\StockControl' => $baseDir . '/classes/Dashboard/Widgets/StockControl.php',
    'Atum\\Dashboard\\Widgets\\Videos' => $baseDir . '/classes/Dashboard/Widgets/Videos.php',
    'Atum\\DataExport\\DataExport' => $baseDir . '/classes/DataExport/DataExport.php',
    'Atum\\DataExport\\Reports\\HtmlReport' => $baseDir . '/classes/DataExport/Reports/HtmlReport.php',
    'Atum\\InboundStock\\InboundStock' => $baseDir . '/classes/InboundStock/InboundStock.php',
    'Atum\\InboundStock\\Lists\\ListTable' => $baseDir . '/classes/InboundStock/Lists/ListTable.php',
    'Atum\\Inc\\Ajax' => $baseDir . '/classes/Inc/Ajax.php',
    'Atum\\Inc\\Globals' => $baseDir . '/classes/Inc/Globals.php',
    'Atum\\Inc\\Helpers' => $baseDir . '/classes/Inc/Helpers.php',
    'Atum\\Inc\\Hooks' => $baseDir . '/classes/Inc/Hooks.php',
    'Atum\\Inc\\Main' => $baseDir . '/classes/Inc/Main.php',
    'Atum\\Inc\\Upgrade' => $baseDir . '/classes/Inc/Upgrade.php',
    'Atum\\Integrations\\Wpml' => $baseDir . '/classes/Integrations/Wpml.php',
    'Atum\\InventoryLogs\\InventoryLogs' => $baseDir . '/classes/InventoryLogs/InventoryLogs.php',
    'Atum\\InventoryLogs\\Items\\LogItemFee' => $baseDir . '/classes/InventoryLogs/Items/LogItemFee.php',
    'Atum\\InventoryLogs\\Items\\LogItemProduct' => $baseDir . '/classes/InventoryLogs/Items/LogItemProduct.php',
    'Atum\\InventoryLogs\\Items\\LogItemShipping' => $baseDir . '/classes/InventoryLogs/Items/LogItemShipping.php',
    'Atum\\InventoryLogs\\Items\\LogItemTax' => $baseDir . '/classes/InventoryLogs/Items/LogItemTax.php',
    'Atum\\InventoryLogs\\Items\\LogItemTrait' => $baseDir . '/classes/InventoryLogs/Items/LogItemTrait.php',
    'Atum\\InventoryLogs\\Models\\Log' => $baseDir . '/classes/InventoryLogs/Models/Log.php',
    'Atum\\InventoryLogs\\Models\\LogItem' => $baseDir . '/classes/InventoryLogs/Models/LogItem.php',
    'Atum\\MetaBoxes\\FileAttachment' => $baseDir . '/classes/MetaBoxes/FileAttachment.php',
    'Atum\\MetaBoxes\\ProductDataMetaBoxes' => $baseDir . '/classes/MetaBoxes/ProductDataMetaBoxes.php',
    'Atum\\Models\\AtumCPTModel' => $baseDir . '/classes/Models/AtumCPTModel.php',
    'Atum\\Models\\DataStores\\AtumDataStoreCPTTrait' => $baseDir . '/classes/Models/DataStores/AtumDataStoreCPTTrait.php',
    'Atum\\Models\\DataStores\\AtumDataStoreCommonTrait' => $baseDir . '/classes/Models/DataStores/AtumDataStoreCommonTrait.php',
    'Atum\\Models\\DataStores\\AtumProductBookingDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductBookingDataStoreCPT.php',
    'Atum\\Models\\DataStores\\AtumProductBundleDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductBundleDataStoreCPT.php',
    'Atum\\Models\\DataStores\\AtumProductDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductDataStoreCPT.php',
    'Atum\\Models\\DataStores\\AtumProductGroupedDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductGroupedDataStoreCPT.php',
    'Atum\\Models\\DataStores\\AtumProductSubscriptionDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductSubscriptionDataStoreCPT.php',
    'Atum\\Models\\DataStores\\AtumProductVariableDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductVariableDataStoreCPT.php',
    'Atum\\Models\\DataStores\\AtumProductVariationDataStoreCPT' => $baseDir . '/classes/Models/DataStores/AtumProductVariationDataStoreCPT.php',
    'Atum\\Models\\Interfaces\\AtumProductInterface' => $baseDir . '/classes/Models/Interfaces/AtumProductInterface.php',
    'Atum\\Models\\Products\\AtumProductBooking' => $baseDir . '/classes/Models/Products/AtumProductBooking.php',
    'Atum\\Models\\Products\\AtumProductBundle' => $baseDir . '/classes/Models/Products/AtumProductBundle.php',
    'Atum\\Models\\Products\\AtumProductDownload' => $baseDir . '/classes/Models/Products/AtumProductDownload.php',
    'Atum\\Models\\Products\\AtumProductGrouped' => $baseDir . '/classes/Models/Products/AtumProductGrouped.php',
    'Atum\\Models\\Products\\AtumProductSimple' => $baseDir . '/classes/Models/Products/AtumProductSimple.php',
    'Atum\\Models\\Products\\AtumProductSubscription' => $baseDir . '/classes/Models/Products/AtumProductSubscription.php',
    'Atum\\Models\\Products\\AtumProductSubscriptionVariation' => $baseDir . '/classes/Models/Products/AtumProductSubscriptionVariation.php',
    'Atum\\Models\\Products\\AtumProductTrait' => $baseDir . '/classes/Models/Products/AtumProductTrait.php',
    'Atum\\Models\\Products\\AtumProductVariable' => $baseDir . '/classes/Models/Products/AtumProductVariable.php',
    'Atum\\Models\\Products\\AtumProductVariableSubscription' => $baseDir . '/classes/Models/Products/AtumProductVariableSubscription.php',
    'Atum\\Models\\Products\\AtumProductVariation' => $baseDir . '/classes/Models/Products/AtumProductVariation.php',
    'Atum\\Modules\\ModuleManager' => $baseDir . '/classes/Modules/ModuleManager.php',
    'Atum\\Orders\\CheckOrderPrices' => $baseDir . '/classes/Orders/CheckOrderPrices.php',
    'Atum\\Orders\\SearchOrdersByColumn' => $baseDir . '/classes/Orders/SearchOrdersByColumn.php',
    'Atum\\PurchaseOrders\\Exports\\POExport' => $baseDir . '/classes/PurchaseOrders/Exports/POExport.php',
    'Atum\\PurchaseOrders\\Items\\POItemFee' => $baseDir . '/classes/PurchaseOrders/Items/POItemFee.php',
    'Atum\\PurchaseOrders\\Items\\POItemProduct' => $baseDir . '/classes/PurchaseOrders/Items/POItemProduct.php',
    'Atum\\PurchaseOrders\\Items\\POItemShipping' => $baseDir . '/classes/PurchaseOrders/Items/POItemShipping.php',
    'Atum\\PurchaseOrders\\Items\\POItemTax' => $baseDir . '/classes/PurchaseOrders/Items/POItemTax.php',
    'Atum\\PurchaseOrders\\Items\\POItemTrait' => $baseDir . '/classes/PurchaseOrders/Items/POItemTrait.php',
    'Atum\\PurchaseOrders\\Models\\POItem' => $baseDir . '/classes/PurchaseOrders/Models/POItem.php',
    'Atum\\PurchaseOrders\\Models\\PurchaseOrder' => $baseDir . '/classes/PurchaseOrders/Models/PurchaseOrder.php',
    'Atum\\PurchaseOrders\\PurchaseOrders' => $baseDir . '/classes/PurchaseOrders/PurchaseOrders.php',
    'Atum\\Queries\\ProductDataQuery' => $baseDir . '/classes/Queries/ProductDataQuery.php',
    'Atum\\Settings\\Settings' => $baseDir . '/classes/Settings/Settings.php',
    'Atum\\Settings\\Tools' => $baseDir . '/classes/Settings/Tools.php',
    'Atum\\StockCentral\\Lists\\ListTable' => $baseDir . '/classes/StockCentral/Lists/ListTable.php',
    'Atum\\StockCentral\\Lists\\UncontrolledListTable' => $baseDir . '/classes/StockCentral/Lists/UncontrolledListTable.php',
    'Atum\\StockCentral\\StockCentral' => $baseDir . '/classes/StockCentral/StockCentral.php',
    'Atum\\Suppliers\\Supplier' => $baseDir . '/classes/Suppliers/Supplier.php',
    'Atum\\Suppliers\\Suppliers' => $baseDir . '/classes/Suppliers/Suppliers.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'DeepCopy\\DeepCopy' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/DeepCopy.php',
    'DeepCopy\\Exception\\CloneException' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Exception/CloneException.php',
    'DeepCopy\\Exception\\PropertyException' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Exception/PropertyException.php',
    'DeepCopy\\Filter\\ChainableFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/ChainableFilter.php',
    'DeepCopy\\Filter\\Doctrine\\DoctrineCollectionFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Doctrine/DoctrineCollectionFilter.php',
    'DeepCopy\\Filter\\Doctrine\\DoctrineEmptyCollectionFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Doctrine/DoctrineEmptyCollectionFilter.php',
    'DeepCopy\\Filter\\Doctrine\\DoctrineProxyFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Doctrine/DoctrineProxyFilter.php',
    'DeepCopy\\Filter\\Filter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/Filter.php',
    'DeepCopy\\Filter\\KeepFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/KeepFilter.php',
    'DeepCopy\\Filter\\ReplaceFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/ReplaceFilter.php',
    'DeepCopy\\Filter\\SetNullFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Filter/SetNullFilter.php',
    'DeepCopy\\Matcher\\Doctrine\\DoctrineProxyMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/Doctrine/DoctrineProxyMatcher.php',
    'DeepCopy\\Matcher\\Matcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/Matcher.php',
    'DeepCopy\\Matcher\\PropertyMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/PropertyMatcher.php',
    'DeepCopy\\Matcher\\PropertyNameMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/PropertyNameMatcher.php',
    'DeepCopy\\Matcher\\PropertyTypeMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Matcher/PropertyTypeMatcher.php',
    'DeepCopy\\Reflection\\ReflectionHelper' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/Reflection/ReflectionHelper.php',
    'DeepCopy\\TypeFilter\\Date\\DateIntervalFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Date/DateIntervalFilter.php',
    'DeepCopy\\TypeFilter\\ReplaceFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/ReplaceFilter.php',
    'DeepCopy\\TypeFilter\\ShallowCopyFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/ShallowCopyFilter.php',
    'DeepCopy\\TypeFilter\\Spl\\ArrayObjectFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Spl/ArrayObjectFilter.php',
    'DeepCopy\\TypeFilter\\Spl\\SplDoublyLinkedList' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Spl/SplDoublyLinkedList.php',
    'DeepCopy\\TypeFilter\\Spl\\SplDoublyLinkedListFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/Spl/SplDoublyLinkedListFilter.php',
    'DeepCopy\\TypeFilter\\TypeFilter' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeFilter/TypeFilter.php',
    'DeepCopy\\TypeMatcher\\TypeMatcher' => $vendorDir . '/myclabs/deep-copy/src/DeepCopy/TypeMatcher/TypeMatcher.php',
    'Madcoda\\Youtube\\Constants' => $vendorDir . '/madcoda/php-youtube-api/src/Constants.php',
    'Madcoda\\Youtube\\Facades\\Youtube' => $vendorDir . '/madcoda/php-youtube-api/src/Facades/Youtube.php',
    'Madcoda\\Youtube\\Youtube' => $vendorDir . '/madcoda/php-youtube-api/src/Youtube.php',
    'Madcoda\\Youtube\\YoutubeServiceProviderLaravel4' => $vendorDir . '/madcoda/php-youtube-api/src/YoutubeServiceProviderLaravel4.php',
    'Madcoda\\Youtube\\YoutubeServiceProviderLaravel5' => $vendorDir . '/madcoda/php-youtube-api/src/YoutubeServiceProviderLaravel5.php',
    'Madcoda\\compat' => $vendorDir . '/madcoda/php-youtube-api/src/compat.php',
    'Mpdf\\AssetFetcher' => $vendorDir . '/mpdf/mpdf/src/AssetFetcher.php',
    'Mpdf\\Barcode' => $vendorDir . '/mpdf/mpdf/src/Barcode.php',
    'Mpdf\\Barcode\\AbstractBarcode' => $vendorDir . '/mpdf/mpdf/src/Barcode/AbstractBarcode.php',
    'Mpdf\\Barcode\\BarcodeException' => $vendorDir . '/mpdf/mpdf/src/Barcode/BarcodeException.php',
    'Mpdf\\Barcode\\BarcodeInterface' => $vendorDir . '/mpdf/mpdf/src/Barcode/BarcodeInterface.php',
    'Mpdf\\Barcode\\Codabar' => $vendorDir . '/mpdf/mpdf/src/Barcode/Codabar.php',
    'Mpdf\\Barcode\\Code11' => $vendorDir . '/mpdf/mpdf/src/Barcode/Code11.php',
    'Mpdf\\Barcode\\Code128' => $vendorDir . '/mpdf/mpdf/src/Barcode/Code128.php',
    'Mpdf\\Barcode\\Code39' => $vendorDir . '/mpdf/mpdf/src/Barcode/Code39.php',
    'Mpdf\\Barcode\\Code93' => $vendorDir . '/mpdf/mpdf/src/Barcode/Code93.php',
    'Mpdf\\Barcode\\EanExt' => $vendorDir . '/mpdf/mpdf/src/Barcode/EanExt.php',
    'Mpdf\\Barcode\\EanUpc' => $vendorDir . '/mpdf/mpdf/src/Barcode/EanUpc.php',
    'Mpdf\\Barcode\\I25' => $vendorDir . '/mpdf/mpdf/src/Barcode/I25.php',
    'Mpdf\\Barcode\\Imb' => $vendorDir . '/mpdf/mpdf/src/Barcode/Imb.php',
    'Mpdf\\Barcode\\Msi' => $vendorDir . '/mpdf/mpdf/src/Barcode/Msi.php',
    'Mpdf\\Barcode\\Postnet' => $vendorDir . '/mpdf/mpdf/src/Barcode/Postnet.php',
    'Mpdf\\Barcode\\Rm4Scc' => $vendorDir . '/mpdf/mpdf/src/Barcode/Rm4Scc.php',
    'Mpdf\\Barcode\\S25' => $vendorDir . '/mpdf/mpdf/src/Barcode/S25.php',
    'Mpdf\\Cache' => $vendorDir . '/mpdf/mpdf/src/Cache.php',
    'Mpdf\\Color\\ColorConverter' => $vendorDir . '/mpdf/mpdf/src/Color/ColorConverter.php',
    'Mpdf\\Color\\ColorModeConverter' => $vendorDir . '/mpdf/mpdf/src/Color/ColorModeConverter.php',
    'Mpdf\\Color\\ColorSpaceRestrictor' => $vendorDir . '/mpdf/mpdf/src/Color/ColorSpaceRestrictor.php',
    'Mpdf\\Color\\NamedColors' => $vendorDir . '/mpdf/mpdf/src/Color/NamedColors.php',
    'Mpdf\\Config\\ConfigVariables' => $vendorDir . '/mpdf/mpdf/src/Config/ConfigVariables.php',
    'Mpdf\\Config\\FontVariables' => $vendorDir . '/mpdf/mpdf/src/Config/FontVariables.php',
    'Mpdf\\Container\\ContainerInterface' => $vendorDir . '/mpdf/mpdf/src/Container/ContainerInterface.php',
    'Mpdf\\Container\\NotFoundException' => $vendorDir . '/mpdf/mpdf/src/Container/NotFoundException.php',
    'Mpdf\\Container\\SimpleContainer' => $vendorDir . '/mpdf/mpdf/src/Container/SimpleContainer.php',
    'Mpdf\\Conversion\\DecToAlpha' => $vendorDir . '/mpdf/mpdf/src/Conversion/DecToAlpha.php',
    'Mpdf\\Conversion\\DecToCjk' => $vendorDir . '/mpdf/mpdf/src/Conversion/DecToCjk.php',
    'Mpdf\\Conversion\\DecToHebrew' => $vendorDir . '/mpdf/mpdf/src/Conversion/DecToHebrew.php',
    'Mpdf\\Conversion\\DecToOther' => $vendorDir . '/mpdf/mpdf/src/Conversion/DecToOther.php',
    'Mpdf\\Conversion\\DecToRoman' => $vendorDir . '/mpdf/mpdf/src/Conversion/DecToRoman.php',
    'Mpdf\\CssManager' => $vendorDir . '/mpdf/mpdf/src/CssManager.php',
    'Mpdf\\Css\\Border' => $vendorDir . '/mpdf/mpdf/src/Css/Border.php',
    'Mpdf\\Css\\DefaultCss' => $vendorDir . '/mpdf/mpdf/src/Css/DefaultCss.php',
    'Mpdf\\Css\\TextVars' => $vendorDir . '/mpdf/mpdf/src/Css/TextVars.php',
    'Mpdf\\DirectWrite' => $vendorDir . '/mpdf/mpdf/src/DirectWrite.php',
    'Mpdf\\Exception\\AssetFetchingException' => $vendorDir . '/mpdf/mpdf/src/Exception/AssetFetchingException.php',
    'Mpdf\\Exception\\FontException' => $vendorDir . '/mpdf/mpdf/src/Exception/FontException.php',
    'Mpdf\\Exception\\InvalidArgumentException' => $vendorDir . '/mpdf/mpdf/src/Exception/InvalidArgumentException.php',
    'Mpdf\\File\\LocalContentLoader' => $vendorDir . '/mpdf/mpdf/src/File/LocalContentLoader.php',
    'Mpdf\\File\\LocalContentLoaderInterface' => $vendorDir . '/mpdf/mpdf/src/File/LocalContentLoaderInterface.php',
    'Mpdf\\File\\StreamWrapperChecker' => $vendorDir . '/mpdf/mpdf/src/File/StreamWrapperChecker.php',
    'Mpdf\\Fonts\\FontCache' => $vendorDir . '/mpdf/mpdf/src/Fonts/FontCache.php',
    'Mpdf\\Fonts\\FontFileFinder' => $vendorDir . '/mpdf/mpdf/src/Fonts/FontFileFinder.php',
    'Mpdf\\Fonts\\GlyphOperator' => $vendorDir . '/mpdf/mpdf/src/Fonts/GlyphOperator.php',
    'Mpdf\\Fonts\\MetricsGenerator' => $vendorDir . '/mpdf/mpdf/src/Fonts/MetricsGenerator.php',
    'Mpdf\\Form' => $vendorDir . '/mpdf/mpdf/src/Form.php',
    'Mpdf\\FpdiTrait' => $vendorDir . '/mpdf/mpdf/src/FpdiTrait.php',
    'Mpdf\\Gif\\ColorTable' => $vendorDir . '/mpdf/mpdf/src/Gif/ColorTable.php',
    'Mpdf\\Gif\\FileHeader' => $vendorDir . '/mpdf/mpdf/src/Gif/FileHeader.php',
    'Mpdf\\Gif\\Gif' => $vendorDir . '/mpdf/mpdf/src/Gif/Gif.php',
    'Mpdf\\Gif\\Image' => $vendorDir . '/mpdf/mpdf/src/Gif/Image.php',
    'Mpdf\\Gif\\ImageHeader' => $vendorDir . '/mpdf/mpdf/src/Gif/ImageHeader.php',
    'Mpdf\\Gif\\Lzw' => $vendorDir . '/mpdf/mpdf/src/Gif/Lzw.php',
    'Mpdf\\Gradient' => $vendorDir . '/mpdf/mpdf/src/Gradient.php',
    'Mpdf\\HTMLParserMode' => $vendorDir . '/mpdf/mpdf/src/HTMLParserMode.php',
    'Mpdf\\Http\\ClientInterface' => $vendorDir . '/mpdf/mpdf/src/Http/ClientInterface.php',
    'Mpdf\\Http\\CurlHttpClient' => $vendorDir . '/mpdf/mpdf/src/Http/CurlHttpClient.php',
    'Mpdf\\Http\\Exception\\ClientException' => $vendorDir . '/mpdf/mpdf/src/Http/Exception/ClientException.php',
    'Mpdf\\Http\\Exception\\ForbiddenRequestException' => $vendorDir . '/mpdf/mpdf/src/Http/Exception/ForbiddenRequestException.php',
    'Mpdf\\Http\\Exception\\NetworkException' => $vendorDir . '/mpdf/mpdf/src/Http/Exception/NetworkException.php',
    'Mpdf\\Http\\Exception\\RequestException' => $vendorDir . '/mpdf/mpdf/src/Http/Exception/RequestException.php',
    'Mpdf\\Http\\Request' => $vendorDir . '/mpdf/mpdf/src/Http/Request.php',
    'Mpdf\\Http\\Response' => $vendorDir . '/mpdf/mpdf/src/Http/Response.php',
    'Mpdf\\Http\\SocketHttpClient' => $vendorDir . '/mpdf/mpdf/src/Http/SocketHttpClient.php',
    'Mpdf\\Http\\Stream' => $vendorDir . '/mpdf/mpdf/src/Http/Stream.php',
    'Mpdf\\Http\\Uri' => $vendorDir . '/mpdf/mpdf/src/Http/Uri.php',
    'Mpdf\\Hyphenator' => $vendorDir . '/mpdf/mpdf/src/Hyphenator.php',
    'Mpdf\\Image\\Bmp' => $vendorDir . '/mpdf/mpdf/src/Image/Bmp.php',
    'Mpdf\\Image\\ImageProcessor' => $vendorDir . '/mpdf/mpdf/src/Image/ImageProcessor.php',
    'Mpdf\\Image\\ImageTypeGuesser' => $vendorDir . '/mpdf/mpdf/src/Image/ImageTypeGuesser.php',
    'Mpdf\\Image\\Svg' => $vendorDir . '/mpdf/mpdf/src/Image/Svg.php',
    'Mpdf\\Image\\Wmf' => $vendorDir . '/mpdf/mpdf/src/Image/Wmf.php',
    'Mpdf\\Language\\LanguageToFont' => $vendorDir . '/mpdf/mpdf/src/Language/LanguageToFont.php',
    'Mpdf\\Language\\LanguageToFontInterface' => $vendorDir . '/mpdf/mpdf/src/Language/LanguageToFontInterface.php',
    'Mpdf\\Language\\ScriptToLanguage' => $vendorDir . '/mpdf/mpdf/src/Language/ScriptToLanguage.php',
    'Mpdf\\Language\\ScriptToLanguageInterface' => $vendorDir . '/mpdf/mpdf/src/Language/ScriptToLanguageInterface.php',
    'Mpdf\\Log\\Context' => $vendorDir . '/mpdf/mpdf/src/Log/Context.php',
    'Mpdf\\Mpdf' => $vendorDir . '/mpdf/mpdf/src/Mpdf.php',
    'Mpdf\\MpdfException' => $vendorDir . '/mpdf/mpdf/src/MpdfException.php',
    'Mpdf\\MpdfImageException' => $vendorDir . '/mpdf/mpdf/src/MpdfImageException.php',
    'Mpdf\\Otl' => $vendorDir . '/mpdf/mpdf/src/Otl.php',
    'Mpdf\\OtlDump' => $vendorDir . '/mpdf/mpdf/src/OtlDump.php',
    'Mpdf\\Output\\Destination' => $vendorDir . '/mpdf/mpdf/src/Output/Destination.php',
    'Mpdf\\PageBox' => $vendorDir . '/mpdf/mpdf/src/PageBox.php',
    'Mpdf\\PageFormat' => $vendorDir . '/mpdf/mpdf/src/PageFormat.php',
    'Mpdf\\Pdf\\Protection' => $vendorDir . '/mpdf/mpdf/src/Pdf/Protection.php',
    'Mpdf\\Pdf\\Protection\\UniqidGenerator' => $vendorDir . '/mpdf/mpdf/src/Pdf/Protection/UniqidGenerator.php',
    'Mpdf\\PsrHttpMessageShim\\Request' => $vendorDir . '/mpdf/psr-http-message-shim/src/Request.php',
    'Mpdf\\PsrHttpMessageShim\\Response' => $vendorDir . '/mpdf/psr-http-message-shim/src/Response.php',
    'Mpdf\\PsrHttpMessageShim\\Stream' => $vendorDir . '/mpdf/psr-http-message-shim/src/Stream.php',
    'Mpdf\\PsrHttpMessageShim\\Uri' => $vendorDir . '/mpdf/psr-http-message-shim/src/Uri.php',
    'Mpdf\\PsrLogAwareTrait\\MpdfPsrLogAwareTrait' => $vendorDir . '/mpdf/psr-log-aware-trait/src/MpdfPsrLogAwareTrait.php',
    'Mpdf\\PsrLogAwareTrait\\PsrLogAwareTrait' => $vendorDir . '/mpdf/psr-log-aware-trait/src/PsrLogAwareTrait.php',
    'Mpdf\\ServiceFactory' => $vendorDir . '/mpdf/mpdf/src/ServiceFactory.php',
    'Mpdf\\Shaper\\Indic' => $vendorDir . '/mpdf/mpdf/src/Shaper/Indic.php',
    'Mpdf\\Shaper\\Myanmar' => $vendorDir . '/mpdf/mpdf/src/Shaper/Myanmar.php',
    'Mpdf\\Shaper\\Sea' => $vendorDir . '/mpdf/mpdf/src/Shaper/Sea.php',
    'Mpdf\\SizeConverter' => $vendorDir . '/mpdf/mpdf/src/SizeConverter.php',
    'Mpdf\\Strict' => $vendorDir . '/mpdf/mpdf/src/Strict.php',
    'Mpdf\\TTFontFile' => $vendorDir . '/mpdf/mpdf/src/TTFontFile.php',
    'Mpdf\\TTFontFileAnalysis' => $vendorDir . '/mpdf/mpdf/src/TTFontFileAnalysis.php',
    'Mpdf\\TableOfContents' => $vendorDir . '/mpdf/mpdf/src/TableOfContents.php',
    'Mpdf\\Tag' => $vendorDir . '/mpdf/mpdf/src/Tag.php',
    'Mpdf\\Tag\\A' => $vendorDir . '/mpdf/mpdf/src/Tag/A.php',
    'Mpdf\\Tag\\Acronym' => $vendorDir . '/mpdf/mpdf/src/Tag/Acronym.php',
    'Mpdf\\Tag\\Address' => $vendorDir . '/mpdf/mpdf/src/Tag/Address.php',
    'Mpdf\\Tag\\Annotation' => $vendorDir . '/mpdf/mpdf/src/Tag/Annotation.php',
    'Mpdf\\Tag\\Article' => $vendorDir . '/mpdf/mpdf/src/Tag/Article.php',
    'Mpdf\\Tag\\Aside' => $vendorDir . '/mpdf/mpdf/src/Tag/Aside.php',
    'Mpdf\\Tag\\B' => $vendorDir . '/mpdf/mpdf/src/Tag/B.php',
    'Mpdf\\Tag\\BarCode' => $vendorDir . '/mpdf/mpdf/src/Tag/BarCode.php',
    'Mpdf\\Tag\\Bdi' => $vendorDir . '/mpdf/mpdf/src/Tag/Bdi.php',
    'Mpdf\\Tag\\Bdo' => $vendorDir . '/mpdf/mpdf/src/Tag/Bdo.php',
    'Mpdf\\Tag\\Big' => $vendorDir . '/mpdf/mpdf/src/Tag/Big.php',
    'Mpdf\\Tag\\BlockQuote' => $vendorDir . '/mpdf/mpdf/src/Tag/BlockQuote.php',
    'Mpdf\\Tag\\BlockTag' => $vendorDir . '/mpdf/mpdf/src/Tag/BlockTag.php',
    'Mpdf\\Tag\\Bookmark' => $vendorDir . '/mpdf/mpdf/src/Tag/Bookmark.php',
    'Mpdf\\Tag\\Br' => $vendorDir . '/mpdf/mpdf/src/Tag/Br.php',
    'Mpdf\\Tag\\Caption' => $vendorDir . '/mpdf/mpdf/src/Tag/Caption.php',
    'Mpdf\\Tag\\Center' => $vendorDir . '/mpdf/mpdf/src/Tag/Center.php',
    'Mpdf\\Tag\\Cite' => $vendorDir . '/mpdf/mpdf/src/Tag/Cite.php',
    'Mpdf\\Tag\\Code' => $vendorDir . '/mpdf/mpdf/src/Tag/Code.php',
    'Mpdf\\Tag\\ColumnBreak' => $vendorDir . '/mpdf/mpdf/src/Tag/ColumnBreak.php',
    'Mpdf\\Tag\\Columns' => $vendorDir . '/mpdf/mpdf/src/Tag/Columns.php',
    'Mpdf\\Tag\\Dd' => $vendorDir . '/mpdf/mpdf/src/Tag/Dd.php',
    'Mpdf\\Tag\\Del' => $vendorDir . '/mpdf/mpdf/src/Tag/Del.php',
    'Mpdf\\Tag\\Details' => $vendorDir . '/mpdf/mpdf/src/Tag/Details.php',
    'Mpdf\\Tag\\Div' => $vendorDir . '/mpdf/mpdf/src/Tag/Div.php',
    'Mpdf\\Tag\\Dl' => $vendorDir . '/mpdf/mpdf/src/Tag/Dl.php',
    'Mpdf\\Tag\\DotTab' => $vendorDir . '/mpdf/mpdf/src/Tag/DotTab.php',
    'Mpdf\\Tag\\Dt' => $vendorDir . '/mpdf/mpdf/src/Tag/Dt.php',
    'Mpdf\\Tag\\Em' => $vendorDir . '/mpdf/mpdf/src/Tag/Em.php',
    'Mpdf\\Tag\\FieldSet' => $vendorDir . '/mpdf/mpdf/src/Tag/FieldSet.php',
    'Mpdf\\Tag\\FigCaption' => $vendorDir . '/mpdf/mpdf/src/Tag/FigCaption.php',
    'Mpdf\\Tag\\Figure' => $vendorDir . '/mpdf/mpdf/src/Tag/Figure.php',
    'Mpdf\\Tag\\Font' => $vendorDir . '/mpdf/mpdf/src/Tag/Font.php',
    'Mpdf\\Tag\\Footer' => $vendorDir . '/mpdf/mpdf/src/Tag/Footer.php',
    'Mpdf\\Tag\\Form' => $vendorDir . '/mpdf/mpdf/src/Tag/Form.php',
    'Mpdf\\Tag\\FormFeed' => $vendorDir . '/mpdf/mpdf/src/Tag/FormFeed.php',
    'Mpdf\\Tag\\H1' => $vendorDir . '/mpdf/mpdf/src/Tag/H1.php',
    'Mpdf\\Tag\\H2' => $vendorDir . '/mpdf/mpdf/src/Tag/H2.php',
    'Mpdf\\Tag\\H3' => $vendorDir . '/mpdf/mpdf/src/Tag/H3.php',
    'Mpdf\\Tag\\H4' => $vendorDir . '/mpdf/mpdf/src/Tag/H4.php',
    'Mpdf\\Tag\\H5' => $vendorDir . '/mpdf/mpdf/src/Tag/H5.php',
    'Mpdf\\Tag\\H6' => $vendorDir . '/mpdf/mpdf/src/Tag/H6.php',
    'Mpdf\\Tag\\HGroup' => $vendorDir . '/mpdf/mpdf/src/Tag/HGroup.php',
    'Mpdf\\Tag\\Header' => $vendorDir . '/mpdf/mpdf/src/Tag/Header.php',
    'Mpdf\\Tag\\Hr' => $vendorDir . '/mpdf/mpdf/src/Tag/Hr.php',
    'Mpdf\\Tag\\I' => $vendorDir . '/mpdf/mpdf/src/Tag/I.php',
    'Mpdf\\Tag\\Img' => $vendorDir . '/mpdf/mpdf/src/Tag/Img.php',
    'Mpdf\\Tag\\IndexEntry' => $vendorDir . '/mpdf/mpdf/src/Tag/IndexEntry.php',
    'Mpdf\\Tag\\IndexInsert' => $vendorDir . '/mpdf/mpdf/src/Tag/IndexInsert.php',
    'Mpdf\\Tag\\InlineTag' => $vendorDir . '/mpdf/mpdf/src/Tag/InlineTag.php',
    'Mpdf\\Tag\\Input' => $vendorDir . '/mpdf/mpdf/src/Tag/Input.php',
    'Mpdf\\Tag\\Ins' => $vendorDir . '/mpdf/mpdf/src/Tag/Ins.php',
    'Mpdf\\Tag\\Kbd' => $vendorDir . '/mpdf/mpdf/src/Tag/Kbd.php',
    'Mpdf\\Tag\\Legend' => $vendorDir . '/mpdf/mpdf/src/Tag/Legend.php',
    'Mpdf\\Tag\\Li' => $vendorDir . '/mpdf/mpdf/src/Tag/Li.php',
    'Mpdf\\Tag\\Main' => $vendorDir . '/mpdf/mpdf/src/Tag/Main.php',
    'Mpdf\\Tag\\Mark' => $vendorDir . '/mpdf/mpdf/src/Tag/Mark.php',
    'Mpdf\\Tag\\Meter' => $vendorDir . '/mpdf/mpdf/src/Tag/Meter.php',
    'Mpdf\\Tag\\Nav' => $vendorDir . '/mpdf/mpdf/src/Tag/Nav.php',
    'Mpdf\\Tag\\NewColumn' => $vendorDir . '/mpdf/mpdf/src/Tag/NewColumn.php',
    'Mpdf\\Tag\\NewPage' => $vendorDir . '/mpdf/mpdf/src/Tag/NewPage.php',
    'Mpdf\\Tag\\Ol' => $vendorDir . '/mpdf/mpdf/src/Tag/Ol.php',
    'Mpdf\\Tag\\Option' => $vendorDir . '/mpdf/mpdf/src/Tag/Option.php',
    'Mpdf\\Tag\\P' => $vendorDir . '/mpdf/mpdf/src/Tag/P.php',
    'Mpdf\\Tag\\PageBreak' => $vendorDir . '/mpdf/mpdf/src/Tag/PageBreak.php',
    'Mpdf\\Tag\\PageFooter' => $vendorDir . '/mpdf/mpdf/src/Tag/PageFooter.php',
    'Mpdf\\Tag\\PageHeader' => $vendorDir . '/mpdf/mpdf/src/Tag/PageHeader.php',
    'Mpdf\\Tag\\Pre' => $vendorDir . '/mpdf/mpdf/src/Tag/Pre.php',
    'Mpdf\\Tag\\Progress' => $vendorDir . '/mpdf/mpdf/src/Tag/Progress.php',
    'Mpdf\\Tag\\Q' => $vendorDir . '/mpdf/mpdf/src/Tag/Q.php',
    'Mpdf\\Tag\\S' => $vendorDir . '/mpdf/mpdf/src/Tag/S.php',
    'Mpdf\\Tag\\Samp' => $vendorDir . '/mpdf/mpdf/src/Tag/Samp.php',
    'Mpdf\\Tag\\Section' => $vendorDir . '/mpdf/mpdf/src/Tag/Section.php',
    'Mpdf\\Tag\\Select' => $vendorDir . '/mpdf/mpdf/src/Tag/Select.php',
    'Mpdf\\Tag\\SetHtmlPageFooter' => $vendorDir . '/mpdf/mpdf/src/Tag/SetHtmlPageFooter.php',
    'Mpdf\\Tag\\SetHtmlPageHeader' => $vendorDir . '/mpdf/mpdf/src/Tag/SetHtmlPageHeader.php',
    'Mpdf\\Tag\\SetPageFooter' => $vendorDir . '/mpdf/mpdf/src/Tag/SetPageFooter.php',
    'Mpdf\\Tag\\SetPageHeader' => $vendorDir . '/mpdf/mpdf/src/Tag/SetPageHeader.php',
    'Mpdf\\Tag\\Small' => $vendorDir . '/mpdf/mpdf/src/Tag/Small.php',
    'Mpdf\\Tag\\Span' => $vendorDir . '/mpdf/mpdf/src/Tag/Span.php',
    'Mpdf\\Tag\\Strike' => $vendorDir . '/mpdf/mpdf/src/Tag/Strike.php',
    'Mpdf\\Tag\\Strong' => $vendorDir . '/mpdf/mpdf/src/Tag/Strong.php',
    'Mpdf\\Tag\\Sub' => $vendorDir . '/mpdf/mpdf/src/Tag/Sub.php',
    'Mpdf\\Tag\\SubstituteTag' => $vendorDir . '/mpdf/mpdf/src/Tag/SubstituteTag.php',
    'Mpdf\\Tag\\Summary' => $vendorDir . '/mpdf/mpdf/src/Tag/Summary.php',
    'Mpdf\\Tag\\Sup' => $vendorDir . '/mpdf/mpdf/src/Tag/Sup.php',
    'Mpdf\\Tag\\TBody' => $vendorDir . '/mpdf/mpdf/src/Tag/TBody.php',
    'Mpdf\\Tag\\TFoot' => $vendorDir . '/mpdf/mpdf/src/Tag/TFoot.php',
    'Mpdf\\Tag\\THead' => $vendorDir . '/mpdf/mpdf/src/Tag/THead.php',
    'Mpdf\\Tag\\Table' => $vendorDir . '/mpdf/mpdf/src/Tag/Table.php',
    'Mpdf\\Tag\\Tag' => $vendorDir . '/mpdf/mpdf/src/Tag/Tag.php',
    'Mpdf\\Tag\\Td' => $vendorDir . '/mpdf/mpdf/src/Tag/Td.php',
    'Mpdf\\Tag\\TextArea' => $vendorDir . '/mpdf/mpdf/src/Tag/TextArea.php',
    'Mpdf\\Tag\\TextCircle' => $vendorDir . '/mpdf/mpdf/src/Tag/TextCircle.php',
    'Mpdf\\Tag\\Th' => $vendorDir . '/mpdf/mpdf/src/Tag/Th.php',
    'Mpdf\\Tag\\Time' => $vendorDir . '/mpdf/mpdf/src/Tag/Time.php',
    'Mpdf\\Tag\\Toc' => $vendorDir . '/mpdf/mpdf/src/Tag/Toc.php',
    'Mpdf\\Tag\\TocEntry' => $vendorDir . '/mpdf/mpdf/src/Tag/TocEntry.php',
    'Mpdf\\Tag\\TocPageBreak' => $vendorDir . '/mpdf/mpdf/src/Tag/TocPageBreak.php',
    'Mpdf\\Tag\\Tr' => $vendorDir . '/mpdf/mpdf/src/Tag/Tr.php',
    'Mpdf\\Tag\\Tt' => $vendorDir . '/mpdf/mpdf/src/Tag/Tt.php',
    'Mpdf\\Tag\\Tta' => $vendorDir . '/mpdf/mpdf/src/Tag/Tta.php',
    'Mpdf\\Tag\\Tts' => $vendorDir . '/mpdf/mpdf/src/Tag/Tts.php',
    'Mpdf\\Tag\\Ttz' => $vendorDir . '/mpdf/mpdf/src/Tag/Ttz.php',
    'Mpdf\\Tag\\U' => $vendorDir . '/mpdf/mpdf/src/Tag/U.php',
    'Mpdf\\Tag\\Ul' => $vendorDir . '/mpdf/mpdf/src/Tag/Ul.php',
    'Mpdf\\Tag\\VarTag' => $vendorDir . '/mpdf/mpdf/src/Tag/VarTag.php',
    'Mpdf\\Tag\\WatermarkImage' => $vendorDir . '/mpdf/mpdf/src/Tag/WatermarkImage.php',
    'Mpdf\\Tag\\WatermarkText' => $vendorDir . '/mpdf/mpdf/src/Tag/WatermarkText.php',
    'Mpdf\\Ucdn' => $vendorDir . '/mpdf/mpdf/src/Ucdn.php',
    'Mpdf\\Utils\\Arrays' => $vendorDir . '/mpdf/mpdf/src/Utils/Arrays.php',
    'Mpdf\\Utils\\NumericString' => $vendorDir . '/mpdf/mpdf/src/Utils/NumericString.php',
    'Mpdf\\Utils\\PdfDate' => $vendorDir . '/mpdf/mpdf/src/Utils/PdfDate.php',
    'Mpdf\\Utils\\UtfString' => $vendorDir . '/mpdf/mpdf/src/Utils/UtfString.php',
    'Mpdf\\Watermark' => $vendorDir . '/mpdf/mpdf/src/Watermark.php',
    'Mpdf\\WatermarkImage' => $vendorDir . '/mpdf/mpdf/src/WatermarkImage.php',
    'Mpdf\\WatermarkText' => $vendorDir . '/mpdf/mpdf/src/WatermarkText.php',
    'Mpdf\\Writer\\BackgroundWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/BackgroundWriter.php',
    'Mpdf\\Writer\\BaseWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/BaseWriter.php',
    'Mpdf\\Writer\\BookmarkWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/BookmarkWriter.php',
    'Mpdf\\Writer\\ColorWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/ColorWriter.php',
    'Mpdf\\Writer\\FontWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/FontWriter.php',
    'Mpdf\\Writer\\FormWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/FormWriter.php',
    'Mpdf\\Writer\\ImageWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/ImageWriter.php',
    'Mpdf\\Writer\\JavaScriptWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/JavaScriptWriter.php',
    'Mpdf\\Writer\\MetadataWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/MetadataWriter.php',
    'Mpdf\\Writer\\ObjectWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/ObjectWriter.php',
    'Mpdf\\Writer\\OptionalContentWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/OptionalContentWriter.php',
    'Mpdf\\Writer\\PageWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/PageWriter.php',
    'Mpdf\\Writer\\ResourceWriter' => $vendorDir . '/mpdf/mpdf/src/Writer/ResourceWriter.php',
    'Psr\\Http\\Message\\MessageInterface' => $vendorDir . '/psr/http-message/src/MessageInterface.php',
    'Psr\\Http\\Message\\RequestInterface' => $vendorDir . '/psr/http-message/src/RequestInterface.php',
    'Psr\\Http\\Message\\ResponseInterface' => $vendorDir . '/psr/http-message/src/ResponseInterface.php',
    'Psr\\Http\\Message\\ServerRequestInterface' => $vendorDir . '/psr/http-message/src/ServerRequestInterface.php',
    'Psr\\Http\\Message\\StreamInterface' => $vendorDir . '/psr/http-message/src/StreamInterface.php',
    'Psr\\Http\\Message\\UploadedFileInterface' => $vendorDir . '/psr/http-message/src/UploadedFileInterface.php',
    'Psr\\Http\\Message\\UriInterface' => $vendorDir . '/psr/http-message/src/UriInterface.php',
    'Psr\\Log\\AbstractLogger' => $vendorDir . '/psr/log/Psr/Log/AbstractLogger.php',
    'Psr\\Log\\InvalidArgumentException' => $vendorDir . '/psr/log/Psr/Log/InvalidArgumentException.php',
    'Psr\\Log\\LogLevel' => $vendorDir . '/psr/log/Psr/Log/LogLevel.php',
    'Psr\\Log\\LoggerAwareInterface' => $vendorDir . '/psr/log/Psr/Log/LoggerAwareInterface.php',
    'Psr\\Log\\LoggerAwareTrait' => $vendorDir . '/psr/log/Psr/Log/LoggerAwareTrait.php',
    'Psr\\Log\\LoggerInterface' => $vendorDir . '/psr/log/Psr/Log/LoggerInterface.php',
    'Psr\\Log\\LoggerTrait' => $vendorDir . '/psr/log/Psr/Log/LoggerTrait.php',
    'Psr\\Log\\NullLogger' => $vendorDir . '/psr/log/Psr/Log/NullLogger.php',
    'Psr\\Log\\Test\\DummyTest' => $vendorDir . '/psr/log/Psr/Log/Test/DummyTest.php',
    'Psr\\Log\\Test\\LoggerInterfaceTest' => $vendorDir . '/psr/log/Psr/Log/Test/LoggerInterfaceTest.php',
    'Psr\\Log\\Test\\TestLogger' => $vendorDir . '/psr/log/Psr/Log/Test/TestLogger.php',
    'Westsworld\\TimeAgo' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo.php',
    'Westsworld\\TimeAgo\\Language' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Language.php',
    'Westsworld\\TimeAgo\\Translations\\Ar' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Ar.php',
    'Westsworld\\TimeAgo\\Translations\\Bg' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Bg.php',
    'Westsworld\\TimeAgo\\Translations\\Ca' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Ca.php',
    'Westsworld\\TimeAgo\\Translations\\Cs' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Cs.php',
    'Westsworld\\TimeAgo\\Translations\\Da' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Da.php',
    'Westsworld\\TimeAgo\\Translations\\De' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/De.php',
    'Westsworld\\TimeAgo\\Translations\\En' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/En.php',
    'Westsworld\\TimeAgo\\Translations\\En_Short' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/En_Short.php',
    'Westsworld\\TimeAgo\\Translations\\Es' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Es.php',
    'Westsworld\\TimeAgo\\Translations\\Fa_IR' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Fa_IR.php',
    'Westsworld\\TimeAgo\\Translations\\Fi' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Fi.php',
    'Westsworld\\TimeAgo\\Translations\\Fr' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Fr.php',
    'Westsworld\\TimeAgo\\Translations\\Ge' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Ge.php',
    'Westsworld\\TimeAgo\\Translations\\Hu' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Hu.php',
    'Westsworld\\TimeAgo\\Translations\\Id' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Id.php',
    'Westsworld\\TimeAgo\\Translations\\It' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/It.php',
    'Westsworld\\TimeAgo\\Translations\\Ja' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Ja.php',
    'Westsworld\\TimeAgo\\Translations\\Ko' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Ko.php',
    'Westsworld\\TimeAgo\\Translations\\Lv' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Lv.php',
    'Westsworld\\TimeAgo\\Translations\\Nl' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Nl.php',
    'Westsworld\\TimeAgo\\Translations\\Pl' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Pl.php',
    'Westsworld\\TimeAgo\\Translations\\Pt_BR' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Pt_BR.php',
    'Westsworld\\TimeAgo\\Translations\\Ru' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Ru.php',
    'Westsworld\\TimeAgo\\Translations\\Sk' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Sk.php',
    'Westsworld\\TimeAgo\\Translations\\Sv_SE' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Sv_SE.php',
    'Westsworld\\TimeAgo\\Translations\\Th' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Th.php',
    'Westsworld\\TimeAgo\\Translations\\Tr' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Tr.php',
    'Westsworld\\TimeAgo\\Translations\\Uk' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Uk.php',
    'Westsworld\\TimeAgo\\Translations\\Vi' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Vi.php',
    'Westsworld\\TimeAgo\\Translations\\Zh_CN' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Zh_CN.php',
    'Westsworld\\TimeAgo\\Translations\\Zh_Tw' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/Zh_Tw.php',
    'Westsworld\\TimeAgo\\Translations\\nb_NO' => $vendorDir . '/jimmiw/php-time-ago/src/Westsworld/TimeAgo/Translations/nb_NO.php',
    'setasign\\Fpdi\\FpdfTpl' => $vendorDir . '/setasign/fpdi/src/FpdfTpl.php',
    'setasign\\Fpdi\\FpdfTplTrait' => $vendorDir . '/setasign/fpdi/src/FpdfTplTrait.php',
    'setasign\\Fpdi\\FpdfTrait' => $vendorDir . '/setasign/fpdi/src/FpdfTrait.php',
    'setasign\\Fpdi\\Fpdi' => $vendorDir . '/setasign/fpdi/src/Fpdi.php',
    'setasign\\Fpdi\\FpdiException' => $vendorDir . '/setasign/fpdi/src/FpdiException.php',
    'setasign\\Fpdi\\FpdiTrait' => $vendorDir . '/setasign/fpdi/src/FpdiTrait.php',
    'setasign\\Fpdi\\GraphicsState' => $vendorDir . '/setasign/fpdi/src/GraphicsState.php',
    'setasign\\Fpdi\\Math\\Matrix' => $vendorDir . '/setasign/fpdi/src/Math/Matrix.php',
    'setasign\\Fpdi\\Math\\Vector' => $vendorDir . '/setasign/fpdi/src/Math/Vector.php',
    'setasign\\Fpdi\\PdfParser\\CrossReference\\AbstractReader' => $vendorDir . '/setasign/fpdi/src/PdfParser/CrossReference/AbstractReader.php',
    'setasign\\Fpdi\\PdfParser\\CrossReference\\CrossReference' => $vendorDir . '/setasign/fpdi/src/PdfParser/CrossReference/CrossReference.php',
    'setasign\\Fpdi\\PdfParser\\CrossReference\\CrossReferenceException' => $vendorDir . '/setasign/fpdi/src/PdfParser/CrossReference/CrossReferenceException.php',
    'setasign\\Fpdi\\PdfParser\\CrossReference\\FixedReader' => $vendorDir . '/setasign/fpdi/src/PdfParser/CrossReference/FixedReader.php',
    'setasign\\Fpdi\\PdfParser\\CrossReference\\LineReader' => $vendorDir . '/setasign/fpdi/src/PdfParser/CrossReference/LineReader.php',
    'setasign\\Fpdi\\PdfParser\\CrossReference\\ReaderInterface' => $vendorDir . '/setasign/fpdi/src/PdfParser/CrossReference/ReaderInterface.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\Ascii85' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/Ascii85.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\Ascii85Exception' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/Ascii85Exception.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\AsciiHex' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/AsciiHex.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\FilterException' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/FilterException.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\FilterInterface' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/FilterInterface.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\Flate' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/Flate.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\FlateException' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/FlateException.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\Lzw' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/Lzw.php',
    'setasign\\Fpdi\\PdfParser\\Filter\\LzwException' => $vendorDir . '/setasign/fpdi/src/PdfParser/Filter/LzwException.php',
    'setasign\\Fpdi\\PdfParser\\PdfParser' => $vendorDir . '/setasign/fpdi/src/PdfParser/PdfParser.php',
    'setasign\\Fpdi\\PdfParser\\PdfParserException' => $vendorDir . '/setasign/fpdi/src/PdfParser/PdfParserException.php',
    'setasign\\Fpdi\\PdfParser\\StreamReader' => $vendorDir . '/setasign/fpdi/src/PdfParser/StreamReader.php',
    'setasign\\Fpdi\\PdfParser\\Tokenizer' => $vendorDir . '/setasign/fpdi/src/PdfParser/Tokenizer.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfArray' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfArray.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfBoolean' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfBoolean.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfDictionary' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfDictionary.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfHexString' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfHexString.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfIndirectObject' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfIndirectObject.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfIndirectObjectReference' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfIndirectObjectReference.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfName' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfName.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfNull' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfNull.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfNumeric' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfNumeric.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfStream' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfStream.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfString' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfString.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfToken' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfToken.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfType' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfType.php',
    'setasign\\Fpdi\\PdfParser\\Type\\PdfTypeException' => $vendorDir . '/setasign/fpdi/src/PdfParser/Type/PdfTypeException.php',
    'setasign\\Fpdi\\PdfReader\\DataStructure\\Rectangle' => $vendorDir . '/setasign/fpdi/src/PdfReader/DataStructure/Rectangle.php',
    'setasign\\Fpdi\\PdfReader\\Page' => $vendorDir . '/setasign/fpdi/src/PdfReader/Page.php',
    'setasign\\Fpdi\\PdfReader\\PageBoundaries' => $vendorDir . '/setasign/fpdi/src/PdfReader/PageBoundaries.php',
    'setasign\\Fpdi\\PdfReader\\PdfReader' => $vendorDir . '/setasign/fpdi/src/PdfReader/PdfReader.php',
    'setasign\\Fpdi\\PdfReader\\PdfReaderException' => $vendorDir . '/setasign/fpdi/src/PdfReader/PdfReaderException.php',
    'setasign\\Fpdi\\TcpdfFpdi' => $vendorDir . '/setasign/fpdi/src/TcpdfFpdi.php',
    'setasign\\Fpdi\\Tcpdf\\Fpdi' => $vendorDir . '/setasign/fpdi/src/Tcpdf/Fpdi.php',
    'setasign\\Fpdi\\Tfpdf\\FpdfTpl' => $vendorDir . '/setasign/fpdi/src/Tfpdf/FpdfTpl.php',
    'setasign\\Fpdi\\Tfpdf\\Fpdi' => $vendorDir . '/setasign/fpdi/src/Tfpdf/Fpdi.php',
);
