@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-rating .wc-block-components-product-rating__container>*{vertical-align:middle}.wc-block-components-product-rating .wc-block-components-product-rating__stars{display:inline-block;margin:0}
