"use strict";(globalThis.webpackChunkwebpackWcBlocksCartCheckoutFrontendJsonp=globalThis.webpackChunkwebpackWcBlocksCartCheckoutFrontendJsonp||[]).push([[476],{826:(e,t,o)=>{o.r(t),o.d(t,{default:()=>h});var c=o(8146),s=o(3911),n=o(4921),l=o(5076),a=o(6589),r=o(3993);const i=(0,o(7723).__)("Go to checkout","woocommerce");var u=o(2578),k=o(790);const h=({className:e,checkoutButtonLabel:t,style:o})=>{const h=(0,l.p)({style:o}),{dispatchOnProceedToCheckout:d}=(0,a.e)();return c.tn?(0,k.jsx)(s.A,{className:(0,n.A)(e,h.className,"wc-block-mini-cart__footer-checkout"),variant:(0,u.IX)(e,"contained"),style:h.style,href:c.tn,onClick:e=>{d().then(t=>{t.some(r.isErrorResponse)&&e.preventDefault()})},children:t||i}):null}},2578:(e,t,o)=>{o.d(t,{Go:()=>l,IX:()=>n,j2:()=>a});var c=o(5703),s=o(3993);const n=(e="",t)=>e.includes("is-style-outline")?"outlined":e.includes("is-style-fill")?"contained":t,l=e=>!!e&&e.some(e=>Array.isArray(e)?l(e):(0,s.isObject)(e)&&null!==e.key),a=()=>(0,c.getSetting)("miniCartFooterDescription","")}}]);