<?php

namespace VIWEC\INC;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class I18n {
	public static function init() {
		return [
			'basic'                   => esc_html__( 'Basic', 'xstore-core' ),
			'sample'                  => esc_html__( 'Sample', 'xstore-core' ),
			'layout'                  => esc_html__( 'Layout', 'xstore-core' ),
			'content'                 => esc_html__( 'Content', 'xstore-core' ),
			'select_email_type'       => esc_html__( 'Select email type', 'xstore-core' ),
			'1_column'                => esc_html__( '1 Column', 'xstore-core' ),
			'2_columns'               => esc_html__( '2 Columns', 'xstore-core' ),
			'3_columns'               => esc_html__( '3 Columns', 'xstore-core' ),
			'4_columns'               => esc_html__( '4 Columns', 'xstore-core' ),
			'text'                    => esc_html__( 'Text', 'xstore-core' ),
			'image'                   => esc_html__( 'Image', 'xstore-core' ),
			'button'                  => esc_html__( 'Button', 'xstore-core' ),
			'order_detail'            => esc_html__( 'Order detail', 'xstore-core' ),
			'order_subtotal'          => esc_html__( 'Order subtotal', 'xstore-core' ),
			'order_total'             => esc_html__( 'Order total', 'xstore-core' ),
			'shipping'                => esc_html__( 'Shipping', 'xstore-core' ),
			'total'                   => esc_html__( 'Total', 'xstore-core' ),
			'shipping_method'         => esc_html__( 'Shipping method', 'xstore-core' ),
			'payment_method'          => esc_html__( 'Payment method', 'xstore-core' ),
			'billing_address'         => esc_html__( 'Billing address', 'xstore-core' ),
			'shipping_address'        => esc_html__( 'Shipping address', 'xstore-core' ),
			'products'                => esc_html__( 'Products', 'xstore-core' ),
			'coupon'                  => esc_html__( 'Coupon', 'xstore-core' ),
			'post'                    => esc_html__( 'Post', 'xstore-core' ),
			'contact'                 => esc_html__( 'Contact', 'xstore-core' ),
			'menu_bar'                => esc_html__( 'Menu bar', 'xstore-core' ),
			'social'                  => esc_html__( 'Social', 'xstore-core' ),
			'divider'                 => esc_html__( 'Divider', 'xstore-core' ),
			'spacer'                  => esc_html__( 'Spacer', 'xstore-core' ),
			'coupon_type'             => esc_html__( 'Coupon type', 'xstore-core' ),
			'select_coupon'           => esc_html__( 'Select coupon', 'xstore-core' ),
			'existing_coupon'         => esc_html__( 'Existing coupon', 'xstore-core' ),
			'generate_coupon'         => esc_html__( 'Generate coupon', 'xstore-core' ),
			'discount_type'           => esc_html__( 'Discount type', 'xstore-core' ),
			'coupon_amount'           => esc_html__( 'Coupon amount', 'xstore-core' ),
			'percentage_discount'     => esc_html__( 'Percentage discount', 'xstore-core' ),
			'fixed_cart_discount'     => esc_html__( 'Fixed cart discount', 'xstore-core' ),
			'fixed_product_discount'  => esc_html__( 'Fixed product discount', 'xstore-core' ),
			'expire_after_x_days'     => esc_html__( 'Expire after x days', 'xstore-core' ),
			'minimum_spend'           => esc_html__( 'Minimum spend', 'xstore-core' ),
			'maximum_spend'           => esc_html__( 'Maximum spend', 'xstore-core' ),
			'exclude_products'        => esc_html__( 'Exclude products', 'xstore-core' ),
			'categories'              => esc_html__( 'Categories', 'xstore-core' ),
			'exclude_categories'      => esc_html__( 'Exclude categories', 'xstore-core' ),
			'usage_limit_per_coupon'  => esc_html__( 'Usage limit per coupon', 'xstore-core' ),
			'limit_usage_to_x_items'  => esc_html__( 'Limit usage to X items', 'xstore-core' ),
			'usage_limit_per_user'    => esc_html__( 'Usage limit per user', 'xstore-core' ),
			'allow_free_shipping'     => esc_html__( 'Allow free shipping', 'xstore-core' ),
			'individual_use_only'     => esc_html__( 'Individual use only', 'xstore-core' ),
			'exclude_sale_items'      => esc_html__( 'Exclude sale items', 'xstore-core' ),
			'template'                => esc_html__( 'Template', 'xstore-core' ),
			'translate_text'          => esc_html__( 'Translate text', 'xstore-core' ),
			'default'                 => esc_html__( 'Default', 'xstore-core' ),
			'vertical_text'           => esc_html__( 'Vertical text', 'xstore-core' ),
			'horizontal_text'         => esc_html__( 'Horizontal text', 'xstore-core' ),
			'quantity'                => esc_html__( 'Quantity', 'xstore-core' ),
			'product'                 => esc_html__( 'Product', 'xstore-core' ),
			'price'                   => esc_html__( 'Price', 'xstore-core' ),
			'last_column_width'       => esc_html__( 'Last column width', 'xstore-core' ),
			'edit'                    => esc_html__( 'Edit', 'xstore-core' ),
			'style'                   => esc_html__( 'Style', 'xstore-core' ),
			'related'                 => esc_html__( 'Related', 'xstore-core' ),
			'category'                => esc_html__( 'Category', 'xstore-core' ),
			'on_sale'                 => esc_html__( 'On sale', 'xstore-core' ),
			'featured'                => esc_html__( 'Featured', 'xstore-core' ),
			'up_sell'                 => esc_html__( 'Up sell', 'xstore-core' ),
			'cross_sell'              => esc_html__( 'Cross sell', 'xstore-core' ),
			'best_seller'             => esc_html__( 'Best seller', 'xstore-core' ),
			'best_rated'              => esc_html__( 'Best rated', 'xstore-core' ),
			'newest'                  => esc_html__( 'Newest', 'xstore-core' ),
			'max_row'                 => esc_html__( 'Max row', 'xstore-core' ),
			'column'                  => esc_html__( 'Column', 'xstore-core' ),
			'character_limit'         => esc_html__( 'Charracter limit', 'xstore-core' ),
			'product_type'            => esc_html__( 'Product type', 'xstore-core' ),
			'product_name'            => esc_html__( 'Product name', 'xstore-core' ),
			'product_distance'        => esc_html__( 'Product distance', 'xstore-core' ),
			'all_category'            => esc_html__( 'All category', 'xstore-core' ),
			'include_posts'           => esc_html__( 'Include posts', 'xstore-core' ),
			'exclude_posts'           => esc_html__( 'Exclude posts', 'xstore-core' ),
			'post_title'              => esc_html__( 'Post title', 'xstore-core' ),
			'post_content'            => esc_html__( 'Post content', 'xstore-core' ),
			'post_distance'           => esc_html__( 'Post distance', 'xstore-core' ),
			'change_template_confirm' => esc_html__( 'Do you want to change email template?', 'xstore-core' ),
			'select'                  => esc_html__( 'Select', 'xstore-core' ),
			'order_items'             => esc_html__( 'Order items', 'xstore-core' ),
			'refund_fully'            => esc_html__( 'Refunded fully', 'xstore-core' ),
			'refund_partial'          => esc_html__( 'Refunded partial', 'xstore-core' ),
			'column_ratio'            => esc_html__( 'Column ratio', 'xstore-core' ),
			'vertical'                => esc_html__( 'Vertical', 'xstore-core' ),
			'horizontal'              => esc_html__( 'Horizontal', 'xstore-core' ),
			'socials'                 => esc_html__( 'Socials', 'xstore-core' ),
			'order_note'              => esc_html__( 'Customer note', 'xstore-core' ),
			'subtotal'                => esc_html__( 'Subtotal', 'xstore-core' ),
			'discount'                => esc_html__( 'Discount', 'xstore-core' ),
			'product_price'           => esc_html__( 'Price', 'xstore-core' ),
			'product_quantity'        => esc_html__( 'Quantity', 'xstore-core' ),
			'auto_add_to_cart'        => esc_html__( 'Auto add to cart in product URL', 'xstore-core' ),
			'enable'                  => esc_html__( 'Enable', 'xstore-core' ),
			'show_sku'                  => esc_html__( 'Show SKU', 'xstore-core' ),
		];
	}
}
