:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-payment{display:flex;flex-direction:row;align-items:center;position:relative;overflow:hidden}.woocommerce-task-payment .components-card__media{width:85px;flex-shrink:0;align-self:flex-start}.woocommerce-task-payment .components-card__media img,.woocommerce-task-payment .components-card__media svg,.woocommerce-task-payment .components-card__media .is-placeholder{margin:auto;max-width:36px;display:block}.woocommerce-task-payment .components-card__media .is-placeholder{height:36px}.woocommerce-task-payment .woocommerce-task-payment__footer .is-placeholder{width:70px;height:36px}.woocommerce-task-payment>.components-form-toggle{min-width:52px}.woocommerce-task-payment .woocommerce-task-payment__title{display:flex;align-items:center;font-size:16px;font-weight:500;color:#2c3338;margin-top:0;margin-bottom:8px}.woocommerce-task-payment .woocommerce-task-payment__title .woocommerce-pill{margin-right:8px}.woocommerce-task-payment .woocommerce-task-payment__title .woocommerce-pill.pill-green{color:#008a20;border-color:#008a20}.woocommerce-task-payment .woocommerce-task-payment__content{font-size:14px;color:#50575e;margin:0;margin-left:36px}.woocommerce-task-payment .woocommerce-task-payment__content .text-style-strong{font-weight:bold}.woocommerce-task-payment .woocommerce-task-payment__content p{font-size:12px}.woocommerce-task-payment .woocommerce-task-payment__transaction-processors_images{padding-top:16px;display:flex;flex-direction:row;flex-wrap:wrap;gap:8px}.woocommerce-task-payment .woocommerce-task-payment__transaction-processors_images img{height:24px}.woocommerce-task-payment .woocommerce-task-payment__description{flex:1}@media(max-width: 600px){.woocommerce-task-payment{flex-wrap:wrap}.woocommerce-task-payment .woocommerce-task-payment__content{margin:0}.woocommerce-task-payment .components-card__media{order:1;flex-basis:50%}.woocommerce-task-payment .components-card__media>svg,.woocommerce-task-payment .components-card__media>img{margin:0 24px 0 0}.woocommerce-task-payment .woocommerce-task-payment__description{order:3;padding:24px 24px 0 0}.woocommerce-task-payment .woocommerce-task-payment__footer{flex-basis:50%;align-self:flex-start;order:2;text-align:left}}.woocommerce-payment-gateway-suggestions-list-placeholder .is-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;max-width:240px;width:80%}.woocommerce-payment-gateway-suggestions-list-placeholder .is-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-payment-gateway-suggestions-list-placeholder .is-placeholder{animation:none}}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-label{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;width:60%}.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-label::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-label{animation:none}}.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-icon{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0)}.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-icon::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-icon{animation:none}}.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step:nth-child(1) .woocommerce-stepper__step-label{width:30%}.woocommerce-task-payment-method.is-loading .woocommerce-stepper__step-number{display:none}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-wcpay-suggestion .woocommerce-recommended-payments-banner{min-width:100%;margin-bottom:24px}.woocommerce-wcpay-suggestion .woocommerce-recommended-payments-banner .woocommerce-recommended-payments-banner__body{padding:30px 24px 0 0;justify-content:space-between}.woocommerce-wcpay-suggestion .woocommerce-recommended-payments-banner .woocommerce-recommended-payments-banner__text_container{width:305px;margin-right:0}.woocommerce-wcpay-suggestion .woocommerce-recommended-payments-banner .woocommerce-recommended-payments-banner__footer{flex-direction:column;align-items:flex-start;padding:20px 24px 30px 38.2px}.woocommerce-wcpay-suggestion .woocommerce-recommended-payments-banner .woocommerce-recommended-payments-banner__footer_icon_container{margin-top:12px;margin-right:-5px}.woocommerce-wcpay-suggestion .woocommerce-recommended-payments-banner .woocommerce-recommended-payments-banner__footer_icon_container>svg{width:38px;height:24px;margin-left:8px}.woocommerce-wcpay-suggestion .woocommerce-wcpay-benefits{margin-bottom:24px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-wcpay-bnpl-suggestion .woocommerce-wcpay-bnpl-suggestion__body{padding:0;justify-content:space-between}.woocommerce-wcpay-bnpl-suggestion .woocommerce-wcpay-bnpl-suggestion__contents-container{padding:32px 24px;position:relative;flex:1;overflow:hidden;width:100%}.woocommerce-wcpay-bnpl-suggestion .svg-background{position:absolute;z-index:0;left:0;top:0;width:auto;height:100%}@media(max-width: 600px){.woocommerce-wcpay-bnpl-suggestion .svg-background{display:none}}.woocommerce-wcpay-bnpl-suggestion .woocommerce-wcpay-bnpl-suggestion__contents{max-width:71%;position:relative;z-index:1}@media(max-width: 600px){.woocommerce-wcpay-bnpl-suggestion .woocommerce-wcpay-bnpl-suggestion__contents{max-width:100%}}.woocommerce-wcpay-bnpl-suggestion .woocommerce-wcpay-bnpl-suggestion__contents p{color:#646970;font-size:14px;font-style:normal;font-weight:400}.woocommerce-wcpay-bnpl-suggestion .woocommerce-wcpay-bnpl-suggestion__contents p:first-of-type{margin-top:8px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-payments .components-card+.components-card{margin-top:24px}.woocommerce-task-payments .woocommerce-task-payment__setup_required{display:flex;align-items:center;font-size:14px;margin-right:12px;font-weight:400;gap:3px}.woocommerce-task-payments .woocommerce-task-payment__setup_required>svg{fill:#efb854}.woocommerce-task-payments .components-card__header{font-size:20px;font-weight:400;line-height:28px;margin:0;display:flex;flex-direction:column;align-items:flex-start}.woocommerce-task-payments .woocommerce-task-payment-header__description{margin:0;color:#757575;font-weight:400;font-size:14px}.woocommerce-task-payments .woocommerce-task-payment__recommended-pill{border:1px solid #dcdcde;border-radius:28px;display:inline-block;font-size:13px;margin-right:12px;padding:1px 10px}.woocommerce-task-payments .woocommerce-task-payment__recommended-pill span{max-width:70px}.woocommerce-task-payments .components-card__divider:last-child{display:none}.woocommerce-task-payments .woocommerce-task-payment-wcpay{margin-bottom:0}.woocommerce-task-payment-method>h3{margin:0;color:#1d2327}.woocommerce-task-payment-method p{font-size:14px;color:#646970;font-weight:400;margin-top:16px;margin-bottom:16px}.woocommerce-task-payment-method__fields{display:grid;grid-template-columns:1fr 1fr;grid-gap:0 16px;margin-bottom:8px}.woocommerce-task-payment-method__fields .components-base-control{margin-bottom:0}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-shipping-rate{display:flex;padding-top:12px;padding-bottom:12px}.woocommerce-shipping-rate .woocommerce-shipping-rate__main{width:100%}.woocommerce-shipping-rate .woocommerce-shipping-rate__icon{padding-top:16px;margin-left:24px}.woocommerce-shipping-rate .woocommerce-shipping-rate__name{align-items:center;display:flex;padding-top:16px;font-size:16px;line-height:22px;color:#1d2327;margin-bottom:12px;border-top:1px solid #dcdcde}.woocommerce-shipping-rate .woocommerce-shipping-rate__name .components-form-toggle{margin-right:auto;height:18px}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .components-base-control{margin-bottom:0}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .components-base-control__label{display:block;position:relative;top:-8px;width:100%;font-size:12px}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .components-base-control__field div.text-control-with-affixes{align-items:baseline}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .text-control-with-affixes__prefix,.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .text-control-with-affixes__suffix{font-size:16px;line-height:24px;color:#646970;border:0;padding:0;align-items:center;display:flex;top:-11px}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .components-text-control__input{position:relative;top:-11px}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .text-control-with-affixes__prefix{margin-left:4px}.woocommerce-shipping-rate .woocommerce-shipping-rate__control-wrapper .text-control-with-affixes__suffix{margin-right:4px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-shipping-recommendation__plugins-install{padding:24px 20px;border:1px solid #ddd;border-radius:3px;justify-content:space-around;margin-bottom:24px}.woocommerce-task-shipping-recommendation__plugins-install.dual{display:flex;flex-direction:column;justify-content:flex-start;width:285px}.woocommerce-task-shipping-recommendation__plugins-install.dual p{margin-top:0;margin-bottom:15px;color:#757575}.woocommerce-task-shipping-recommendation__plugins-install.dual .plugins-install__plugin-banner-image{display:flex;margin-bottom:24px;width:100%;align-items:center;gap:12px}.woocommerce-task-shipping-recommendation__plugins-install.dual .plugins-install__plugin-banner-image img{width:120px;height:28px}.woocommerce-task-shipping-recommendation__plugins-install.dual .plugins-install__plugin-banner-image img.with-label{width:60px;height:auto}.woocommerce-task-shipping-recommendation__plugins-install.dual .plugins-install__plugin-banner-image div{display:flex;flex:1;font-size:12px;color:#757575;justify-content:flex-end}.woocommerce-task-shipping-recommendation__plugins-install.single{display:flex;gap:12px}.woocommerce-task-shipping-recommendation__plugins-install.single .plugins-install__list{max-width:360px}.woocommerce-task-shipping-recommendation__plugins-install .plugins-install__plugin-banner-image{display:flex;width:150px}.woocommerce-task-shipping-recommendation__plugins-install .plugins-install__plugin-banner-image img{width:100%}.woocommerce-task-shipping-recommendation__plugins-install .plugins-install__list{display:flex;flex-direction:column;justify-content:space-around;gap:10px}.woocommerce-task-shipping-recommendation__plugins-install .woocommerce-task-shipping-recommendations_plugins-buttons{display:flex;justify-content:space-between;margin-top:24px;flex-grow:1;align-items:flex-end}.woocommerce-task-shipping-recommendation__plugins-install .woocommerce-task-shipping-recommendations_plugins-buttons button{min-width:40%;padding-inline:8px;margin-inline:4px}.woocommerce-task-shipping-recommendation__plugins-install .plugins-install__list-item{display:flex;align-items:center}.woocommerce-task-shipping-recommendation__plugins-install .plugins-install__list-icon{margin-left:12px}.woocommerce-task-shipping-recommendation_plugins-install-container{display:flex;flex-direction:row;flex-wrap:wrap;gap:10px}.woocommerce-task-shipping-recommendations_skip-button.dual{margin-inline:calc(50% - 34px)}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-marketing .components-card__header{flex-direction:column;align-items:flex-start;display:flex !important}.woocommerce-task-marketing .components-card__header h2{align-self:start !important;color:#1e1e1e;font-size:20px;margin-bottom:0}.woocommerce-task-marketing .components-card__header span{margin-right:0;margin-top:8px;color:#757575}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-plugin-list__plugin{display:flex;padding:24px;border-top:1px solid #e0e0e0}.woocommerce-plugin-list__plugin:first-child{border-top:0}.woocommerce-plugin-list__plugin h4{margin-bottom:12px;font-weight:600;color:#1e1e1e}.woocommerce-plugin-list__plugin p{color:#757575;font-weight:400}.woocommerce-plugin-list__plugin-logo{margin-left:45px;display:flex;align-items:center}.woocommerce-plugin-list__plugin-logo img{width:50px}.woocommerce-plugin-list__plugin-text{max-width:370px;margin-left:16px}.woocommerce-plugin-list__plugin-text .woocommerce-pill{color:#646970;margin-right:12px}.woocommerce-plugin-list__plugin-action{display:flex;align-items:center;margin-right:auto}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-plugin-list__title{padding:24px 30px 0 30px;position:relative}.woocommerce-plugin-list__title h3{font-weight:500;color:#000;text-transform:uppercase}.woocommerce-plugin-list__plugin{border-top:none;border-bottom:1px solid #e0e0e0}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-promo .components-card__body{display:flex;padding:24px}.woocommerce-task-promo h4{margin-bottom:12px;font-weight:600;color:#1e1e1e}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-tax-partner-card{border:1px solid #ddd;border-radius:3px;margin:0 8px 16px 8px;padding:20px;display:flex;flex-direction:column}.woocommerce-tax-partner-card a{text-decoration:none}.woocommerce-tax-partner-card__logo{margin-bottom:8px}.woocommerce-tax-partner-card__logo img{max-height:35px}.woocommerce-tax-partner-card__description{color:#757575}.woocommerce-tax-partner-card__benefits{color:#1e1e1e;list-style:none}.woocommerce-tax-partner-card__benefits li{margin-bottom:8px;display:flex}.woocommerce-tax-partner-card__benefits li svg{margin-left:10px}.woocommerce-tax-partner-card__action{margin-top:auto}.woocommerce-tax-partner-card__terms{color:#949494;font-size:12px;margin-bottom:8px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-tax-partners__partners{display:grid;grid-template-columns:1fr 1fr}.woocommerce-tax-partners__partners.woocommerce-tax-partners__partners-count-1{grid-template-columns:1fr}@media(max-width: 782px){.woocommerce-tax-partners__partners{grid-template-columns:1fr}}.woocommerce-tax-partners__partners-count-1 .woocommerce-tax-partners__partners{grid-template-columns:1fr;justify-items:center}.woocommerce-tax-partners .components-card__body.is-size-medium{padding:36px}.woocommerce-tax-partners .components-card__header{line-height:28px;font-size:20px}.woocommerce-tax-partners__other-actions{text-align:center;list-style:none;display:flex;align-items:center;justify-content:center;margin:0}@media(max-width: 782px){.woocommerce-tax-partners__other-actions{flex-direction:column}}.woocommerce-tax-partners__other-actions li{margin-top:16px;margin-left:4px}.woocommerce-tax-partners__other-actions li button.is-tertiary{padding:0;height:auto}.woocommerce-tax-partners__other-actions li::after{content:"•";color:#bbb;margin-right:4px}@media(max-width: 782px){.woocommerce-tax-partners__other-actions li::after{content:""}}.woocommerce-tax-partners__other-actions li:last-child{margin-left:0}.woocommerce-tax-partners__other-actions li:last-child::after{content:""}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-tax__automated-tax-control{display:flex;align-items:center;margin-top:16px}.woocommerce-task-tax__automated-tax-control i{margin-right:16px;margin-left:24px}.woocommerce-task-tax__automated-tax-control .woocommerce-task-tax__automated-tax-control-inner{border-top:1px solid #dcdcde;display:flex;align-items:center;flex:1;font-size:16px;padding-top:16px;padding-bottom:16px}.woocommerce-task-tax__automated-tax-control .components-form-toggle{margin-right:auto}.woocommerce-task-tax__success{display:flex;flex-direction:column;align-items:center;padding:40px;text-align:center}.woocommerce-task-tax__success .woocommerce-task-tax__success-icon{font-size:48px;height:48px;align-items:center;display:flex}.woocommerce-task-tax__success #woocommerce-task-tax__success-message{font-size:32px;font-weight:400}.woocommerce-task-tax__success p{margin-top:0;font-size:16px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-dashboard__container .woocommerce-task-card,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link{max-width:680px;margin-right:auto;margin-left:auto;margin-bottom:24px;overflow:hidden}.woocommerce-task-dashboard__container .woocommerce-task-card .components-card__header.is-size-large,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link .components-card__header.is-size-large{padding-bottom:12px}.woocommerce-task-dashboard__container .woocommerce-task-card .components-card__header.is-size-large .woocommerce-card__menu,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link .components-card__header.is-size-large .woocommerce-card__menu{margin-top:8px}.woocommerce-task-dashboard__container .woocommerce-task-card .woocommerce-task-card__header,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link .woocommerce-task-card__header{display:flex}.woocommerce-task-dashboard__container .woocommerce-task-card .woocommerce-task-card__header .components-text+.woocommerce-badge,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link .woocommerce-task-card__header .components-text+.woocommerce-badge{margin-right:16px}.woocommerce-task-dashboard__container .woocommerce-task-card .woocommerce-list__item-text .woocommerce-pill,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link .woocommerce-list__item-text .woocommerce-pill{padding:1px 8px;margin-right:8px}.woocommerce-task-dashboard__container .woocommerce-task-card .components-popover__content,.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link .components-popover__content{min-width:unset}.woocommerce-task-dashboard__container .woocommerce-task-payments{width:680px;margin:auto;max-width:100%}.woocommerce-task__additional-info,.woocommerce-task__estimated-time,.woocommerce-task-list__item-expandable-content{color:#757575;font-weight:400;font-size:12px}.woocommerce-task-list__item-expandable-content{font-size:13px}.components-modal__screen-overlay{background:rgba(43,45,47,.4)}.components-modal__frame .components-modal__header{margin-bottom:0}.components-modal__frame .woocommerce-task-payments__stripe-error-wrapper{align-items:flex-end;flex-grow:1;display:flex;flex-direction:column}.woocommerce-task-dashboard__container .woocommerce-stepper button.components-button.is-primary{margin:0 0 0 8px}.woocommerce-task-dashboard__container button.components-button.is-link{margin:0;height:auto;color:#50575e;font-weight:normal}.woocommerce-task-card__prompt{width:100%;min-width:100%;margin-bottom:24px;margin-top:-4px;cursor:default}.woocommerce-task-card__prompt .components-snackbar__content{display:block;align-items:unset;justify-content:unset}.woocommerce-task-card__prompt .components-snackbar__content span{margin-right:-24px}.woocommerce-task-card__prompt .woocommerce-task-card__prompt-actions button.is-link,.woocommerce-task-card__prompt .woocommerce-task-card__prompt-actions button.is-link:active,.woocommerce-task-card__prompt .woocommerce-task-card__prompt-actions button.is-link:focus{color:#fff;margin-right:24px;background:rgba(0,0,0,0)}.woocommerce-task-card__prompt .woocommerce-task-card__prompt-actions button.is-link:hover{color:#fff}.woocommerce-task-card__prompt .woocommerce-task-card__prompt-pointer{border-bottom:10px solid #1e1e1e;border-right:10px solid rgba(0,0,0,0);border-left:10px solid rgba(0,0,0,0);position:relative;width:0;height:0;display:inline-block;top:-30px}.woocommerce-task-card__prompt .woocommerce-task-card__prompt-content{display:flex;align-items:baseline;justify-content:space-between;max-height:10px;margin-right:24px;position:relative;top:-40px}.woocommerce-task-card__prompt .woocommerce-task-card__prompt-actions{margin-left:-16px}.woocommerce-task-card__prompt:hover .woocommerce-task-card__prompt-pointer{border-bottom-color:#1e1e1e}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-card__body{border-top:1px solid #dcdcde}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:16px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder{animation:none}}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-card__title .is-placeholder{width:70%;height:28px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-before .is-placeholder{height:36px;width:36px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-text{width:100%}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-text .woocommerce-list__item-title .is-placeholder{height:22px;width:60%}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-after .is-placeholder{height:18px;width:60px}.woocommerce-task-dashboard__container .muriel-component{margin-top:16px;margin-bottom:16px}.woocommerce-task-dashboard__container .components-base-control.has-error{margin-bottom:32px !important;border-color:#d63638}@media(max-width: 782px){.woocommerce-task-dashboard__container .components-base-control.has-error{margin-bottom:44px !important}}.woocommerce-task-dashboard__container .components-base-control.has-error .components-base-control__help{top:100%;right:12px;position:absolute;margin-top:4px;font-size:12px;font-style:normal;color:#d63638}.woocommerce-task-dashboard__container .components-form-toggle{display:inline-block}.woocommerce-task-dashboard__container .components-form-toggle label{font-size:14px}.woocommerce-task-dashboard__container .components-form-toggle .components-base-control{display:inline-block}.woocommerce-task-dashboard__container .components-form-toggle .components-base-control__field{margin-bottom:0}.woocommerce-task-dashboard__container .woocommerce-task__caption{color:#757575;margin-top:16px}.woocommerce-task-dashboard__container .woocommerce-task__caption.is-tos{margin-bottom:16px}.woocommerce-task-list__setup .woocommerce-experimental-list .woocommerce-experimental-list__item.complete{text-decoration:line-through;color:var(--wp-admin-theme-color)}.woocommerce-task-list__setup .woocommerce-experimental-list .woocommerce-experimental-list__item.complete .woocommerce-task-list__item-title{color:var(--wp-admin-theme-color)}@media(max-width: 782px){.woocommerce-task-dashboard__container .woocommerce-task-marketplace-link{padding:0 16px}}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-progress-header{position:relative;min-height:28px}.woocommerce-task-progress-header h1{font-size:24px}.woocommerce-task-progress-header p{color:#757575;font-size:16px;line-height:24px;margin-top:8px}.woocommerce-task-progress-header .woocommerce-task-progress-header__progress-bar{appearance:none;border:1px solid #ddd;border-radius:16px;height:12px;width:100%;margin-bottom:0}.woocommerce-task-progress-header .woocommerce-task-progress-header__progress-bar{background-color:#fff}.woocommerce-task-progress-header .woocommerce-task-progress-header__progress-bar::-moz-progress-bar{background-color:var(--wp-admin-theme-color);border-radius:16px}.woocommerce-task-progress-header .woocommerce-task-progress-header__progress-bar::-webkit-progress-bar{background-color:#fff;border-radius:16px}.woocommerce-task-progress-header .woocommerce-task-progress-header__progress-bar::-webkit-progress-value{background-color:var(--wp-admin-theme-color);border-bottom-right-radius:16px;border-top-right-radius:16px}.woocommerce-task-progress-header .woocommerce-card__menu{position:absolute;left:0;top:-7px}.woocommerce-setup-panel .woocommerce-task-progress-header{padding:16px}.woocommerce-setup-panel .woocommerce-task-progress-header h1{font-size:16px;font-weight:600}.woocommerce-setup-panel .woocommerce-task-progress-header p{font-size:16px}.woocommerce-setup-panel .woocommerce-task-progress-header .woocommerce-card__menu{top:17px}@media(max-width: 782px){.woocommerce-task-progress-header{padding-right:var(--large-gap);padding-left:var(--large-gap)}}h1.woocommerce-task-progress-header__title{padding-top:4px}@media(max-width: 782px){h1.woocommerce-task-progress-header__title{padding-right:var(--large-gap);padding-left:var(--large-gap)}}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-card__header .woocommerce-task-card__header-subtitle{color:#757575;margin-bottom:24px}.woocommerce-task-card__finished-header-image{max-width:75%}.customer-feedback-simple__container{height:64px}.woocommerce-task-card__header-menu{position:absolute;left:0;top:0}.woocommerce-task-card__header-ces-feedback{height:64px;display:flex;justify-content:center;align-items:center}.woocommerce-task-header__contents-container img.svg-background{padding-left:16px;padding-top:9px}.woocommerce-task-header__contents-container.woocommerce-task-header__launch_your_store img.svg-background{padding:8px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-homescreen .woocommerce-task-dashboard__container:empty{margin-bottom:0}.woocommerce-task-dashboard__container .woocommerce-homescreen-card{max-width:none;width:100%}.woocommerce-task-dashboard__container .woocommerce-task-card__header-container{display:flex;position:relative;border-bottom:1px solid #dcdcde}.woocommerce-task-dashboard__container .woocommerce-task-card__header{width:100%;flex:1}.woocommerce-task-dashboard__container .woocommerce-ellipsis-menu{position:absolute;top:16px;left:24px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-card__body{border-top:1px solid #dcdcde}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .components-card__header{background:#fff;height:130px;display:block}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .components-card__header .is-placeholder{margin:20px;width:100%;height:90px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-task-card__header{align-self:inherit}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:16px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder{animation:none}}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-card__title .is-placeholder{width:70%;height:28px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-task-list__item-before .is-placeholder{height:36px;width:36px;border-radius:50%}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-task-list__item-text .is-placeholder{width:80%}.woocommerce-task-dashboard__container .woocommerce-task-card.completed{display:block}.woocommerce-task-dashboard__container .woocommerce-task-card.completed .components-card__header{display:block}.woocommerce-task-dashboard__container .woocommerce-task-card.completed h2{margin-top:24px;margin-bottom:12px}.woocommerce-task-dashboard__container .woocommerce-task-card.completed .woocommerce-task-card__header{display:block;text-align:center}.woocommerce-task-dashboard__container .woocommerce-task-card.completed button.is-secondary{margin-left:12px}.woocommerce-task-dashboard__container.setup-task-list{max-width:1032px;display:flex;flex-direction:row;margin:0 auto;justify-content:space-between}.woocommerce-task-dashboard__container.setup-task-list ul li.complete .woocommerce-task-list__item-title{font-weight:600;color:#949494}.woocommerce-task-dashboard__container.setup-task-list ul li{display:block;width:100%;border-left:1px solid #e0e0e0;border-top:none;padding:16px 24px}.woocommerce-task-dashboard__container.setup-task-list ul li:last-child{border-left:none}.woocommerce-task-dashboard__container.setup-task-list ul li.is-active{box-shadow:inset 0 -4px 0 0 var(--wp-admin-theme-color);transition:box-shadow .1s linear}.woocommerce-task-dashboard__container.setup-task-list ul li.is-active .woocommerce-task-list__item-badge{background-color:#fff;position:relative;z-index:1}.woocommerce-task-dashboard__container.setup-task-list ul li.is-active::after{background-color:var(--wp-admin-theme-color);opacity:.1;content:"";top:0;right:0;position:absolute;width:100%;height:100%;pointer-events:none}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.complete) .woocommerce-task__icon{border:1px solid var(--wp-admin-theme-color);background:rgba(0,0,0,0)}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item.in_progress .woocommerce-task__icon{background:linear-gradient(to left, var(--wp-admin-theme-color) 50%, transparent 50%)}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item.complete:not(.complete) .woocommerce-task__icon{border:none}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item-before{display:block;padding:0}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item-text{display:flex;flex-direction:row;align-items:center;gap:16px}.woocommerce-task-dashboard__container.setup-task-list .numbered-circle,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-10 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-9 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-8 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-7 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-6 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-5 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-4 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-3 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-2 .woocommerce-task__icon::after,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-1 .woocommerce-task__icon::after{justify-content:center;display:flex;align-items:center;height:100%;width:100%}.woocommerce-task-dashboard__container.setup-task-list ul{display:block}.woocommerce-task-dashboard__container.setup-task-list ul li{display:grid;grid-template-columns:48px auto 48px;border-left:none;border-bottom:1px solid #e0e0e0}.woocommerce-task-dashboard__container.setup-task-list ul li.is-active{box-shadow:inset -5px 0 0 0 var(--wp-admin-theme-color);transition:box-shadow .1s linear}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item-text{display:flex;flex-direction:row;align-items:center;gap:16px;padding:0;margin-top:0}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:65%}@media(max-width: 782px){.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:380px}}@media(max-width: 600px){.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:100%}}.woocommerce-task-dashboard__container.setup-task-list .svg-background{left:6%}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-1 .woocommerce-task__icon::after{content:"1";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-2 .woocommerce-task__icon::after{content:"2";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-3 .woocommerce-task__icon::after{content:"3";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-4 .woocommerce-task__icon::after{content:"4";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-5 .woocommerce-task__icon::after{content:"5";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-6 .woocommerce-task__icon::after{content:"6";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-7 .woocommerce-task__icon::after{content:"7";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-8 .woocommerce-task__icon::after{content:"8";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-9 .woocommerce-task__icon::after{content:"9";color:var(--wp-admin-theme-color);font-weight:bold}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item:not(.in_progress):not(.complete).index-10 .woocommerce-task__icon::after{content:"10";color:var(--wp-admin-theme-color);font-weight:bold}@media(max-width: 782px){.woocommerce-task-dashboard__container.setup-task-list ul{display:block}.woocommerce-task-dashboard__container.setup-task-list ul li{display:grid;grid-template-columns:48px auto 48px;border-left:none;border-bottom:1px solid #e0e0e0}.woocommerce-task-dashboard__container.setup-task-list ul li.is-active{box-shadow:inset -5px 0 0 0 var(--wp-admin-theme-color);transition:box-shadow .1s linear}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-list__item-text{display:flex;flex-direction:row;align-items:center;gap:16px;padding:0;margin-top:0}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:65%}}@media(max-width: 782px)and (max-width: 782px){.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:380px}}@media(max-width: 782px)and (max-width: 600px){.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:100%}}@media(max-width: 782px){.woocommerce-task-dashboard__container.setup-task-list .svg-background{left:6%}}.woocommerce-setup-panel .woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents-container{padding:16px}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents-container{padding:24px 24px 24px 40px;position:relative;flex:1;overflow:hidden;width:100%}.woocommerce-task-dashboard__container.setup-task-list .svg-background{position:absolute;z-index:0;left:24px;max-width:25%;max-height:150px;width:auto;height:auto}@media(max-width: 600px){.woocommerce-task-dashboard__container.setup-task-list .svg-background{display:none}}@media(max-width: 782px){.woocommerce-task-dashboard__container.setup-task-list .svg-background{left:.5%;width:40%}}.woocommerce-task-dashboard__container.setup-task-list .svg-background .admin-theme-color{fill:var(--wp-admin-theme-color)}.woocommerce-task-dashboard__container.setup-task-list .svg-background .admin-theme-color-darker-10{fill:var(--wp-admin-theme-color-darker-10)}.woocommerce-task-dashboard__container.setup-task-list .svg-background .admin-theme-color-darker-20{fill:var(--wp-admin-theme-color-darker-20)}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:70%;position:relative;z-index:1}@media(max-width: 782px){.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents{max-width:380px}}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents h1{color:#1e1e1e;font-size:1.25rem;font-style:normal;font-weight:400;line-height:28px;padding:0}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents p,.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents span{color:#757575;font-size:.8125rem;font-style:normal;font-weight:400;line-height:16px}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__contents p:first-of-type{margin-top:8px}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__timer{display:flex;align-items:center;line-height:22px;margin-bottom:0}.woocommerce-task-dashboard__container.setup-task-list .woocommerce-task-header__timer img{margin-left:6px}.woocommerce-task-dismiss-modal{width:565px;max-width:100%}.woocommerce-task-dismiss-modal .components-modal__header{border-bottom:1px solid #ddd}.woocommerce-task-dismiss-modal .woocommerce-usage-modal__message{box-sizing:border-box;border-bottom:1px solid #ddd;padding:0 32px;display:flex;flex-direction:row;justify-content:space-between;background:#fff;align-items:center;height:60px;z-index:10;position:relative;position:sticky;top:0;margin:0 -32px 24px;font-size:1.2em}.woocommerce-task-dismiss-modal .woocommerce-usage-modal__actions{display:flex;justify-content:flex-end;margin-top:16px}.woocommerce-task-dismiss-modal .woocommerce-usage-modal__actions button{margin-right:16px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-layout__header-back-button{cursor:pointer;margin-right:40px;margin-right:var(--large-gap);margin-left:-16px;display:flex;z-index:2}.woocommerce-layout__header-back-button:focus{box-shadow:inset 1px -1px 0 #757575,inset -1px 1px 0 #757575}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-card__body{border-top:1px solid #dcdcde}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:16px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .is-placeholder{animation:none}}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-card__title .is-placeholder{width:70%;height:28px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-before .is-placeholder{height:36px;width:36px}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-text{width:100%}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-text .woocommerce-list__item-title .is-placeholder{height:22px;width:60%}.woocommerce-task-dashboard__container .woocommerce-task-card.is-loading .woocommerce-list__item-after .is-placeholder{height:18px;width:60px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-task-list__item.woocommerce-list__item-enter{opacity:0;max-height:0}.woocommerce-task-list__item.woocommerce-list__item-enter-active{opacity:1;max-height:100px;transition:opacity 500ms,max-height 500ms}.woocommerce-task-list__item.woocommerce-list__item-exit{opacity:1;max-height:100px}.woocommerce-task-list__item.woocommerce-list__item-exit-active{opacity:0;max-height:0;transition:opacity 500ms,max-height 500ms}
