<?php return array(
    'root' => array(
        'name' => 'wpovernight/woocommerce-pdf-invoices-packing-slips',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => '23149f4d7a44ad73624d4b15a4a4cbc1d9694c6a',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'dompdf/dompdf' => array(
            'pretty_version' => 'v3.1.5',
            'version' => '3.1.5.0',
            'reference' => 'f11ead23a8a76d0ff9bbc6c7c8fd7e05ca328496',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/dompdf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dompdf/php-font-lib' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'a6e9a688a2a80016ac080b97be73d3e10c444c9a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/php-font-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dompdf/php-svg-lib' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => '8259ffb930817e72b1ff1caef5d226501f3dfeb1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/php-svg-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.10.0',
            'version' => '2.10.0.0',
            'reference' => 'fcf91eb64359852f00d921887b219479b4f21251',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabberworm/php-css-parser' => array(
            'pretty_version' => 'v8.9.0',
            'version' => '8.9.0.0',
            'reference' => 'd8e916507b88e389e26d4ab03c904a082aa66bb9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabberworm/php-css-parser',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/uri' => array(
            'pretty_version' => '3.0.2',
            'version' => '3.0.2.0',
            'reference' => '38eeab6ed9eec435a2188db489d4649c56272c51',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/xml' => array(
            'pretty_version' => '4.0.6',
            'version' => '4.0.6.0',
            'reference' => 'a89257fd188ce30e456b841b6915f27905dfdbe3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/xml',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-iconv' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '5f3b930437ae03ae5dff61269024d8ea1b3774aa',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-iconv',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.33.0',
            'version' => '1.33.0.0',
            'reference' => '6d857f4d76bd4b343eac26d6b539585d2bc56493',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wpovernight/woocommerce-pdf-invoices-packing-slips' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => '23149f4d7a44ad73624d4b15a4a4cbc1d9694c6a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
