//
// ATUM Supplier Modal
//------------
.add-suppliers-modal {
	.swal2-header {
		
		display: block;
		border-bottom: solid 1px $gray-400;
		margin-left: -20px;
		margin-right: -20px;
		padding: 0 20px !important;
		
		h2 {
			
			display: block !important;
			text-align: left;
			font-size: 18px;
			margin-bottom: 15px !important;
			
			small {
				display: block;
				color: $gray-600;
				font-weight: normal;
				font-size: 12px;
				margin-top: 5px;
			}
		}
		
		
	}
	
	.swal2-actions {
		justify-content: right;
		padding: 20px 0 0;
		margin-top: 0;
		
		.swal2-confirm {
			margin: 0;
			font-size: 12px;
		}
	}
}