"use strict";(globalThis.webpackChunkwebpackWcBlocksCartCheckoutFrontendJsonp=globalThis.webpackChunkwebpackWcBlocksCartCheckoutFrontendJsonp||[]).push([[762],{3152:(c,e,t)=>{t.r(e),t.d(e,{default:()=>o});var s=t(4656),n=t(3491),a=t(790);const o=({children:c,className:e})=>{const{cartItems:t}=(0,n.V)();return 0===t.length?null:(0,a.jsxs)("div",{className:e,children:[(0,a.jsx)(s.StoreNoticesContainer,{context:"wc/cart"}),c]})}}}]);