@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-filter-chips fieldset{display:contents}:where(.wc-block-product-filter-chips__items){display:flex;flex-wrap:wrap;gap:4px}.wc-block-product-filter-chips__item{appearance:none;background:transparent;border:1px solid color-mix(in srgb,currentColor 40%,transparent);border-radius:2px;color:inherit;cursor:pointer;font-family:inherit;font-size:.8em;padding:.25em .75em}.wc-block-product-filter-chips__item:focus{outline:1px solid currentColor;outline-offset:1px}.wc-block-product-filter-chips__item:hover{background-color:color-mix(in srgb,var(--wp--preset--color--contrast) 10%,transparent)}.has-chip-text-color .wc-block-product-filter-chips__item{color:var(--wc-product-filter-chips-text)}.has-chip-background-color .wc-block-product-filter-chips__item{background:var(--wc-product-filter-chips-background)}.has-chip-border-color .wc-block-product-filter-chips__item{border-color:var(--wc-product-filter-chips-border)}.has-selected-chip-text-color .wc-block-product-filter-chips__item[aria-checked=true]{color:var(--wc-product-filter-chips-selected-text)}.has-selected-chip-background-color .wc-block-product-filter-chips__item[aria-checked=true]{background:var(--wc-product-filter-chips-selected-background)}.has-selected-chip-border-color .wc-block-product-filter-chips__item[aria-checked=true]{border-color:var(--wc-product-filter-chips-selected-border)}:where(.wc-block-product-filter-chips__label){align-items:center;display:inline-flex;gap:4px}.wc-block-product-filter-chips__text{display:contents}.wc-block-product-filter-chips__count{display:contents;white-space:nowrap}.wc-block-product-filter-chips__show-more{appearance:none;background:transparent;border:none;font-family:inherit;padding:0;text-decoration:underline}
