@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-block-woocommerce-add-to-cart-with-options.block-editor-block-list__block:not(.remove-outline).is-highlighted:after,.wp-block-woocommerce-add-to-cart-with-options.block-editor-block-list__block:not(.remove-outline).is-hovered:not(.is-selected):after,.wp-block-woocommerce-add-to-cart-with-options.block-editor-block-list__block:not(.remove-outline).is-selected:after{outline-color:var(--wp-block-synced-color)}.wp-block-woocommerce-add-to-cart-with-options.block-editor-block-list__block:not(.remove-outline).block-editor-block-list__block:not([contenteditable]):focus:after{outline-color:var(--wp-block-synced-color)}.wp-block-woocommerce-add-to-cart-with-options__skeleton-wrapper{margin-bottom:16px;max-width:300px}.wp-block-woocommerce-add-to-cart-with-options__block-icon{color:#720eec}.block-editor-list-view-leaf.is-selected .block-editor-list-view-block-contents .wp-block-woocommerce-add-to-cart-with-options__block-icon{color:inherit}:where(.wc-block-add-to-cart-with-options__quantity-selector .components-disabled){display:contents}
