(()=>{"use strict";var e,t,o,r={1125:(e,t,o)=>{const r=window.wp.blocks;var i=o(7871),n=o(5410);const a=JSON.parse('{"$schema":"https://schemas.wp.org/trunk/block.json","apiVersion":3,"name":"woocommerce/add-to-cart-with-options-variation-description","title":"Variation Description (Beta)","description":"Displays the description of the selected variation.","category":"woocommerce","textdomain":"woocommerce","ancestor":["woocommerce/add-to-cart-with-options"],"supports":{"interactivity":true,"html":false,"dimensions":{"minHeight":true},"spacing":{"padding":true,"margin":true},"color":{"gradients":true,"link":true},"typography":{"fontSize":true,"lineHeight":true,"__experimentalFontFamily":true,"__experimentalFontWeight":true,"__experimentalFontStyle":true,"__experimentalTextTransform":true,"__experimentalTextDecoration":true,"__experimentalLetterSpacing":true},"__experimentalBorder":{"radius":true,"color":true,"width":true,"style":true}},"viewScriptModule":"woocommerce/product-elements"}'),c=window.wp.blockEditor;var s=o(7723),l=o(790);(0,r.registerBlockType)(a,{edit:function(){const e=(0,c.useBlockProps)();return(0,l.jsx)("div",{...e,children:(0,l.jsx)("p",{children:(0,s.__)("This block displays the variation description. When the shopper selects a variation, the description content will automatically appear here.","woocommerce")})})},icon:{src:(0,l.jsx)(i.A,{icon:n.A,className:"wc-block-editor-components-block-icon"})},save:()=>null})},790:e=>{e.exports=window.ReactJSXRuntime},6087:e=>{e.exports=window.wp.element},7723:e=>{e.exports=window.wp.i18n},5573:e=>{e.exports=window.wp.primitives}},i={};function n(e){var t=i[e];if(void 0!==t)return t.exports;var o=i[e]={exports:{}};return r[e](o,o.exports,n),o.exports}n.m=r,e=[],n.O=(t,o,r,i)=>{if(!o){var a=1/0;for(p=0;p<e.length;p++){for(var[o,r,i]=e[p],c=!0,s=0;s<o.length;s++)(!1&i||a>=i)&&Object.keys(n.O).every(e=>n.O[e](o[s]))?o.splice(s--,1):(c=!1,i<a&&(a=i));if(c){e.splice(p--,1);var l=r();void 0!==l&&(t=l)}}return t}i=i||0;for(var p=e.length;p>0&&e[p-1][2]>i;p--)e[p]=e[p-1];e[p]=[o,r,i]},n.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return n.d(t,{a:t}),t},o=Object.getPrototypeOf?e=>Object.getPrototypeOf(e):e=>e.__proto__,n.t=function(e,r){if(1&r&&(e=this(e)),8&r)return e;if("object"==typeof e&&e){if(4&r&&e.__esModule)return e;if(16&r&&"function"==typeof e.then)return e}var i=Object.create(null);n.r(i);var a={};t=t||[null,o({}),o([]),o(o)];for(var c=2&r&&e;"object"==typeof c&&!~t.indexOf(c);c=o(c))Object.getOwnPropertyNames(c).forEach(t=>a[t]=()=>e[t]);return a.default=()=>e,n.d(i,a),i},n.d=(e,t)=>{for(var o in t)n.o(t,o)&&!n.o(e,o)&&Object.defineProperty(e,o,{enumerable:!0,get:t[o]})},n.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),n.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),n.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.j=9730,(()=>{var e={9730:0};n.O.j=t=>0===e[t];var t=(t,o)=>{var r,i,[a,c,s]=o,l=0;if(a.some(t=>0!==e[t])){for(r in c)n.o(c,r)&&(n.m[r]=c[r]);if(s)var p=s(n)}for(t&&t(o);l<a.length;l++)i=a[l],n.o(e,i)&&e[i]&&e[i][0](),e[i]=0;return n.O(p)},o=globalThis.webpackChunkwebpackWcBlocksMainJsonp=globalThis.webpackChunkwebpackWcBlocksMainJsonp||[];o.forEach(t.bind(null,0)),o.push=t.bind(null,o.push.bind(o))})();var a=n.O(void 0,[94],()=>n(1125));a=n.O(a),((this.wc=this.wc||{}).blocks=this.wc.blocks||{})["add-to-cart-with-options-variation-description"]=a})();