:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-analytics-import-status-bar-wrapper{display:flex;flex-direction:column;gap:6px}.woocommerce-analytics-import-status-bar-wrapper__label{margin:7px 0 0;font-size:13px;line-height:20px;color:#1e1e1e;font-weight:400}@media screen and (max-width: 960px){.woocommerce-analytics-import-status-bar-wrapper{gap:5px}.woocommerce-analytics-import-status-bar-wrapper__label{line-height:18px;margin-top:5px}}.woocommerce-analytics-import-status-bar{display:flex;align-items:center;border:1px solid #ccc;border-radius:4px;padding:16px 12px;font-size:11px;line-height:20px;font-weight:400;height:50px}.woocommerce-analytics-import-status-bar__content{display:flex;align-items:center;gap:32px}@media screen and (max-width: 1280px){.woocommerce-analytics-import-status-bar__content{gap:24px}}@media screen and (max-width: 960px){.woocommerce-analytics-import-status-bar__content{gap:16px}}.woocommerce-analytics-import-status-bar__item{display:flex;flex-direction:column}.woocommerce-analytics-import-status-bar__label{color:#757575;white-space:nowrap}.woocommerce-analytics-import-status-bar__value{color:#1e1e1e}.woocommerce-analytics-import-status-bar__trigger{font-size:11px;font-weight:500;line-height:20px;width:88px}.woocommerce-analytics-import-status-bar .components-spinner{height:8px;width:8px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper){position:relative;display:flex;align-items:flex-start;gap:16px}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-filters{flex:1;width:100%}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-filters-filter{min-width:fit-content}@media screen and (max-width: 1280px){.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-filters-filter{width:100%}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-analytics-import-status-bar-wrapper{flex:1}}@media screen and (max-width: 782px){.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper){flex-direction:column;gap:0}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-filters__basic-filters{margin-bottom:16px}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-analytics-import-status-bar-wrapper{margin-bottom:24px;width:100%}.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper) .woocommerce-analytics-import-status-bar__content{width:100%;justify-content:space-between}}@media screen and (max-width: 600px){.woocommerce-analytics-report-header:has(>.woocommerce-analytics-import-status-bar-wrapper){align-items:center}}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-revenue-report-date-tour h2.woocommerce-tour-kit-step__heading{font-size:1.5em;line-height:1.5em;letter-spacing:.4px}
