@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-gallery-large-image__inner-blocks .wp-block-woocommerce-product-image{bottom:-5px;right:-5px;position:absolute;left:-5px;top:-5px}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-1),:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-auto){aspect-ratio:1/1}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-4-3){aspect-ratio:4/3}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-3-4){aspect-ratio:3/4}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-3-2){aspect-ratio:3/2}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-2-3){aspect-ratio:2/3}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-16-9){aspect-ratio:16/9}:where(.wc-block-product-gallery-large-image):has(.wc-block-components-product-image--aspect-ratio-9-16){aspect-ratio:9/16}
