@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list{border:1px solid color-mix(in srgb,currentColor 20%,transparent);border-radius:4px;display:grid;grid-template-columns:1fr max-content;padding:0}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dd,.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dt{border-bottom:1px solid color-mix(in srgb,currentColor 20%,transparent)}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dd:last-of-type,.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dt:last-of-type{border-bottom:0}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dt{box-sizing:border-box;font-style:normal;font-weight:700;margin:0;padding:16px}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dt:after{display:none}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dd{box-sizing:border-box;margin:0;padding:16px;text-align:left}@media screen and (max-width:768px){.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list{display:block}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dt{border-bottom:0;padding-bottom:0}.wc-block-order-confirmation-additional-fields .wc-block-components-additional-fields-list dd{border-bottom:1px solid color-mix(in srgb,currentColor 20%,transparent);padding-top:0;text-align:right}}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-additional-fields-list{margin:0;padding:0}.wc-block-components-additional-fields-list dt{display:inline;font-style:normal;font-weight:700;margin:0;padding:0}.wc-block-components-additional-fields-list dt:after{content:": "}.wc-block-components-additional-fields-list dt:before{content:"";display:block}.wc-block-components-additional-fields-list dd{display:inline;font-style:normal;margin:0;padding:0}
