
  .modal {
    /* background-color: #F4F7F7; */
    width: 100%;
    padding: 20px;
    border-radius: 12px;
    display: flex;
    flex-direction: column;
    gap: 30px;
    box-shadow: 0 4px 10px rgba(0, 0, 0, 0.15);
    z-index: 99999;
  }

  .close {
    display: flex;
    justify-content: flex-end;
/*    background-color: #252B42 !important;*/
   
  }
  
  .logo {
    height: 30px;
  }
  
  .modal .options{
    display: flex;
    flex-direction: column;
    gap: 10px;
  }
  
  .modal .more {
    color: var(--text-color, #252B42);
    font-family: Montserrat;
    font-size: 32px;
    font-style: normal;
    font-weight: 700;
    line-height: 48px; 
    letter-spacing: 0.2px;
  }
  
  .modal .options .table{
    border-radius: 12px;
    border: 1px solid var(--Gray-200, #EAECF0);
    background: var(--Neutrals-White, #FFF);
  }

  .modal .options .table .details{
    border-bottom: 1px solid var(--Gray-200, #EAECF0);
    display: flex;
    justify-content: space-between;
  }

  .modal .options .table .details span{
    padding: 16px 24px;
    color: var(--Gray-700, #344054);
    font-family: Inter;
    font-size: 14px;
    font-style: normal;
    font-weight: 600;
    line-height: 24px;
    letter-spacing: 0.16px;
  }
  
  .modal .options .table .details .right{
    width: 40%;
  }

  .modal .options .table .details:last-child {
    border-bottom: none;
  }
    
  .modal .options .more-options {
    color: var(--second-text-color, #737373);
    font-family: Montserrat;
    font-size: 14px;
    font-style: normal;
    font-weight: 700;
    line-height: 24px; 
    letter-spacing: 0.2px;
      cursor: pointer;

  }
  
  .how-it-works{
    display: flex;
    flex-direction: column;
    gap: 30px;
  }

  .how-it-works .how {
    color: var(--text-color, #252B42);
    font-family: Montserrat;
    font-size: 24px;
    font-style: normal;
    font-weight: 700;
    line-height: 32px; 
    letter-spacing: 0.1px;
  }
  
  .how-it-works .arrows{
    display: flex;
    flex-direction: column;
    gap: 6px;
  }

  .how-it-works .arrows .sentence {
    color: var(--second-text-color, #737373);
    font-family: Montserrat;
    font-size: 14px;
    font-style: normal;
    font-weight: 700;
    line-height: 24px;
    letter-spacing: 0.2px;
    display: flex;
    flex-direction: row;
    gap: 20px;
  }
  
  .how-it-works .arrows .arrow{
    width: 9px;
    height: 16px;
    padding-right: 15px;
    color: var(--second-text-color, #737373);
  }
  
  .buttons {
    display: flex;
    justify-content: space-around;
    margin-top: 20px;
  }
  
  .continue-shopping,
  .buy-now {
    border: none;
    cursor: pointer;
    display: flex;
    width: 352px;
    padding: 21px;
    justify-content: center;
    align-items: center;
  }
  
  .continue-shopping {
    border-radius: 5px;
    background: var(--primary-color, #23A6F0);
    color: var(--light-text-color, #FFF);
    text-align: center;
    font-family: Montserrat;
    font-size: 18px;
    font-style: normal;
    font-weight: 700;
    line-height: 18px;
    letter-spacing: 0.2px;
  }
  
  .buy-now {
    border-radius: 5px;
    background: #00B3AA;
    color: var(--light-text-color, #FFF);
    text-align: center;
    font-family: Montserrat;
    font-size: 18px;
    font-style: normal;
    font-weight: 700;
    line-height: 18px;
    letter-spacing: 0.2px;
  }

/* Responsive Design */
@media (max-width: 336px) {
  .modal {
    width: 90%;
    padding: 16px;
    gap: 24px;
  }

  .modal .more {
    font-size: 20px;
    line-height: 32px;
  }

  .modal .options .more-options {
    font-size: 14px;
      cursor: pointer;

  }

  .modal .options .table .details {
    display: flex;
    flex-direction: column;
    padding: 16px 0px;
  }

  .modal .options .table .details span {
    font-size: 14px;
    padding: 0px 24px;
  }

  .modal .options .table .details .right {
    width: 100%;
  }

  .modal .options .more-options {
    font-size: 14px;
      cursor: pointer;

  }

  .how-it-works {
    gap: 16px;
  }

  .how-it-works .how {
    font-size: 20px;
    line-height: 28px;
  }

  .how-it-works .arrows {
    gap: 12px;
  }

  .how-it-works .arrows .sentence {
    font-size: 14px;
    line-height: 24px;
  }

  .buttons {
    flex-direction: column;
    gap: 20px;
    margin-top: 0px;
  }

  .continue-shopping,
  .buy-now {
    width: 100%;
    font-size: 18px;
  }
}

.container {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 20px;
  border-radius: 10px;
  border: 1px solid var(--primary-color, #23A6F0);
  background: var(--light-background-color, #FFF);
  margin-top: 20px;
}

.info {
  text-align: left;
  display: flex;
  width: 45%;
  flex-direction: column;
  gap: 12px;
}

.paragraph{
  color: #252B42;
  font-family: Montserrat;
  font-size: 16px;
  font-style: normal;
  font-weight: 600;
  line-height: 24px;
  letter-spacing: 0.2px;
}

.details {
  color: #252B42;
  font-family: Montserrat;
  font-size: 16px;
  font-style: normal;
  font-weight: 700;
  line-height: 24px; 
  letter-spacing: 0.2px;
}

.bullet {
  margin-left: 5px;
  margin-right: 5px;
  width: 8px;
  height: 8px;
  flex-shrink: 0;
} 

.learn-more {
  color: #23A6F0;
  font-family: Montserrat;
  font-size: 16px;
  font-style: normal;
  font-weight: 900;
  line-height: 20px; 
  letter-spacing: 0.2px;
  text-decoration: none;
}
 
.logo{
  width: 105px;
  height: 36px;
  flex-shrink: 0;
}

@media (max-width: 336px) {
  .container {
    padding: 16px 12px 16px 16px;
  }

  .paragraph {
    font-size: 14px;
    /* width: 195px; */
  }

  .details {
    font-size: 12px;
    /* width: 200px; */
  }

  .learn-more {
    font-size: 16px;
  }

  .logo {
    width: 78px;
    height: 26px;
  }
}

.modal-content {
	background-color: #F4F7F7;
	margin: 5% auto;
	padding: 20px;
	border: 1px solid #f4f5f7;
	width: 80%;
}