@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-order-confirmation-downloads{border:0!important;margin-bottom:48px;margin-top:24px}.wc-block-order-confirmation-downloads table{border:1px solid color-mix(in srgb,currentColor 20%,transparent);border-radius:4px;border-spacing:0;width:100%}.wc-block-order-confirmation-downloads table td,.wc-block-order-confirmation-downloads table th{border:solid color-mix(in srgb,currentColor 20%,transparent);border-width:0 0 1px;font-weight:inherit;margin:0;padding:16px;text-align:center}.wc-block-order-confirmation-downloads table tr>td:first-child,.wc-block-order-confirmation-downloads table tr>th:first-child{text-align:left}.wc-block-order-confirmation-downloads table tr>td:last-child,.wc-block-order-confirmation-downloads table tr>th:last-child{text-align:right}.wc-block-order-confirmation-downloads table thead{font-weight:700}.wc-block-order-confirmation-downloads table tbody tr:last-child td,.wc-block-order-confirmation-downloads table tbody tr:last-child th{border-bottom-width:0}.wc-block-order-confirmation-downloads table[style*=border-color] td,.wc-block-order-confirmation-downloads table[style*=border-color] th,.wc-block-order-confirmation-downloads table[style*=border-color] tr,.wc-block-order-confirmation-downloads table[style*=border-color]>*,.wc-block-order-confirmation-downloads table[style*=border-width] td,.wc-block-order-confirmation-downloads table[style*=border-width] th,.wc-block-order-confirmation-downloads table[style*=border-width] tr,.wc-block-order-confirmation-downloads table[style*=border-width]>*{border:inherit;border-left-width:0;border-right-width:0;border-top-width:0}
