<?php
declare(strict_types=1);
namespace Automattic\WooCommerce\Internal\Agentic\Enums\Specs;

/**
 * Payment methods as defined in the Agentic Commerce Protocol.
 */
class PaymentMethod {
	/**
	 * Card payment method.
	 */
	const CARD = 'card';
}
