.woocommerce-address-suggestions{position:absolute;z-index:1000;width:100%;max-width:100%;margin-top:4px;background:#fff;border:1px solid #ddd;border-radius:4px;box-shadow:0 2px 4px rgba(0,0,0,.1);box-sizing:border-box;display:none}.woocommerce-address-suggestions .suggestions-list{list-style:none;margin:0;padding:0;max-height:200px;overflow-y:auto}.woocommerce-address-suggestions .suggestions-list li{padding:8px 12px;font-size:14px;cursor:pointer;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;color:var(--wc-form-color-text,#444)}.woocommerce-address-suggestions .suggestions-list li:last-child{border-bottom:none}.woocommerce-address-suggestions .suggestions-list li.active,.woocommerce-address-suggestions .suggestions-list li:hover{background-color:var(--wp-admin-theme-color,#0073aa);color:#fff}.woocommerce-address-suggestions .suggestions-list li:focus{outline:0;background-color:var(--wp-admin-theme-color,#0073aa);color:#fff}.woocommerce-address-suggestions .woocommerce-address-autocomplete-branding{background:#d3d3d3;padding:8px 12px;color:rgba(34,34,34,.66);font-size:12px;display:flex;align-items:center}.woocommerce-input-wrapper:has(#billing_address_1,#shipping_address_1){position:relative;display:block}.woocommerce-input-wrapper:has(#billing_address_1,#shipping_address_1) .address-search-icon{display:none}.woocommerce-input-wrapper:has(#billing_address_1,#shipping_address_1).autocomplete-available input#billing_address_1,.woocommerce-input-wrapper:has(#billing_address_1,#shipping_address_1).autocomplete-available input#shipping_address_1{padding-left:calc(1.1rem + 16px)}.woocommerce-input-wrapper:has(#billing_address_1,#shipping_address_1).autocomplete-available .address-search-icon{display:block;position:absolute;inset-inline-end:16px;top:50%;transform:translateY(-50%);pointer-events:none;width:16px;height:16px;line-height:16px;z-index:1;background-color:var(--wc-form-color-text,#444);mask:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAxNCAxNCIgZm9jdXNhYmxlPSJmYWxzZSIgYXJpYS1oaWRkZW49InRydWUiPgogIDxjaXJjbGUgY3g9IjYiIGN5PSI2IiByPSI0IiBmaWxsPSJub25lIiBzdHJva2U9ImJsYWNrIiBzdHJva2Utd2lkdGg9IjEuNSI+PC9jaXJjbGU+CiAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2U9ImJsYWNrIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0ibTkuMjUgOS4yNSAyLjUgMi41Ij48L3BhdGg+Cjwvc3ZnPg==) no-repeat center;mask-size:contain;-webkit-mask:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAxNCAxNCIgZm9jdXNhYmxlPSJmYWxzZSIgYXJpYS1oaWRkZW49InRydWUiPgogIDxjaXJjbGUgY3g9IjYiIGN5PSI2IiByPSI0IiBmaWxsPSJub25lIiBzdHJva2U9ImJsYWNrIiBzdHJva2Utd2lkdGg9IjEuNSI+PC9jaXJjbGU+CiAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2U9ImJsYWNrIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0ibTkuMjUgOS4yNSAyLjUgMi41Ij48L3BhdGg+Cjwvc3ZnPg==) no-repeat center;-webkit-mask-size:contain}