@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-order-confirmation-status-description .woocommerce-verify-email{margin-top:36px}.wc-block-order-confirmation-status-description .woocommerce-verify-email #verify-email{width:50%}@media(max-width:782px){.wc-block-order-confirmation-status-description .woocommerce-verify-email #verify-email{width:100%}}.wc-block-order-confirmation-status{margin-bottom:16px;margin-top:16px}.wc-block-order-confirmation-status p{margin-bottom:0;margin-top:0}.wc-block-order-confirmation-status.has-background{padding:16px}.wc-block-order-confirmation-status .wc-block-order-confirmation-status__actions{margin-top:16px}.wc-block-order-confirmation-status .wc-block-order-confirmation-status__actions a{margin-left:16px}.wc-block-order-confirmation-status .wc-block-order-confirmation-status__actions a.has-link-color{color:inherit}
