@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-product-filter-removable-chips.is-vertical .wc-block-product-filter-removable-chips__items{flex-direction:column}.wc-block-product-filter-removable-chips.is-content-justification-center .wc-block-product-filter-removable-chips__items{justify-content:center}.wc-block-product-filter-removable-chips.is-content-justification-right .wc-block-product-filter-removable-chips__items{justify-content:flex-end}.wc-block-product-filter-removable-chips.is-content-justification-space-between .wc-block-product-filter-removable-chips__items{justify-content:space-between}.wc-block-product-filter-removable-chips.is-horizontal .wc-block-product-filter-removable-chips__items{width:100%}.wc-block-product-filter-removable-chips__items{color:var(--wc-product-filter-removable-chips-text,currentColor);display:inline-flex;flex-wrap:wrap;gap:4px;list-style:none;margin:0;padding:0}.wc-block-product-filter-removable-chips__items .wc-block-product-filter-removable-chips__item{align-items:center;appearance:none;background:var(--wc-product-filter-removable-chips-background,transparent);border:1px solid var(--wc-product-filter-removable-chips-border,color-mix(in srgb,currentColor 20%,transparent));border-radius:2px;display:flex;font-size:.875em;gap:8px;justify-content:space-between;padding:.25em .75em}.wc-block-product-filter-removable-chips__items .wc-block-product-filter-removable-chips__item .wc-block-product-filter-removable-chips__remove{align-items:center;background-color:transparent;border:none;color:var(--wc-product-filter-removable-chips-text,currentColor);cursor:pointer;display:flex;margin:0;padding:0}.wc-block-product-filter-removable-chips__items .wc-block-product-filter-removable-chips__item .wc-block-product-filter-removable-chips__remove .wc-block-product-filter-removable-chips__remove-icon{fill:currentColor}
