(()=>{"use strict";var e,t,o,r={2185:(e,t,o)=>{const r=window.wp.blocks;var n=o(247);const c=JSON.parse('{"$schema":"https://schemas.wp.org/trunk/block.json","apiVersion":3,"name":"woocommerce/product-collection-no-results","title":"No results","category":"woocommerce","description":"The contents of this block will display when there are no products found.","textdomain":"woocommerce","keywords":["Product Collection"],"usesContext":["queryId","query"],"ancestor":["woocommerce/product-collection"],"supports":{"interactivity":{"clientNavigation":true},"align":true,"reusable":false,"html":false,"color":{"gradients":true,"link":true},"typography":{"fontSize":true,"lineHeight":true,"__experimentalFontFamily":true,"__experimentalFontWeight":true,"__experimentalFontStyle":true,"__experimentalTextTransform":true,"__experimentalTextDecoration":true,"__experimentalLetterSpacing":true,"__experimentalDefaultControls":{"fontSize":true}},"email":true}}'),i=window.wp.blockEditor;var l=o(7723),a=o(790);const s=[["core/group",{layout:{type:"flex",orientation:"vertical",justifyContent:"center",flexWrap:"wrap"}},[["core/paragraph",{textAlign:"center",fontSize:"medium",content:`<strong>${(0,l.__)("No results found","woocommerce")}</strong>`}],["core/paragraph",{content:`${(0,l.__)("You can try","woocommerce")} <a href="#" class="wc-link-clear-any-filters">${(0,l.__)("clearing any filters","woocommerce")}</a> ${(0,l.__)("or head to our","woocommerce")} <a href="#" class="wc-link-stores-home">${(0,l.__)("store's home","woocommerce")}</a>`}]]]];(0,r.registerBlockType)(c,{icon:n.A,edit:()=>{const e=(0,i.useBlockProps)({className:"wc-block-product-collection-no-results"});return(0,a.jsx)("div",{...e,children:(0,a.jsx)(i.InnerBlocks,{template:s})})},save:function(){return(0,a.jsx)(i.InnerBlocks.Content,{})}})},790:e=>{e.exports=window.ReactJSXRuntime},7723:e=>{e.exports=window.wp.i18n},5573:e=>{e.exports=window.wp.primitives}},n={};function c(e){var t=n[e];if(void 0!==t)return t.exports;var o=n[e]={exports:{}};return r[e](o,o.exports,c),o.exports}c.m=r,e=[],c.O=(t,o,r,n)=>{if(!o){var i=1/0;for(u=0;u<e.length;u++){for(var[o,r,n]=e[u],l=!0,a=0;a<o.length;a++)(!1&n||i>=n)&&Object.keys(c.O).every(e=>c.O[e](o[a]))?o.splice(a--,1):(l=!1,n<i&&(i=n));if(l){e.splice(u--,1);var s=r();void 0!==s&&(t=s)}}return t}n=n||0;for(var u=e.length;u>0&&e[u-1][2]>n;u--)e[u]=e[u-1];e[u]=[o,r,n]},c.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return c.d(t,{a:t}),t},o=Object.getPrototypeOf?e=>Object.getPrototypeOf(e):e=>e.__proto__,c.t=function(e,r){if(1&r&&(e=this(e)),8&r)return e;if("object"==typeof e&&e){if(4&r&&e.__esModule)return e;if(16&r&&"function"==typeof e.then)return e}var n=Object.create(null);c.r(n);var i={};t=t||[null,o({}),o([]),o(o)];for(var l=2&r&&e;"object"==typeof l&&!~t.indexOf(l);l=o(l))Object.getOwnPropertyNames(l).forEach(t=>i[t]=()=>e[t]);return i.default=()=>e,c.d(n,i),n},c.d=(e,t)=>{for(var o in t)c.o(t,o)&&!c.o(e,o)&&Object.defineProperty(e,o,{enumerable:!0,get:t[o]})},c.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),c.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),c.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},c.j=5838,(()=>{var e={5838:0};c.O.j=t=>0===e[t];var t=(t,o)=>{var r,n,[i,l,a]=o,s=0;if(i.some(t=>0!==e[t])){for(r in l)c.o(l,r)&&(c.m[r]=l[r]);if(a)var u=a(c)}for(t&&t(o);s<i.length;s++)n=i[s],c.o(e,n)&&e[n]&&e[n][0](),e[n]=0;return c.O(u)},o=globalThis.webpackChunkwebpackWcBlocksMainJsonp=globalThis.webpackChunkwebpackWcBlocksMainJsonp||[];o.forEach(t.bind(null,0)),o.push=t.bind(null,o.push.bind(o))})();var i=c.O(void 0,[94],()=>c(2185));i=c.O(i),((this.wc=this.wc||{}).blocks=this.wc.blocks||{})["product-collection-no-results"]=i})();