:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.wp-block-woocommerce-product-linked-list-field{display:flex;flex-direction:column;gap:24px}.wp-block-woocommerce-product-linked-list-field .woocommerce-advice-card{min-height:233px}.wp-block-woocommerce-product-linked-list-field .woocommerce-advice-card__footer{padding:0 96px 16px}
