:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}html{font-family:"SF Pro Text",-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif}body.woocommerce-settings-payments-tab #mainform,body.woocommerce-settings-payments-tab #wpcontent{background-color:#fff}.settings-payments-offline__container{margin:0 -30px}.settings-payments-offline__container .settings-layout{margin:0 48px 0}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.settings-layout{margin:48px 12px 0;display:flex;flex-flow:row}@media(max-width: 960px){.settings-layout{flex-flow:column}}.settings-layout .form__actions{display:flex;flex-direction:row-reverse}.settings-layout .settings-card__wrapper{box-shadow:none}.settings-form{width:80%}.settings-section{display:flex;align-items:flex-start;flex-flow:row}.settings-section:not(.settings-section:last-child){margin-bottom:24px}@media(max-width: 782px){.settings-section{flex-flow:column}}.settings-section__details{flex:0 0 33%;margin:0 24px 0 0}@media(max-width: 782px){.settings-section__details{margin:0 0 40px 0;max-width:328px}}.settings-section__details h2{font-size:16px;line-height:24px}.settings-section__details p{font-size:13px;line-height:20px;margin:12px 0}.settings-section__details>:last-child{margin-bottom:0}.settings-section__icons>li{display:inline-block;margin:0 5px 0 0}.settings-section__icons svg{border-radius:2px;box-shadow:0 0 0 1px #ddd;height:auto;width:38px}.settings-section__controls{margin-top:6px;flex:1 1 auto}.settings-section .form-field:not(:first-child){margin-top:24px}.components-base-control{margin-bottom:32px}.components-base-control+.components-base-control__help{margin-top:0;margin-bottom:0}.components-base-control__help{margin-bottom:32px}.woocommerce-tree-select-control__control{margin-bottom:0}.woocommerce-tree-select-control__label{font-size:11px;font-weight:500;line-height:1.4;color:#757575;text-transform:uppercase;display:block;margin-bottom:8px;padding:0}.woocommerce-tree-select-control__help{margin-top:8px;margin-bottom:32px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-field-placeholder{margin-bottom:32px}.woocommerce-field-placeholder .components-placeholder{background-color:#f0f0f0;border:none;border-radius:4px;display:flex;align-items:center;padding:0 12px;box-shadow:none}.woocommerce-field-placeholder .components-placeholder .components-placeholder__label,.woocommerce-field-placeholder .components-placeholder .components-placeholder__instructions{display:none}.woocommerce-field-placeholder--small .components-placeholder{min-height:32px}.woocommerce-field-placeholder--medium .components-placeholder{min-height:96px}.woocommerce-field-placeholder--large .components-placeholder{min-height:160px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.bank-account-modal{width:512px;max-width:512px;max-height:90%;display:flex;flex-direction:column}.bank-account-modal .components-modal__content{padding:0;overflow-y:auto}.bank-account-modal__content{padding:8px 32px 0 32px;overflow-y:auto}.bank-account-modal__description{margin-top:0;margin-bottom:24px}.bank-account-modal__field{margin-bottom:24px}.bank-account-modal__field.is-required label::after{content:" *"}.bank-account-modal__error{color:#c00}.bank-account-modal__actions{display:flex;justify-content:flex-end;margin-top:auto;padding:16px 24px;background-color:#fff;position:sticky;bottom:0;z-index:10;border-top:1px solid #e0e0e0}.bank-account-modal__actions>.bank-account-modal__save{margin-left:8px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.bank-accounts__list{list-style:none;margin:0;padding:0;border:1px solid #dcdcde;border-radius:4px;overflow:hidden}.bank-accounts__add-button{display:flex;justify-content:flex-end;padding:12px 16px;border-top:1px solid #e0e0e0}.bank-accounts__list-header{display:flex;align-items:center;padding:12px 16px;background-color:#f8f9fa;border-bottom:1px solid #dcdcde;font-weight:600;font-size:11px;color:#1e1e1e;text-transform:uppercase;border-top:none}.bank-accounts__list-header>.bank-accounts__list-item-inner{display:flex;width:100%;align-items:center}.bank-accounts__list-header>.bank-accounts__list-item-inner>.bank-accounts__list-item-before{width:24px;height:20px;display:flex;justify-content:center;align-items:center;margin-right:16px}.bank-accounts__list-header>.bank-accounts__list-item-inner>.bank-accounts__list-item-text{display:grid;grid-template-columns:1fr 1fr 1fr;flex-grow:1;column-gap:24px}.bank-accounts__list-header>.bank-accounts__list-item-inner>.bank-accounts__list-item-after{width:32px;margin-left:16px}.bank-accounts__list-item{display:flex;align-items:center;padding:12px 16px;border-top:1px solid #e0e0e0}.bank-accounts__list-item.first-item{border-top:none}.bank-accounts__list-item:not(.action):hover{background-color:#f8f9fa}.bank-accounts__list-item.action{display:flex;justify-content:flex-end;padding:12px 16px}.bank-accounts__list-item>.bank-accounts__list-item-inner{display:flex;width:100%;align-items:center}.bank-accounts__list-item>.bank-accounts__list-item-inner>.bank-accounts__list-item-before{width:24px;display:flex;justify-content:center;align-items:center;margin-right:16px}.bank-accounts__list-item>.bank-accounts__list-item-inner>.bank-accounts__list-item-text{display:grid;grid-template-columns:1fr 1fr 1fr;flex-grow:1;column-gap:24px}.bank-accounts__list-item>.bank-accounts__list-item-inner>.bank-accounts__list-item-text div{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.bank-accounts__list-item>.bank-accounts__list-item-inner>.bank-accounts__list-item-after{display:flex;justify-content:flex-end;align-items:center;margin-left:16px}
