@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.woocommerce.wc-block-breadcrumbs{font-size:inherit}.woocommerce.woocommerce-shop .wc-block-breadcrumbs .woocommerce-breadcrumb{display:block;margin:auto}
