<?php return array(
    'root' => array(
        'name' => 'stock-management-labs/atum-stock-manager-for-woocommerce',
        'pretty_version' => 'dev-develop',
        'version' => 'dev-develop',
        'reference' => '88a8fa29516bb5d6e88b4b8a440793e55b93d894',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'jimmiw/php-time-ago' => array(
            'pretty_version' => '3.2.4',
            'version' => '3.2.4.0',
            'reference' => 'd5b37a93aee579962117310644965d0f7bf1302d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jimmiw/php-time-ago',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'madcoda/php-youtube-api' => array(
            'pretty_version' => 'v1.2.6',
            'version' => '1.2.6.0',
            'reference' => '70debe2a140339e145a57d64cd4e9e12f393332f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../madcoda/php-youtube-api',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mpdf/mpdf' => array(
            'pretty_version' => 'v8.2.0',
            'version' => '8.2.0.0',
            'reference' => '170a236a588d177c2aa7447ce490a030ca68e6f4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mpdf/mpdf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mpdf/psr-http-message-shim' => array(
            'pretty_version' => 'v2.0.1',
            'version' => '2.0.1.0',
            'reference' => 'f25a0153d645e234f9db42e5433b16d9b113920f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mpdf/psr-http-message-shim',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mpdf/psr-log-aware-trait' => array(
            'pretty_version' => 'v2.0.0',
            'version' => '2.0.0.0',
            'reference' => '7a077416e8f39eb626dee4246e0af99dd9ace275',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mpdf/psr-log-aware-trait',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'myclabs/deep-copy' => array(
            'pretty_version' => '1.11.1',
            'version' => '1.11.1.0',
            'reference' => '7284c22080590fb39f2ffa3e9057f10a4ddd0e0c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../myclabs/deep-copy',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/random_compat' => array(
            'pretty_version' => 'v9.99.100',
            'version' => '9.99.100.0',
            'reference' => '996434e5492cb4c3edcb9168db6fbb1359ef965a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/random_compat',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message' => array(
            'pretty_version' => '2.0',
            'version' => '2.0.0.0',
            'reference' => '402d35bcb92c70c026d1a6a9883f06b2ead23d71',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'setasign/fpdi' => array(
            'pretty_version' => 'v2.5.0',
            'version' => '2.5.0.0',
            'reference' => 'ecf0459643ec963febfb9a5d529dcd93656006a4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../setasign/fpdi',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'stock-management-labs/atum-stock-manager-for-woocommerce' => array(
            'pretty_version' => 'dev-develop',
            'version' => 'dev-develop',
            'reference' => '88a8fa29516bb5d6e88b4b8a440793e55b93d894',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
