@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-order-confirmation-address-wrapper,.woocommerce-order-confirmation-address-wrapper{margin-block-start:48px}.wc-block-order-confirmation-address-wrapper .wp-block-column:empty,.wc-block-order-confirmation-address-wrapper .wp-block-column:not(:has(*)),.woocommerce-order-confirmation-address-wrapper .wp-block-column:empty,.woocommerce-order-confirmation-address-wrapper .wp-block-column:not(:has(*)){display:none}.wp-block-woocommerce-order-confirmation-billing-wrapper>:first-child{margin-top:0}.wp-block-woocommerce-order-confirmation-billing-wrapper .block-editor-block-list__layout>:first-child{margin-top:0!important}.wc-block-order-confirmation-billing-wrapper .wp-block-heading{margin-top:0}.wc-block-order-confirmation-billing-address{border:1px solid color-mix(in srgb,currentColor 20%,transparent);border-radius:4px;padding:16px}.wc-block-order-confirmation-billing-address address,.wc-block-order-confirmation-billing-address p{box-sizing:border-box;display:block;font-style:normal;margin:0;width:100%!important}.wc-block-order-confirmation-billing-address p:not(.woocommerce-customer-details--phone){margin:8px 0 0}.wc-block-order-confirmation-billing-address p:not(.woocommerce-customer-details--phone) strong{display:block;font-weight:700}.wc-block-order-confirmation-billing-address p:not(.woocommerce-customer-details--phone) strong:after{content:":"}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-additional-fields-list{margin:0;padding:0}.wc-block-components-additional-fields-list dt{display:inline;font-style:normal;font-weight:700;margin:0;padding:0}.wc-block-components-additional-fields-list dt:after{content:": "}.wc-block-components-additional-fields-list dt:before{content:"";display:block}.wc-block-components-additional-fields-list dd{display:inline;font-style:normal;margin:0;padding:0}
