<?php

declare(strict_types=1);

namespace Automattic\WooCommerce\Internal\Api\Schema;

/**
 * Stable subclass of the webonyx InputObjectType used by autogenerated
 * input types.
 *
 * The constructor accepts the same associative-array config webonyx
 * documents (keys: `name`, `description`, `fields`).
 *
 * @internal Reserved for autogenerated resolver code.
 */
class InputObjectType extends \Automattic\WooCommerce\Vendor\GraphQL\Type\Definition\InputObjectType {
}
