:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-email-sidebar-template-settings-sender-options h2{margin-top:0}.woocommerce-email-sidebar-template-settings-sender-options p{color:#757575}.woocommerce-email-sidebar-template-settings-sender-options-input{margin-bottom:10px;width:100%}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-email-editor__settings-panel .woocommerce-settings-panel-preheader-text .components-base-control__help{text-align:left}.woocommerce-email-editor__settings-panel .woocommerce-settings-panel-preheader-text .components-base-control__help{text-align:left}.woocommerce-email-editor__settings-panel .woocommerce-settings-panel__preview-text-length{color:#000;display:inline-block;font-weight:500;padding:3px}.woocommerce-email-editor__settings-panel .woocommerce-settings-panel__preview-text-length-warning{color:#f0b849}.woocommerce-email-editor__settings-panel .woocommerce-settings-panel__preview-text-length-error{color:#cc1818}.woocommerce-email-editor__settings-panel .woocommerce-email-editor-recipients-help{color:#757575;font-size:12px;font-style:normal;margin-bottom:0;margin-top:8px}.editor-post-excerpt__dropdown button{display:none}
