@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}:where(.wc-block-next-previous-buttons)[hidden]{display:none!important}:where(.wc-block-next-previous-buttons__icon){color:inherit}:where(.wc-block-next-previous-buttons__icon--left){padding:2px 2px 0 0}:where(.wc-block-next-previous-buttons__icon--right){padding:2px 0 0 2px}:where(.rtl) :where(.wc-block-next-previous-buttons__icon--left){padding:2px 0 0 2px}:where(.rtl) :where(.wc-block-next-previous-buttons__icon--right){padding:2px 2px 0 0}:where(.wc-block-next-previous-buttons__button){background:#fff;border:none;cursor:pointer;font-size:12px;height:40px;outline-offset:-2px;padding:0;pointer-events:all;width:40px;z-index:22}:where(.wc-block-next-previous-buttons__button[aria-disabled=true]){cursor:not-allowed}:where(.wc-block-next-previous-buttons__button[aria-disabled=true]) :where(.wc-block-next-previous-buttons__icon){opacity:30%}
