:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-dashboard__store-performance{margin-bottom:24px}@media(max-width: 782px){.woocommerce-dashboard__store-performance{border-width:0}}.woocommerce-dashboard__store-performance .woocommerce-summary__item{background-color:#fff}.woocommerce-dashboard__store-performance .woocommerce-summary__item:hover{background-color:#f0f0f0}.woocommerce-dashboard__store-performance .woocommerce-summary{background-color:#f0f0f0;margin:0}@media(max-width: 782px){.woocommerce-dashboard__store-performance .woocommerce-summary.is-placeholder{border-top:0}.woocommerce-dashboard__store-performance .woocommerce-summary:not(.is-placeholder) .woocommerce-summary__item-container:first-child .woocommerce-summary__item{border-top:1px solid #ccc}}
