:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.components-modal__screen-overlay .woocommerce-create-new-taxonomy-modal{min-width:650px;overflow:visible}.components-modal__screen-overlay .woocommerce-create-new-taxonomy-modal__buttons{margin-top:36px;display:flex;flex-direction:row;gap:8px;justify-content:flex-end}.components-modal__screen-overlay .woocommerce-create-new-taxonomy-modal__optional{color:#757575}.components-modal__screen-overlay .woocommerce-create-new-taxonomy-modal .components-modal__content{overflow:visible}.components-modal__screen-overlay .components-base-control{margin-bottom:16px}.components-modal__screen-overlay .components-base-control__field .components-base-control{margin-bottom:0}.components-modal__screen-overlay .has-error .components-text-control__input{border-color:#d63638}.components-modal__screen-overlay .has-error .components-base-control__help{color:#d63638}
