<?php
declare(strict_types=1);

// THIS FILE IS AUTO-GENERATED. DO NOT EDIT MANUALLY.

namespace Automattic\WooCommerce\Internal\Api\Autogenerated\GraphQLTypes\Enums;

use Automattic\WooCommerce\Api\Enums\Products\StockStatus as StockStatusEnum;
use Automattic\WooCommerce\Internal\Api\Schema\EnumType;

class StockStatus {
	private static ?EnumType $instance = null;

	public static function get(): EnumType {
		if ( null === self::$instance ) {
			self::$instance = new EnumType(
				array(
					'name'        => 'StockStatus',
					'description' => __( 'The stock status of a product.', 'woocommerce' ),
					'values'      => array(
						'IN_STOCK'     => array(
							'value'       => StockStatusEnum::InStock,
							'description' => __( 'The product is in stock.', 'woocommerce' ),
						),
						'OUT_OF_STOCK' => array(
							'value'       => StockStatusEnum::OutOfStock,
							'description' => __( 'The product is out of stock.', 'woocommerce' ),
						),
						'ON_BACKORDER' => array(
							'value'       => StockStatusEnum::OnBackorder,
							'description' => __( 'The product is on backorder.', 'woocommerce' ),
						),
						'OTHER'        => array(
							'value'       => StockStatusEnum::Other,
							'description' => __( 'The stock status is not one of the standard WooCommerce values (e.g. added by a plugin). Inspect raw_stock_status for the underlying value.', 'woocommerce' ),
						),
					),
				)
			);
		}
		return self::$instance;
	}
}
