"use strict";(globalThis.webpackChunkwebpackWcBlocksStylingJsonp=globalThis.webpackChunkwebpackWcBlocksStylingJsonp||[]).push([[9762],{3152:(c,s,e)=>{e.r(s),e.d(s,{default:()=>a});var t=e(14656),l=e(74058),n=e(10790);const a=({children:c,className:s})=>{const{cartItems:e}=(0,l.V)();return 0===e.length?null:(0,n.jsxs)("div",{className:s,children:[(0,n.jsx)(t.StoreNoticesContainer,{context:"wc/cart"}),c]})}}}]);