<?php return array(
    'root' => array(
        'name' => 'woocommerce/woocommerce',
        'pretty_version' => '10.8.1',
        'version' => '10.8.1.0',
        'reference' => null,
        'type' => 'wordpress-plugin',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'automattic/block-delimiter' => array(
            'pretty_version' => 'v0.3.4',
            'version' => '0.3.4.0',
            'reference' => 'f36d786abdd4e10cfec8b261796dac9cdd192457',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/block-delimiter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-a8c-mc-stats' => array(
            'pretty_version' => 'v3.0.5',
            'version' => '3.0.5.0',
            'reference' => '60401a41c714d93f7a31e36493260ad6683ca4be',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-a8c-mc-stats',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-admin-ui' => array(
            'pretty_version' => 'v0.5.11',
            'version' => '0.5.11.0',
            'reference' => '51268f256c821ebcdaaa769f3249d34e0106cfb2',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-admin-ui',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-assets' => array(
            'pretty_version' => 'v4.3.11',
            'version' => '4.3.11.0',
            'reference' => '02b14206e6f0713aea9c79af55b67422eaa17c39',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-assets',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-autoloader' => array(
            'pretty_version' => 'v5.0.0',
            'version' => '5.0.0.0',
            'reference' => 'eb6331a5c50a03afd9896ce012e66858de9c49c5',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../automattic/jetpack-autoloader',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-config' => array(
            'pretty_version' => 'v3.0.0',
            'version' => '3.0.0.0',
            'reference' => 'fc719eff5073634b0c62793b05be913ca634e192',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-config',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-connection' => array(
            'pretty_version' => 'v6.19.2',
            'version' => '6.19.2.0',
            'reference' => '74ac48945c6de0283fd1f4a52324a17d5e9c0b43',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-connection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-constants' => array(
            'pretty_version' => 'v3.0.8',
            'version' => '3.0.8.0',
            'reference' => 'f9bf00ab48956b8326209e7c0baf247a0ed721c4',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-constants',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-redirect' => array(
            'pretty_version' => 'v3.0.9',
            'version' => '3.0.9.0',
            'reference' => 'afb74d7c2ae46863c2af46b5703cf1c8728e6a5d',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-redirect',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-roles' => array(
            'pretty_version' => 'v3.0.8',
            'version' => '3.0.8.0',
            'reference' => '96e09fc813ccf5e691f46297875d6b85b859c669',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-roles',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'automattic/jetpack-status' => array(
            'pretty_version' => 'v6.1.0',
            'version' => '6.1.0.0',
            'reference' => '7dbcfff7f1005611a3d27e3553df9389c658b3a8',
            'type' => 'jetpack-library',
            'install_path' => __DIR__ . '/../automattic/jetpack-status',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'composer/installers' => array(
            'pretty_version' => 'v1.12.0',
            'version' => '1.12.0.0',
            'reference' => 'd20a64ed3c94748397ff5973488761b22f6d3f19',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/./installers',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'maxmind-db/reader' => array(
            'pretty_version' => 'v1.12.1',
            'version' => '1.12.1.0',
            'reference' => '815939e006b7e68062b540ec9e86aaa8be2b6ce4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../maxmind-db/reader',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'opis/json-schema' => array(
            'pretty_version' => '2.6.0',
            'version' => '2.6.0.0',
            'reference' => '8458763e0dd0b6baa310e04f1829fc73da4e8c8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../opis/json-schema',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'opis/string' => array(
            'pretty_version' => '2.1.0',
            'version' => '2.1.0.0',
            'reference' => '3e4d2aaff518ac518530b89bb26ed40f4503635e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../opis/string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'opis/uri' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '0f3ca49ab1a5e4a6681c286e0b2cc081b93a7d5a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../opis/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/plugin-installer' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'shama/baton' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'woocommerce/action-scheduler' => array(
            'pretty_version' => '3.9.3',
            'version' => '3.9.3.0',
            'reference' => 'c58cdbab17651303d406cd3b22cf9d75c71c986c',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../packages/action-scheduler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'woocommerce/blueprint' => array(
            'pretty_version' => '0.0.1',
            'version' => '0.0.1.0',
            'reference' => 'f996d43977196b9670d783b58c167243950876d3',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../packages/blueprint',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'woocommerce/email-editor' => array(
            'pretty_version' => '2.12.0',
            'version' => '2.12.0.0',
            'reference' => 'cb255266fec1c3ac8c2841ab36ac08d19aa12412',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../packages/email-editor',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'woocommerce/woocommerce' => array(
            'pretty_version' => '10.8.1',
            'version' => '10.8.1.0',
            'reference' => null,
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wordpress/abilities-api' => array(
            'pretty_version' => 'v0.4.0',
            'version' => '0.4.0.0',
            'reference' => '0759075aed37c4247adbf273bdebec096d52e825',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wordpress/abilities-api',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wordpress/mcp-adapter' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'reference' => '653ca8d95180b25809b1a1dc489d8305ec5beb63',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wordpress/mcp-adapter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
