.type-shop_order .column-order_actions a.button.wpo_wcpdf {
	float: left;
	width: 26px;
	height: 26px;
	padding: 3px 2px;
}

.type-shop_order .column-wc_actions a.button.wpo_wcpdf img {
	margin-top: 3px;
}
