<?php return array('dependencies' => array('react-jsx-runtime', 'wc-blocks-components', 'wc-sanitize', 'wc-settings', 'wp-api-fetch', 'wp-block-editor', 'wp-blocks', 'wp-components', 'wp-element', 'wp-escape-html', 'wp-html-entities', 'wp-i18n', 'wp-is-shallow-equal', 'wp-polyfill', 'wp-primitives'), 'version' => '44762cb5beaa05dc2bc2');
