@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wp-block-woocommerce-stock-filter{margin-bottom:24px}.wp-block-woocommerce-stock-filter h1,.wp-block-woocommerce-stock-filter h2,.wp-block-woocommerce-stock-filter h3,.wp-block-woocommerce-stock-filter h4,.wp-block-woocommerce-stock-filter h5,.wp-block-woocommerce-stock-filter h6{text-transform:inherit}
