@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-name{font-size:1em;overflow-wrap:anywhere;word-break:break-word}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-title{display:block;font-size:inherit;font-weight:700;line-height:1.5;margin-bottom:12px;margin-top:0;padding:0}.wc-block-components-product-title a{color:inherit;font-size:inherit}.is-loading .wc-block-components-product-title:before{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;content:".";display:block;display:inline-block;line-height:1;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;width:7em;z-index:1}.is-loading .wc-block-components-product-title:before>*{visibility:hidden}.is-loading .wc-block-components-product-title:before:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;transform:translateX(-100%)}@keyframes loading__animation{to{transform:translateX(100%)}}@media screen and (prefers-reduced-motion:reduce){.is-loading .wc-block-components-product-title:before{animation:none}}.is-loading .wc-block-grid .wc-block-components-product-title:before{width:10em}.wc-block-components-product-title--align-left{text-align:left}.wc-block-components-product-title--align-center{text-align:center}.wc-block-components-product-title--align-right{text-align:right}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-price--align-left{display:block;text-align:left}.wc-block-components-product-price--align-center{display:block;text-align:center}.wc-block-components-product-price--align-right{display:block;text-align:right}.wc-block-components-product-price{display:block}.wc-block-components-product-price[hidden]{display:none}.wc-block-components-product-price>:empty{display:none}.wc-block-components-product-price .wc-block-all-products .wc-block-components-product-price{margin-bottom:12px}.wc-block-components-product-price ins{text-decoration:none}.wc-block-components-product-price .woocommerce-Price-amount{white-space:nowrap}.wc-block-components-product-price__value.is-discounted{margin-left:.5em}.is-loading .wc-block-components-product-price:before{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;content:".";display:block;display:inline-block;line-height:1;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;width:5em;z-index:1}.is-loading .wc-block-components-product-price:before>*{visibility:hidden}.is-loading .wc-block-components-product-price:before:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;transform:translateX(-100%)}@keyframes loading__animation{to{transform:translateX(100%)}}@media screen and (prefers-reduced-motion:reduce){.is-loading .wc-block-components-product-price:before{animation:none}}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-block-woocommerce-product-sale-badge{display:flex;flex-direction:column}.wc-block-components-product-sale-badge{background:#fff;border:1px solid #43454b;border-radius:4px;box-sizing:border-box;color:#43454b;display:inline-block;font-size:.875em;font-weight:600;padding:.25em .75em;position:static;text-align:center;text-transform:uppercase;width:fit-content;z-index:9}.wc-block-components-product-sale-badge--align-left{align-self:auto}.wc-block-components-product-sale-badge--align-center{align-self:center}.wc-block-components-product-sale-badge--align-right{align-self:flex-end}.wc-block-components-product-sale-badge span{background-color:inherit;color:inherit}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image,.wc-block-components-product-image{display:block;position:relative;text-decoration:none}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image a,.wc-block-components-product-image a{border:0;border-radius:inherit;box-shadow:none;display:block;text-decoration:none}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image img,.wc-block-components-product-image img{border-radius:inherit;height:auto;vertical-align:middle;width:100%}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image img[hidden],.wc-block-components-product-image img[hidden]{display:none}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image img[alt=""],.wc-block-components-product-image img[alt=""]{border:1px solid #f2f2f2}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image .wc-block-components-product-sale-badge--align-left,.wc-block-components-product-image .wc-block-components-product-sale-badge--align-left{left:4px;margin:0;position:absolute;right:auto;top:4px}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image .wc-block-components-product-sale-badge--align-center,.wc-block-components-product-image .wc-block-components-product-sale-badge--align-center{left:50%;margin:0;position:absolute;right:auto;top:4px;transform:translateX(-50%)}.editor-styles-wrapper .wc-block-grid__products .wc-block-grid__product .wc-block-components-product-image .wc-block-components-product-sale-badge--align-right,.wc-block-components-product-image .wc-block-components-product-sale-badge--align-right{left:auto;margin:0;position:absolute;right:4px;top:4px}.editor-styles-wrapper .wc-block-components-product-image__inner-container{justify-content:flex-start}.is-loading .wc-block-components-product-image{background-color:currentColor!important;border:0!important;box-shadow:none;color:currentColor!important;display:block;line-height:1;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;width:auto;z-index:1}.is-loading .wc-block-components-product-image>*{visibility:hidden}.is-loading .wc-block-components-product-image:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;transform:translateX(-100%)}@keyframes loading__animation{to{transform:translateX(100%)}}@media screen and (prefers-reduced-motion:reduce){.is-loading .wc-block-components-product-image{animation:none}}.wc-block-components-product-image__inner-container{bottom:0;display:flex;flex-direction:column;left:0;padding:12px;position:absolute;right:0;top:0}.wc-block-product-image__tools-panel .components-input-control{margin-bottom:8px}.wc-block-components-product-image img{max-width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-rating .wc-block-components-product-rating__container>*{vertical-align:middle}.wc-block-components-product-rating .wc-block-components-product-rating__stars{display:inline-block;margin:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-rating-stars{display:block;line-height:1}.wc-block-components-product-rating-stars__stars{display:inline-block;font-family:WooCommerce;font-size:1em;font-weight:400;height:1.618em;line-height:1.618;overflow:hidden;position:relative;text-align:left;width:5.3em}.wc-block-components-product-rating-stars__stars:before{color:inherit;content:"SSSSS";left:0;opacity:.5;position:absolute;right:0;top:0;white-space:nowrap}.wc-block-components-product-rating-stars__stars span{color:inherit;left:0;overflow:hidden;padding-top:1.5em;position:absolute;right:0;top:0}.wc-block-components-product-rating-stars__stars span:before{color:inherit;content:"SSSSS";left:0;position:absolute;right:0;top:0;white-space:nowrap}.wc-block-components-product-rating-stars__link{display:inline-block;font-size:.875em;height:1.618em;text-align:inherit;width:100%}.wc-block-all-products .wc-block-components-product-rating-stars{margin-bottom:12px;margin-top:0}.wc-block-components-product-rating-stars__norating-container{align-items:center;display:inline-flex;flex-direction:row;gap:8px}.wc-block-components-product-rating-stars__norating{-webkit-text-stroke:2px var(--wp--preset--color--black,#000);display:inline-block;font-family:WooCommerce;font-size:1em;font-weight:400;height:1.618em;line-height:1.618;overflow:hidden;position:relative;width:1.5em}.wc-block-components-product-rating-stars__norating:before{color:transparent;content:"S";left:0;position:absolute;right:0;text-align:center;top:0;white-space:nowrap}.wp-block-woocommerce-single-product .wc-block-components-product-rating__stars{margin:0}.wc-block-all-products .is-loading .wc-block-components-product-rating,.wp-block-query .is-loading .wc-block-components-product-rating{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;display:block;line-height:1;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;width:7em;z-index:1}.wc-block-all-products .is-loading .wc-block-components-product-rating>*,.wp-block-query .is-loading .wc-block-components-product-rating>*{visibility:hidden}.wc-block-all-products .is-loading .wc-block-components-product-rating:after,.wp-block-query .is-loading .wc-block-components-product-rating:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;transform:translateX(-100%)}@keyframes loading__animation{to{transform:translateX(100%)}}@media screen and (prefers-reduced-motion:reduce){.wc-block-all-products .is-loading .wc-block-components-product-rating,.wp-block-query .is-loading .wc-block-components-product-rating{animation:none}}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-block-button.wc-block-components-product-button{align-items:center;display:flex;flex-direction:column;gap:12px;justify-content:center;white-space:normal}.wp-block-button.wc-block-components-product-button.is-style-outline .wp-block-button__link{border:2px solid}.wp-block-button.wc-block-components-product-button.is-style-outline .wp-block-button__link:not(.has-text-color){color:currentColor}.wp-block-button.wc-block-components-product-button.is-style-outline .wp-block-button__link:not(.has-background){background-color:transparent;background-image:none}.wp-block-button.wc-block-components-product-button.has-custom-width .wp-block-button__link{box-sizing:border-box}.wp-block-button.wc-block-components-product-button.wp-block-button__width-25 .wp-block-button__link{width:25%}.wp-block-button.wc-block-components-product-button.wp-block-button__width-50 .wp-block-button__link{width:50%}.wp-block-button.wc-block-components-product-button.wp-block-button__width-75 .wp-block-button__link{width:75%}.wp-block-button.wc-block-components-product-button.wp-block-button__width-100 .wp-block-button__link{width:100%}.wp-block-button.wc-block-components-product-button .wp-block-button__link{display:inline-flex;justify-content:center;text-align:center;white-space:normal;width:auto}.wp-block-button.wc-block-components-product-button a[hidden],.wp-block-button.wc-block-components-product-button button[hidden]{display:none}@keyframes slideOut{0%{transform:translateY(0)}to{transform:translateY(-100%)}}@keyframes slideIn{0%{opacity:0;transform:translateY(90%)}to{opacity:1;transform:translate(0)}}.wp-block-button.wc-block-components-product-button.align-left{align-items:flex-start}.wp-block-button.wc-block-components-product-button.align-right{align-items:flex-end}.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button{align-items:center;border-style:none;display:inline-flex;justify-content:center;line-height:inherit;overflow:hidden;white-space:normal;word-break:normal}.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button span.wc-block-slide-out{animation:slideOut .1s linear 1 normal forwards}.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button span.wc-block-slide-in{animation:slideIn .1s linear 1 normal}.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button--placeholder{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;display:block;line-height:1;max-width:100%!important;min-height:3em;min-width:8em;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;z-index:1}.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button--placeholder>*{visibility:hidden}.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button--placeholder:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;transform:translateX(-100%)}@keyframes loading__animation{to{transform:translateX(100%)}}@media screen and (prefers-reduced-motion:reduce){.wp-block-button.wc-block-components-product-button .wc-block-components-product-button__button--placeholder{animation:none}}.wc-block-all-products .wp-block-button.wc-block-components-product-button{margin-bottom:12px}.theme-twentytwentyone .editor-styles-wrapper .wc-block-components-product-button .wp-block-button__link{background-color:var(--button--color-background);border-color:var(--button--color-background);color:var(--button--color-text)}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-summary{word-wrap:break-word;margin-bottom:12px;margin-top:0}.wc-block-components-product-summary h1,.wc-block-components-product-summary h2,.wc-block-components-product-summary h3,.wc-block-components-product-summary h4,.wc-block-components-product-summary h5,.wc-block-components-product-summary h6{color:inherit;font-size:1.15em}.wc-block-components-product-summary__more-link{display:inline-block}.is-loading .wc-block-components-product-summary:before{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;content:".";display:block;height:6em;line-height:1;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;z-index:1}.is-loading .wc-block-components-product-summary:before>*{visibility:hidden}.is-loading .wc-block-components-product-summary:before:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;transform:translateX(-100%)}@keyframes loading__animation{to{transform:translateX(100%)}}@media screen and (prefers-reduced-motion:reduce){.is-loading .wc-block-components-product-summary:before{animation:none}}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-sku{display:block;overflow-wrap:break-word}.wc-block-components-product-sku__prefix{color:var(--wp--preset--color--contrast-2)}.wc-block-components-product-sku__suffix{display:none}.wc-block-components-product-sku.is-selected .wc-block-components-product-sku__suffix,.wc-block-components-product-sku__suffix.has-content{display:inline}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-stock-indicator{display:block;font-size:.875em;margin-bottom:.75em;margin-top:0}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.woocommerce .wp-block-woocommerce-product-image-gallery{clear:both;max-width:512px;position:relative}.woocommerce .wp-block-woocommerce-product-image-gallery span.onsale{left:-1rem;right:unset;z-index:1}.woocommerce .wp-block-woocommerce-product-image-gallery:after{clear:both;content:"";display:table}.woocommerce .wp-block-woocommerce-product-image-gallery .woocommerce-product-gallery.images{width:100%}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-pagination{margin:0 auto 16px}.wc-block-components-pagination__ellipsis,.wc-block-components-pagination__page{color:#333;display:inline-block;font-size:1em;font-weight:400}.wc-block-components-pagination__page{border-color:transparent;min-width:2.2em;padding:.3em .6em}.wc-block-components-pagination__page:not([disabled]){cursor:pointer}@media(max-width:782px){.wc-block-components-pagination__page{min-width:1.6em;padding:.1em .2em}}.wc-block-components-pagination__page:not(.toggle){background-color:transparent}.wc-block-components-pagination__ellipsis{padding:.3em}@media(max-width:782px){.wc-block-components-pagination__ellipsis{padding:.1em}}.wc-block-components-pagination__page--active[disabled]{color:#333;font-weight:700;opacity:1!important}.wc-block-components-pagination__page--active[disabled]:focus,.wc-block-components-pagination__page--active[disabled]:hover{background-color:inherit;color:#333;opacity:1!important}html[dir=rtl] .wc-block-components-pagination-page--arrow span{display:inline-block;transform:scaleX(-1)}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.with-scroll-to-top__scroll-point{position:relative;top:-36px}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-product-sort-select{margin-bottom:24px;text-align:left}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}@keyframes spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.wc-block-grid{text-align:center}.wc-block-grid__no-products{padding:48px;text-align:center;width:100%}.wc-block-grid__no-products .wc-block-grid__no-products-image{color:inherit;display:block;margin:0 auto 1em;max-width:150px}.wc-block-grid__no-products .wc-block-grid__no-products-title{display:block;font-weight:700;margin:0}.wc-block-grid__no-products .wc-block-grid__no-products-description{display:block;margin:.25em 0 1em}.wc-block-grid__products{background-clip:padding-box;display:flex;flex-wrap:wrap;margin:0 -8px 16px;padding:0}.wc-block-grid__product{border-bottom:16px solid transparent;border-left:8px solid transparent;border-right:8px solid transparent;box-sizing:border-box;float:none;list-style:none;margin:0;padding:0;position:relative;text-align:center;width:auto}.wc-block-grid__product.wc-block-grid__product{box-sizing:border-box}.theme-twentytwenty .wc-block-grid.has-aligned-buttons .wc-block-grid__product,.wc-block-grid.has-aligned-buttons .wc-block-grid__product{display:flex;flex-direction:column}.theme-twentytwenty .wc-block-grid.has-aligned-buttons .wc-block-grid__product>:last-child,.wc-block-grid.has-aligned-buttons .wc-block-grid__product>:last-child{margin-bottom:0;margin-top:auto;padding-bottom:12px}.theme-twentytwenty .wc-block-grid.has-1-columns .wc-block-grid__product,.wc-block-grid.has-1-columns .wc-block-grid__product{flex:1 0 100%;max-width:100%}.theme-twentytwenty .wc-block-grid.has-2-columns .wc-block-grid__product,.wc-block-grid.has-2-columns .wc-block-grid__product{flex:1 0 50%;max-width:50%}.theme-twentytwenty .wc-block-grid.has-3-columns .wc-block-grid__product,.wc-block-grid.has-3-columns .wc-block-grid__product{flex:1 0 33.3333333333%;max-width:33.3333333333%}.theme-twentytwenty .wc-block-grid.has-4-columns .wc-block-grid__product,.wc-block-grid.has-4-columns .wc-block-grid__product{flex:1 0 25%;max-width:25%}.theme-twentytwenty .wc-block-grid.has-5-columns .wc-block-grid__product,.wc-block-grid.has-5-columns .wc-block-grid__product{flex:1 0 20%;max-width:20%}.theme-twentytwenty .wc-block-grid.has-6-columns .wc-block-grid__product,.wc-block-grid.has-6-columns .wc-block-grid__product{flex:1 0 16.6666666667%;max-width:16.6666666667%}.theme-twentytwenty .wc-block-grid.has-7-columns .wc-block-grid__product,.wc-block-grid.has-7-columns .wc-block-grid__product{flex:1 0 14.2857142857%;max-width:14.2857142857%}.theme-twentytwenty .wc-block-grid.has-8-columns .wc-block-grid__product,.wc-block-grid.has-8-columns .wc-block-grid__product{flex:1 0 12.5%;max-width:12.5%}.theme-twentytwenty .wc-block-grid.has-6-columns .wc-block-grid__product,.wc-block-grid.has-6-columns .wc-block-grid__product{font-size:.5em}.theme-twentytwenty .wc-block-grid.has-5-columns .wc-block-grid__product,.theme-twentytwenty .wc-block-grid.has-6-columns.alignfull .wc-block-grid__product,.wc-block-grid.has-5-columns .wc-block-grid__product,.wc-block-grid.has-6-columns.alignfull .wc-block-grid__product{font-size:.58em}.theme-twentytwenty .wc-block-grid.has-4-columns:not(.alignwide):not(.alignfull) .wc-block-grid__product,.theme-twentytwenty .wc-block-grid.has-5-columns.alignfull .wc-block-grid__product,.wc-block-grid.has-4-columns:not(.alignwide):not(.alignfull) .wc-block-grid__product,.wc-block-grid.has-5-columns.alignfull .wc-block-grid__product{font-size:.75em}.theme-twentytwenty .wc-block-grid.has-3-columns:not(.alignwide):not(.alignfull),.wc-block-grid.has-3-columns:not(.alignwide):not(.alignfull){font-size:.92em}@media(max-width:480px){.wc-block-grid.has-2-columns .wc-block-grid__products{display:block}.wc-block-grid.has-2-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}.wc-block-grid.has-3-columns .wc-block-grid__products{display:block}.wc-block-grid.has-3-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}.wc-block-grid.has-4-columns .wc-block-grid__products{display:block}.wc-block-grid.has-4-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}.wc-block-grid.has-5-columns .wc-block-grid__products{display:block}.wc-block-grid.has-5-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}.wc-block-grid.has-6-columns .wc-block-grid__products{display:block}.wc-block-grid.has-6-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}.wc-block-grid.has-7-columns .wc-block-grid__products{display:block}.wc-block-grid.has-7-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}.wc-block-grid.has-8-columns .wc-block-grid__products{display:block}.wc-block-grid.has-8-columns .wc-block-grid__product{flex:1 0 100%;margin-left:auto;margin-right:auto;max-width:100%;padding:0}}@media(min-width:481px)and (max-width:600px){.wc-block-grid.has-2-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-2-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-2-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}.wc-block-grid.has-3-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-3-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-3-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}.wc-block-grid.has-4-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-4-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-4-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}.wc-block-grid.has-5-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-5-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-5-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}.wc-block-grid.has-6-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-6-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-6-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}.wc-block-grid.has-7-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-7-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-7-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}.wc-block-grid.has-8-columns .wc-block-grid__product{flex:1 0 50%;margin:0 0 24px;max-width:50%;padding:0}.wc-block-grid.has-8-columns .wc-block-grid__product:nth-child(odd){padding-right:8px}.wc-block-grid.has-8-columns .wc-block-grid__product:nth-child(2n){padding-left:8px}}
@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-error{align-items:center;color:#757575;display:flex;flex-direction:column;justify-content:center;margin:48px 0;padding:48px 0;text-align:center}.wc-block-components-error__header{color:#646970;font-size:2em;margin:0}.wc-block-components-error__image{margin:0 0 24px;width:25%}.wc-block-components-error__text{color:#8c8f94;font-size:1.25em;margin:1em 0 0;max-width:60ch}.wc-block-components-error__message{color:#8c8f94;font-style:italic;margin:1em auto 0;max-width:60ch}.wc-block-error__button{margin:48px 0 0}
