@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs{border-bottom-color:inherit;border-bottom-width:0;overflow:visible;padding:0}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs:after,html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs:before{display:none}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li{background:transparent;border:solid transparent;border-radius:0;border-width:0 0 2px;color:inherit;display:inline-block;float:none;font-weight:700;margin:0;opacity:.65;padding:0}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li a{border:none;color:inherit;display:inline-block;padding:.5em 1em;text-decoration:none;text-shadow:none}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li.active,html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:focus-within,html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:hover{background:inherit;border-color:inherit;color:inherit;opacity:1}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li.active a,html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:focus-within a,html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:hover a{border:none;color:inherit;text-decoration:none}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li a:focus:not(:focus-visible),html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:focus:not(:focus-visible){outline:none}@media only screen and (max-width:768px){html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li{border-bottom-width:0;border-left-width:2px;display:block;margin-bottom:2px}}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:first-child{margin-left:0}html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:after,html body .wp-block-woocommerce-product-details.is-style-minimal ul.tabs.wc-tabs li:before{display:none}
