@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-notice-banner{align-content:flex-start;align-items:stretch;background-color:#fff;border:1px solid #2f2f2f;border-radius:4px;box-sizing:border-box;color:#2f2f2f;display:flex;font-size:.875em;font-weight:400;gap:12px;line-height:1.5;margin:16px 0;padding:16px!important}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content{align-self:center;flex-basis:100%;padding-left:16px;white-space:normal}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content:last-child{padding-left:0}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-block-components-notice-banner__summary{font-weight:600;margin:0 0 8px}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content ol,.wc-block-components-notice-banner>.wc-block-components-notice-banner__content ul{margin:0 24px 0 0;padding:0}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content ol li:after,.wc-block-components-notice-banner>.wc-block-components-notice-banner__content ul li:after{clear:both;content:"";display:block}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-forward{appearance:none;background:transparent!important;border:0;color:#2f2f2f!important;float:left;margin:0;opacity:.7;padding:0!important;text-decoration-line:underline;text-underline-position:under;transition:all .2s ease-in-out}.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-forward:active,.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-forward:focus,.wc-block-components-notice-banner>.wc-block-components-notice-banner__content .wc-forward:hover{opacity:1;text-decoration:none}.wc-block-components-notice-banner>svg{fill:#fff;background-color:#2f2f2f;border-radius:50%;flex-grow:0;flex-shrink:0;height:100%;padding:2px}.wc-block-components-notice-banner>.wc-block-components-button{background:transparent none!important;border:0!important;box-shadow:none!important;color:#2f2f2f!important;flex:0 0 16px;height:16px!important;margin:6px auto 0 0!important;min-height:auto!important;min-width:0!important;opacity:.6;outline:none!important;padding:0!important;width:16px!important}.wc-block-components-notice-banner>.wc-block-components-button>svg{margin:0!important}.wc-block-components-notice-banner>.wc-block-components-button:active,.wc-block-components-notice-banner>.wc-block-components-button:focus,.wc-block-components-notice-banner>.wc-block-components-button:hover{opacity:1}.wc-block-components-notice-banner>.wc-block-components-button:focus{outline:2px solid currentColor!important;outline-offset:0}.wc-block-components-notice-banner.is-error{background-color:#fff0f0;border-color:#cc1818}.wc-block-components-notice-banner.is-error>svg{background-color:#cc1818;transform:rotate(-180deg)}.wc-block-components-notice-banner.is-warning{background-color:#fffbf4;border-color:#f0b849}.wc-block-components-notice-banner.is-warning>svg{background-color:#f0b849;transform:rotate(-180deg)}.wc-block-components-notice-banner.is-success{background-color:#f4fff7;border-color:#4ab866}.wc-block-components-notice-banner.is-success>svg{background-color:#4ab866}.wc-block-components-notice-banner.is-info{background-color:#f4f8ff;border-color:#007cba}.wc-block-components-notice-banner.is-info>svg{background-color:#007cba}.wc-block-components-notice-banner:focus{outline-width:0}.wc-block-components-notice-banner:focus-visible{outline-style:solid;outline-width:2px}.woocommerce.wc-block-store-notices.alignwide{max-width:var(--wp--style--global--wide-size)}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-button:not(.is-link){align-items:center;display:inline-flex;height:auto;justify-content:center;position:relative;text-align:center;transition:box-shadow .1s linear}.wc-block-components-button:not(.is-link):focus{box-shadow:0 0 0 2px #0675c4;box-shadow:inset 0 0 0 1px #fff,0 0 0 2px #0675c4;outline:3px solid transparent}.wc-block-components-button:not(.is-link) .wc-block-components-button__text{text-wrap:balance;text-wrap:pretty;display:block}.wc-block-components-button:not(.is-link) .wc-block-components-button__text>svg{fill:currentColor}.wc-block-components-button:not(.is-link).text{color:#1e1e1e}.wc-block-components-button:not(.is-link).text:hover{opacity:.9}.wc-block-components-button:not(.is-link):disabled .wc-block-components-button__text{opacity:.5}.wc-block-components-button:not(.is-link).is-style-outline,.wc-block-components-button:not(.is-link).outlined{background:transparent;color:currentColor}.wc-block-components-button:not(.is-link).is-style-outline:not(:focus),.wc-block-components-button:not(.is-link).outlined:not(:focus){box-shadow:inset 0 0 0 1px currentColor}.wc-block-components-button:not(.is-link).is-style-outline:active,.wc-block-components-button:not(.is-link).is-style-outline:disabled,.wc-block-components-button:not(.is-link).is-style-outline:focus,.wc-block-components-button:not(.is-link).is-style-outline:hover,.wc-block-components-button:not(.is-link).outlined:active,.wc-block-components-button:not(.is-link).outlined:disabled,.wc-block-components-button:not(.is-link).outlined:focus,.wc-block-components-button:not(.is-link).outlined:hover{background-color:#1e1e1e;color:#fff}.wc-block-components-button:not(.is-link).is-style-outline:hover,.wc-block-components-button:not(.is-link).outlined:hover{background-color:#1e1e1e;color:#fff;opacity:1}body:not(.woocommerce-block-theme-has-button-styles) .wc-block-components-button:not(.is-link){min-height:3em}body:not(.woocommerce-block-theme-has-button-styles) .wc-block-components-button:not(.is-link):focus{box-shadow:0 0 0 2px #0675c4;box-shadow:inset 0 0 0 1px #fff,0 0 0 2px #0675c4;outline:3px solid transparent}body:not(.woocommerce-block-theme-has-button-styles) .wc-block-components-button:not(.is-link).text{color:#1e1e1e}body:not(.woocommerce-block-theme-has-button-styles) .wc-block-components-button:not(.is-link).text:hover{opacity:.9}
@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-store-notices:has(>.woocommerce-notices-wrapper:only-child:empty){margin-block-end:0;margin-block-start:0}
