@use "../../common/breakpoints" as *;

//
// "Current Stock Value" widget
//-----------------------

.atum-widget.atum_current_stock_value_widget {
	.widget-body {
		padding: 10px 30px 0;
		
		@include tablet-max {
			padding-top: 0;
			padding-bottom: 0;
		}
	}
	
	.grid-stack-item-content {
		overflow-x: hidden;
		overflow-y: hidden;
	}
}

.current-stock-value-widget {
	
	h5 {
		font-size: 15px;
		color: var(--atum-text-color-var1);
		font-weight: 100;
		text-transform: uppercase;
	}

	.current-stock-value-filters {
		display: flex;
		justify-content: flex-start;
		align-items: center;
		flex-wrap: wrap;
		
		.nice-select {
			margin-right: 7px;
			margin-top: 10px;
			
			&.open {
				.list {
					max-height: 200px;
					overflow-x: hidden;
					overflow-y: auto;
				}
			}
			
		}
	}
	
	.current-stock-value-content {
		text-align: left;
		padding: 40px 0;
		
		.total-items-purchase-price, .items-count {
			font-size: 36px;
			font-weight: bold;
		}
		
		.total {
			display: inline;
		}
		
		.total-items-purchase-price {
			color: var(--dash-stats-data-widget-success);
		}
		
		.items-value-title, .stock-value-title {
			h5 {
				margin: 17px 0;
			}
		}
		
		.items-count {
			color: var(--primary);
		}
		
		.separator-line {
			width: 100%;
			height: 1px;
			background-color: var(--gray-400);
			margin: 21px 0 30px 0;
		}
		
		.stock-counter {
			padding-bottom: 25px;
		}
		
		.items-without-purchase-price {
			border-radius: 4px;
			background-color: var(--dash-widget-current-stock-value-bg);
			font-size: 12px;
			line-height: 1;
			color: var(--dash-widget-current-stock-value-text);
			padding: 6px 7px;
		}
	}
	
}