<?php return array('dependencies' => array('react', 'wc-components', 'wc-navigation', 'wc-sanitize', 'wc-settings', 'wp-api-fetch', 'wp-components', 'wp-compose', 'wp-core-data', 'wp-data', 'wp-dom', 'wp-editor', 'wp-element', 'wp-hooks', 'wp-i18n', 'wp-notices', 'wp-primitives', 'wp-url'), 'version' => '12498f7323dec3efc141');
