@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.woocommerce .wp-block-woocommerce-product-image-gallery{clear:both;max-width:512px;position:relative}.woocommerce .wp-block-woocommerce-product-image-gallery span.onsale{right:-1rem;left:unset;z-index:1}.woocommerce .wp-block-woocommerce-product-image-gallery:after{clear:both;content:"";display:table}.woocommerce .wp-block-woocommerce-product-image-gallery .woocommerce-product-gallery.images{width:100%}
