<?php
declare(strict_types=1);

// THIS FILE IS AUTO-GENERATED. DO NOT EDIT MANUALLY.

namespace Automattic\WooCommerce\Internal\Api\Autogenerated;

use Automattic\WooCommerce\Internal\Api\Schema\Schema;

class GraphQLController extends \Automattic\WooCommerce\Internal\Api\GraphQLController {
	protected function build_schema(): Schema {
		return new Schema(
			array(
				'query'    => RootQueryType::get(),
				'mutation' => RootMutationType::get(),
				'types'    => TypeRegistry::get_interface_implementors(),
			)
		);
	}
}
