@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-next,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-numbers,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-previous{font-size:inherit;margin-bottom:.5em;margin-right:.5em}.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-next:last-child,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-numbers:last-child,.wp-block-woocommerce-product-reviews-pagination>.wp-block-woocommerce-product-reviews-pagination-previous:last-child{margin-right:0}.wp-block-woocommerce-product-reviews-pagination .wp-block-woocommerce-product-reviews-pagination-previous-arrow{display:inline-block;margin-right:1ch}.wp-block-woocommerce-product-reviews-pagination .wp-block-woocommerce-product-reviews-pagination-previous-arrow:not(.is-arrow-chevron){transform:scaleX(1)}.wp-block-woocommerce-product-reviews-pagination .wp-block-woocommerce-product-reviews-pagination-next-arrow{display:inline-block;margin-left:1ch}.wp-block-woocommerce-product-reviews-pagination .wp-block-woocommerce-product-reviews-pagination-next-arrow:not(.is-arrow-chevron){transform:scaleX(1)}.wp-block-woocommerce-product-reviews-pagination.aligncenter{justify-content:center}
