"use strict";(globalThis.webpackChunk_wcAdmin_webpackJsonp=globalThis.webpackChunk_wcAdmin_webpackJsonp||[]).push([[945],{5874:(e,s,t)=>{t.r(s),t.d(s,{default:()=>l});var o=t(86087),r=t(27723),n=t(98846),a=t(94e3),i=t(60598),c=t(39793);const u=(0,o.lazy)(()=>t.e(3404).then(t.bind(t,69884)));class d extends o.Component{render(){const{path:e,query:s}=this.props;return(0,c.jsxs)(o.Suspense,{fallback:(0,c.jsx)(n.Spinner,{}),children:[(0,c.jsx)(a.Tv,{title:(0,r.__)("Discover what drives your sales","woocommerce"),description:(0,r.__)("Understand what truly drives revenue with our powerful order attribution extension. Use it to track your sales journey, identify your most effective marketing channels, and optimize your sales strategy.","woocommerce"),buttonText:(0,r.__)("Try it now","woocommerce"),badgeText:(0,r.__)("New","woocommerce"),bannerImage:(0,c.jsx)(a.iR,{}),dismissable:!0}),(0,c.jsx)(i.Zh,{}),(0,c.jsx)(u,{query:s,path:e})]})}}const l=d}}]);