(()=>{var e,t,r,o={4234:(e,t,r)=>{"use strict";const o=window.wp.blocks;var i=r(7871);const n=JSON.parse('{"name":"woocommerce/breadcrumbs","title":"Store Breadcrumbs","description":"Enable customers to keep track of their location within the store and navigate back to parent pages.","category":"woocommerce","keywords":["WooCommerce"],"textdomain":"woocommerce","attributes":{"contentJustification":{"type":"string"},"fontSize":{"type":"string","default":"small"},"align":{"type":"string","default":"wide"}},"supports":{"interactivity":{"clientNavigation":true},"align":["wide","full"],"color":{"background":false,"link":true},"html":false,"typography":{"fontSize":true,"lineHeight":true,"__experimentalFontFamily":true,"__experimentalFontStyle":true,"__experimentalFontWeight":true,"__experimentalTextTransform":true,"__experimentalDefaultControls":{"fontSize":true}}},"apiVersion":3,"$schema":"https://schemas.wp.org/trunk/block.json"}'),c=window.wp.blockEditor,s=window.wp.components;var a=r(7723),l=r(790);var u=r(5573);const p=(0,l.jsxs)(u.SVG,{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",children:[(0,l.jsx)(u.Rect,{x:"4",y:"10.5",width:"6",height:"3",rx:"1.5",fill:"currentColor"}),(0,l.jsx)(u.Rect,{x:"12",y:"10.5",width:"3",height:"3",rx:"1.5",fill:"currentColor"}),(0,l.jsx)(u.Rect,{x:"17",y:"10.5",width:"3",height:"3",rx:"1.5",fill:"currentColor"})]});r(4922),(0,o.registerBlockType)(n,{icon:{src:(0,l.jsx)(i.A,{icon:p,className:"wc-block-editor-components-block-icon"})},attributes:{...n.attributes},edit:()=>{const e=(0,c.useBlockProps)({className:"woocommerce wc-block-breadcrumbs"});return(0,l.jsx)("div",{...e,children:(0,l.jsxs)(s.Disabled,{children:[(0,l.jsx)("a",{href:"/",children:(0,a.__)("Breadcrumbs","woocommerce")}),(0,a.__)(" / Navigation / Path","woocommerce")]})})},save:()=>null})},4922:()=>{},790:e=>{"use strict";e.exports=window.ReactJSXRuntime},6087:e=>{"use strict";e.exports=window.wp.element},7723:e=>{"use strict";e.exports=window.wp.i18n},5573:e=>{"use strict";e.exports=window.wp.primitives}},i={};function n(e){var t=i[e];if(void 0!==t)return t.exports;var r=i[e]={exports:{}};return o[e](r,r.exports,n),r.exports}n.m=o,e=[],n.O=(t,r,o,i)=>{if(!r){var c=1/0;for(u=0;u<e.length;u++){for(var[r,o,i]=e[u],s=!0,a=0;a<r.length;a++)(!1&i||c>=i)&&Object.keys(n.O).every(e=>n.O[e](r[a]))?r.splice(a--,1):(s=!1,i<c&&(c=i));if(s){e.splice(u--,1);var l=o();void 0!==l&&(t=l)}}return t}i=i||0;for(var u=e.length;u>0&&e[u-1][2]>i;u--)e[u]=e[u-1];e[u]=[r,o,i]},n.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return n.d(t,{a:t}),t},r=Object.getPrototypeOf?e=>Object.getPrototypeOf(e):e=>e.__proto__,n.t=function(e,o){if(1&o&&(e=this(e)),8&o)return e;if("object"==typeof e&&e){if(4&o&&e.__esModule)return e;if(16&o&&"function"==typeof e.then)return e}var i=Object.create(null);n.r(i);var c={};t=t||[null,r({}),r([]),r(r)];for(var s=2&o&&e;"object"==typeof s&&!~t.indexOf(s);s=r(s))Object.getOwnPropertyNames(s).forEach(t=>c[t]=()=>e[t]);return c.default=()=>e,n.d(i,c),i},n.d=(e,t)=>{for(var r in t)n.o(t,r)&&!n.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},n.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),n.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),n.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.j=5159,(()=>{var e={5159:0};n.O.j=t=>0===e[t];var t=(t,r)=>{var o,i,[c,s,a]=r,l=0;if(c.some(t=>0!==e[t])){for(o in s)n.o(s,o)&&(n.m[o]=s[o]);if(a)var u=a(n)}for(t&&t(r);l<c.length;l++)i=c[l],n.o(e,i)&&e[i]&&e[i][0](),e[i]=0;return n.O(u)},r=globalThis.webpackChunkwebpackWcBlocksMainJsonp=globalThis.webpackChunkwebpackWcBlocksMainJsonp||[];r.forEach(t.bind(null,0)),r.push=t.bind(null,r.push.bind(r))})();var c=n.O(void 0,[94],()=>n(4234));c=n.O(c),((this.wc=this.wc||{}).blocks=this.wc.blocks||{}).breadcrumbs=c})();