/* wc orders list */
.type-shop_order .column-wc_actions a.button.wpo_wcpdf,
.type-shop_order .column-wc_actions a.button.wpo_wcpdf:hover,
.woocommerce_page_wc-orders .column-wc_actions a.button.wpo_wcpdf,
.woocommerce_page_wc-orders .column-wc_actions a.button.wpo_wcpdf:hover {
	background-repeat: no-repeat;
	background-position: center;
	text-align: center;
	background-size: 16px 16px;
}

.type-shop_order .column-wc_actions a.button.wpo_wcpdf > svg,
.woocommerce_page_wc-orders .column-wc_actions a.button.wpo_wcpdf > svg {
	display: block;
	position: absolute;
	width: 10px;
	height: 10px;
	bottom: 1px;
	background: #f6f7f7;
}

.type-shop_order .column-wc_actions a.button.wpo_wcpdf.exists > svg.icon-exists,
.woocommerce_page_wc-orders .column-wc_actions a.button.wpo_wcpdf.exists > svg.icon-exists {
	left: auto;
	right: 2px;
	fill: #2aad2a;
}

.type-shop_order .column-wc_actions a.button.wpo_wcpdf.xml > svg.icon-edi,
.woocommerce_page_wc-orders .column-wc_actions a.button.wpo_wcpdf.xml > svg.icon-edi {
	left: auto;
	right: 2px;
	fill: black;
}

.type-shop_order .column-wc_actions a.button.wpo_wcpdf.printed > svg.icon-printed,
.woocommerce_page_wc-orders .column-wc_actions a.button.wpo_wcpdf.printed > svg.icon-printed {
	left: 2px;
	right: auto;
	fill: #51266b;
}

ul.wpo-ips-edi-actions {
	margin: 0;
}

ul.wpo-ips-edi-actions > li {
	margin: 12px 0 0 0;
}

.wpo_wcpdf-actions a.button.exists > svg,
.wpo-ips-edi-actions a.button.exists > svg {
	width: 14px;
	height: 14px;
	line-height: 30px;
	margin-left: 4px;
	margin-bottom: 3px;
	fill: #2aad2a;
	vertical-align: middle;
}

.wpo-ips-edi-actions a.button.disabled {
	pointer-events: none;
	cursor: not-allowed;
}

.wpo_wcpdf-actions .printed-data,
.wcpdf-data-fields .printed-data {
	font-size: 8pt;
	color: #999;
	margin-left: 5px;
	vertical-align: middle;
	margin-top: 3px !important;
}

.wpo_wcpdf-actions .printed-data > svg,
.wcpdf-data-fields .printed-data > svg {
	width: 14px;
	height: 14px;
	background: #fff;
	fill: #999;
	vertical-align: middle;
	margin-right: 3px;
}

.wpo_wcpdf-actions a.unmark_printed,
.wcpdf-data-fields a.unmark_printed {
	margin-left: 4px;
	color: #a00;;
}

.widefat .column-pdf_invoice_number {
	width: 110px;
}

#wpo_wcpdf-data-input-box > .inside {
	margin: 0;
	padding: 10px 0;
	background-color: #f8f8f8;
}

#wpo_wcpdf-data-input-box h4 {
	font-size: 14px;
	line-height: 1.4;
	margin: 0;
}

#wpo_wcpdf-data-input-box p {
	margin: 0.5em 0;
}

#wpo_wcpdf-data-input-box .form-field input {
	width: auto;
}

#wpo_ips-edi-box .inside {
	margin: 0;
	padding: 12px;
}

#wpo_ips-edi-box .inside > .notice {
	margin: 0 0 12px 0 !important;
}

#wpo_ips-edi-box .inside > .notice > p {
	font-size: 12px !important;
}

#wpo_ips-edi-box .inside > div table {
	margin-bottom: 12px;
}

#wpo_ips-edi-box .inside > div:last-child table {
	margin-bottom: 0;
}

#wpo_ips-edi-box .inside table td {
	font-size: 12px !important;
}

#wpo_ips-edi-box .inside table td.right {
	text-align: right;
}

#wpo_ips-edi-box .inside table thead td {
	background-color: #f4f4f4;
}

#wpo_ips-edi-box .inside table thead td:first-of-type {
	font-weight: bold;
}

#wpo_ips-edi-box .inside table > tbody > tr:not(:last-of-type) > td {
	border-bottom: 1px solid #f4f4f4;
}

#wpo_ips-edi-box .inside .peppol table {
	width: 100%;
	table-layout: fixed;
}

#wpo_ips-edi-box .inside > .edi-order-actions table td {
	vertical-align: middle;
}

#wpo_ips-edi-box .edi-order-actions table th:last-child,
#wpo_ips-edi-box .edi-order-actions table td:last-child {
	text-align: right;
	white-space: nowrap;
}

#wpo_ips-edi-box .edi-order-actions tbody td:last-child {
	display: flex;
	justify-content: flex-end;
	align-items: center;
	flex-wrap: nowrap;
}

#wpo_ips-edi-box .inside > .edi-order-actions .xml {
	display: inline-flex;
	align-items: center;
	justify-content: center;
	width: 32px;
	height: 32px;
	padding: 0;
	margin-left: 3px;
	line-height: 1;
}

#wpo_ips-edi-box .inside > .edi-order-actions .xml .dashicons {
	font-size: 18px;
	line-height: 1;
}

#wpo_ips-edi-box .inside > .edi-order-actions .xml.disabled {
	pointer-events: none;
	cursor: not-allowed;
}

#wpo_ips-edi-box .inside > .edi-order-actions .xml.sent {
	background-color: #e7f7ec !important;
	color: #0a7a29 !important;
	border-color: #e7f7ec !important;
}

#wpo_ips-edi-box .inside > .edi-order-actions .order-id {
	font-size: 10px;
	color: #999;
}

#wpo_ips-edi-box .inside .peppol tbody td.edit,
#wpo_ips-edi-box .inside .peppol tfoot,
#wpo_ips-edi-box .inside .peppol table.is-editing thead .editable a,
#wpo_ips-edi-box .inside .peppol table.is-editing tbody td.display {
	display: none;
}

#wpo_ips-edi-box .inside .peppol tbody td.edit input {
	width: 100%;
}

#wpo_ips-edi-box .inside .peppol table.is-editing tbody td.edit {
	display: table-cell;
}

#wpo_ips-edi-box .inside .peppol table.is-editing tfoot {
	display: table-row-group;
}

.wcpdf-data-fields {
	margin-left: 10px;
	margin-right: 10px;
	margin-bottom: 10px;
	background-color: white;
	border: 1px solid #c3c4c7;
	box-shadow: 0 1px 1px rgba(0,0,0,.04);
}

.wcpdf-data-fields:last-child {
	margin-bottom: 0;
}

.wcpdf-data-fields .read-only {
	height: auto;
	display: block;
	padding: 10px;
}

.wcpdf-data-fields .editable,
.wcpdf-data-fields .editable-notes {
	height: auto;
	display: none;
	padding: 10px;
}

.wcpdf-data-fields .editable-number-date {
	border-bottom: 1px solid #dfdfdf;
}

.wcpdf-data-fields .data-fields-grid {
	display: flex;
	flex-direction: column;
	gap: 1rem;
	max-width: 50%;
}

.wcpdf-data-fields .data-fields-grid:first-of-type {
	margin-bottom: 1rem;
}

.wcpdf-data-fields .data-fields-row {
	display: grid;
	grid-template-columns: repeat(3, 1fr);
	gap: 1rem;
	align-items: start;
	position: relative;
}

.wcpdf-data-fields .data-fields-row .field-group {
	display: flex;
	flex-direction: column;
}

.wcpdf-data-fields .data-fields-row .field-group label {
	margin-bottom: .4rem;
}

.wcpdf-data-fields .data-fields-row .field-group input.formatted-number.changed {
	background-color: #fff3cd;
}

.wcpdf-data-fields .data-fields-row .placeholder {
	visibility: hidden;
}

.wcpdf-data-fields .data-fields-row .row-note {
	grid-column: 1 / -1; /* makes the note span across all columns */
	font-size: 0.8em;
	color: #999;
}

.wcpdf-data-fields h4 {
	padding: 10px;
	border-bottom: 1px solid #dfdfdf;
}

/* Edit buttons Invoice, Proforma and Credit */
.wcpdf-data-fields h4 .dashicons:first-of-type {
	margin-left:20px !important;
}

.wcpdf-data-fields .wpo-wcpdf-edit-date-number,
.wcpdf-data-fields .wpo-wcpdf-delete-document,
.wcpdf-data-fields .wpo-wcpdf-regenerate-document,
.wcpdf-data-fields .wpo-wcpdf-edit-document-notes {
	opacity:0.5;
}

.wcpdf-data-fields .wpo-wcpdf-edit-date-number:hover,
.wcpdf-data-fields .wpo-wcpdf-delete-document:hover,
.wcpdf-data-fields .wpo-wcpdf-regenerate-document:hover,
.wcpdf-data-fields .wpo-wcpdf-edit-document-notes:hover {
	opacity:1;
	cursor:pointer;
}

.wcpdf-data-fields .wpo-wcpdf-document-buttons {
	display: none;
	padding: 10px;
	border-top: 1px solid #dfdfdf;
}

.wcpdf-data-fields h4 .wcpdf-regenerate-spin {
	opacity: 1;
	-webkit-animation: spin 1.6s linear infinite; /* Safari */
	animation: spin 1.6s linear infinite;
	pointer-events: none;
}

.wcpdf-data-fields table {
	width: 40%;
	margin-bottom: 8px;
}

.wcpdf-data-fields table th,
.wcpdf-data-fields table td {
	padding-right: 10px;
}

.wcpdf-data-fields table > thead th {
	font-weight: normal;
	text-align: left;
}

.wcpdf-data-fields table > tbody input,
.wcpdf-data-fields table > tbody textarea {
	width: 100%;
}

.wcpdf-data-fields table > tfoot td {
	font-size: 8pt;
	color: #999;
	padding-top: 4px;
}

.edi-customer-identifiers table td + td,
.wpo-ips-edi-actions table td + td {
	text-align: end;
	text-align: right;
}

.edi-customer-identifiers .missing {
	color: #d63638;
}

.edi-customer-identifiers .optional {
	color: #996800;
}

.edi-customer-identifiers td.scheme-required {
	background-color: #fff3cd;
}

@media screen and (max-width: 782px) {

	.wp-list-table .column-pdf_invoice_number, .wp-list-table tr:not(.inline-edit-row):not(.no-items) td.column-pdf_invoice_number:not(.check-column) {
		display: none;
	}

	.wp-list-table tr:not(.inline-edit-row):not(.no-items) td.column-pdf_invoice_number {
		padding: 3px 8px 3px 35%
	}

}

@media screen and (max-width: 1200px) {

	.wcpdf-data-fields .editable > table,
	.wcpdf-data-fields .editable-notes > table {
		width: 100% !important;
		max-width: 100% !important;
	}

}

/* Safari */
@-webkit-keyframes wcpdf-regenerate-spin {
	0% { -webkit-transform: rotate(0deg); }
	100% { -webkit-transform: rotate(-360deg); }
}

@keyframes wcpdf-regenerate-spin {
	0% { transform: rotate(0deg); }
	100% { transform: rotate(-360deg); }
}
