export default {
    icons: [
    "cafecito-o",
    "cafecito",
    "dribbble-o",
    "dribbble",
    "kofi-o",
    "kofi",
    "line-o",
    "line",
    "patreon-o",
    "patreon",
    "strava-o",
    "strava",
    "reddit",
    "reddit-o",
    "discord",
    "discord-o",
    "downloads",
    "logout",
    "filter",
    "clear-filter",
    "grid-2-columns",
    "grid-4-columns",
    "grid-5-columns",
    "grid-6-columns",
    "emoji-happy",
    "emoji-neutral",
    "emoji-sad",
    "home",
    "home-o",
    "shop",
    "shop-2",
    "facebook",
    "behance",
    "youtube",
    "snapchat",
    "instagram",
    "google-plus",
    "pinterest",
    "linkedin",
    "rss",
    "tripadvisor",
    "twitter",
    "tumblr",
    "vk",
    "vimeo",
    "skype",
    "whatsapp",
    "houzz",
    "telegram",
    "etsy",
    "tik-tok",
    "twitch",
    "untapped",
    "viber",
    "facebook-o",
    "behance-o",
    "youtube-o",
    "snapchat-o",
    "instagram-o",
    "google-plus-o",
    "pinterest-o",
    "linkedin-o",
    "rss-o",
    "tripadvisor-o",
    "twitter-o",
    "tumblr-o",
    "vk-o",
    "vimeo-o",
    "skype-o",
    "whatsapp-o",
    "houzz-o",
    "telegram-o",
    "etsy-o",
    "tik-tok-o",
    "twitch-o",
    "untapped-o",
    "viber-o",
    "exclamation",
    "play-button",
    "left-arrow",
    "up-arrow",
    "right-arrow",
    "down-arrow",
    "info",
    "view",
    "view-2",
    "heart",
    "heart-o",
    "heart-2",
    "heart-2-o",
    "delete",
    "zoom",
    "search",
    "shopping-cart",
    "shopping-cart-2",
    "shopping-bag-2-o",
    "shopping-bag-2",
    "shopping-bag-3",
    "shopping-cart-2-plus",
    "shopping-cart-plus",
    "star",
    "360-degrees",
    "plus",
    "transfer",
    "minus",
    "compare",
    "shopping-basket",
    "loader-gif",
    "tick",
    "coupon",
    "share-arrow",
    "diagonal-arrow",
    "checked",
    "circle",
    "cart-unavailable",
    "grid-list",
    "list-grid",
    "share",
    "controls",
    "burger",
    "calendar",
    "chat",
    "internet",
    "message",
    "shopping-bag-o",
    "shopping-bag",
    "delivery",
    "square",
    "square-filled",
    "sent",
    "more",
    "more-2",
    "upload",
    "phone-call",
    "gift",
    "left-arrow-2",
    "right-arrow-2",
    "left-arrow-3",
    "right-arrow-3",
    "time",
    "size",
    "wallet",
    "protect",
    "money-bag",
    "guarantee",
    "clock",
    "conversation",
    "debit-card",
    "dev-menu",
    "top-right-arrow",
    "file",
    "location",
    "location-2",
    "rocket",
    "trash",
    "play-button-2",
    "gallery",
    "user",
    "user-2",
    "user-3",
    "star-o",
    "star-2",
    "star-2-o",
    "bell",
    "bell-filled",
    "dot-inside",
    "dot",
    "phone",
    "tablet",
    "laptop",
    "support",
    "blog",
    "box",
    "chat-2",
    "chat-3",
    "compare-2-o",
    "compare-2",
    "compare-3",
    "coupon-2",
    "sale",
    "desktop",
    "info-2",
    "fire",
    "flash"
]
}