(globalThis.webpackChunkwebpackWcBlocksMainJsonp=globalThis.webpackChunkwebpackWcBlocksMainJsonp||[]).push([[2105],{8708:(t,e,o)=>{"use strict";o.d(e,{A:()=>d});var s=o(4921),r=o(415),c=o(1616),n=o(572),a=o(2269),l=o(5076),i=(o(7578),o(790));const u=({children:t,headingLevel:e,elementType:o=`h${e}`,...s})=>(0,i.jsx)(o,{...s,children:t}),d=(0,c.withProductDataContext)(t=>{const{className:e,headingLevel:o=2,showProductLink:c=!0,linkTarget:d,align:m}=t,p=(0,l.p)(t),{parentClassName:y}=(0,r.useInnerBlockLayoutContext)(),{product:h}=(0,r.useProductDataContext)(),{dispatchStoreEvent:g}=(0,a.y)();return h.id?(0,i.jsx)(u,{headingLevel:o,className:(0,s.A)(e,p.className,"wc-block-components-product-title",{[`${y}__product-title`]:y,[`wc-block-components-product-title--align-${m}`]:m}),style:p.style,children:(0,i.jsx)(n.A,{disabled:!c,name:h.name,permalink:h.permalink,target:d,onClick:()=>{g("product-view-link",{product:h})}})}):(0,i.jsx)(u,{headingLevel:o,className:(0,s.A)(e,p.className,"wc-block-components-product-title",{[`${y}__product-title`]:y,[`wc-block-components-product-title--align-${m}`]:m}),style:p.style})})},3777:(t,e,o)=>{"use strict";o.r(e),o.d(e,{default:()=>n});var s=o(1616),r=o(8708),c=o(3925);const n=(0,s.withFilteredAttributes)(c.attributes)(r.A)},572:(t,e,o)=>{"use strict";o.d(e,{A:()=>c});var s=o(4921),r=(o(959),o(790));const c=({className:t="",disabled:e=!1,name:o,permalink:c="",target:n,rel:a,style:l,onClick:i,disabledTagName:u="span",...d})=>{const m=(0,s.A)("wc-block-components-product-name",t),p=u;if(e){const t=d;return(0,r.jsx)(p,{className:m,...t,dangerouslySetInnerHTML:{__html:o}})}return(0,r.jsx)("a",{className:m,href:c,target:n,...d,dangerouslySetInnerHTML:{__html:o},style:l})}},2269:(t,e,o)=>{"use strict";o.d(e,{y:()=>n});var s=o(2619),r=o(7143),c=o(6087);const n=()=>({dispatchStoreEvent:(0,c.useCallback)((t,e={})=>{try{(0,s.doAction)(`experimental__woocommerce_blocks-${t}`,e)}catch(t){console.error(t)}},[]),dispatchCheckoutEvent:(0,c.useCallback)((t,e={})=>{try{(0,s.doAction)(`experimental__woocommerce_blocks-checkout-${t}`,{...e,storeCart:(0,r.select)("wc/store/cart").getCartData()})}catch(t){console.error(t)}},[])})},5076:(t,e,o)=>{"use strict";o.d(e,{p:()=>a});var s=o(4921),r=o(3993),c=o(8270),n=o(5154);const a=t=>{const e=(t=>{const e=(0,r.isObject)(t)?t:{style:{}};let o=e.style;return(0,r.isString)(o)&&(o=JSON.parse(o)||{}),(0,r.isObject)(o)||(o={}),{...e,style:o}})(t),o=(0,n.BK)(e),a=(0,n.aR)(e),l=(0,n.fo)(e),i=(0,c.x)(e);return{className:(0,s.A)(i.className,o.className,a.className,l.className),style:{...i.style,...o.style,...a.style,...l.style}}}},8270:(t,e,o)=>{"use strict";o.d(e,{x:()=>r});var s=o(3993);const r=t=>{const e=(0,s.isObject)(t.style.typography)?t.style.typography:{},o=(0,s.isString)(e.fontFamily)?e.fontFamily:"";return{className:t.fontFamily?`has-${t.fontFamily}-font-family`:o,style:{fontSize:t.fontSize?`var(--wp--preset--font-size--${t.fontSize})`:e.fontSize,fontStyle:e.fontStyle,fontWeight:e.fontWeight,letterSpacing:e.letterSpacing,lineHeight:e.lineHeight,textDecoration:e.textDecoration,textTransform:e.textTransform}}}},5154:(t,e,o)=>{"use strict";o.d(e,{BK:()=>i,aR:()=>u,fo:()=>d});var s=o(4921),r=o(7356),c=o(9786),n=o(3993);function a(t={}){const e={};return(0,c.getCSSRules)(t,{selector:""}).forEach(t=>{e[t.key]=t.value}),e}function l(t,e){return t&&e?`has-${(0,r.c)(e)}-${t}`:""}function i(t){const{backgroundColor:e,textColor:o,gradient:r,style:c}=t,i=l("background-color",e),u=l("color",o),d=function(t){if(t)return`has-${t}-gradient-background`}(r),m=d||c?.color?.gradient;return{className:(0,s.A)(u,d,{[i]:!m&&!!i,"has-text-color":o||c?.color?.text,"has-background":e||c?.color?.background||r||c?.color?.gradient,"has-link-color":(0,n.isObject)(c?.elements?.link)?c?.elements?.link?.color:void 0}),style:a({color:c?.color||{}})}}function u(t){const e=t.style?.border||{};return{className:function(t){const{borderColor:e,style:o}=t,r=e?l("border-color",e):"";return(0,s.A)({"has-border-color":!!e||!!o?.border?.color,[r]:!!r})}(t),style:a({border:e})}}function d(t){return{className:void 0,style:a({spacing:t.style?.spacing||{}})}}},7578:()=>{},959:()=>{}}]);