@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-components-quantity-selector{border:1px solid color-mix(in srgb,currentColor 30%,transparent);border-radius:4px;box-sizing:border-box;display:flex;position:relative;width:107px}.wc-block-components-quantity-selector input.wc-block-components-quantity-selector__input{appearance:textfield;background:transparent;border:0;box-shadow:none;color:currentColor;flex:1 1 auto;font-size:var(--wp--preset--font-size--small,14px);line-height:1.4;line-height:1;margin:0;min-width:40px;order:2;text-align:center;vertical-align:middle}.wc-block-components-quantity-selector input.wc-block-components-quantity-selector__input:focus{box-shadow:inset 0 0 1px 1px currentColor;outline:none}.wc-block-components-quantity-selector input.wc-block-components-quantity-selector__input:disabled{opacity:.6}.wc-block-components-quantity-selector input::-webkit-inner-spin-button,.wc-block-components-quantity-selector input::-webkit-outer-spin-button{-webkit-appearance:none;margin:0}.wc-block-components-quantity-selector .wc-block-components-quantity-selector__button{background:none transparent;border:0;box-shadow:none;color:currentColor;cursor:pointer;font-size:.9em;font-style:normal;font-weight:400;margin:0;min-width:30px;opacity:.6;padding:0;text-align:center;text-decoration:none}.wc-block-components-quantity-selector .wc-block-components-quantity-selector__button:focus{box-shadow:inset 0 0 1px 1px currentColor;outline:none}.wc-block-components-quantity-selector .wc-block-components-quantity-selector__button:focus,.wc-block-components-quantity-selector .wc-block-components-quantity-selector__button:hover{opacity:1}.wc-block-components-quantity-selector .wc-block-components-quantity-selector__button:disabled{box-shadow:none;cursor:default;opacity:.6}.wc-block-components-quantity-selector>.wc-block-components-quantity-selector__button--minus{border-radius:4px 0 0 4px;order:1}.wc-block-components-quantity-selector>.wc-block-components-quantity-selector__button--plus{border-radius:0 4px 4px 0;order:3}.wc-block-components-quantity-selector[hidden]{display:none}:where(.wc-block-components-quantity-selector .wc-block-components-quantity-selector__input){padding:.4em 0}.theme-twentyseventeen .wc-block-components-quantity-selector .wc-block-components-quantity-selector__button:focus,.theme-twentyseventeen .wc-block-components-quantity-selector .wc-block-components-quantity-selector__button:hover{background:none transparent}:where(.wp-block-group.is-layout-flex:not(.is-vertical)>.wc-block-add-to-cart-with-options-grouped-product-item-selector){min-width:6.8em;text-align:right}:where(.wc-block-add-to-cart-with-options-grouped-product-item-selector .button){display:inline-flex}
