:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}[data-gateway_id=pre_install_woocommerce_payments_promotion]>.status a{visibility:hidden !important}[data-gateway_id=pre_install_woocommerce_payments_promotion]>.action .is-secondary,[data-gateway_id=pre_install_woocommerce_payments_promotion]>.action.is-secondary:hover{box-shadow:none}[data-gateway_id=pre_install_woocommerce_payments_promotion]>.action a{position:relative;display:none}.wc_gateways .name .wc-payment-gateway-method-name{display:inline-flex}.wc_gateways .name .wc-payment-gateway-method-name img{height:24px;width:auto;margin-right:4px}.wc_gateways .wc-payment-gateway-method__name{display:flex}.wc_gateways .wc-payment-gateway-method__name .pre-install-payment-gateway__subtitle{margin-right:16px}.wc_gateways .wc-payment-gateway-method__name .pre-install-payment-gateway__subtitle>img{height:24px;width:auto;margin-right:4px}.wc_gateways .pre-install-payment-gateway__actions{display:flex}.wc_gateways .pre-install-payment-gateway__actions-menu{margin-left:24px}.wc_gateways .pre-install-payment-gateway__actions-menu-options{text-align:center}
