(()=>{"use strict";var e,t,r,o={1614:(e,t,r)=>{var o=r(7723),n=r(2730);const i=window.wp.blocks,a=JSON.parse('{"$schema":"https://schemas.wp.org/trunk/block.json","apiVersion":3,"name":"woocommerce/product-reviews-pagination-next","title":"Reviews Next Page","category":"woocommerce","ancestor":["woocommerce/product-reviews-pagination"],"description":"Displays the next product review\'s page link.","textdomain":"woocommerce","attributes":{"label":{"type":"string","role":"content"}},"usesContext":["postId","reviews/paginationArrow"],"supports":{"reusable":false,"html":false,"color":{"gradients":true,"text":false,"__experimentalDefaultControls":{"background":true}},"typography":{"fontSize":true,"lineHeight":true,"__experimentalFontFamily":true,"__experimentalFontWeight":true,"__experimentalFontStyle":true,"__experimentalTextTransform":true,"__experimentalTextDecoration":true,"__experimentalLetterSpacing":true,"__experimentalDefaultControls":{"fontSize":true}},"interactivity":{"clientNavigation":true}}}'),s=window.wp.blockEditor;var l=r(790);const c={none:"",arrow:"→",chevron:"»"};(0,i.registerBlockType)(a,{icon:n.A,edit:function({attributes:{label:e},setAttributes:t,context:{"reviews/paginationArrow":r}}){const n=c[r];return(0,l.jsxs)("a",{href:"#reviews-pagination-next-pseudo-link",onClick:e=>e.preventDefault(),...(0,s.useBlockProps)(),children:[(0,l.jsx)(s.PlainText,{__experimentalVersion:2,tagName:"span","aria-label":(0,o.__)("Newer reviews page link","woocommerce"),placeholder:(0,o.__)("Newer Reviews","woocommerce"),value:e,onChange:e=>t({label:e})}),n&&(0,l.jsx)("span",{className:`wp-block-woocommerce-product-reviews-pagination-next-arrow is-arrow-${r}`,children:n})]})},example:{attributes:{label:(0,o.__)("Newer Reviews","woocommerce")}}})},790:e=>{e.exports=window.ReactJSXRuntime},7723:e=>{e.exports=window.wp.i18n},5573:e=>{e.exports=window.wp.primitives}},n={};function i(e){var t=n[e];if(void 0!==t)return t.exports;var r=n[e]={exports:{}};return o[e](r,r.exports,i),r.exports}i.m=o,e=[],i.O=(t,r,o,n)=>{if(!r){var a=1/0;for(p=0;p<e.length;p++){for(var[r,o,n]=e[p],s=!0,l=0;l<r.length;l++)(!1&n||a>=n)&&Object.keys(i.O).every(e=>i.O[e](r[l]))?r.splice(l--,1):(s=!1,n<a&&(a=n));if(s){e.splice(p--,1);var c=o();void 0!==c&&(t=c)}}return t}n=n||0;for(var p=e.length;p>0&&e[p-1][2]>n;p--)e[p]=e[p-1];e[p]=[r,o,n]},i.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return i.d(t,{a:t}),t},r=Object.getPrototypeOf?e=>Object.getPrototypeOf(e):e=>e.__proto__,i.t=function(e,o){if(1&o&&(e=this(e)),8&o)return e;if("object"==typeof e&&e){if(4&o&&e.__esModule)return e;if(16&o&&"function"==typeof e.then)return e}var n=Object.create(null);i.r(n);var a={};t=t||[null,r({}),r([]),r(r)];for(var s=2&o&&e;"object"==typeof s&&!~t.indexOf(s);s=r(s))Object.getOwnPropertyNames(s).forEach(t=>a[t]=()=>e[t]);return a.default=()=>e,i.d(n,a),n},i.d=(e,t)=>{for(var r in t)i.o(t,r)&&!i.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},i.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),i.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),i.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},i.j=1789,(()=>{var e={1789:0};i.O.j=t=>0===e[t];var t=(t,r)=>{var o,n,[a,s,l]=r,c=0;if(a.some(t=>0!==e[t])){for(o in s)i.o(s,o)&&(i.m[o]=s[o]);if(l)var p=l(i)}for(t&&t(r);c<a.length;c++)n=a[c],i.o(e,n)&&e[n]&&e[n][0](),e[n]=0;return i.O(p)},r=globalThis.webpackChunkwebpackWcBlocksMainJsonp=globalThis.webpackChunkwebpackWcBlocksMainJsonp||[];r.forEach(t.bind(null,0)),r.push=t.bind(null,r.push.bind(r))})();var a=i.O(void 0,[94],()=>i(1614));a=i.O(a),((this.wc=this.wc||{}).blocks=this.wc.blocks||{})["product-reviews-pagination-next"]=a})();