@keyframes wc-skeleton-shimmer{to{transform:translateX(100%)}}.wc-block-product-filter-checkbox-list fieldset{display:contents}.wc-block-product-filter-checkbox-list__label{align-items:center;display:inline-flex;gap:.625em}.wc-block-product-filter-checkbox-list__item .wc-block-product-filter-checkbox-list__label{margin-bottom:0}:where(.wc-block-product-filter-checkbox-list__input-wrapper){display:block;position:relative}.wc-block-product-filter-checkbox-list__input-wrapper:before{background:currentColor;border-radius:2px;content:"";height:1em;left:0;opacity:.1;pointer-events:none;position:absolute;top:0;width:1em}.has-option-element-color .wc-block-product-filter-checkbox-list__input-wrapper:before{display:none}input[type=checkbox].wc-block-product-filter-checkbox-list__input{appearance:none;background:var(--wc-product-filter-checkbox-list-option-element,transparent);border:1px solid var(--wc-product-filter-checkbox-list-option-element-border,transparent);border-radius:2px;color:inherit;cursor:pointer;display:block;font-size:inherit;height:1em;margin:0;width:1em}input[type=checkbox].wc-block-product-filter-checkbox-list__input:focus{outline-color:var(--wc-product-filter-checkbox-list-option-element-border,currentColor);outline-width:1px}svg.wc-block-product-filter-checkbox-list__mark{box-sizing:border-box;color:var(--wc-product-filter-checkbox-list-option-element-selected,currentColor);display:none;height:1em;left:0;padding:.2em;position:absolute;top:0;width:1em}input[type=checkbox].wc-block-product-filter-checkbox-list__input:checked:after,input[type=checkbox].wc-block-product-filter-checkbox-list__input:checked:before{content:none}input[type=checkbox].wc-block-product-filter-checkbox-list__input:checked+.wc-block-product-filter-checkbox-list__mark{display:block;pointer-events:none}:where(.wc-block-product-filter-checkbox-list__text-wrapper){align-items:center;display:inline-flex;font-size:.875em;gap:4px}.wc-block-product-filter-checkbox-list__text{color:var(--wc-product-filter-checkbox-list-label-element,currentColor);display:contents}.wc-block-product-filter-checkbox-list__count{display:contents;white-space:nowrap}.wc-block-product-filter-checkbox-list__show-more{appearance:none;background:transparent;border:none;font-family:inherit;padding:0;text-decoration:underline}
