<?php declare(strict_types=1);

namespace Automattic\WooCommerce\Vendor\GraphQL\Server\Exception;

use Automattic\WooCommerce\Vendor\GraphQL\Server\RequestError;

class PersistedQueriesAreNotSupported extends RequestError {}
