@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-components-product-price--align-left{display:block;text-align:right}.wc-block-components-product-price--align-center{display:block;text-align:center}.wc-block-components-product-price--align-right{display:block;text-align:left}.wc-block-components-product-price{display:block}.wc-block-components-product-price[hidden]{display:none}.wc-block-components-product-price>:empty{display:none}.wc-block-components-product-price .wc-block-all-products .wc-block-components-product-price{margin-bottom:12px}.wc-block-components-product-price ins{text-decoration:none}.wc-block-components-product-price .woocommerce-Price-amount{white-space:nowrap}.wc-block-components-product-price__value.is-discounted{margin-right:.5em}.is-loading .wc-block-components-product-price:before{background-color:currentColor!important;border:0!important;border-radius:.25rem;box-shadow:none;color:currentColor!important;content:".";display:block;display:inline-block;line-height:1;max-width:100%!important;opacity:.15;outline:0!important;overflow:hidden!important;pointer-events:none;position:relative!important;width:100%;width:5em;z-index:1}.is-loading .wc-block-components-product-price:before>*{visibility:hidden}.is-loading .wc-block-components-product-price:before:after{animation:loading__animation 1.5s ease-in-out infinite;background-image:linear-gradient(-90deg,currentColor,hsla(0,0%,96%,.302),currentColor);background-repeat:no-repeat;content:" ";display:block;height:100%;right:0;position:absolute;left:0;top:0;transform:translateX(100%)}@keyframes loading__animation{to{transform:translateX(-100%)}}@media screen and (prefers-reduced-motion:reduce){.is-loading .wc-block-components-product-price:before{animation:none}}
