import * as actions from './actions';
import * as selectors from './selectors';
/**
 * The abilities store definition.
 */
export declare const store: import("@wordpress/data/build-types/types").StoreDescriptor<import("@wordpress/data/build-types/types").ReduxStoreConfig<unknown, typeof actions, typeof selectors>>;
//# sourceMappingURL=index.d.ts.map