(globalThis.webpackChunkwebpackWcBlocksCartCheckoutFrontendJsonp=globalThis.webpackChunkwebpackWcBlocksCartCheckoutFrontendJsonp||[]).push([[88],{3965:(c,s,a)=>{"use strict";a.r(s),a.d(s,{default:()=>l});var t=a(3491),e=a(7646),n=a(4921),o=a(790);const l=({className:c})=>{const{cartItems:s,cartIsLoading:a}=(0,t.V)();return(0,o.jsx)("div",{className:(0,n.A)(c,"wc-block-mini-cart__products-table"),children:(0,o.jsx)(e.A,{lineItems:s,isLoading:a,className:"wc-block-mini-cart-items"})})}},7826:()=>{}}]);