<?php declare(strict_types=1);

namespace Automattic\WooCommerce\Vendor\GraphQL\Language\AST;

/**
 * export type SelectionNode = FieldNode | FragmentSpreadNode | InlineFragmentNode.
 */
interface SelectionNode {}
