:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.wp-block-woocommerce-product-summary-field-wrapper .wp-block-woocommerce-product-summary-field{margin-top:0;margin-bottom:0}.components-summary-control{width:100%;min-height:108px;background-color:#fff;box-sizing:border-box;border:1px solid #757575;border-radius:2px;padding:8px;margin:0;-webkit-appearance:textarea;-moz-appearance:textarea;appearance:textarea;resize:vertical;overflow:hidden}.components-summary-control.rich-text [data-rich-text-placeholder]:after{color:#757575;opacity:1}.components-summary-control:focus{box-shadow:inset 0 0 0 1px var(--wp-admin-theme-color-darker-10, --wp-admin-theme-color);border-color:var(--wp-admin-theme-color-darker-10, --wp-admin-theme-color)}.has-text-align-justify{text-align:justify}
