.woocommerce-wishlist .page-heading,
.woocommerce-waitlist .page-heading,
.woocommerce-compare .page-heading,
.woocommerce-account .page-heading {
  padding: 2.3vw 0;
  margin-bottom: 2.3vw;
  line-height: 1.4;
  background-color: #fafafa;
}
@media only screen and (max-width: 768px) {
  .woocommerce-wishlist .page-heading,
  .woocommerce-waitlist .page-heading,
  .woocommerce-compare .page-heading,
  .woocommerce-account .page-heading {
    margin-bottom: 50px;
  }
}
@media only screen and (max-width: 480px) {
  .woocommerce-wishlist .page-heading,
  .woocommerce-waitlist .page-heading,
  .woocommerce-compare .page-heading,
  .woocommerce-account .page-heading {
    padding: 15px 0;
  }
}
.woocommerce-wishlist .page-heading .breadcrumbs,
.woocommerce-waitlist .page-heading .breadcrumbs,
.woocommerce-compare .page-heading .breadcrumbs,
.woocommerce-account .page-heading .breadcrumbs,
.woocommerce-wishlist .page-heading .back-history,
.woocommerce-waitlist .page-heading .back-history,
.woocommerce-compare .page-heading .back-history,
.woocommerce-account .page-heading .back-history {
  display: none;
}
.woocommerce-wishlist .page-heading .title,
.woocommerce-waitlist .page-heading .title,
.woocommerce-compare .page-heading .title,
.woocommerce-account .page-heading .title {
  display: block;
  font-size: 1.7rem;
  text-transform: uppercase;
  text-align: center;
}
.woocommerce-wishlist .page-heading .title:before,
.woocommerce-waitlist .page-heading .title:before,
.woocommerce-compare .page-heading .title:before,
.woocommerce-account .page-heading .title:before {
  font-family: 'xstore-icons';
  font-size: 0.75em;
  -webkit-margin-end: 7px;
          margin-inline-end: 7px;
  content: '\e1000';
}
.woocommerce-wishlist.et-header-overlap .page-heading,
.woocommerce-waitlist.et-header-overlap .page-heading,
.woocommerce-compare.et-header-overlap .page-heading,
.woocommerce-account.et-header-overlap .page-heading {
  padding: 7em 0 3em;
}
.woocommerce-wishlist .page-heading .title:before {
  content: '\e908';
}
.woocommerce-waitlist .page-heading .title:before {
  content: '\e959';
}
.single-tags,
.product_meta {
  width: 100%;
}
.single-tags span,
.product_meta span span,
.single-tags a,
.product_meta span a {
  color: var(--et_main-color);
}
.single-tags a:hover,
.product_meta span a:hover {
  color: var(--et_dark-2-white);
}
.product_meta {
  clear: both;
}
.product_meta > span,
.product_meta > div {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}
.product_meta > span *:first-child,
.product_meta .products-page-cats a:first-child {
  -webkit-padding-start: 3px;
          padding-inline-start: 3px;
}
.product_meta > .sales-booster-estimated-delivery > span:first-child {
  -webkit-padding-start: 0;
          padding-inline-start: 0;
}
.product_meta > .sales-booster-estimated-delivery > span + span {
  -webkit-padding-start: 3px;
          padding-inline-start: 3px;
}
.product_meta .product_brand,
.product_meta .product_seller {
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
}
.product_meta,
.product_meta > span,
.product_meta .products-page-cats,
.product_meta .wcml_currency_switcher,
.product_meta .wcml-dropdown.product,
.wcpv-sold-by-single {
  margin-bottom: 10px;
}
.product_meta .wcml_currency_switcher,
.product_meta .wcml-dropdown.product {
  margin-top: 0;
}
.single-tags,
.product_meta,
.product-share,
.product_meta > .sales-booster-estimated-delivery > span:first-child,
.wcpv-sold-by-single {
  color: var(--et_dark-2-white);
  font-size: 1.14rem;
}
.et-socials span,
.single-tags span {
  color: var(--et_dark-2-white);
}
.single-tags {
  margin: 0 0 25px;
}
/* waitlist page */
.xstore-waitlist-items tr + tr {
  border-top: 1px solid var(--et_border-color);
}
.xstore-waitlist-items td {
  vertical-align: middle;
}
.xstore-waitlist-items .product-title {
  display: block;
  font-size: 1.14em;
}
.xstore-waitlist-items .product_meta {
  font-size: 1rem;
  margin-top: 0.7rem;
  margin-bottom: 0;
}
.xstore-waitlist-items .mobile-price {
  margin-top: 0.7rem;
}
.xstore-waitlist-items .quantity {
  float: none;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
  margin: 0;
}
.xstore-waitlist-product {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  max-width: 300px;
  padding-left: 0;
  padding-right: 0;
}
.xstore-waitlist-image {
  display: inline-block;
  float: left;
  padding: 0;
}
.xstore-waitlist-image img {
  max-width: 6rem;
  max-height: 100px;
  float: left;
  -webkit-margin-end: 15px;
          margin-inline-end: 15px;
}
@media only screen and (max-width: 992px) {
  .xstore-waitlist-image img {
    max-width: 3.5rem;
  }
}
.xstore-waitlist-details {
  overflow: hidden;
}
.xstore-waitlist-action .button {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  background-color: var(--et_btn-dark-bg-color);
  border: 1px solid var(--et_btn-dark-br-color);
  color: var(--et_btn-dark-color);
  --loader-side-color: var(--et_btn-dark-color);
  height: auto;
  -webkit-margin-start: 7px;
          margin-inline-start: 7px;
}
.xstore-waitlist-action .button:hover {
  background-color: var(--et_btn-dark-bg-color-hover);
  border-color: var(--et_btn-dark-br-color-hover);
  color: var(--et_btn-dark-color-hover);
  --loader-side-color: var(--et_btn-dark-color-hover);
}
.xstore-waitlist-action .button:focus {
  color: var(--et_btn-dark-color);
}
.xstore-waitlist-action .button svg {
  fill: currentColor;
}
@media only screen and (min-width: 993px) {
  .xstore-waitlist-action .button > svg {
    display: none;
  }
}
@media only screen and (max-width: 992px) {
  .xstore-waitlist-action .button {
    font-size: 1.14rem;
    padding-left: 0.75rem;
    padding-right: 0.75rem;
  }
  .xstore-waitlist-action .button .button-text {
    display: none;
  }
}
.xstore-waitlist-action .xstore-waitlist[data-action=remove]:not(.processing) .et-icon {
  color: currentColor;
}
.xstore-waitlist-action .show-quickly,
.xstore-waitlist-action .xstore-waitlist,
.xstore-waitlist-action .xstore-waitlist-remove {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  font-size: 1.14rem;
  padding-left: 0.75rem;
  padding-right: 0.75rem;
  height: auto;
  z-index: auto;
  cursor: pointer;
}
@media only screen and (max-width: 992px) {
  .xstore-waitlist-action .show-quickly {
    display: none;
  }
}
.xstore-waitlist-action .actions-wrapper {
  position: relative;
  display: inline-block;
}
.xstore-waitlist-action .actions-buttons {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
}
.xstore-waitlist-action .date-added {
  position: absolute;
  top: 100%;
  width: 100%;
  left: 0;
  right: 0;
  text-align: end;
  color: var(--et_main-color);
  font-size: 0.85rem;
  margin-top: 7px;
}
.xstore-waitlist-apply-actions select {
  min-width: 170px;
  -webkit-margin-end: 10px;
          margin-inline-end: 10px;
}
.xstore-waitlist-table tr:first-child td {
  padding-top: 1.5em;
}
.xstore-waitlist-table td,
.xstore-waitlist-table th {
  padding-top: 1.5em;
  padding-bottom: 1.5em;
}
.xstore-waitlist-table .xstore-waitlist-checkbox {
  padding-right: 0;
  padding-left: 0;
}
.xstore-waitlist-table .xstore-waitlist-checkbox {
  width: 25px;
}
.xstore-waitlist-table .xstore-waitlist-stock_status p {
  line-height: var(--p-line-height, 1.6);
  font-size: var(--p-font-size, 1.14rem);
}
.xstore-waitlist-table .xstore-waitlist-stock_status p:last-child {
  margin-bottom: 0;
}
.xstore-waitlist-share {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap;
  margin-bottom: 10px;
}
.xstore-waitlist-share .share-title {
  color: var(--et_dark-2-white);
  font-size: calc(var(--h4-size-proportion) * 1rem);
  -webkit-margin-end: 15px;
          margin-inline-end: 15px;
}
@media only screen and (min-width: 993px) {
  .xstore-waitlist-share {
    border: 1px solid var(--et_border-color);
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    padding: 25px 0;
    margin-bottom: 3.5em;
  }
}
@media only screen and (max-width: 992px) {
  .xstore-waitlist-share .share-title,
  .xstore-waitlist-share .menu-social-icons {
    margin-bottom: 10px;
  }
}
.xstore-waitlist-actions,
.compare-more-products {
  height: auto;
  padding-top: 0.89rem;
  padding-bottom: 0.89rem;
}
.form-actions {
  border-top: 1px solid var(--et_border-color);
  padding-top: 15px;
  padding-bottom: 15px;
  margin-bottom: -10px;
}
@media only screen and (min-width: 993px) {
  .form-actions {
    padding-top: 1.5em;
    padding-bottom: 3em;
  }
}
.form-actions > div > div {
  margin-bottom: 10px;
}
.form-actions .add-all-products {
  -webkit-margin-start: 10px;
          margin-inline-start: 10px;
}
.form-actions .et-call-popup:empty {
  display: none;
}
@media only screen and (max-width: 480px) {
  .form-actions .et-call-popup {
    text-align: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    width: 100%;
  }
}
.form-actions .btn {
  height: auto;
  padding-top: 0.89rem;
  padding-bottom: 0.89rem;
}
.empty-waitlist-block {
  text-align: center;
  color: var(--et_dark-2-white);
  padding: 5em 0;
}
.empty-waitlist-block:before {
  content: "\e908";
  font-family: 'xstore-icons';
  display: block;
  border: none !important;
  font-size: 2.6rem;
  line-height: 1.5;
}
.empty-waitlist-block h1,
.empty-waitlist-block h2 {
  font-size: 1.7rem;
  text-transform: uppercase;
}
.empty-waitlist-block .btn {
  background-color: var(--et_btn-dark-bg-color);
  border: 1px solid var(--et_btn-dark-br-color);
  color: var(--et_btn-dark-color);
  -webkit-text-fill-color: currentColor;
  height: auto;
}
.empty-waitlist-block .btn:hover {
  background-color: var(--et_btn-dark-bg-color-hover);
  border-color: var(--et_btn-dark-br-color-hover);
  color: var(--et_btn-dark-color-hover);
}
.empty-waitlist-block p {
  color: var(--et_font-color);
}
@media only screen and (max-width: 992px) {
  .form-actions > div > div {
    -webkit-box-flex: 1;
        -ms-flex: 1;
            flex: 1;
    -ms-flex-preferred-size: 100%;
        flex-basis: 100%;
    width: 100%;
  }
  .xstore-waitlist-apply-actions select {
    -webkit-box-flex: 1;
        -ms-flex: 1;
            flex: 1;
    min-width: unset;
  }
}
