@keyframes wc-skeleton-shimmer{to{transform:translateX(-100%)}}.wc-block-product-categories{margin-bottom:1em}.wc-block-product-categories.is-dropdown{display:flex}.wc-block-product-categories select{margin-left:.5em}.wc-block-product-categories-list--has-images{list-style:none outside}.wc-block-product-categories-list--has-images .wc-block-product-categories-list-item{clear:both;list-style:none outside;margin:4px 60px 4px 0}.wc-block-product-categories-list--has-images .wc-block-product-categories-list-item ul{margin:4px 0 0}.wc-block-product-categories-list--has-images .wc-block-product-categories-list-item__image{border:1px solid #eee;display:inline-block;margin:0 -60px 0 .5em;max-width:50px;padding:0;position:relative;vertical-align:middle}.wc-block-product-categories-list--has-images .wc-block-product-categories-list-item__image img{display:block;height:auto;margin:0;max-width:100%;padding:0}.wc-block-product-categories-list-item-count:before{content:" ("}.wc-block-product-categories-list-item-count:after{content:")"}.wp-block-woocommerce-product-categories.is-loading .wc-block-product-categories__placeholder{background:currentColor;display:inline-block;height:1em;min-width:200px;opacity:.2;width:50%}.wc-block-product-categories__button{align-items:center;display:flex;margin:0;overflow:hidden;padding:0 .5em;position:relative}.wc-block-product-categories__button svg{fill:currentColor;outline:none}.rtl .wc-block-product-categories__button svg{transform:rotate(-180deg)}.wc-block-product-categories__button:active{color:currentColor}.wc-block-product-categories__button:disabled,.wc-block-product-categories__button[aria-disabled=true]{cursor:default;opacity:.3}.wc-block-product-categories__button:disabled:focus,.wc-block-product-categories__button[aria-disabled=true]:focus{box-shadow:none}
